{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "---\n",
    "title: \"✅ Week 08 - Student Solutions\"\n",
    "subtitle: \"Clustering using k-means and dbscan\"\n",
    "author: \"MY NAME (MY CANDIDATE NUMBER)\"\n",
    "---\n",
    "\n",
    "Let's start by loading the required libraries!"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "            <div id=\"NZGEhU\"></div>\n",
       "            <script type=\"text/javascript\" data-lets-plot-script=\"library\">\n",
       "                if(!window.letsPlotCallQueue) {\n",
       "                    window.letsPlotCallQueue = [];\n",
       "                }; \n",
       "                window.letsPlotCall = function(f) {\n",
       "                    window.letsPlotCallQueue.push(f);\n",
       "                };\n",
       "                (function() {\n",
       "                    var script = document.createElement(\"script\");\n",
       "                    script.type = \"text/javascript\";\n",
       "                    script.src = \"https://cdn.jsdelivr.net/gh/JetBrains/lets-plot@v4.5.2/js-package/distr/lets-plot.min.js\";\n",
       "                    script.onload = function() {\n",
       "                        window.letsPlotCall = function(f) {f();};\n",
       "                        window.letsPlotCallQueue.forEach(function(f) {f();});\n",
       "                        window.letsPlotCallQueue = [];\n",
       "                        \n",
       "                    };\n",
       "                    script.onerror = function(event) {\n",
       "                        window.letsPlotCall = function(f) {};    // noop\n",
       "                        window.letsPlotCallQueue = [];\n",
       "                        var div = document.createElement(\"div\");\n",
       "                        div.style.color = 'darkred';\n",
       "                        div.textContent = 'Error loading Lets-Plot JS';\n",
       "                        document.getElementById(\"NZGEhU\").appendChild(div);\n",
       "                    };\n",
       "                    var e = document.getElementById(\"NZGEhU\");\n",
       "                    e.appendChild(script);\n",
       "                })()\n",
       "            </script>\n",
       "            "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import numpy as np\n",
    "import pandas as pd\n",
    "from sklearn.cluster import KMeans, DBSCAN\n",
    "from sklearn.preprocessing import StandardScaler\n",
    "from sklearn.pipeline import Pipeline\n",
    "from umap import UMAP\n",
    "from lets_plot import *\n",
    "LetsPlot.setup_html()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Employing k-means on a two-dimensional customer segmentation data set (30 minutes)\n",
    "\n",
    "We will create a data frame object named `customers` that has two features\n",
    "\n",
    "  -   `income` shows income of customers in thousands of USD\n",
    "  -   `spending_score` provides a 0-100 index that compares spending amongst customers"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Open the data set, and select only the variables needed for the analysis\n",
    "customers = pd.read_csv(\"../data/customers-data.csv\").filter(items=[\"income\",\"spending_score\"])"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Let's plot the correlation between both variables using a scatter plot."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"uIFxX6\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "   \n",
       "   (function() {\n",
       "   // ----------\n",
       "   \n",
       "   var containerDiv = document.getElementById(\"uIFxX6\");\n",
       "   var observer = new ResizeObserver(function(entries) {\n",
       "       for (let entry of entries) {\n",
       "           var width = containerDiv.clientWidth\n",
       "           if (entry.contentBoxSize && width > 0) {\n",
       "           \n",
       "               // Render plot\n",
       "               if (observer) {\n",
       "                   observer.disconnect();\n",
       "                   observer = null;\n",
       "               }\n",
       "\n",
       "               var plotSpec={\n",
       "\"data\":{\n",
       "\"income\":[15.0,15.0,16.0,16.0,17.0,17.0,18.0,18.0,19.0,19.0,19.0,19.0,20.0,20.0,20.0,20.0,21.0,21.0,23.0,23.0,24.0,24.0,25.0,25.0,28.0,28.0,28.0,28.0,29.0,29.0,30.0,30.0,33.0,33.0,33.0,33.0,34.0,34.0,37.0,37.0,38.0,38.0,39.0,39.0,39.0,39.0,40.0,40.0,40.0,40.0,42.0,42.0,43.0,43.0,43.0,43.0,44.0,44.0,46.0,46.0,46.0,46.0,47.0,47.0,48.0,48.0,48.0,48.0,48.0,48.0,49.0,49.0,50.0,50.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,57.0,57.0,58.0,58.0,59.0,59.0,60.0,60.0,60.0,60.0,60.0,60.0,61.0,61.0,62.0,62.0,62.0,62.0,62.0,62.0,63.0,63.0,63.0,63.0,63.0,63.0,64.0,64.0,65.0,65.0,65.0,65.0,67.0,67.0,67.0,67.0,69.0,69.0,70.0,70.0,71.0,71.0,71.0,71.0,71.0,71.0,72.0,72.0,73.0,73.0,73.0,73.0,74.0,74.0,75.0,75.0,76.0,76.0,77.0,77.0,77.0,77.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,79.0,79.0,81.0,81.0,85.0,85.0,86.0,86.0,87.0,87.0,87.0,87.0,87.0,87.0,88.0,88.0,88.0,88.0,93.0,93.0,97.0,97.0,98.0,98.0,99.0,99.0,101.0,101.0,103.0,103.0,103.0,103.0,113.0,113.0,120.0,120.0,126.0,126.0,137.0,137.0],\n",
       "\"spending_score\":[39.0,81.0,6.0,77.0,40.0,76.0,6.0,94.0,3.0,72.0,14.0,99.0,15.0,77.0,13.0,79.0,35.0,66.0,29.0,98.0,35.0,73.0,5.0,73.0,14.0,82.0,32.0,61.0,31.0,87.0,4.0,73.0,4.0,92.0,14.0,81.0,17.0,73.0,26.0,75.0,35.0,92.0,36.0,61.0,28.0,65.0,55.0,47.0,42.0,42.0,52.0,60.0,54.0,60.0,45.0,41.0,50.0,46.0,51.0,46.0,56.0,55.0,52.0,59.0,51.0,59.0,50.0,48.0,59.0,47.0,55.0,42.0,49.0,56.0,47.0,54.0,53.0,48.0,52.0,42.0,51.0,55.0,41.0,44.0,57.0,46.0,58.0,55.0,60.0,46.0,55.0,41.0,49.0,40.0,42.0,52.0,47.0,50.0,42.0,49.0,41.0,48.0,59.0,55.0,56.0,42.0,50.0,46.0,43.0,48.0,52.0,54.0,42.0,46.0,48.0,50.0,43.0,59.0,43.0,57.0,56.0,40.0,58.0,91.0,29.0,77.0,35.0,95.0,11.0,75.0,9.0,75.0,34.0,71.0,5.0,88.0,7.0,73.0,10.0,72.0,5.0,93.0,40.0,87.0,12.0,97.0,36.0,74.0,22.0,90.0,17.0,88.0,20.0,76.0,16.0,89.0,1.0,78.0,1.0,73.0,35.0,83.0,5.0,93.0,26.0,75.0,20.0,95.0,27.0,63.0,13.0,75.0,10.0,92.0,13.0,86.0,15.0,69.0,14.0,90.0,32.0,86.0,15.0,88.0,39.0,97.0,24.0,68.0,17.0,85.0,23.0,69.0,8.0,91.0,16.0,79.0,28.0,74.0,18.0,83.0]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"income\",\n",
       "\"y\":\"spending_score\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"type\":\"int\",\n",
       "\"column\":\"income\"\n",
       "},{\n",
       "\"type\":\"int\",\n",
       "\"column\":\"spending_score\"\n",
       "}]\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"minimal\",\n",
       "\"panel_grid_minor\":{\n",
       "\"blank\":true\n",
       "}\n",
       "},\n",
       "\"guides\":{\n",
       "\"x\":{\n",
       "\"title\":\"Income\"\n",
       "},\n",
       "\"y\":{\n",
       "\"title\":\"Spending score\"\n",
       "}\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[],\n",
       "\"spec_id\":\"1\"\n",
       "};\n",
       "               window.letsPlotCall(function() {\n",
       "       \n",
       "               var toolbar = null;\n",
       "               var plotContainer = containerDiv;               \n",
       "               \n",
       "                   var options = {\n",
       "                       sizing: {\n",
       "                           width_mode: \"min\",\n",
       "                           height_mode: \"scaled\",\n",
       "                           width: width\n",
       "                       }\n",
       "                   };\n",
       "                   var fig = LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer, options);\n",
       "                   if (toolbar) {\n",
       "                     toolbar.bind(fig);\n",
       "                   }\n",
       "               });\n",
       "               \n",
       "               break;\n",
       "           }\n",
       "       }\n",
       "   });\n",
       "   \n",
       "   observer.observe(containerDiv);\n",
       "   \n",
       "   // ----------\n",
       "   })();\n",
       "   \n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x330428d10>"
      ]
     },
     "execution_count": 3,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "  ggplot(customers, aes(\"income\", \"spending_score\")) +\n",
    "  geom_point() +\n",
    "  theme_minimal() +\n",
    "  theme(panel_grid_minor = element_blank()) +\n",
    "  labs(x = \"Income\", y = \"Spending score\")\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Looking at the graph, we can see that there are distinct segments of customers organised into somewhat distinct clusters.\n",
    "\n",
    "🗣️ **CLASSROOM DISCUSSION:**\n",
    "\n",
    "How many clusters do you see? Can you describe intuitively what each cluster represents?\n",
    "\n",
    "*Intuitively, we could point to around 5 clusters, though we can also see that some clusters are more tightly integrated than others.*\n",
    "\n",
    "-   *Low income, low spending score*\n",
    "-   *Low income, high spending score*\n",
    "-   *Middling income, middling spending score*\n",
    "-   *High income, low spending score*\n",
    "-   *High income, high spending score*\n",
    "\n",
    "## Implementing k-means clustering\n",
    "\n",
    "Implementing k-means clustering in Python is fairly straightforward. We build a pipeline that standardises the data and instantiates a k-means model with 5 clusters. We then fit this pipeline to `customers`."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Instantiate a model\n",
    "pipe = Pipeline([(\"scaler\", StandardScaler()), (\"kmeans\", KMeans(n_clusters=5))])\n",
    "\n",
    "# Fit the model to the data\n",
    "_ = pipe.fit(customers)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "After this, we can create a new variable (`cluster`) by finding the vector of cluster assignments in `kclust_customers`, and converting the results into a factor. After that, we can use some simple modifications to our `ggplot` to see some results.\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"ilMGHd\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "   \n",
       "   (function() {\n",
       "   // ----------\n",
       "   \n",
       "   var containerDiv = document.getElementById(\"ilMGHd\");\n",
       "   var observer = new ResizeObserver(function(entries) {\n",
       "       for (let entry of entries) {\n",
       "           var width = containerDiv.clientWidth\n",
       "           if (entry.contentBoxSize && width > 0) {\n",
       "           \n",
       "               // Render plot\n",
       "               if (observer) {\n",
       "                   observer.disconnect();\n",
       "                   observer = null;\n",
       "               }\n",
       "\n",
       "               var plotSpec={\n",
       "\"data\":{\n",
       "\"income\":[15.0,15.0,16.0,16.0,17.0,17.0,18.0,18.0,19.0,19.0,19.0,19.0,20.0,20.0,20.0,20.0,21.0,21.0,23.0,23.0,24.0,24.0,25.0,25.0,28.0,28.0,28.0,28.0,29.0,29.0,30.0,30.0,33.0,33.0,33.0,33.0,34.0,34.0,37.0,37.0,38.0,38.0,39.0,39.0,39.0,39.0,40.0,40.0,40.0,40.0,42.0,42.0,43.0,43.0,43.0,43.0,44.0,44.0,46.0,46.0,46.0,46.0,47.0,47.0,48.0,48.0,48.0,48.0,48.0,48.0,49.0,49.0,50.0,50.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,57.0,57.0,58.0,58.0,59.0,59.0,60.0,60.0,60.0,60.0,60.0,60.0,61.0,61.0,62.0,62.0,62.0,62.0,62.0,62.0,63.0,63.0,63.0,63.0,63.0,63.0,64.0,64.0,65.0,65.0,65.0,65.0,67.0,67.0,67.0,67.0,69.0,69.0,70.0,70.0,71.0,71.0,71.0,71.0,71.0,71.0,72.0,72.0,73.0,73.0,73.0,73.0,74.0,74.0,75.0,75.0,76.0,76.0,77.0,77.0,77.0,77.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,79.0,79.0,81.0,81.0,85.0,85.0,86.0,86.0,87.0,87.0,87.0,87.0,87.0,87.0,88.0,88.0,88.0,88.0,93.0,93.0,97.0,97.0,98.0,98.0,99.0,99.0,101.0,101.0,103.0,103.0,103.0,103.0,113.0,113.0,120.0,120.0,126.0,126.0,137.0,137.0],\n",
       "\"spending_score\":[39.0,81.0,6.0,77.0,40.0,76.0,6.0,94.0,3.0,72.0,14.0,99.0,15.0,77.0,13.0,79.0,35.0,66.0,29.0,98.0,35.0,73.0,5.0,73.0,14.0,82.0,32.0,61.0,31.0,87.0,4.0,73.0,4.0,92.0,14.0,81.0,17.0,73.0,26.0,75.0,35.0,92.0,36.0,61.0,28.0,65.0,55.0,47.0,42.0,42.0,52.0,60.0,54.0,60.0,45.0,41.0,50.0,46.0,51.0,46.0,56.0,55.0,52.0,59.0,51.0,59.0,50.0,48.0,59.0,47.0,55.0,42.0,49.0,56.0,47.0,54.0,53.0,48.0,52.0,42.0,51.0,55.0,41.0,44.0,57.0,46.0,58.0,55.0,60.0,46.0,55.0,41.0,49.0,40.0,42.0,52.0,47.0,50.0,42.0,49.0,41.0,48.0,59.0,55.0,56.0,42.0,50.0,46.0,43.0,48.0,52.0,54.0,42.0,46.0,48.0,50.0,43.0,59.0,43.0,57.0,56.0,40.0,58.0,91.0,29.0,77.0,35.0,95.0,11.0,75.0,9.0,75.0,34.0,71.0,5.0,88.0,7.0,73.0,10.0,72.0,5.0,93.0,40.0,87.0,12.0,97.0,36.0,74.0,22.0,90.0,17.0,88.0,20.0,76.0,16.0,89.0,1.0,78.0,1.0,73.0,35.0,83.0,5.0,93.0,26.0,75.0,20.0,95.0,27.0,63.0,13.0,75.0,10.0,92.0,13.0,86.0,15.0,69.0,14.0,90.0,32.0,86.0,15.0,88.0,39.0,97.0,24.0,68.0,17.0,85.0,23.0,69.0,8.0,91.0,16.0,79.0,28.0,74.0,18.0,83.0],\n",
       "\"labels\":[\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"0\",\"4\",\"3\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"2\",\"1\",\"0\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"0\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\"]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"income\",\n",
       "\"y\":\"spending_score\",\n",
       "\"colour\":\"labels\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"type\":\"int\",\n",
       "\"column\":\"income\"\n",
       "},{\n",
       "\"type\":\"int\",\n",
       "\"column\":\"spending_score\"\n",
       "},{\n",
       "\"type\":\"str\",\n",
       "\"column\":\"labels\"\n",
       "}]\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"minimal\",\n",
       "\"legend_position\":\"bottom\",\n",
       "\"panel_grid_minor\":{\n",
       "\"blank\":true\n",
       "}\n",
       "},\n",
       "\"guides\":{\n",
       "\"x\":{\n",
       "\"title\":\"Income\"\n",
       "},\n",
       "\"y\":{\n",
       "\"title\":\"Spending score\"\n",
       "},\n",
       "\"colour\":{\n",
       "\"title\":\"Cluster #\"\n",
       "}\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[],\n",
       "\"spec_id\":\"2\"\n",
       "};\n",
       "               window.letsPlotCall(function() {\n",
       "       \n",
       "               var toolbar = null;\n",
       "               var plotContainer = containerDiv;               \n",
       "               \n",
       "                   var options = {\n",
       "                       sizing: {\n",
       "                           width_mode: \"min\",\n",
       "                           height_mode: \"scaled\",\n",
       "                           width: width\n",
       "                       }\n",
       "                   };\n",
       "                   var fig = LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer, options);\n",
       "                   if (toolbar) {\n",
       "                     toolbar.bind(fig);\n",
       "                   }\n",
       "               });\n",
       "               \n",
       "               break;\n",
       "           }\n",
       "       }\n",
       "   });\n",
       "   \n",
       "   observer.observe(containerDiv);\n",
       "   \n",
       "   // ----------\n",
       "   })();\n",
       "   \n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x33042bfb0>"
      ]
     },
     "execution_count": 5,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# Identify cluster labels for each row\n",
    "kmeans_labels = [str(i) for i in pipe.named_steps[\"kmeans\"].labels_]\n",
    "\n",
    "# Create a data frame based on customers by adding the cluster labels\n",
    "plot_kmeans = customers\n",
    "plot_kmeans[\"labels\"] = kmeans_labels\n",
    "\n",
    "(\n",
    "  ggplot(plot_kmeans, aes(\"income\", \"spending_score\", colour = \"labels\")) +\n",
    "  geom_point() +\n",
    "  theme_minimal() +\n",
    "  theme(panel_grid_minor = element_blank(),\n",
    "        legend_position = \"bottom\") +\n",
    "  labs(x = \"Income\", y = \"Spending score\",\n",
    "       colour = \"Cluster #\")\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Validating k-means\n",
    "\n",
    "We can tell intuitively that 5 clusters probably makes the most sense. However, in most cases, we will not have the luxury of being able to do this, and will need to validate our choice of cluster number.\n",
    "\n",
    "### The elbow method\n",
    "\n",
    "One widely used method is the elbow method.  Simply put, when we see distinct \"elbows\" in the plot, we decide that adding more clusters will not result in a significant reduction in the total within-sum cluster sum of squared errors.  As a result, we can stop and use that many clusters.\n",
    "\n",
    "We can create an elbow plot using the nested tibble approach."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"uEq7FZ\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "   \n",
       "   (function() {\n",
       "   // ----------\n",
       "   \n",
       "   var containerDiv = document.getElementById(\"uEq7FZ\");\n",
       "   var observer = new ResizeObserver(function(entries) {\n",
       "       for (let entry of entries) {\n",
       "           var width = containerDiv.clientWidth\n",
       "           if (entry.contentBoxSize && width > 0) {\n",
       "           \n",
       "               // Render plot\n",
       "               if (observer) {\n",
       "                   observer.disconnect();\n",
       "                   observer = null;\n",
       "               }\n",
       "\n",
       "               var plotSpec={\n",
       "\"data\":{\n",
       "\"k\":[1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0],\n",
       "\"inertia\":[600.0,358.32109965193973,257.80263643765016,129.2902357435169,65.57885579985049,55.067795914519664,50.15195131596869,43.723642936592654,42.597516564049535]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"k\",\n",
       "\"y\":\"inertia\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"type\":\"int\",\n",
       "\"column\":\"k\"\n",
       "},{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"inertia\"\n",
       "}]\n",
       "},\n",
       "\"guides\":{\n",
       "\"x\":{\n",
       "\"title\":\"Number of clusters\"\n",
       "},\n",
       "\"y\":{\n",
       "\"title\":\"Inertia\"\n",
       "}\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "},{\n",
       "\"geom\":\"line\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"linetype\":\"dashed\",\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[],\n",
       "\"spec_id\":\"3\"\n",
       "};\n",
       "               window.letsPlotCall(function() {\n",
       "       \n",
       "               var toolbar = null;\n",
       "               var plotContainer = containerDiv;               \n",
       "               \n",
       "                   var options = {\n",
       "                       sizing: {\n",
       "                           width_mode: \"min\",\n",
       "                           height_mode: \"scaled\",\n",
       "                           width: width\n",
       "                       }\n",
       "                   };\n",
       "                   var fig = LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer, options);\n",
       "                   if (toolbar) {\n",
       "                     toolbar.bind(fig);\n",
       "                   }\n",
       "               });\n",
       "               \n",
       "               break;\n",
       "           }\n",
       "       }\n",
       "   });\n",
       "   \n",
       "   observer.observe(containerDiv);\n",
       "   \n",
       "   // ----------\n",
       "   })();\n",
       "   \n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x330489220>"
      ]
     },
     "execution_count": 6,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# Create a function that returns inertia scores for a range of k\n",
    "def find_optimal_cluster(k, data):\n",
    "    # Create a pipeline that scales the data then fits k-means models over a range of k\n",
    "    pipe = Pipeline([(\"scaler\",StandardScaler()),(\"kmeans\",KMeans(n_clusters=k))])\n",
    "    # Fit the model to the data\n",
    "    pipe.fit(data)\n",
    "    # Return the inertia_ attribute\n",
    "    return pipe.named_steps[\"kmeans\"].inertia_\n",
    "\n",
    "# Create a data frame with the k range and associated inertia scores\n",
    "inertias_df = pd.DataFrame({\"k\":range(1,10), \"inertia\": [find_optimal_cluster(k, customers) for k in range(1,10)]})\n",
    "\n",
    "# Plot the output\n",
    "(\n",
    "  ggplot(inertias_df, aes(\"k\", \"inertia\")) +\n",
    "  geom_point() +\n",
    "  geom_line(linetype = \"dashed\") +\n",
    "  labs(x = \"Number of clusters\", y = \"Inertia\")\n",
    "\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "::: callout-note\n",
    "\n",
    "The elbow method is undoubtedly the most popular method to determine the number of clusters in $k-$means and it is likely the most intuitive too. However, there are doubts about its reliability and many are the voices in the scientific community that are calling to stop using it altogether or at least supplement it with alternative methods. See, for example, [this post](https://medium.com/towards-data-science/are-you-still-using-the-elbow-method-5d271b3063bd) or [this one](https://medium.com/geekculture/stop-using-the-elbow-method-96bcfbbbe9fd) or [this *ACM SIGKDD Explorations Newsletter* paper](https://dl.acm.org/doi/10.1145/3606274.3606278).\n",
    "\n",
    ":::"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Is k-means clustering always the right choice?\n",
    "\n",
    "The answer is emphatically no.  Due to the fact that k-means clustering uses the distance between points to identify clusters, it will typically try to create evenly sized clusters when clusters should, in fact, be uneven. \n",
    "\n",
    "## Example 1: Odd conditional distributions"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"Ih4mii\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "   \n",
       "   (function() {\n",
       "   // ----------\n",
       "   \n",
       "   var containerDiv = document.getElementById(\"Ih4mii\");\n",
       "   var observer = new ResizeObserver(function(entries) {\n",
       "       for (let entry of entries) {\n",
       "           var width = containerDiv.clientWidth\n",
       "           if (entry.contentBoxSize && width > 0) {\n",
       "           \n",
       "               // Render plot\n",
       "               if (observer) {\n",
       "                   observer.disconnect();\n",
       "                   observer = null;\n",
       "               }\n",
       "\n",
       "               var plotSpec={\n",
       "\"data\":{\n",
       "\"x1\":[-0.1385234304379497,-0.968404878770772,0.2367122400692957,-0.8116432101298103,-0.1989328276846431,0.1562865006930383,0.0418799638221204,-0.234075069268132,-0.2791532938102485,0.6777068447254445,-0.1103164242844411,-0.3059735909635604,0.236909501962332,0.3392661048637714,-0.8174875761231151,0.2694949165160713,0.1881777130201391,-0.9517849323685644,-0.9354595052839584,-0.4900470062659255,-0.1595283266954398,0.2972496191943019,0.018101721084598,-0.0702451122816901,0.2926071500699811,-0.0077971267627824,-0.556345415179456,0.2727516407949819,0.3588624567451891,-0.9275324468001211,0.4070805128934966,-0.0099149661386284,0.3915481254883153,-0.0914228820295895,0.5568286456708167,0.0294298516101975,-0.0478517395521724,0.2421612596128086,-0.244605853816717,-0.2693045202222509,-0.3497641513762519,-0.232645615164422,-0.952521555253614,-0.2113184648650455,-0.2065585494361429,0.9825253087307356,0.1389748868262583,0.0660676940549479,0.1147984261855755,-0.9957867662800096,-0.0685288220083554,0.2954591437452022,0.1465467675073756,0.2665348147202847,-0.0345529929348901,-1.0056808667851926,0.9785656522339176,0.7831483757961263,-0.545033496554271,-0.3133949440447747,-1.029966844406068,0.1433343572413716,0.2866543649083677,-0.0317319389324139,0.2757281302046473,-0.0956636935884884,0.1729447541382895,-0.3969869348461352,0.2008646892693458,-0.0628612753383157,-0.8967901642193171,-0.4119444682544819,-0.1847258071316249,0.268930942736871,0.6174700682867629,0.951558505938648,0.0368723308533419,0.017909392351217,0.9363336815076668,-0.052040849025586,-0.2373288848444096,-0.2625045768510721,-0.1933961316655393,0.99468634061051,0.0888711962326175,0.8118057050296555,0.5428003709268114,0.3109444730143115,0.1541626302293454,0.9461645356719848,-0.2785657995173437,0.2484591226325496,-0.0010375311657842,-0.0081149062065542,-0.1554774300095328,-0.8431742590377078,0.8768496699399508,-0.1752182335470386,-0.1368912659662658,-0.2156320944370024,-0.7115498917632788,-0.1309104590881496,0.2111858100802197,0.1179473970125769,0.1445131385691795,-0.3426054612066069,-0.0434535102213614,-0.3061116659979073,-0.1717628078880773,-0.4986109153379811,-0.1204944728103138,-0.6851424401320018,-0.2806441968808778,-0.709423824654942,-0.2511548935355158,-0.2602342494941747,0.7485618060607664,0.5682912166172756,0.952319821343578,-0.783032829847297,0.2963783585240289,-0.2139941108125244,0.1878970439803911,0.967215856973874,0.0607521903251049,-0.243743643580321,0.1797270637757366,0.5172518436561979,-0.2270026320470816,0.3305688350788389,-0.2317967886000417,0.9457263940376598,0.2645786706948564,-0.1630364745694128,0.9954842048547822,0.3359013488637598,-0.2439907696142858,-0.8663029459878253,0.8929349969605112,-0.8622263476689399,-0.229159395809796,0.1727534048016044,0.1847864097917901,-0.929258669605182,0.2788222421729484,-0.2890456876692325,0.070612010505883,-0.2386969743092462,0.2103158289049959,0.9297879163722031,-0.1361139558303136,-0.1729538280734344,0.0265051909214146,-0.2569896933451047,-0.0560250582267893,0.309452147733206,0.1165203117253023,-0.1353851406625731,0.4672849615454277,-0.9614946430628382,-0.8596603536498789,0.6855381839573991,0.235492369177217,-0.9149504118553272,-0.4320624357453775,-0.2572714692018278,-0.2770231031182066,0.2174064476174789,0.5520296229140162,-0.2986750814168907,-0.2122121303986662,-0.919824049103648,0.2803887030153897,-0.7412017550335901,-0.0227292495679937,0.0328707576552672,-0.2599484094374302,-0.1012508986802072,-0.2589911277133656,-0.9721495522587272,-0.255665910713144,0.0755462508437808,-0.0111057147731749,0.2671712539142701,-0.0733161147152511,-0.1220718092646662,-0.2620300026221732,-0.45187714098771,-0.1302253370442017,0.0262748294558733,0.281440575851569,-0.201006020508358,0.1674044245528351,-0.07759791876031,-0.7808154562185049,0.019259429427906,0.1469610805524063,-0.6998192377652053,-0.1519638650170033,-0.3087517672749177,0.0768214610591858,-0.2895717869074933,-0.295674474298057,-0.0128035222042246,-0.9526397493413844,-0.2959259843206596,-0.1389338905923149,-0.1278931536688877,-0.059119117021386,-0.0618990395527633,0.0305940025459174,-0.2166065227007334,-0.2446527461868317,0.0242592435075139,-0.8919384305645286,-0.1565624578759386,-0.9267159313414686,-0.1205231841335554,0.1143114210952407,0.0835979974346431,0.1269357937068478,0.1438309826086942,0.1492461359336777,0.2339331251295731,0.307173926389369,0.3015374291838182,-0.2524063665116942,0.2260689628471303,0.285776413992703,-0.2554388301316829,-0.0633947685911547,-0.0520928082840772,0.7506486615307003,0.0973979944303854,0.9603707079528646,0.244236319278521,0.0656572307074492,0.1513813024724465,0.2727189272517276,0.0617791790546635,1.0319500897237133,0.9535442258249034,0.1159219333595456,0.2920651943746812,-0.0423096793316379,-0.1094746295847633,0.2773613107187705,-0.2823902067674736,-1.0342932056316818,-0.9966179135352626,-0.1522701336822554,-0.2237263933359271,0.7825010299658266,-0.0205410799752592,-0.0920946079310479,0.4880459764882904,-0.9621877717907642,-0.2747841503567565,-0.9211090771223024,-0.2680514044019541,-0.0424786731502672,-0.9759227103721552,0.0931600005271127,-0.2767699186921158,0.4833185137925599,0.0329937927999215,-0.0369265173389767,0.5362850505013546,0.0415430581699844,0.4386418992445642,1.007143828728354,-0.2655499938501351,-0.3355125561541497,-0.22004831891769,0.2090513957633389,-0.2369876816565132,0.1497335287608705,0.0762749047424607,0.262594831682373,-0.7312902227561765,0.2468292874100151,-0.416695228057896,0.2126765863927177,0.3467433930749246,0.2738751994417496,-0.8468271361832991,0.2585182283680209,0.1269668725871344,0.0281925929771764,0.1713775129940706,0.1875913591568772,0.1312300966224205,0.2557653558357532,0.198162671662213,-0.0265555224576158,-0.0158922879154333,-0.3033427842244655,0.8287446708849951,0.2338039037019024,-0.358653057773823,-0.0694072671488604,0.0702777562333065,-0.7015129353392298,-0.3100170370378283,-0.6807283196234142,0.9997251461455788,-0.7355142937294711,0.1553701071355268,-0.0826349134367788,-0.1054246891678987,0.1699716517358936,-0.3088524003154511,-0.1652009895809198,0.0571380908418484,0.232627919980537,-0.1585385662119197,0.2245090569808719,-0.4744773498248544,-0.1185769886504174,-0.2427846234659564,-0.0708168236481903,-0.3211265760412773,0.8048484088990872,-0.2501781788207414,0.1929554775659887,-0.0903248052094329,0.9103361075534347,-0.1637735214054645,0.2458662669660795,0.3646426688371993,0.0399614328647831,-0.5724228443825059,-0.3195230765430936,0.2157374376333453,-0.2039920176585973,0.7548841342909611,-0.0828265335296252,-0.1434333481310609,0.763762479176805,-0.1353156903554065,0.0727799134577408,-0.0742137733906372,0.2609679797741085,-0.2517775925270532,0.1659419198354751,0.2683074475389219,-0.1680800314241699,-0.1047476949117219,-0.289320156858102,-0.2222671356375418,-0.2501546070666143,0.1412219402848953,0.2627600006221074,0.928524276911942,0.182698137147228,-0.2476655186683797,0.2702020548040014,-0.0691127997875169,-0.1754735995920879,-1.0080183605813786,-0.0771211637192359,0.7571040681341497,-0.2516468870231406,0.8408097773234195,0.2232486196877526,-0.8151951121768007,0.1737237120650531,0.282187832165285,-0.0854576094362201,-0.2846315841575234,-0.247760171480601,-0.2489434969035713,0.9359928481470016,-0.3184276064053256,0.2780956955117652,0.3593078001282489,0.3464318685537267,-0.5306809422988833,-1.0140521453239366,-0.7404622088395693,0.3304868235001911,-0.5044513439820726,-0.3241633079759849,0.0247693429231923,0.1526058298680864,-0.0413855724251043,-0.639844432871609,0.078594594796724,0.1963993229360476,0.2316010422356015,0.0478157733234298,-0.9444019886054532,0.3084864306993309,0.276188691543865,-0.0077337874430667,0.1545653165760284,-0.1728553254128005,-0.2251287125382435,-0.614315207189044,-0.1372980662533991,-0.2993470316243778,0.2919630774114096,-0.0033792097852051,-0.9762381592208784,0.0240245554313452,-0.1639346029578446,0.2941649638616872,0.0522233380355403,0.2408065470951337,-0.0496471926621285,-0.1016302006257871,0.1035403272577982,0.0991342373848368,0.8130166458240975,0.0590314801582622,-0.5698784072524513,0.173491974008791,0.09282367661897,0.1865315360906637,0.2399089840710199,-1.0274187414969955,0.1051030276521082,-0.2951828114905452,0.2701473612686966,1.0067430590541928,-0.2780563393397526,0.1999889877471789,-0.2101098512134586,0.2893884170363056,-0.2014184832200256,-0.7811556134662724,-0.2419118146130908,-0.2469059605365172,0.1299723387510945,-0.6349043578159463,0.3577216733397898,0.9892913066641996,0.2815115065893698,0.1101039196644467,-0.2990603645882504,-0.1665950012358033,0.2151831150071114,-0.2634079878963455,-0.872701433606142,-0.2584667939331593,0.9130622018270764,0.1822193110457124,-0.2026757929289422,0.3296253723607074,-0.2957349048389931,0.2426537184815384,0.2196192862164607,0.0194419607894327,0.2838893965462531,0.0673594220392598,-0.2889713580299942,0.2898774923323535,0.2099808320938593,-0.9076812600775116,-0.4826357037325296,-0.9806322467983823,0.0366652105965166,-0.944768494943647,-0.4794425281092463,-0.2446399039688192,0.2449608564532175,-0.2442262844874063,-0.1665525033004358,0.2191795134362961,-0.7723072317119826,-0.273680018685718,-0.3189107027620051,0.9706294106731842,0.1633909902353295,0.2125178258060883,0.3308937475192985,0.2797034411102999,-0.080049110429213,-0.7368844693265978,-0.1939120234698752,0.0960467159500105,0.1559621092690796,0.2736952655741569,-0.0739232592964769,0.2984033567248106,0.6032217461717146,-0.2324744943344396,-0.1533683478630272,0.1327833364518977,0.5052238465804747,-0.0374998435501213,-0.2625289616650838,-0.2897987335147298,0.9893031769576068,-0.3154414067518175,0.2685765837671198,1.0119031003512942,0.3926914283093114,0.1964398440712108,-0.1818980214894232,-0.0486876206532493,-0.2561359663333503,0.3127764766709273,0.8352397396667975,0.2560847903909042,1.0271755359957966,0.2648894389219105,-0.8069033899887501,-0.2852804963466216,-0.2357006850682213,-0.1915082235262562,-1.014816072023465,0.3232186119328753,0.3248129964474673,0.3073252291718696,-0.2128921527608318,0.274715475968089,0.7235839815889867,-0.2121437035965687,0.0494289136960012,-0.2974331000568898,-0.2209840217785891,0.8124138416081572,-0.3646523324171764,0.2690827112807456,0.2544845456019077,-1.0072989783013135,0.8359224851409064,0.4936735407761751,-0.2289769588127978,0.0498610001309933,0.4466030222617423,0.2380142463204957,1.0336909657159474,-0.2716295973518515,0.2614953885022163,-0.277445305407101,0.2648714982454507,0.1830185504165012,0.1264543801950012,0.2565709451803408,-0.2462293047479328,0.227304640305774,-0.1937629854358601,0.243582662193687,-0.2090765909940639,0.2401931885494654,-0.2103285075427028,0.185252602787424,-0.1066693389905974,0.3139566544041806,-0.0727914756942635,0.2903717241461807,-0.2272296190307125,-0.2672343331192347,-0.2016477056085781,0.1363512446565452,0.9063183735064678,0.9720894997832696,-0.4432640831438624,-0.2591162598963109,0.1895019310156389,-0.1912847583582667,-0.2110829528563644,-0.6031511285084189,-0.8289398366808465,0.8452322158858073,-0.6982147293460435,0.7134656248336756,-0.2824297911897867,0.2919362017419363,0.303525342081807,0.6791653120568293,0.6232789147017476,-0.2433895216335896,0.666989640026438,0.5905926340143132,0.2748065621739277,-0.0666484961745779,0.0581288226349481,1.0164738813571057,0.102533531557135,0.0975442583808523,0.2600053963564839,0.9477942706980088,-0.1312244941210046,0.0142098607368106,-0.1287277172902274,0.2587165629064178,-0.0392819496064969,0.9894208889083764,-0.2303754789265607,0.9110382175889622,0.0026976763754824,0.0855041320588824,0.4034359137412558,-0.618980822674548,0.2187396801002969,0.1227946507389817,0.002238227312223,0.124761874517136,-0.272830303898087,0.3096937471726819,-0.2425434929175533,-0.1016433818875407,0.7068166927231019,0.260462617523079,-0.3779413623294649,0.0157880789215005,0.2643228102133578,-0.1228310428143801,-0.0217871757393988,0.2921830138717942,0.2686607838426416,0.2349306389039006,-0.1169757159477485,0.127689995510136,-0.2729585387171457,0.2255888302909137,-0.0163536026559523,0.1215000309103625,0.3269921007325545,0.3050090930669475,-0.3239815367794843,0.3219645533442101,0.1528473759180416,-0.9810409583251972,0.0848749714184419,0.7923509131395182,-0.7912583180656771,-0.3222116806483267,-0.1591297452117782,-0.3178149764899974,0.0632976121053907,0.2484822537932069,-0.0733512348213416,0.2565594154905227,-0.2711563768748005,-0.2792643703747319,-0.1953538331745301,-0.2977296780852061,0.8585256728675684,-0.0635884342637367,-0.8226819037486809,-0.2887779604287342,0.1742623862984751,0.3099086945282433,0.2205434726646344,0.980526013320548,-0.3339687804517109,0.6623272512110318,-0.223645693533557,-0.9634528117589096,0.3530202221728791,0.4182336702340584,0.2591836688074864,-0.3477753675742409,-0.0152469803664412,0.6079732494520961,0.2987441252484457,0.2304092462972853,-0.2021529561617544,-0.2829521293742039,-0.3449006851047188,0.6098815197645558,1.027407747163033,-0.660472346532067,0.2494283329140437,0.2424442397352634,-0.0176438583648665,0.0397605648841977,0.273897061679425,0.1873149641781564,-0.0660913563715643,-0.281445464058554,-0.3362869478876946,-0.0860631126659446,0.3471702806135713,0.5764806847498569,-0.7484960110020671,0.9682293278782568,-0.3134477874574476,-0.3053184526946665,0.202421243526702,0.3033458080892134,-0.1928442367642441,-0.1851994665195947,-0.1315245376354039,-0.8992927377044504,0.7741411952129615,-0.1579625837187375,0.2409294564713739,0.1685222962395413,-0.2580957494238489,-0.0497220947236745,-0.9421691120875696,0.9847598487670522,-0.9709107319210852,0.3021672804206495,0.1948269164803593,-0.5394557922749162,-0.0984001447749432,0.2405487859048737,-0.0453679499375168,0.3064578959887092,0.2051722353158377,0.9846014570678712,-0.1710000829293804,-0.337069301830705,-0.3122248793261121,-0.0641135000602808,-0.16265115411139,-0.2668360759743786,0.8555913440674121,-0.3040670931042752,0.1137514941753848,0.0036210061680852,-0.2736408370327245,-0.4033012804017144,-0.2315277783431498,-0.3286329083885775,-0.7950734076818805,-0.0951041689664277,-0.2340018489016148,-0.0542455995425817,0.0407281223457891,-0.1133911717619168,0.0397792928176397,0.2198895355057977,0.3587008418590788,0.1195748106317213,-0.2715079091354311,0.0950581093507428,-0.2597029805132124,-0.3094222828563848,-0.0657080446465774,-0.1444274825164247,-0.0724635044554179,0.1756011314790994,-0.2512237395078328,-0.1408273799927261,-0.9888559823720098,0.1233570667232021,0.2436402793243978,0.312375742240417,0.1402375134712878,0.2763825642151415,0.0226720175304713,0.9854904871758912,0.0988482820274384,-0.2904350686466702,-0.968404878770772,0.5797229025467567,-0.8116432101298103,-0.4047086411972457,0.1562865006930383,0.0770204424424176,-0.518689340151846,-0.6689640429248794,0.6777068447254445,-0.1654325405582963,-0.705184282334869,0.5514248748169797,0.7266993693152238,-0.8174875761231151,0.2694949165160713,0.3896269936744435,-0.9517849323685644,-0.9354595052839584,-0.4900470062659255,-0.3695981786799581,0.6972180368758283,0.1224383236005569,-0.1842528172696805,0.635617812547442,-0.0228731998307562,-0.556345415179456,0.2727516407949819,0.3588624567451891,-0.9275324468001211,0.4070805128934966,0.0202157560725448,0.3915481254883153,-0.2339876335148898,0.5568286456708167,0.0944847176881511,-0.1129066056301258,0.6158928365954536,-0.6200993968782667,-0.6222210107962322,-0.7301867578943133,-0.5648839748427471,-0.952521555253614,-0.4544905839428877,-0.5179434700629523,0.9825253087307356,0.3183281732622711,0.1211838103288032,0.2667100643942962,-0.9957867662800096,-0.1186621154340771,0.6863663931724796,0.3775758488762825,0.5959478537716556,-0.0345529929348901,-1.0056808667851926,0.9785656522339176,0.7831483757961263,-0.545033496554271,-0.6995475995780842,-1.029966844406068,0.2133435808314821,0.6753070580742373,-0.0417839771097488,0.6545674522025451,-0.2750169800245012,0.4161168732161316,-0.3969869348461352,0.2008646892693458,-0.1816779079691297,-0.8967901642193171,-0.4119444682544819,-0.1847258071316249,0.268930942736871,0.6174700682867629,0.951558505938648,0.0368723308533419,0.0580540782917029,0.9363336815076668,-0.1220500726156964,-0.5878515568619551,-0.628601045899439,-0.4444726761818194,0.99468634061051,0.1883471510985594,0.8118057050296555,0.5428003709268114,0.7047702068259937,0.3424442030954784,0.9461645356719848,-0.660511617416001,0.6037137021579674,-0.080921523371547,0.0019371319707808,-0.3865065113784399,-0.8431742590377078,0.8768496699399508,-0.4301878294465145,-0.2216941099350877,-0.517332646731444,-0.7115498917632788,-0.3236119287288357,0.528781969539354,0.2367640296433907,0.3193594452295526,-0.3426054612066069,-0.0935868036470829,-0.6701540542719056,-0.4305851925158551,-0.4986109153379811,-0.2908061894363429,-0.6851424401320018,-0.6795077569851233,-0.709423824654942,-0.6283511078926616,-0.5952454655110314,0.7485618060607664,0.5682912166172756,0.952319821343578,-0.783032829847297,0.678324176422686,-0.432551849506232,0.4653583663055131,0.967215856973874,0.1553517891345948,-0.6035057442068695,0.1797270637757366,0.5172518436561979,-0.5564156710984526,0.3305688350788389,-0.5334973408944832,0.9457263940376598,0.6620231949028598,-0.4404977968945348,0.9954842048547822,0.7357750245770797,-0.5521960667246015,-0.8663029459878253,0.8929349969605112,-0.8622263476689399,-0.5991902785435793,0.439158151775305,0.4436087944195678,-0.929258669605182,0.6293449141904938,-0.6858915681950237,0.1749486130218418,-0.537073432478919,0.4841346712764713,0.9297879163722031,-0.3332048924496302,-0.4161259471512764,-0.0036255312897585,-0.640398408952055,-0.1457333626065419,0.6928608633401563,0.3516344126422915,-0.1353851406625731,0.4672849615454277,-0.9614946430628382,-0.8596603536498789,0.6855381839573991,0.5371929214716585,-0.9149504118553272,-0.4320624357453775,-0.6192022901882356,-0.6200337655956675,0.5524176636343356,0.5520296229140162,-0.6820837970238411,-0.2122121303986662,-0.919824049103648,0.6750630806985369,-0.7412017550335901,-0.0026315222960858,0.1225790620350196,-0.649759158552061,-0.2670011310775208,-0.6270838666597137,-0.9721495522587272,-0.5879042703914691,0.1991530485937597,-0.051250400713661,0.6152447557820805,-0.172792069581193,-0.2693216303385374,-0.5246643049233557,-0.45187714098771,-0.3571329166949043,0.0913296955338267,0.281440575851569,-0.4361201214253473,0.3005322423620298,-0.196414551391124,-0.7808154562185049,0.0443756372396315,0.3612917985440049,-0.6998192377652053,-0.3662945830086019,-0.6935628359093521,0.1762974159251277,-0.6833975207191755,-0.6637672132444051,-0.0128035222042246,-0.9526397493413844,-0.6620224533690267,-0.3227658348409099,-0.3027394603292609,-0.059119117021386,-0.0920297617639363,0.1153968465147392,-0.479240825001916,-0.6393271238699789,-0.0108812351127833,-0.8919384305645286,-0.4153848425037162,-0.9267159313414686,-0.2816857584190205,0.2708608878301219,0.0835979974346431,0.2409434986948384,0.1438309826086942,0.3761537155843803,0.6000295941779402,0.6919849950238033,0.6221642231321688,-0.2524063665116942,0.5664667555650073,0.6576870083480036,-0.5984494926091438,-0.0633947685911547,-0.0520928082840772,0.7506486615307003,0.2585605687158505,0.9603707079528646,0.6303889748118305,0.194034674630333,0.3571571159850492,0.6131167199696043,0.1119124724803852,1.0319500897237133,0.9535442258249034,0.2537791026293524,0.5970421987792603,-0.1073645454095912,-0.3021760992254494,0.6693033316724692,-0.662812813285535,-1.0342932056316818,-0.9966179135352626,-0.3493610703015721,-0.5351113139627365,0.7825010299658266,-0.0155146640219182,-0.2204720518539317,0.4880459764882904,-0.9621877717907642,-0.6676990506482319,-0.9211090771223024,-0.6136207712790882,-0.1025689087985699,-0.9759227103721552,0.2215374444499964,-0.670595652503798,0.4833185137925599,0.0530915200718293,-0.1217293613077986,0.5362850505013546,0.1361426569794743,0.4386418992445642,1.007143828728354,-0.6111193607272692,-0.7354809738356762,-0.5465840192045636,0.4754561427370396,-0.6124812247180629,0.3640642467524692,0.218839656227761,0.6266372199563713,-0.7312902227561765,0.5582142080368244,-0.416695228057896,0.4937365743122575,0.3467433930749246,0.6738751994417496,-0.8468271361832991,0.6160547980285265,0.1269668725871344,0.1080765851829392,0.4185213582302043,0.1875913591568772,0.245237801610411,0.5823010561226267,0.4792226595817526,-0.0315819384109568,-0.035990015187341,-0.7007873084324688,0.8287446708849951,0.5321803618715752,-0.358653057773823,-0.1443597929831503,0.0702777562333065,-0.7015129353392298,-0.6961696925711378,-0.6807283196234142,0.9997251461455788,-0.7355142937294711,0.3863991885044338,-0.1575874392710687,-0.2290314869178777,0.4091336449589012,-0.6728947885894494,-0.4162775340971999,0.1663188650487787,0.232627919980537,-0.3977005594349272,0.4430667956745795,-0.4744773498248544,-0.2277577628573475,-0.5957011140399378,-0.2273662903830712,-0.7199901361455229,0.8048484088990872,-0.5737849765707204,0.4030253295505069,-0.2651711118698059,0.9103361075534347,-0.3520550942715974,0.5304805378497937,0.7641374514796063,0.034935016911442,-0.5724228443825059,-0.6914336708983942,0.3995693818819405,-0.5215881771177314,0.7548841342909611,-0.2393760002645061,-0.3448826287853652,0.763762479176805,-0.2731728596252132,0.1915965460885548,-0.1639220777703896,0.6290607187204565,-0.5433650434956179,0.1659419198354751,0.6544601030722313,-0.4230496273236457,-0.1047476949117219,-0.6297179495759787,-0.2222671356375418,-0.5982281089344246,0.3922984848011756,0.6431826071401687,0.928524276911942,0.4528312603956377,-0.5712723164183586,0.6473982691611473,-0.1637123985970066,-0.4565335875116276,-1.0080183605813786,-0.2007279614692149,0.7571040681341497,-0.2516468870231406,0.8408097773234195,0.5314539167980683,-0.8151951121768007,0.4248002565813333,0.6719985812799159,-0.213835053359104,-0.6826119909500434,-0.5742958717674745,-0.5634588697582189,0.9359928481470016,-0.7183012821186455,0.6749415760375564,0.3593078001282489,0.7464002862352532,-0.5306809422988833,-1.0140521453239366,-0.7404622088395693,0.7243125573118734,-0.5044513439820726,-0.7216078321839883,0.0247693429231923,0.3917678230910939,-0.0665017802368296,-0.639844432871609,0.1237371487461166,0.470218165307523,0.627785612514262,0.1178249969135402,-0.9444019886054532,0.7039471285944965,0.6550280135417627,-0.0528763413924594,0.1545653165760284,-0.3247669636215209,-0.5427248719973776,-0.614315207189044,-0.2798628177386993,-0.6940214093075251,0.6638736717667102,0.0217369980265202,-0.9762381592208784,0.0989770812656349,-0.4520582129130074,0.6517015335221927,0.1994731591094116,0.5863759139722678,-0.2153974250594422,-0.2347580184349819,0.2738520438838273,0.1492675308105585,0.8130166458240975,0.2062813012321333,-0.5698784072524513,0.49709877175877,0.2899146132382867,0.4781189870592283,0.4870528293071537,-1.0274187414969955,0.2142838018590383,-0.66891438847319,0.6341897495426948,1.0067430590541928,-0.662867407974187,0.4626232900483614,-0.5183151483237743,0.6848491149314712,-0.4485623284561594,-0.7811556134662724,-0.5369170615563604,-0.4779350419054242,0.2678295080209014,-0.6349043578159463,0.3577216733397898,0.9892913066641996,0.6807221979606783,0.320173771648965,-0.6899676140155279,-0.4329997482095039,0.5067705659756762,-0.5928210269477164,-0.872701433606142,-0.6203976149195671,0.9130622018270764,0.4049695576409876,-0.4764946353004176,0.7264712528864986,-0.6911956027341587,0.5720667575329094,0.5278245833267764,0.0745580770632879,0.6344120685637986,0.0673594220392598,-0.6465079276904997,0.6043928651870011,0.2099808320938593,-0.9076812600775116,-0.4826357037325296,-0.9806322467983823,0.0818077645459092,-0.944768494943647,-0.4794425281092463,-0.6446083216503458,0.5563457770800269,-0.2442262844874063,-0.3893027498957109,0.5892103961700794,-0.7723072317119826,-0.6691407165808836,-0.3189107027620051,0.9706294106731842,0.3902985698860323,0.5331446197544392,0.7143024631262489,0.6534350180929447,-0.1843857129451717,-0.7368844693265978,-0.5536741240964236,0.0960467159500105,0.3574113899233839,0.5687005125174264,-0.0739232592964769,0.2984033567248106,0.6032217461717146,-0.5531012882827904,-0.3591441613756297,0.3076296431122708,0.5052238465804747,-0.0374998435501213,-0.6200655313255893,-0.6617093278700305,0.9893031769576068,-0.3154414067518175,0.6614914840585953,1.0119031003512942,0.3926914283093114,0.514036003530345,-0.1818980214894232,-0.1087778563015521,-0.5545124245030232,0.6747072976573352,0.8352397396667975,0.6158468910174526,1.0271755359957966,0.6201440184473284,-0.8069033899887501,-0.6781953966380971,-0.5909552645936391,-0.5265194395431129,-1.014816072023465,0.6932494946666585,0.7245287855037029,0.7035097994505302,-0.4939521406803715,0.5628390859232518,0.7235839815889867,-0.4472578045135579,0.0795596359071743,-0.6762724220547874,-0.2209840217785891,0.8124138416081572,-0.3646523324171764,0.6685774939231526,0.607401036175889,-1.0072989783013135,0.8359224851409064,0.4936735407761751,-0.6209189797664965,0.0548874160843343,0.4466030222617423,0.62282531495493,1.0336909657159474,-0.6700830410091204,0.6095688903700266,-0.5824223098116801,0.6623160224534541,0.5511112893628494,0.3235453168143177,0.6452236383462104,-0.5839604749487387,0.4822742362052499,-0.46389610868427,0.5701183624805606,-0.486537913319186,0.5451701929540446,-0.4949427784264169,0.4203667037044132,-0.2445265082604042,0.7068715546956561,-0.1279075919681186,0.6658652672077302,-0.474373464266846,-0.5817497059738822,-0.4680524525822788,0.3549089833502529,0.9063183735064678,0.9720894997832696,-0.4432640831438624,-0.6589899356096308,0.3952777445282415,-0.4304467515812742,-0.5591564547241747,-0.6031511285084189,-0.8289398366808465,0.8452322158858073,-0.6982147293460435,0.7134656248336756,-0.6596260055469325,0.683878222695635,0.7027360334531155,0.6791653120568293,0.6232789147017476,-0.2433895216335896,0.666989640026438,0.5905926340143132,0.6727869689664477,-0.1612480949840677,0.0982735085754341,1.0164738813571057,0.1774860573914251,0.2540937251157332,0.2600053963564839,0.9477942706980088,-0.3455552121126032,0.0242618989141456,-0.2990394339162566,0.5909549225847428,-0.0392819496064969,0.9894208889083764,-0.5041943212980362,0.9110382175889622,-0.0073543618018523,0.218631949868077,0.4034359137412558,-0.618980822674548,0.5204402323947384,0.2885448831362953,-0.0228779804995022,0.2766735127258564,-0.6465618808807317,0.7043681248558291,-0.563170286865904,-0.2347711996967351,0.7068166927231019,0.592700977201404,-0.3779413623294649,0.1005909228903223,0.6640385992695935,-0.2839936170998452,-0.006711102671425,0.6906364575290632,0.2686607838426416,0.5805000057810348,-0.3184249966020528,0.2702547469954363,-0.6698044192429369,0.510203101174628,0.0437366329923505,0.3142015005510489,0.7168028498471853,0.6805026361284972,-0.7201661070581449,0.7093978177956625,0.3140099502035066,-0.9810409583251972,0.0848749714184419,0.7923509131395182,-0.7912583180656771,-0.6922425633821099,-0.338483031647791,-0.7052482409414499,0.1233878477536935,0.5434875007364764,-0.1776878373373003,0.6564330912038427,-0.6115541695926772,-0.6679170635406015,-0.4903590801177996,-0.6796754959838632,0.8585256728675684,-0.0635884342637367,-0.8226819037486809,-0.6796852098560117,0.4292319821979511,0.7083621381855122,0.2205434726646344,0.980526013320548,-0.3339687804517109,0.6623272512110318,-0.223645693533557,-0.9634528117589096,0.7334428286909405,0.4182336702340584,0.5827904665574654,-0.3477753675742409,0.0198934982538559,0.6079732494520961,0.6896513746757231,0.518532856252448,-0.5071299605663336,-0.6826679184304395,-0.7441113764760273,0.6098815197645558,1.027407747163033,-0.660472346532067,0.6113591539004516,0.5801754099360694,-0.0627864123142593,0.0397605648841976,0.6510932760365709,0.4499492664793391,-0.1752721305784943,-0.6733874850122528,-0.7357817305301017,-0.0860631126659446,0.7460338407178169,0.5764806847498569,-0.7484960110020671,0.9682293278782568,-0.7114281942499676,-0.7050342417509021,0.5007977016963748,0.6562622986631947,-0.4844316877328087,-0.3734810393857278,-0.3500822763291115,-0.8992927377044504,0.7741411952129615,-0.1579625837187375,0.5786606266721801,0.3912725428348166,-0.6542803197025094,-0.1197313183137849,-0.9421691120875696,0.9847598487670522,-0.9709107319210852,0.6682637494690166,0.4722882388054813,-0.5394557922749162,-0.0984001447749432,0.4837209049827158,-0.030291876869543,0.6884037138873664,0.5401834513326944,0.9846014570678712,-0.4411332061777901,-0.6875919738482503,-0.7122248793261121,-0.1042581860007668,-0.3099009751852611,-0.5549596859295413,0.8555913440674121,-0.3040670931042752,0.306452963816071,-0.0164767211038226,-0.6113720072335306,-0.4033012804017144,-0.6201804715090193,-0.7270863520458464,-0.7950734076818805,-0.130244647586725,-0.4178337931502098,-0.1341295917483446,0.0256520492778155,-0.3234610237464349,0.1196632850234024,0.4900226587542076,0.7566812486515988,0.2989280970677342,-0.6503472311333288,0.2788900535993379,-0.6149575600386302,-0.7089170654987919,-0.1797157496345678,-0.3713350621671273,-0.1719394593213597,0.3459128481051284,-0.6386570039592853,-0.3635776265880013,-0.9888559823720098,0.246963864473181,0.5024626639521756,0.6721378428669654,0.3059877458686014,0.6752461243193871,0.1123803219102238,0.9854904871758912,0.2871298548935716],\n",
       "\"x2\":[0.2652371636080013,0.1131631581337271,-0.1733968125835168,0.5542760377872187,-0.2703889703579717,-0.9738417435175094,-0.2809827368307136,-0.1447564214978481,0.0644475141005745,-0.7471536741811885,0.332666475916741,-0.0629950127731978,0.2056103583865236,0.104431654304317,0.5664840990969573,-1.0495648140565847,0.2536768616246788,-0.2761135141493472,0.3493368067208611,0.8676643347174068,0.2055937907115666,0.0304518758765982,-0.2928911688056429,-0.2616158024179665,0.1900213149619263,0.2934043184970543,0.8060121948573069,0.9423968320967548,0.907577596867593,-0.0489215573745599,0.930637571027046,-0.2892187748666321,0.844429336656185,0.1948488158933971,0.8297690521016335,-0.2754489559417776,0.282157140320302,-0.0944628476014749,-0.0528019748880543,0.1444191969206713,0.1158649987352082,-0.1704789849984286,-0.2974741355044185,0.2596553580862287,-0.2027641617249829,-0.0434929286782988,0.3391932093799026,-0.3183082963677733,-0.288523663070645,0.0647987775052138,0.2789338082152699,-0.0488722256398076,-0.3089742165004436,-0.1766179873310608,0.9813919311504312,0.054313806250125,0.4132008485723928,-0.5794157848470212,-0.8593901572362995,-0.0735025076381132,-0.0313316649966544,-0.3185376024487463,0.0028548825752882,0.3133873839500231,-0.1543853907968707,0.2923346884579976,0.1821481559658309,0.9141371084312184,-0.9479939236831424,-0.3074126972255938,-0.4451727967606284,0.9061180886253783,-0.961244110512696,-0.9415387490175388,-0.7990238398898287,-0.2849812569237476,-0.9927782125396312,-0.326874972520039,-0.3519547786095817,0.2992716624137175,0.1492036291963577,-0.0701580063265388,0.2822237614674912,-0.1350032713914082,-0.2676682878697312,0.6338425748489701,0.8213314636683493,0.071374228222408,0.2293990963664102,-0.3218270729948077,-0.1523983486914295,0.1678347760625345,0.329848569301495,0.2807041698999101,0.2663889207575099,0.4930026014881612,-0.4294227483220789,0.2409628889297189,-0.3032109150627639,0.1885781927247894,-0.7858340459964889,-0.2881436317347385,-0.1038292510027524,-0.2862002262406735,0.2667345803488641,-0.9326587946364574,-0.2508328878950195,-0.1863045714191303,0.2267168279777539,0.885600156848997,0.2812554852180505,0.8243768095351488,0.0316445653054251,-0.7052526975071733,-0.0364421064613124,0.1660010099397162,0.7505056702488455,-0.8436709163211766,0.2447071094398613,0.6293622434506109,-0.055309709190533,-0.2747254488743664,0.2078941537530653,-0.1290937577125363,0.2687823219829763,0.0965721008173242,0.9928135519228352,-0.8314617636632805,0.1415760578381452,-0.9829355688815696,-0.2364820400491719,0.3029875688692609,-0.0595324329870121,-0.2774452921869543,-0.2935479170039495,-0.0490974015633818,0.1894694880654894,0.4697479432100694,-0.5206886837766459,0.4342399538351137,0.0620052186071577,-0.2153239576271855,0.2395781255800455,0.4027291342214513,-0.1224295217819224,0.0562038333494711,0.2847614208053449,0.2120624002553139,-0.1898363688373409,-0.4616959101056157,0.2694715732725421,-0.2669432440885079,0.2803951323091155,0.08211467558116,-0.3246326917360623,-0.1271337321925787,-0.2895351405322086,0.950472901868249,-0.8964157725916333,0.3549774183177498,-0.4603256356114163,-0.7465154738508565,-0.1660962957175607,-0.4380169935922285,-0.8898627675475289,-0.1311374774677391,0.1417070106723148,0.1663066486461884,0.8167953148361392,-0.0095235722544612,-0.9034019041111414,0.5013479149132963,0.0193057050975716,0.6696041926140632,-0.295303918520277,0.2774488551784269,-0.0927824356881496,0.2435866452714153,0.1000796251540871,-0.2387288160282165,0.1632927541153124,0.2944301092100326,-0.2913801891314825,0.1938865454203878,0.2035261563280287,-0.3038105956156146,-0.2174455965212358,-0.88787958156518,-0.2456551167722853,0.337351263849312,0.9943855519133892,-0.252687700121479,-0.3597897229401163,0.2821427613941182,-0.5961680247792361,-0.2362978873313303,0.2302594858191247,-0.7220287929982037,-0.257987459459346,-0.0804895267735471,0.2950633989942162,0.0605930235590264,-0.1295032610930377,-1.0149081426645932,-0.1585202333416705,0.1332714737137881,-0.287127361103908,0.2500521866517565,-1.0043298308880506,-0.277428796746492,0.3000031191936843,0.2163388716060334,0.0615925840399506,0.3083434026428979,-0.3778923386835714,-0.2135986479806618,0.4480581494503034,-0.2878395456321349,-0.2464260642369047,0.9688001665455054,-0.2655424789582648,-1.0305363951252238,0.275753525124778,0.1191277469884441,0.0611840438748541,0.1915653316602343,0.9298796772622973,-0.1254783694711939,-0.1339539630175936,-0.1526160773157683,1.0297488807679949,0.9897052682466312,0.6415074916921967,0.2615000269976806,-0.3091487036197269,0.0302350163816744,0.2805988128870121,-0.2733440562659821,0.1794826415234645,-0.3093279739635368,0.1134173995913723,-0.4970905687789675,0.261564085708122,0.1626077890147478,-0.2466580574942165,0.2407710725892861,0.0884498270029465,-0.118339633982951,0.1966240917499239,-0.1223416090089478,-0.1633372341570794,0.1643166778324766,0.6555539069489257,-0.2900520204925202,0.2942731603551886,0.8580229092788658,-0.1195421152566914,-0.0360872403461394,0.2970512981669859,-0.166628317767195,-0.3004090898873551,-0.112126239293557,-0.3200231743175771,-0.0752193944143551,-0.8129657879997427,0.2957859542791355,0.2896901071343193,0.8362974170913913,-0.3394958334510736,-0.9260349284809012,0.2137842818015388,0.1659784702150942,-0.0398510897772519,-0.2507149196355184,0.2299739538071087,0.1002221157473969,-0.2649838078813744,0.2998338124227729,0.1389507565387186,0.7038423129759274,0.2174231129412918,0.933366060623831,-0.2275110319876126,0.92872590728421,-0.0065714413110362,-0.482338977827536,-0.1496456271841312,0.966574029842997,0.3628324359670952,0.2642473300446784,0.9633195906980324,0.2986501364800509,-0.1626190600537517,0.1672813373877119,0.3171584516646223,-0.3128440438542335,-0.0602490959944065,0.5895916340392886,-0.1799396135085032,-0.9335905261431552,0.3147636982514512,1.00246417400761,-0.6731530465719038,0.0507496470337365,-0.7414669066654699,-0.1621308727918415,-0.7521025383448041,0.2677357719576643,-0.276104778213012,0.2661629004560222,0.2878701280400499,0.1661510579035321,-0.2023198460109206,-0.2851112690344138,1.001469780276227,-0.2102596940767441,0.245358450118863,-0.9061478530200316,0.3046170421513919,-0.14881363380965,0.2790100220633915,-0.0141344505094717,0.5526428183918866,0.1662701832766646,-0.2306618865776373,-0.245813122567351,0.4766370127342835,-0.2787874290371696,0.2392816940113908,-0.0383550740950973,-0.2761092950060416,0.7852158775113091,-0.099455611182671,-0.2260036495101958,-0.1731776458366091,-0.6182104207869628,-0.3026772630273666,0.2884417140118485,-0.7155713843674615,-0.3312498821733951,0.3320536172039431,0.3511600352408377,-0.0822134525204033,0.2271930911477635,-1.0204852695788813,-0.0691698597735019,-0.2466628741814805,1.0320603776894086,0.1777886264314118,0.9470476397345172,0.1564078763545993,-0.2529476335839155,-0.076336004936729,0.3493019694211195,-0.1811909800150039,-0.1803090731838064,-0.1260494464388945,-0.2308632959799021,0.2248271887831476,-0.2770653248216471,-0.2931299506331437,0.635843549052004,-1.0045697378444245,-0.5659049003582861,-0.2357262533955062,0.4614370994168014,0.273311434563696,0.118587219414095,-0.2637955319114227,-0.0268121309511584,0.1692772329157613,0.2021543481662527,-0.2804030474667302,-0.0541371400036683,0.0063696447200126,-0.9304205467600491,0.0372752441788764,0.8856403798729975,0.2272638305910354,0.6488221762526442,-0.0628627523024925,-0.8888004572220821,-0.0078409183285302,-0.984520312808786,-0.2697883808897913,-0.2997856730203719,0.823485378116767,0.3300881082158541,0.1964150756207749,0.0553558790363879,0.2980690851606423,-0.355015123657411,-0.0425349777585416,0.1276043211385286,0.3109312399960712,0.9609590223947072,-0.2188175167404903,0.2103583670512875,0.7851632735040004,-0.3140340538447883,-0.0834602219085916,0.1443998786378355,0.3170855881024673,-0.338429109976865,0.3271079769396653,0.2223127061201793,0.1482289285775872,-0.2778402952261284,-0.1669451256665561,-0.2647235545119191,0.218420860037877,0.2795481474987075,0.3041422247816124,0.5156473067204539,0.2465070300836643,-0.821618248605185,-0.2009426599367301,0.2686834465902072,0.2363372539383906,-0.2360695683725799,-0.1034136109453093,0.2870213426163214,-0.0839259432539535,-0.107503977500807,-0.2648339261012518,0.0718299541658804,0.2207444333297746,-0.2049392497181064,0.0457053391618798,0.2042269496845669,0.656099291359555,-0.1794773640861859,-0.2795637158904581,-0.3084108384112726,0.8035417468342286,-0.9153167344937808,0.0912497361063857,0.0749652681664013,0.2386147498031222,-0.1052964593956207,0.1861128800041065,-0.1970850200641405,-0.1908431796305255,-0.5310804898479734,0.0769097357013286,0.49987766399523,0.2441430656043869,-0.2339631346850983,0.0155456251704161,0.0276393609147959,0.122124439660633,0.1917191777511752,0.2749721078363209,0.1461344435755269,-1.016300631955758,-0.1082913497205865,-0.1317298640220179,-0.9816978446102236,-0.4288694920154729,0.9081572453312404,0.0698067105678496,-0.3125449918550497,0.349398191735692,0.8769986072936069,-0.0252096746223517,-0.1503892079752793,-0.91874580348208,-0.2123864708193523,-0.1019069880844156,0.6387186344910406,-0.0282489726526054,0.9317226543911152,0.1472735900912323,-0.257989098672355,-0.2017853451802106,0.1046610297396804,0.084865786731629,0.3166946534594271,-0.631234680334425,-0.096565988202898,-1.011750418626529,-0.2779334954282108,-0.1894454416280567,-0.9663864746101728,0.9906152668790824,0.8524422049011313,0.2277065726857104,0.2457762527621466,-0.3038610338808214,-0.8801192135510619,0.275776991921881,0.1830833207549121,0.1455036994919412,0.1553142163871034,1.0042050379125596,-0.0283829575475258,-0.0609814786526115,0.9081456233806297,0.2075929420277884,0.9860770604698562,0.2975918217765686,-0.1413903129508252,-0.1053925825662132,-0.6293940047078981,0.0944239988909747,0.3090093228807242,-0.1452920980729523,-0.5926412832891327,0.0519022891343913,0.1828508491362083,-0.1146521362953152,0.2294180646572948,0.0994492849266099,0.0094435340642309,-0.0271806613372591,-0.21354532719357,-0.2112616250078151,-0.6821172613729792,0.2067738985087301,0.3244476491158019,-0.1045434906028287,0.971476021290438,0.5606707886241333,0.9847609222868632,0.0310796185058175,-0.1424086824389013,-0.0099096673441004,-0.4895100677415752,0.8324724525638058,-0.0401899353813841,0.2840204191179817,-0.9433791285685728,-0.0666796822109468,0.1247629742963294,0.0493561246078026,-0.1415852741534608,-0.2035922900838217,0.0316280401462631,0.1527230097386204,-0.2850311693519323,-0.0884680766070353,0.1503915256983017,0.1829135341693611,0.2559222218128401,0.2138250474886925,0.2524945257899367,-0.1103553622659178,0.2325478246446699,0.2609087865310237,0.3024659397862442,0.0995187892277972,-0.3293941089210255,0.1145482615669584,-0.2510091590950814,-0.2397161180529355,-0.239374229064985,-0.2699003162835192,-0.4797855755476899,-0.1161858477283507,-0.878866061058939,0.0584048118024472,0.3133681655130588,0.2248743143776836,-0.1738060974702995,-0.8129654610380758,-0.563421868887842,-0.5558886663154244,0.72929113150443,-0.6281665207107145,0.0677537646300826,-0.11306062189975,-0.0075838671051072,0.7769618658264489,-0.7472122141451947,0.9459806596408944,-0.6847423110609132,-0.7862462941523636,-0.056551371715053,0.2826330859885383,0.2520508530919407,0.2785766073574482,-0.2857460188633601,0.2711378604656053,-0.988880840231652,-0.4283729783343166,0.2635017724481946,-0.2924550699176838,-0.2409855640133859,0.1921771336558048,0.9842538561883528,0.3555733208523491,0.2614098468419544,0.3704106167855925,-0.3268086442574207,0.2737492226764254,-0.8780530718192262,0.7951294482249827,0.1967727766149597,0.2926475978558732,0.3096855895585336,0.2136076464941758,0.1896350641502877,-0.0200478445770951,-0.1565714582958781,-0.2775361277031841,0.6907479354491847,-0.1848361853790237,-0.881896287132152,-0.3340908148422124,-0.0042436327343346,0.2645934322419024,-0.2899735774444527,-0.0326737588806977,-0.9546723785093884,0.1593511972475778,-0.3161942418048143,-0.2806781099828525,-0.041206067974424,-0.2079328863918057,-0.2693299233900741,-0.2221969976031504,-0.0447734316886132,-0.116117365629255,0.0415036043297627,-0.1047914921172094,-0.2591035829963722,-0.2272823900570433,1.016759265716177,0.6132173631801704,0.5690300816254703,-0.0930262966153586,-0.2558141750483992,-0.0224102672459832,0.310978847147113,0.2120493150062609,-0.2881599491272816,0.0231179304775611,-0.1744263611700889,0.0693314058199432,0.2266381541974703,0.0558923146673146,0.4999287815716387,0.9553842694425664,-0.5899732047558268,0.0095487722825467,-0.2108582721006077,0.0367456210293098,0.9793928678087755,-0.178204178682247,-0.9290476053619524,0.7353060594609491,-0.90147812914015,0.1148654001061918,0.1265129772195935,0.9410247757458868,0.1684634395732783,0.9325301947210628,0.3647015190119308,-0.8356948481870743,0.0652117744341481,0.1782630986376816,0.1558921278947655,-0.0259693432323901,-0.0064757994649313,0.725183611946918,0.2403647330562417,-0.7766616079526695,0.1266330008347067,0.1643549203178356,-0.2748085739197935,-0.3128834801610474,0.1621356699775474,-0.1889483333798719,-0.2244363018736242,0.0707886238405757,-0.0099728359789908,-1.0079958011070105,-6.410939429346216E-5,0.8184058024512865,-0.7273276495970026,0.079228237315331,0.0467242741767208,-0.0152296816661472,0.160133558625364,0.0961289527800789,-0.1898702391479661,0.2479408902634571,0.2278134728035442,-0.4078639379727601,-0.6085429770285297,-0.9966811025533324,-0.1351723145927699,-0.2036156926588073,-0.1056347303663288,-0.2794825047021656,0.2340625936425834,0.0088671696819266,0.2795067044658136,-0.1095237184017638,-0.187469484438833,-0.8112124867681116,-1.017701983903245,-0.2027457528822268,0.3099038887314614,0.0921378712570792,-0.2226797226005271,-0.0292787328254713,-0.23238885935364,-0.165935411912929,-0.031291907129724,0.3197121213116387,0.2372081129141459,-0.1418514904035895,0.4771232901438528,-0.963569734727803,0.2170938546709517,0.3237307475420091,-0.1531497797934581,-0.9327252212614304,-0.087323559767794,-0.0357335966385338,-0.6291679830766714,-0.3275956110249621,0.2575894766855051,-0.3037540490917575,-0.3482723662043058,-0.2259531150296332,-0.3103082238784214,0.2623022026437113,0.0122954685301421,-0.2538859548391994,0.0949341281977962,0.2721124368739338,-0.1368025364058689,-0.0761014535299178,0.2636740834729899,0.2256310249540437,-0.2962289499340148,-0.200462903380645,0.0654974321974737,0.2667548932185843,0.1681405658438711,-0.2749129289226926,-0.2367229518958467,-0.1328352343367074,-0.2925748940455244,0.0341543933758124,-0.3031490840962975,-0.0129290177635334,-0.2736146434341161,0.6352680463417846,0.1131631581337271,-0.3791726260961192,0.5542760377872187,-0.6133996328354325,-0.9738417435175094,-0.6794361804879825,-0.4258164094173878,0.1541558184803269,-0.7471536741811885,0.7288510461954015,-0.0881112205849231,0.4527542036226574,0.2039076091702589,0.5664840990969573,-1.0495648140565847,0.5992462285018129,-0.2761135141493472,0.3493368067208611,0.8676643347174068,0.5459915834294432,0.0354782918299393,-0.6790438243389524,-0.6450245180249169,0.3957971284745289,0.6931201075532899,0.8060121948573069,0.9423968320967548,0.907577596867593,-0.0489215573745599,0.930637571027046,-0.6880823349708777,0.844429336656185,0.5685803928760419,0.8297690521016335,-0.6701233336249248,0.6768315180034492,-0.2370275990867751,-0.1906591441578612,0.3327007697868043,0.2394717964851871,-0.3932292315937037,-0.2974741355044185,0.5772515175453627,-0.4538407062412631,-0.0434929286782988,0.6967297790404082,-0.7144928666464339,-0.6585545458044281,0.0647987775052138,0.675779688741061,-0.1336750696086295,-0.6355099167873173,-0.4035255669817633,0.9813919311504312,0.054313806250125,0.4132008485723928,-0.5794157848470212,-0.8593901572362995,-0.177839110154072,-0.0313316649966544,-0.7123633362604284,0.0974544813847781,0.7132610596633431,-0.2827628347197543,0.6498712581185031,0.4997443154249649,0.9141371084312184,-0.9479939236831424,-0.6893585151242511,-0.4451727967606284,0.9061180886253783,-0.961244110512696,-0.9415387490175388,-0.7990238398898287,-0.2849812569237476,-0.9927782125396312,-0.7248553793125591,-0.3519547786095817,0.6930973962253997,0.3419050988370437,-0.231320580612004,0.5936086820943005,-0.1350032713914082,-0.6551015523211836,0.6338425748489701,0.8213314636683493,0.1413834518125184,0.5823155869403916,-0.3218270729948077,-0.2712149813222436,0.3516667203111296,0.7217905902551937,0.6805778456132301,0.5929246210443834,0.4930026014881612,-0.4294227483220789,0.5491681860400346,-0.6941181644900413,0.451212495025972,-0.7858340459964889,-0.638666303752284,-0.3470013700805944,-0.6681460441393307,0.6264966809754126,-0.9326587946364574,-0.6476787684208107,-0.3520548038164439,0.531693832382333,0.885600156848997,0.6431863062044584,0.8243768095351488,0.0617752875165981,-0.7052526975071733,-0.1695699242705071,0.3845587486334239,0.7505056702488455,-0.8436709163211766,0.2447071094398613,0.6293622434506109,-0.174126341821347,-0.609736664891223,0.496017763708228,-0.1290937577125363,0.6574350151488458,0.2714184074776973,0.9928135519228352,-0.8314617636632805,0.3684836374888477,-0.9829355688815696,-0.4991163423503545,0.3029875688692609,-0.1046749869364045,-0.5655689021421171,-0.2935479170039495,-0.0591494397407166,0.4444390839649652,0.4697479432100694,-0.5206886837766459,0.4342399538351137,0.2139168568158781,-0.5137004157968584,0.5445551299846246,0.4027291342214513,-0.3151309914226086,0.1063371267751927,0.6709140763386545,0.4784671472290146,-0.4814238198059055,-0.4616959101056157,0.6175450751403524,-0.5845394035476421,0.6792586924133611,0.1961223805691505,-0.7144434408506932,-0.2411414371805692,-0.6131419382821875,0.950472901868249,-0.8964157725916333,0.3549774183177498,-0.4603256356114163,-0.7465154738508565,-0.4287305980187433,-0.4380169935922285,-0.8898627675475289,-0.3014491940937682,0.3474828241849174,0.3848643873398961,0.8167953148361392,-0.1235312772424516,-0.9034019041111414,0.5013479149132963,0.084360571175525,0.6696041926140632,-0.694798701162684,0.6672596042930578,-0.1824907400679021,0.6076290335454136,0.256629091888968,-0.2387288160282165,0.3860430007105875,0.674852715728094,-0.6893605959240026,0.3909774820397045,0.5909594207794813,-0.6757211899709151,-0.5191461488156773,-0.88787958156518,-0.5750681558236562,0.7320256415324592,0.9943855519133892,-0.5762944978714579,-0.7369859372972621,0.6640885792927753,-0.5961680247792361,-0.6355085787026389,0.5679906560199307,-0.7220287929982037,-0.5957186296601521,-0.1896703009804772,0.6824966634456686,0.1306022471491367,-0.2860527278279187,-1.0149081426645932,-0.1585202333416705,0.2944340479992532,-0.6423819406293259,0.6098142872783049,-1.0043298308880506,-0.6762923568507375,0.6909103686209617,0.5180394239004749,0.1266474501179039,0.7067968463001668,-0.3778923386835714,-0.518575652385241,0.4480581494503034,-0.6539360146805019,-0.6145188031832527,0.9688001665455054,-0.6489511945652151,-1.0305363951252238,0.6051665641761489,0.2802903212739092,0.1703648180817841,0.4307273248832419,0.9298796772622973,-0.3355482214557121,-0.2812037840914648,-0.3583918908283709,1.0297488807679949,0.9897052682466312,0.6415074916921967,0.6275964960460477,-0.3091487036197269,0.1345716188976332,0.6594381348849098,-0.616354718743443,0.3895524935079827,-0.706173854489328,0.1134173995913723,-0.4970905687789675,0.6370576287696716,0.4214301736425255,-0.6413324351773637,0.5912937446068315,0.1683338192087093,-0.2419464317329299,0.1966240917499239,-0.1223416090089478,-0.5114107360248897,0.4153932223487568,0.6555539069489257,-0.6900204381740467,0.6731124823530863,0.8580229092788658,-0.1195421152566914,-0.1110397661804293,0.2970512981669859,-0.3680775984214993,-0.6958697877825207,-0.112126239293557,-0.6988624963154747,-0.1452286180044655,-0.8129657879997427,0.6952807369215426,0.6805973565615967,0.8362974170913913,-0.7281485266169432,-0.9260349284809012,0.2137842818015388,0.3674277508693986,-0.0348246738239109,-0.4817440010044255,0.5283504119767816,0.2380792850172037,-0.6027149780821803,0.6735653894054177,0.3047009889360322,0.7038423129759274,0.468499657457572,0.933366060623831,-0.5121253028713267,0.92872590728421,-0.0065714413110362,-0.482338977827536,-0.328998913620144,0.966574029842997,0.7547744569207939,0.578762702899326,0.9633195906980324,0.6820588520870012,-0.3936481414226588,0.451895608271426,0.7171268693461488,-0.7123388264966405,-0.1053916499437991,0.5895916340392886,-0.4463443604822039,-0.9335905261431552,0.7076785985429266,1.00246417400761,-0.6731530465719038,0.1550862495496953,-0.7414669066654699,-0.1621308727918415,-0.7521025383448041,0.5942714722445379,-0.6690196785044875,0.6465855069740836,0.6084969219884006,0.3319012903008456,-0.51370476663773,-0.6699223376688481,1.001469780276227,-0.5308864880250946,0.5803696661357197,-0.9061478530200316,0.6894281107858262,-0.3370952066757831,0.6471027610097395,-0.0442651727206448,0.5526428183918866,0.4013842841936539,-0.5710596792955139,-0.6055752231938996,0.4766370127342835,-0.6317039196111509,0.5203416819309304,-0.0182573468231895,-0.6760777126875681,0.7852158775113091,-0.2467054322565422,-0.5812582290356135,-0.4163497649144513,-0.6182104207869628,-0.6707700019737147,0.6340110808889826,-0.7155713843674615,-0.7067434252349447,0.7139994351026003,0.7409707843554686,-0.2387629192552843,0.501011933519239,-1.0204852695788813,-0.1735064622894606,-0.5548681712917962,1.0320603776894086,0.3878584784159301,0.9470476397345172,0.3534988129739159,-0.5643325542107249,-0.199942802686708,0.3493019694211195,-0.4761962269582735,-0.4154231741007957,-0.259177264248089,-0.6195159891457717,0.5094414596668618,-0.2770653248216471,-0.6735525571512051,0.635843549052004,-1.0045697378444245,-0.5659049003582861,-0.4906958492949821,0.4614370994168014,0.5846963551905053,0.2082955237938474,-0.6426348539093204,0.0133325549893275,0.4003063142846684,0.4492981934023864,-0.2804030474667302,-0.0440851018263333,-0.0437636487057089,-0.9304205467600491,0.0322488282255356,0.8856403798729975,0.2272638305910354,0.6488221762526442,-0.1328719758926028,-0.8888004572220821,0.0373016356208622,-0.984520312808786,-0.5904151748381419,-0.6989963643916804,0.823485378116767,0.7275326324238575,0.4880025265893395,0.1104719953102431,0.6918948189723244,-0.355015123657411,-0.1026252134068443,0.2559817650614124,0.7083757642040746,0.9609590223947072,-0.5888483994742736,0.4535304861291296,0.7851632735040004,-0.6877656308274331,-0.148515087986545,0.2916496997117067,0.7162962794737758,-0.338429109976865,0.7200228772311408,0.4997740284453013,0.3275822150136001,-0.6497508895814289,-0.3683944063208605,-0.6287659427859174,0.5956170743950229,0.6414789684851153,0.7009881053074036,0.5156473067204539,0.618417624438965,-0.821618248605185,-0.4360567608537194,0.6167569484580175,0.5101560963098661,-0.5505849412272275,-0.1034136109453093,0.6718324112507557,-0.2264906947392539,-0.2732542098981207,-0.2648339261012518,0.1810107283728105,0.5224449856242162,-0.4599088456175822,0.1057955748101826,0.5187423225392145,0.656099291359555,-0.4496104873345956,-0.6060994161773318,-0.6839043814728223,0.8035417468342286,-0.9153167344937808,0.0912497361063857,0.1000814759781267,0.5790125425209989,-0.1900993033644425,0.4844893381737794,-0.4709038624356158,-0.4177507592812281,-0.5310804898479734,0.2472214523273576,0.49987766399523,0.576381425282712,-0.525550585653663,0.0656789185961378,0.0877295965630988,0.3490320193113356,0.4466887736506511,0.6711566781149815,0.3388359132162131,-1.016300631955758,-0.2876446361565994,-0.3788737092581516,-0.9816978446102236,-0.4288694920154729,0.9081572453312404,0.0698067105678496,-0.709989516063053,0.349398191735692,0.8769986072936069,-0.0302360905756927,-0.4014657524915594,-0.91874580348208,-0.5446248304976774,-0.2538186262931361,0.6387186344910406,-0.0883392083009084,0.9317226543911152,0.1472735900912323,-0.5874021377237258,-0.440947338403218,0.2186687347276708,0.2274305382169293,0.7028473089927366,-0.631234680334425,-0.2714122948632713,-1.011750418626529,-0.6235028623053448,-0.4595785648764665,-0.9663864746101728,0.9906152668790824,0.8524422049011313,0.4668685659087179,0.5887869152396076,-0.6636231345073698,-0.8801192135510619,0.675776991921881,0.3624366071909251,0.2927535205658123,0.1553142163871034,1.0042050379125596,-0.1033354833818157,-0.0609814786526115,0.9081456233806297,0.4507650611056306,0.9860770604698562,0.6930525196717342,-0.4077950599245259,-0.2757042991922421,-0.6293940047078981,0.2692703055513479,0.3090093228807242,-0.3291240423215474,-0.5926412832891327,0.1268548149686811,0.3666827933848035,-0.3332098749890228,0.2294180646572948,0.2513609231353303,0.0245196071322048,-0.0822967776111142,-0.4981595980772841,-0.488722947332937,-0.6821172613729792,0.5303806962587091,0.7233112092200475,-0.2329209345257125,0.971476021290438,0.5606707886241333,0.9847609222868632,0.0109818912339097,-0.3306902553050343,-0.0099096673441004,-0.4895100677415752,0.8324724525638058,-0.120073927587147,0.6839888367995082,-0.9433791285685728,-0.1758604564178769,0.1247629742963294,0.0844966032280998,-0.3386762107727775,-0.4624146747115993,0.0767705940956557,0.3092724764735013,-0.6331046712197426,-0.1830676754165251,0.3647222436899004,0.4911188312796768,0.5509274687561097,0.4448541288575995,0.5406181357450994,-0.3691777468936955,0.5136078125642095,0.5845155842810026,0.6779594828477937,0.174471315062087,-0.725578679199686,0.2524054308367652,-0.5655245319497291,-0.4868599632890693,-0.5377506872346578,-0.6049115323003758,-0.4797855755476899,-0.1161858477283507,-0.878866061058939,0.0483527736251122,0.6563788279905197,0.5455011083260343,-0.3708970340896161,-0.8129654610380758,-0.563421868887842,-0.5558886663154244,0.72929113150443,-0.6281665207107145,0.2008815824392772,-0.1929446141055129,-0.0327000749168325,0.7769618658264489,-0.7472122141451947,0.9459806596408944,-0.6847423110609132,-0.7862462941523636,-0.096696057655539,0.6712857791544079,0.6500312598844609,0.2785766073574482,-0.6786609191548355,0.6392305994119534,-0.988880840231652,-0.4283729783343166,0.6012329426490007,-0.6923287456310038,-0.6029163849997936,0.41492738025108,0.9842538561883528,0.3555733208523491,0.552997297810519,0.3704106167855925,-0.7266823199707407,0.6509454370335712,-0.8780530718192262,0.7951294482249827,0.4594070789161423,0.6566899861298715,0.7088962809298421,0.583638529227959,0.332199815635588,-0.0851027106550485,-0.3957334515188855,-0.6547323420603299,0.6907479354491847,-0.4075864319742989,-0.881896287132152,-0.7249980642694898,-0.0193197058023083,0.6306899012902695,-0.6896893665006882,-0.067814237500995,-0.9546723785093884,0.3608004779018821,-0.6617636086819484,-0.6544096869654973,-0.0913393614001457,-0.4889928743113453,-0.6647906212852398,-0.5727196696206958,-0.1344817360683654,-0.2539745348990617,0.0966197206036179,-0.2042674469831512,-0.6252000520447393,-0.2272823900570433,1.016759265716177,0.6132173631801704,0.5690300816254703,-0.244937934824079,-0.6133507447089047,-0.1218862221119252,0.7064395450422786,0.4821824382546707,-0.6743126046605912,0.0331699686548961,-0.3844962131546072,0.163931004629433,0.4967712774458801,0.1747089472981285,0.4999287815716387,0.9553842694425664,-0.5899732047558268,0.0943516162513686,-0.5190635692109232,0.0718860996496071,0.9793928678087755,-0.178204178682247,-0.9290476053619524,0.7353060594609491,-0.90147812914015,0.1148654001061918,0.2501197749695724,0.9410247757458868,0.4035775404902676,0.9325301947210628,0.7631549626691997,-0.8356948481870743,0.15001461840297,0.4557244209628037,0.4147145125225431,-0.041045416300364,0.0186404083467938,0.725183611946918,0.2403647330562417,-0.7766616079526695,0.2969447174607358,0.3786856383094343,-0.6722530981277969,-0.7128834801610474,0.295263487786742,-0.4906488856743132,-0.6092473705080585,0.1506726160463385,0.010124891292917,-1.0079958011070105,-0.0301948316054665,0.8184058024512865,-0.7273276495970026,0.079228237315331,0.0065795882362347,-1.536085981734E-4,0.4265383055990647,0.2844105256462119,-0.4636890815194416,0.6008573808374384,0.5628246888204009,-0.4078639379727601,-0.6085429770285297,-0.9966811025533324,-0.3495030325843684,-0.5358540523371323,-0.1607508466401841,-0.6733082385138478,0.2340625936425834,0.0088671696819266,0.2795067044658136,-0.270686292687229,-0.4755930943939957,-0.8112124867681116,-1.017701983903245,-0.520341912341361,0.7096196777876971,0.2109545038878932,-0.4412374612942346,-0.0292787328254713,-0.5273941062969096,-0.3586368815536151,-0.0312919071297239,0.7176925281041587,0.6091187072694465,-0.4193128127287115,0.4771232901438528,-0.963569734727803,0.5676165266884972,0.7232255301844162,-0.3674804977850568,-0.9327252212614304,-0.1819231585772839,-0.0708740752588311,-0.6291679830766714,-0.726049054682231,0.6128440562109229,-0.6956960700454562,-0.7479881552605415,-0.5663509077475101,-0.7022502448321202,0.557307449586981,0.0524401544706281,-0.6114225244997049,0.2233115721206799,0.6273670163993517,-0.3206344806544641,-0.0961991808018256,0.6470827990799403,0.5550440640054146,-0.6836622143854673,-0.5623937243670528,0.1649733870634157,0.5989932528969094,0.1681405658438711,-0.6553355354407541,-0.5416999563004257,-0.3076815409970804,-0.6566172823195227,0.0642851155869855,-0.6929598332109284,-0.0129290177635334,-0.6265311340080972]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"x1\",\n",
       "\"y\":\"x2\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"x1\"\n",
       "},{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"x2\"\n",
       "}]\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"minimal\"\n",
       "},\n",
       "\"guides\":{\n",
       "\"x\":{\n",
       "\"title\":\"First dimension\"\n",
       "},\n",
       "\"y\":{\n",
       "\"title\":\"Second dimension\"\n",
       "}\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[],\n",
       "\"spec_id\":\"4\"\n",
       "};\n",
       "               window.letsPlotCall(function() {\n",
       "       \n",
       "               var toolbar = null;\n",
       "               var plotContainer = containerDiv;               \n",
       "               \n",
       "                   var options = {\n",
       "                       sizing: {\n",
       "                           width_mode: \"min\",\n",
       "                           height_mode: \"scaled\",\n",
       "                           width: width\n",
       "                       }\n",
       "                   };\n",
       "                   var fig = LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer, options);\n",
       "                   if (toolbar) {\n",
       "                     toolbar.bind(fig);\n",
       "                   }\n",
       "               });\n",
       "               \n",
       "               break;\n",
       "           }\n",
       "       }\n",
       "   });\n",
       "   \n",
       "   observer.observe(containerDiv);\n",
       "   \n",
       "   // ----------\n",
       "   })();\n",
       "   \n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x330488e90>"
      ]
     },
     "execution_count": 7,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# Open the circles data\n",
    "circles = pd.read_csv(\"../data/circles-data.csv\").drop(\"label\",axis=1)\n",
    "\n",
    "# Plot x1 and x2 features in circles data\n",
    "(\n",
    "  ggplot(circles, aes(\"x1\", \"x2\")) +\n",
    "  geom_point() +\n",
    "  theme_minimal() +\n",
    "  labs(x = \"First dimension\", y = \"Second dimension\")\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Find the optimal number of clusters"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"b68Dqu\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "   \n",
       "   (function() {\n",
       "   // ----------\n",
       "   \n",
       "   var containerDiv = document.getElementById(\"b68Dqu\");\n",
       "   var observer = new ResizeObserver(function(entries) {\n",
       "       for (let entry of entries) {\n",
       "           var width = containerDiv.clientWidth\n",
       "           if (entry.contentBoxSize && width > 0) {\n",
       "           \n",
       "               // Render plot\n",
       "               if (observer) {\n",
       "                   observer.disconnect();\n",
       "                   observer = null;\n",
       "               }\n",
       "\n",
       "               var plotSpec={\n",
       "\"data\":{\n",
       "\"k\":[1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0],\n",
       "\"inertia\":[3000.0000000000005,1977.5847008543194,1274.5021479546754,951.3887314671811,783.6483543278556,604.3459700953697,503.0610059943844,432.00315073365397,384.70878827377]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"k\",\n",
       "\"y\":\"inertia\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"type\":\"int\",\n",
       "\"column\":\"k\"\n",
       "},{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"inertia\"\n",
       "}]\n",
       "},\n",
       "\"guides\":{\n",
       "\"x\":{\n",
       "\"title\":\"Number of clusters\"\n",
       "},\n",
       "\"y\":{\n",
       "\"title\":\"Inertia\"\n",
       "}\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "},{\n",
       "\"geom\":\"line\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"linetype\":\"dashed\",\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[],\n",
       "\"spec_id\":\"5\"\n",
       "};\n",
       "               window.letsPlotCall(function() {\n",
       "       \n",
       "               var toolbar = null;\n",
       "               var plotContainer = containerDiv;               \n",
       "               \n",
       "                   var options = {\n",
       "                       sizing: {\n",
       "                           width_mode: \"min\",\n",
       "                           height_mode: \"scaled\",\n",
       "                           width: width\n",
       "                       }\n",
       "                   };\n",
       "                   var fig = LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer, options);\n",
       "                   if (toolbar) {\n",
       "                     toolbar.bind(fig);\n",
       "                   }\n",
       "               });\n",
       "               \n",
       "               break;\n",
       "           }\n",
       "       }\n",
       "   });\n",
       "   \n",
       "   observer.observe(containerDiv);\n",
       "   \n",
       "   // ----------\n",
       "   })();\n",
       "   \n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x324e31e50>"
      ]
     },
     "execution_count": 8,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# Create a data frame with the k range and associated inertia scores\n",
    "inertias_df = pd.DataFrame({\"k\":range(1,10), \"inertia\": [find_optimal_cluster(k, circles) for k in range(1,10)]})\n",
    "\n",
    "# Plot the output\n",
    "(\n",
    "  ggplot(inertias_df, aes(\"k\", \"inertia\")) +\n",
    "  geom_point() +\n",
    "  geom_line(linetype = \"dashed\") +\n",
    "  labs(x = \"Number of clusters\", y = \"Inertia\")\n",
    "\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Run the model"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Instantiate model\n",
    "kmeans_model = KMeans(n_clusters=4)\n",
    "\n",
    "# Fit to the data\n",
    "_ = kmeans_model.fit(circles)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Plot the results"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"I8VnSL\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "   \n",
       "   (function() {\n",
       "   // ----------\n",
       "   \n",
       "   var containerDiv = document.getElementById(\"I8VnSL\");\n",
       "   var observer = new ResizeObserver(function(entries) {\n",
       "       for (let entry of entries) {\n",
       "           var width = containerDiv.clientWidth\n",
       "           if (entry.contentBoxSize && width > 0) {\n",
       "           \n",
       "               // Render plot\n",
       "               if (observer) {\n",
       "                   observer.disconnect();\n",
       "                   observer = null;\n",
       "               }\n",
       "\n",
       "               var plotSpec={\n",
       "\"data\":{\n",
       "\"x1\":[-0.1385234304379497,-0.968404878770772,0.2367122400692957,-0.8116432101298103,-0.1989328276846431,0.1562865006930383,0.0418799638221204,-0.234075069268132,-0.2791532938102485,0.6777068447254445,-0.1103164242844411,-0.3059735909635604,0.236909501962332,0.3392661048637714,-0.8174875761231151,0.2694949165160713,0.1881777130201391,-0.9517849323685644,-0.9354595052839584,-0.4900470062659255,-0.1595283266954398,0.2972496191943019,0.018101721084598,-0.0702451122816901,0.2926071500699811,-0.0077971267627824,-0.556345415179456,0.2727516407949819,0.3588624567451891,-0.9275324468001211,0.4070805128934966,-0.0099149661386284,0.3915481254883153,-0.0914228820295895,0.5568286456708167,0.0294298516101975,-0.0478517395521724,0.2421612596128086,-0.244605853816717,-0.2693045202222509,-0.3497641513762519,-0.232645615164422,-0.952521555253614,-0.2113184648650455,-0.2065585494361429,0.9825253087307356,0.1389748868262583,0.0660676940549479,0.1147984261855755,-0.9957867662800096,-0.0685288220083554,0.2954591437452022,0.1465467675073756,0.2665348147202847,-0.0345529929348901,-1.0056808667851926,0.9785656522339176,0.7831483757961263,-0.545033496554271,-0.3133949440447747,-1.029966844406068,0.1433343572413716,0.2866543649083677,-0.0317319389324139,0.2757281302046473,-0.0956636935884884,0.1729447541382895,-0.3969869348461352,0.2008646892693458,-0.0628612753383157,-0.8967901642193171,-0.4119444682544819,-0.1847258071316249,0.268930942736871,0.6174700682867629,0.951558505938648,0.0368723308533419,0.017909392351217,0.9363336815076668,-0.052040849025586,-0.2373288848444096,-0.2625045768510721,-0.1933961316655393,0.99468634061051,0.0888711962326175,0.8118057050296555,0.5428003709268114,0.3109444730143115,0.1541626302293454,0.9461645356719848,-0.2785657995173437,0.2484591226325496,-0.0010375311657842,-0.0081149062065542,-0.1554774300095328,-0.8431742590377078,0.8768496699399508,-0.1752182335470386,-0.1368912659662658,-0.2156320944370024,-0.7115498917632788,-0.1309104590881496,0.2111858100802197,0.1179473970125769,0.1445131385691795,-0.3426054612066069,-0.0434535102213614,-0.3061116659979073,-0.1717628078880773,-0.4986109153379811,-0.1204944728103138,-0.6851424401320018,-0.2806441968808778,-0.709423824654942,-0.2511548935355158,-0.2602342494941747,0.7485618060607664,0.5682912166172756,0.952319821343578,-0.783032829847297,0.2963783585240289,-0.2139941108125244,0.1878970439803911,0.967215856973874,0.0607521903251049,-0.243743643580321,0.1797270637757366,0.5172518436561979,-0.2270026320470816,0.3305688350788389,-0.2317967886000417,0.9457263940376598,0.2645786706948564,-0.1630364745694128,0.9954842048547822,0.3359013488637598,-0.2439907696142858,-0.8663029459878253,0.8929349969605112,-0.8622263476689399,-0.229159395809796,0.1727534048016044,0.1847864097917901,-0.929258669605182,0.2788222421729484,-0.2890456876692325,0.070612010505883,-0.2386969743092462,0.2103158289049959,0.9297879163722031,-0.1361139558303136,-0.1729538280734344,0.0265051909214146,-0.2569896933451047,-0.0560250582267893,0.309452147733206,0.1165203117253023,-0.1353851406625731,0.4672849615454277,-0.9614946430628382,-0.8596603536498789,0.6855381839573991,0.235492369177217,-0.9149504118553272,-0.4320624357453775,-0.2572714692018278,-0.2770231031182066,0.2174064476174789,0.5520296229140162,-0.2986750814168907,-0.2122121303986662,-0.919824049103648,0.2803887030153897,-0.7412017550335901,-0.0227292495679937,0.0328707576552672,-0.2599484094374302,-0.1012508986802072,-0.2589911277133656,-0.9721495522587272,-0.255665910713144,0.0755462508437808,-0.0111057147731749,0.2671712539142701,-0.0733161147152511,-0.1220718092646662,-0.2620300026221732,-0.45187714098771,-0.1302253370442017,0.0262748294558733,0.281440575851569,-0.201006020508358,0.1674044245528351,-0.07759791876031,-0.7808154562185049,0.019259429427906,0.1469610805524063,-0.6998192377652053,-0.1519638650170033,-0.3087517672749177,0.0768214610591858,-0.2895717869074933,-0.295674474298057,-0.0128035222042246,-0.9526397493413844,-0.2959259843206596,-0.1389338905923149,-0.1278931536688877,-0.059119117021386,-0.0618990395527633,0.0305940025459174,-0.2166065227007334,-0.2446527461868317,0.0242592435075139,-0.8919384305645286,-0.1565624578759386,-0.9267159313414686,-0.1205231841335554,0.1143114210952407,0.0835979974346431,0.1269357937068478,0.1438309826086942,0.1492461359336777,0.2339331251295731,0.307173926389369,0.3015374291838182,-0.2524063665116942,0.2260689628471303,0.285776413992703,-0.2554388301316829,-0.0633947685911547,-0.0520928082840772,0.7506486615307003,0.0973979944303854,0.9603707079528646,0.244236319278521,0.0656572307074492,0.1513813024724465,0.2727189272517276,0.0617791790546635,1.0319500897237133,0.9535442258249034,0.1159219333595456,0.2920651943746812,-0.0423096793316379,-0.1094746295847633,0.2773613107187705,-0.2823902067674736,-1.0342932056316818,-0.9966179135352626,-0.1522701336822554,-0.2237263933359271,0.7825010299658266,-0.0205410799752592,-0.0920946079310479,0.4880459764882904,-0.9621877717907642,-0.2747841503567565,-0.9211090771223024,-0.2680514044019541,-0.0424786731502672,-0.9759227103721552,0.0931600005271127,-0.2767699186921158,0.4833185137925599,0.0329937927999215,-0.0369265173389767,0.5362850505013546,0.0415430581699844,0.4386418992445642,1.007143828728354,-0.2655499938501351,-0.3355125561541497,-0.22004831891769,0.2090513957633389,-0.2369876816565132,0.1497335287608705,0.0762749047424607,0.262594831682373,-0.7312902227561765,0.2468292874100151,-0.416695228057896,0.2126765863927177,0.3467433930749246,0.2738751994417496,-0.8468271361832991,0.2585182283680209,0.1269668725871344,0.0281925929771764,0.1713775129940706,0.1875913591568772,0.1312300966224205,0.2557653558357532,0.198162671662213,-0.0265555224576158,-0.0158922879154333,-0.3033427842244655,0.8287446708849951,0.2338039037019024,-0.358653057773823,-0.0694072671488604,0.0702777562333065,-0.7015129353392298,-0.3100170370378283,-0.6807283196234142,0.9997251461455788,-0.7355142937294711,0.1553701071355268,-0.0826349134367788,-0.1054246891678987,0.1699716517358936,-0.3088524003154511,-0.1652009895809198,0.0571380908418484,0.232627919980537,-0.1585385662119197,0.2245090569808719,-0.4744773498248544,-0.1185769886504174,-0.2427846234659564,-0.0708168236481903,-0.3211265760412773,0.8048484088990872,-0.2501781788207414,0.1929554775659887,-0.0903248052094329,0.9103361075534347,-0.1637735214054645,0.2458662669660795,0.3646426688371993,0.0399614328647831,-0.5724228443825059,-0.3195230765430936,0.2157374376333453,-0.2039920176585973,0.7548841342909611,-0.0828265335296252,-0.1434333481310609,0.763762479176805,-0.1353156903554065,0.0727799134577408,-0.0742137733906372,0.2609679797741085,-0.2517775925270532,0.1659419198354751,0.2683074475389219,-0.1680800314241699,-0.1047476949117219,-0.289320156858102,-0.2222671356375418,-0.2501546070666143,0.1412219402848953,0.2627600006221074,0.928524276911942,0.182698137147228,-0.2476655186683797,0.2702020548040014,-0.0691127997875169,-0.1754735995920879,-1.0080183605813786,-0.0771211637192359,0.7571040681341497,-0.2516468870231406,0.8408097773234195,0.2232486196877526,-0.8151951121768007,0.1737237120650531,0.282187832165285,-0.0854576094362201,-0.2846315841575234,-0.247760171480601,-0.2489434969035713,0.9359928481470016,-0.3184276064053256,0.2780956955117652,0.3593078001282489,0.3464318685537267,-0.5306809422988833,-1.0140521453239366,-0.7404622088395693,0.3304868235001911,-0.5044513439820726,-0.3241633079759849,0.0247693429231923,0.1526058298680864,-0.0413855724251043,-0.639844432871609,0.078594594796724,0.1963993229360476,0.2316010422356015,0.0478157733234298,-0.9444019886054532,0.3084864306993309,0.276188691543865,-0.0077337874430667,0.1545653165760284,-0.1728553254128005,-0.2251287125382435,-0.614315207189044,-0.1372980662533991,-0.2993470316243778,0.2919630774114096,-0.0033792097852051,-0.9762381592208784,0.0240245554313452,-0.1639346029578446,0.2941649638616872,0.0522233380355403,0.2408065470951337,-0.0496471926621285,-0.1016302006257871,0.1035403272577982,0.0991342373848368,0.8130166458240975,0.0590314801582622,-0.5698784072524513,0.173491974008791,0.09282367661897,0.1865315360906637,0.2399089840710199,-1.0274187414969955,0.1051030276521082,-0.2951828114905452,0.2701473612686966,1.0067430590541928,-0.2780563393397526,0.1999889877471789,-0.2101098512134586,0.2893884170363056,-0.2014184832200256,-0.7811556134662724,-0.2419118146130908,-0.2469059605365172,0.1299723387510945,-0.6349043578159463,0.3577216733397898,0.9892913066641996,0.2815115065893698,0.1101039196644467,-0.2990603645882504,-0.1665950012358033,0.2151831150071114,-0.2634079878963455,-0.872701433606142,-0.2584667939331593,0.9130622018270764,0.1822193110457124,-0.2026757929289422,0.3296253723607074,-0.2957349048389931,0.2426537184815384,0.2196192862164607,0.0194419607894327,0.2838893965462531,0.0673594220392598,-0.2889713580299942,0.2898774923323535,0.2099808320938593,-0.9076812600775116,-0.4826357037325296,-0.9806322467983823,0.0366652105965166,-0.944768494943647,-0.4794425281092463,-0.2446399039688192,0.2449608564532175,-0.2442262844874063,-0.1665525033004358,0.2191795134362961,-0.7723072317119826,-0.273680018685718,-0.3189107027620051,0.9706294106731842,0.1633909902353295,0.2125178258060883,0.3308937475192985,0.2797034411102999,-0.080049110429213,-0.7368844693265978,-0.1939120234698752,0.0960467159500105,0.1559621092690796,0.2736952655741569,-0.0739232592964769,0.2984033567248106,0.6032217461717146,-0.2324744943344396,-0.1533683478630272,0.1327833364518977,0.5052238465804747,-0.0374998435501213,-0.2625289616650838,-0.2897987335147298,0.9893031769576068,-0.3154414067518175,0.2685765837671198,1.0119031003512942,0.3926914283093114,0.1964398440712108,-0.1818980214894232,-0.0486876206532493,-0.2561359663333503,0.3127764766709273,0.8352397396667975,0.2560847903909042,1.0271755359957966,0.2648894389219105,-0.8069033899887501,-0.2852804963466216,-0.2357006850682213,-0.1915082235262562,-1.014816072023465,0.3232186119328753,0.3248129964474673,0.3073252291718696,-0.2128921527608318,0.274715475968089,0.7235839815889867,-0.2121437035965687,0.0494289136960012,-0.2974331000568898,-0.2209840217785891,0.8124138416081572,-0.3646523324171764,0.2690827112807456,0.2544845456019077,-1.0072989783013135,0.8359224851409064,0.4936735407761751,-0.2289769588127978,0.0498610001309933,0.4466030222617423,0.2380142463204957,1.0336909657159474,-0.2716295973518515,0.2614953885022163,-0.277445305407101,0.2648714982454507,0.1830185504165012,0.1264543801950012,0.2565709451803408,-0.2462293047479328,0.227304640305774,-0.1937629854358601,0.243582662193687,-0.2090765909940639,0.2401931885494654,-0.2103285075427028,0.185252602787424,-0.1066693389905974,0.3139566544041806,-0.0727914756942635,0.2903717241461807,-0.2272296190307125,-0.2672343331192347,-0.2016477056085781,0.1363512446565452,0.9063183735064678,0.9720894997832696,-0.4432640831438624,-0.2591162598963109,0.1895019310156389,-0.1912847583582667,-0.2110829528563644,-0.6031511285084189,-0.8289398366808465,0.8452322158858073,-0.6982147293460435,0.7134656248336756,-0.2824297911897867,0.2919362017419363,0.303525342081807,0.6791653120568293,0.6232789147017476,-0.2433895216335896,0.666989640026438,0.5905926340143132,0.2748065621739277,-0.0666484961745779,0.0581288226349481,1.0164738813571057,0.102533531557135,0.0975442583808523,0.2600053963564839,0.9477942706980088,-0.1312244941210046,0.0142098607368106,-0.1287277172902274,0.2587165629064178,-0.0392819496064969,0.9894208889083764,-0.2303754789265607,0.9110382175889622,0.0026976763754824,0.0855041320588824,0.4034359137412558,-0.618980822674548,0.2187396801002969,0.1227946507389817,0.002238227312223,0.124761874517136,-0.272830303898087,0.3096937471726819,-0.2425434929175533,-0.1016433818875407,0.7068166927231019,0.260462617523079,-0.3779413623294649,0.0157880789215005,0.2643228102133578,-0.1228310428143801,-0.0217871757393988,0.2921830138717942,0.2686607838426416,0.2349306389039006,-0.1169757159477485,0.127689995510136,-0.2729585387171457,0.2255888302909137,-0.0163536026559523,0.1215000309103625,0.3269921007325545,0.3050090930669475,-0.3239815367794843,0.3219645533442101,0.1528473759180416,-0.9810409583251972,0.0848749714184419,0.7923509131395182,-0.7912583180656771,-0.3222116806483267,-0.1591297452117782,-0.3178149764899974,0.0632976121053907,0.2484822537932069,-0.0733512348213416,0.2565594154905227,-0.2711563768748005,-0.2792643703747319,-0.1953538331745301,-0.2977296780852061,0.8585256728675684,-0.0635884342637367,-0.8226819037486809,-0.2887779604287342,0.1742623862984751,0.3099086945282433,0.2205434726646344,0.980526013320548,-0.3339687804517109,0.6623272512110318,-0.223645693533557,-0.9634528117589096,0.3530202221728791,0.4182336702340584,0.2591836688074864,-0.3477753675742409,-0.0152469803664412,0.6079732494520961,0.2987441252484457,0.2304092462972853,-0.2021529561617544,-0.2829521293742039,-0.3449006851047188,0.6098815197645558,1.027407747163033,-0.660472346532067,0.2494283329140437,0.2424442397352634,-0.0176438583648665,0.0397605648841977,0.273897061679425,0.1873149641781564,-0.0660913563715643,-0.281445464058554,-0.3362869478876946,-0.0860631126659446,0.3471702806135713,0.5764806847498569,-0.7484960110020671,0.9682293278782568,-0.3134477874574476,-0.3053184526946665,0.202421243526702,0.3033458080892134,-0.1928442367642441,-0.1851994665195947,-0.1315245376354039,-0.8992927377044504,0.7741411952129615,-0.1579625837187375,0.2409294564713739,0.1685222962395413,-0.2580957494238489,-0.0497220947236745,-0.9421691120875696,0.9847598487670522,-0.9709107319210852,0.3021672804206495,0.1948269164803593,-0.5394557922749162,-0.0984001447749432,0.2405487859048737,-0.0453679499375168,0.3064578959887092,0.2051722353158377,0.9846014570678712,-0.1710000829293804,-0.337069301830705,-0.3122248793261121,-0.0641135000602808,-0.16265115411139,-0.2668360759743786,0.8555913440674121,-0.3040670931042752,0.1137514941753848,0.0036210061680852,-0.2736408370327245,-0.4033012804017144,-0.2315277783431498,-0.3286329083885775,-0.7950734076818805,-0.0951041689664277,-0.2340018489016148,-0.0542455995425817,0.0407281223457891,-0.1133911717619168,0.0397792928176397,0.2198895355057977,0.3587008418590788,0.1195748106317213,-0.2715079091354311,0.0950581093507428,-0.2597029805132124,-0.3094222828563848,-0.0657080446465774,-0.1444274825164247,-0.0724635044554179,0.1756011314790994,-0.2512237395078328,-0.1408273799927261,-0.9888559823720098,0.1233570667232021,0.2436402793243978,0.312375742240417,0.1402375134712878,0.2763825642151415,0.0226720175304713,0.9854904871758912,0.0988482820274384,-0.2904350686466702,-0.968404878770772,0.5797229025467567,-0.8116432101298103,-0.4047086411972457,0.1562865006930383,0.0770204424424176,-0.518689340151846,-0.6689640429248794,0.6777068447254445,-0.1654325405582963,-0.705184282334869,0.5514248748169797,0.7266993693152238,-0.8174875761231151,0.2694949165160713,0.3896269936744435,-0.9517849323685644,-0.9354595052839584,-0.4900470062659255,-0.3695981786799581,0.6972180368758283,0.1224383236005569,-0.1842528172696805,0.635617812547442,-0.0228731998307562,-0.556345415179456,0.2727516407949819,0.3588624567451891,-0.9275324468001211,0.4070805128934966,0.0202157560725448,0.3915481254883153,-0.2339876335148898,0.5568286456708167,0.0944847176881511,-0.1129066056301258,0.6158928365954536,-0.6200993968782667,-0.6222210107962322,-0.7301867578943133,-0.5648839748427471,-0.952521555253614,-0.4544905839428877,-0.5179434700629523,0.9825253087307356,0.3183281732622711,0.1211838103288032,0.2667100643942962,-0.9957867662800096,-0.1186621154340771,0.6863663931724796,0.3775758488762825,0.5959478537716556,-0.0345529929348901,-1.0056808667851926,0.9785656522339176,0.7831483757961263,-0.545033496554271,-0.6995475995780842,-1.029966844406068,0.2133435808314821,0.6753070580742373,-0.0417839771097488,0.6545674522025451,-0.2750169800245012,0.4161168732161316,-0.3969869348461352,0.2008646892693458,-0.1816779079691297,-0.8967901642193171,-0.4119444682544819,-0.1847258071316249,0.268930942736871,0.6174700682867629,0.951558505938648,0.0368723308533419,0.0580540782917029,0.9363336815076668,-0.1220500726156964,-0.5878515568619551,-0.628601045899439,-0.4444726761818194,0.99468634061051,0.1883471510985594,0.8118057050296555,0.5428003709268114,0.7047702068259937,0.3424442030954784,0.9461645356719848,-0.660511617416001,0.6037137021579674,-0.080921523371547,0.0019371319707808,-0.3865065113784399,-0.8431742590377078,0.8768496699399508,-0.4301878294465145,-0.2216941099350877,-0.517332646731444,-0.7115498917632788,-0.3236119287288357,0.528781969539354,0.2367640296433907,0.3193594452295526,-0.3426054612066069,-0.0935868036470829,-0.6701540542719056,-0.4305851925158551,-0.4986109153379811,-0.2908061894363429,-0.6851424401320018,-0.6795077569851233,-0.709423824654942,-0.6283511078926616,-0.5952454655110314,0.7485618060607664,0.5682912166172756,0.952319821343578,-0.783032829847297,0.678324176422686,-0.432551849506232,0.4653583663055131,0.967215856973874,0.1553517891345948,-0.6035057442068695,0.1797270637757366,0.5172518436561979,-0.5564156710984526,0.3305688350788389,-0.5334973408944832,0.9457263940376598,0.6620231949028598,-0.4404977968945348,0.9954842048547822,0.7357750245770797,-0.5521960667246015,-0.8663029459878253,0.8929349969605112,-0.8622263476689399,-0.5991902785435793,0.439158151775305,0.4436087944195678,-0.929258669605182,0.6293449141904938,-0.6858915681950237,0.1749486130218418,-0.537073432478919,0.4841346712764713,0.9297879163722031,-0.3332048924496302,-0.4161259471512764,-0.0036255312897585,-0.640398408952055,-0.1457333626065419,0.6928608633401563,0.3516344126422915,-0.1353851406625731,0.4672849615454277,-0.9614946430628382,-0.8596603536498789,0.6855381839573991,0.5371929214716585,-0.9149504118553272,-0.4320624357453775,-0.6192022901882356,-0.6200337655956675,0.5524176636343356,0.5520296229140162,-0.6820837970238411,-0.2122121303986662,-0.919824049103648,0.6750630806985369,-0.7412017550335901,-0.0026315222960858,0.1225790620350196,-0.649759158552061,-0.2670011310775208,-0.6270838666597137,-0.9721495522587272,-0.5879042703914691,0.1991530485937597,-0.051250400713661,0.6152447557820805,-0.172792069581193,-0.2693216303385374,-0.5246643049233557,-0.45187714098771,-0.3571329166949043,0.0913296955338267,0.281440575851569,-0.4361201214253473,0.3005322423620298,-0.196414551391124,-0.7808154562185049,0.0443756372396315,0.3612917985440049,-0.6998192377652053,-0.3662945830086019,-0.6935628359093521,0.1762974159251277,-0.6833975207191755,-0.6637672132444051,-0.0128035222042246,-0.9526397493413844,-0.6620224533690267,-0.3227658348409099,-0.3027394603292609,-0.059119117021386,-0.0920297617639363,0.1153968465147392,-0.479240825001916,-0.6393271238699789,-0.0108812351127833,-0.8919384305645286,-0.4153848425037162,-0.9267159313414686,-0.2816857584190205,0.2708608878301219,0.0835979974346431,0.2409434986948384,0.1438309826086942,0.3761537155843803,0.6000295941779402,0.6919849950238033,0.6221642231321688,-0.2524063665116942,0.5664667555650073,0.6576870083480036,-0.5984494926091438,-0.0633947685911547,-0.0520928082840772,0.7506486615307003,0.2585605687158505,0.9603707079528646,0.6303889748118305,0.194034674630333,0.3571571159850492,0.6131167199696043,0.1119124724803852,1.0319500897237133,0.9535442258249034,0.2537791026293524,0.5970421987792603,-0.1073645454095912,-0.3021760992254494,0.6693033316724692,-0.662812813285535,-1.0342932056316818,-0.9966179135352626,-0.3493610703015721,-0.5351113139627365,0.7825010299658266,-0.0155146640219182,-0.2204720518539317,0.4880459764882904,-0.9621877717907642,-0.6676990506482319,-0.9211090771223024,-0.6136207712790882,-0.1025689087985699,-0.9759227103721552,0.2215374444499964,-0.670595652503798,0.4833185137925599,0.0530915200718293,-0.1217293613077986,0.5362850505013546,0.1361426569794743,0.4386418992445642,1.007143828728354,-0.6111193607272692,-0.7354809738356762,-0.5465840192045636,0.4754561427370396,-0.6124812247180629,0.3640642467524692,0.218839656227761,0.6266372199563713,-0.7312902227561765,0.5582142080368244,-0.416695228057896,0.4937365743122575,0.3467433930749246,0.6738751994417496,-0.8468271361832991,0.6160547980285265,0.1269668725871344,0.1080765851829392,0.4185213582302043,0.1875913591568772,0.245237801610411,0.5823010561226267,0.4792226595817526,-0.0315819384109568,-0.035990015187341,-0.7007873084324688,0.8287446708849951,0.5321803618715752,-0.358653057773823,-0.1443597929831503,0.0702777562333065,-0.7015129353392298,-0.6961696925711378,-0.6807283196234142,0.9997251461455788,-0.7355142937294711,0.3863991885044338,-0.1575874392710687,-0.2290314869178777,0.4091336449589012,-0.6728947885894494,-0.4162775340971999,0.1663188650487787,0.232627919980537,-0.3977005594349272,0.4430667956745795,-0.4744773498248544,-0.2277577628573475,-0.5957011140399378,-0.2273662903830712,-0.7199901361455229,0.8048484088990872,-0.5737849765707204,0.4030253295505069,-0.2651711118698059,0.9103361075534347,-0.3520550942715974,0.5304805378497937,0.7641374514796063,0.034935016911442,-0.5724228443825059,-0.6914336708983942,0.3995693818819405,-0.5215881771177314,0.7548841342909611,-0.2393760002645061,-0.3448826287853652,0.763762479176805,-0.2731728596252132,0.1915965460885548,-0.1639220777703896,0.6290607187204565,-0.5433650434956179,0.1659419198354751,0.6544601030722313,-0.4230496273236457,-0.1047476949117219,-0.6297179495759787,-0.2222671356375418,-0.5982281089344246,0.3922984848011756,0.6431826071401687,0.928524276911942,0.4528312603956377,-0.5712723164183586,0.6473982691611473,-0.1637123985970066,-0.4565335875116276,-1.0080183605813786,-0.2007279614692149,0.7571040681341497,-0.2516468870231406,0.8408097773234195,0.5314539167980683,-0.8151951121768007,0.4248002565813333,0.6719985812799159,-0.213835053359104,-0.6826119909500434,-0.5742958717674745,-0.5634588697582189,0.9359928481470016,-0.7183012821186455,0.6749415760375564,0.3593078001282489,0.7464002862352532,-0.5306809422988833,-1.0140521453239366,-0.7404622088395693,0.7243125573118734,-0.5044513439820726,-0.7216078321839883,0.0247693429231923,0.3917678230910939,-0.0665017802368296,-0.639844432871609,0.1237371487461166,0.470218165307523,0.627785612514262,0.1178249969135402,-0.9444019886054532,0.7039471285944965,0.6550280135417627,-0.0528763413924594,0.1545653165760284,-0.3247669636215209,-0.5427248719973776,-0.614315207189044,-0.2798628177386993,-0.6940214093075251,0.6638736717667102,0.0217369980265202,-0.9762381592208784,0.0989770812656349,-0.4520582129130074,0.6517015335221927,0.1994731591094116,0.5863759139722678,-0.2153974250594422,-0.2347580184349819,0.2738520438838273,0.1492675308105585,0.8130166458240975,0.2062813012321333,-0.5698784072524513,0.49709877175877,0.2899146132382867,0.4781189870592283,0.4870528293071537,-1.0274187414969955,0.2142838018590383,-0.66891438847319,0.6341897495426948,1.0067430590541928,-0.662867407974187,0.4626232900483614,-0.5183151483237743,0.6848491149314712,-0.4485623284561594,-0.7811556134662724,-0.5369170615563604,-0.4779350419054242,0.2678295080209014,-0.6349043578159463,0.3577216733397898,0.9892913066641996,0.6807221979606783,0.320173771648965,-0.6899676140155279,-0.4329997482095039,0.5067705659756762,-0.5928210269477164,-0.872701433606142,-0.6203976149195671,0.9130622018270764,0.4049695576409876,-0.4764946353004176,0.7264712528864986,-0.6911956027341587,0.5720667575329094,0.5278245833267764,0.0745580770632879,0.6344120685637986,0.0673594220392598,-0.6465079276904997,0.6043928651870011,0.2099808320938593,-0.9076812600775116,-0.4826357037325296,-0.9806322467983823,0.0818077645459092,-0.944768494943647,-0.4794425281092463,-0.6446083216503458,0.5563457770800269,-0.2442262844874063,-0.3893027498957109,0.5892103961700794,-0.7723072317119826,-0.6691407165808836,-0.3189107027620051,0.9706294106731842,0.3902985698860323,0.5331446197544392,0.7143024631262489,0.6534350180929447,-0.1843857129451717,-0.7368844693265978,-0.5536741240964236,0.0960467159500105,0.3574113899233839,0.5687005125174264,-0.0739232592964769,0.2984033567248106,0.6032217461717146,-0.5531012882827904,-0.3591441613756297,0.3076296431122708,0.5052238465804747,-0.0374998435501213,-0.6200655313255893,-0.6617093278700305,0.9893031769576068,-0.3154414067518175,0.6614914840585953,1.0119031003512942,0.3926914283093114,0.514036003530345,-0.1818980214894232,-0.1087778563015521,-0.5545124245030232,0.6747072976573352,0.8352397396667975,0.6158468910174526,1.0271755359957966,0.6201440184473284,-0.8069033899887501,-0.6781953966380971,-0.5909552645936391,-0.5265194395431129,-1.014816072023465,0.6932494946666585,0.7245287855037029,0.7035097994505302,-0.4939521406803715,0.5628390859232518,0.7235839815889867,-0.4472578045135579,0.0795596359071743,-0.6762724220547874,-0.2209840217785891,0.8124138416081572,-0.3646523324171764,0.6685774939231526,0.607401036175889,-1.0072989783013135,0.8359224851409064,0.4936735407761751,-0.6209189797664965,0.0548874160843343,0.4466030222617423,0.62282531495493,1.0336909657159474,-0.6700830410091204,0.6095688903700266,-0.5824223098116801,0.6623160224534541,0.5511112893628494,0.3235453168143177,0.6452236383462104,-0.5839604749487387,0.4822742362052499,-0.46389610868427,0.5701183624805606,-0.486537913319186,0.5451701929540446,-0.4949427784264169,0.4203667037044132,-0.2445265082604042,0.7068715546956561,-0.1279075919681186,0.6658652672077302,-0.474373464266846,-0.5817497059738822,-0.4680524525822788,0.3549089833502529,0.9063183735064678,0.9720894997832696,-0.4432640831438624,-0.6589899356096308,0.3952777445282415,-0.4304467515812742,-0.5591564547241747,-0.6031511285084189,-0.8289398366808465,0.8452322158858073,-0.6982147293460435,0.7134656248336756,-0.6596260055469325,0.683878222695635,0.7027360334531155,0.6791653120568293,0.6232789147017476,-0.2433895216335896,0.666989640026438,0.5905926340143132,0.6727869689664477,-0.1612480949840677,0.0982735085754341,1.0164738813571057,0.1774860573914251,0.2540937251157332,0.2600053963564839,0.9477942706980088,-0.3455552121126032,0.0242618989141456,-0.2990394339162566,0.5909549225847428,-0.0392819496064969,0.9894208889083764,-0.5041943212980362,0.9110382175889622,-0.0073543618018523,0.218631949868077,0.4034359137412558,-0.618980822674548,0.5204402323947384,0.2885448831362953,-0.0228779804995022,0.2766735127258564,-0.6465618808807317,0.7043681248558291,-0.563170286865904,-0.2347711996967351,0.7068166927231019,0.592700977201404,-0.3779413623294649,0.1005909228903223,0.6640385992695935,-0.2839936170998452,-0.006711102671425,0.6906364575290632,0.2686607838426416,0.5805000057810348,-0.3184249966020528,0.2702547469954363,-0.6698044192429369,0.510203101174628,0.0437366329923505,0.3142015005510489,0.7168028498471853,0.6805026361284972,-0.7201661070581449,0.7093978177956625,0.3140099502035066,-0.9810409583251972,0.0848749714184419,0.7923509131395182,-0.7912583180656771,-0.6922425633821099,-0.338483031647791,-0.7052482409414499,0.1233878477536935,0.5434875007364764,-0.1776878373373003,0.6564330912038427,-0.6115541695926772,-0.6679170635406015,-0.4903590801177996,-0.6796754959838632,0.8585256728675684,-0.0635884342637367,-0.8226819037486809,-0.6796852098560117,0.4292319821979511,0.7083621381855122,0.2205434726646344,0.980526013320548,-0.3339687804517109,0.6623272512110318,-0.223645693533557,-0.9634528117589096,0.7334428286909405,0.4182336702340584,0.5827904665574654,-0.3477753675742409,0.0198934982538559,0.6079732494520961,0.6896513746757231,0.518532856252448,-0.5071299605663336,-0.6826679184304395,-0.7441113764760273,0.6098815197645558,1.027407747163033,-0.660472346532067,0.6113591539004516,0.5801754099360694,-0.0627864123142593,0.0397605648841976,0.6510932760365709,0.4499492664793391,-0.1752721305784943,-0.6733874850122528,-0.7357817305301017,-0.0860631126659446,0.7460338407178169,0.5764806847498569,-0.7484960110020671,0.9682293278782568,-0.7114281942499676,-0.7050342417509021,0.5007977016963748,0.6562622986631947,-0.4844316877328087,-0.3734810393857278,-0.3500822763291115,-0.8992927377044504,0.7741411952129615,-0.1579625837187375,0.5786606266721801,0.3912725428348166,-0.6542803197025094,-0.1197313183137849,-0.9421691120875696,0.9847598487670522,-0.9709107319210852,0.6682637494690166,0.4722882388054813,-0.5394557922749162,-0.0984001447749432,0.4837209049827158,-0.030291876869543,0.6884037138873664,0.5401834513326944,0.9846014570678712,-0.4411332061777901,-0.6875919738482503,-0.7122248793261121,-0.1042581860007668,-0.3099009751852611,-0.5549596859295413,0.8555913440674121,-0.3040670931042752,0.306452963816071,-0.0164767211038226,-0.6113720072335306,-0.4033012804017144,-0.6201804715090193,-0.7270863520458464,-0.7950734076818805,-0.130244647586725,-0.4178337931502098,-0.1341295917483446,0.0256520492778155,-0.3234610237464349,0.1196632850234024,0.4900226587542076,0.7566812486515988,0.2989280970677342,-0.6503472311333288,0.2788900535993379,-0.6149575600386302,-0.7089170654987919,-0.1797157496345678,-0.3713350621671273,-0.1719394593213597,0.3459128481051284,-0.6386570039592853,-0.3635776265880013,-0.9888559823720098,0.246963864473181,0.5024626639521756,0.6721378428669654,0.3059877458686014,0.6752461243193871,0.1123803219102238,0.9854904871758912,0.2871298548935716],\n",
       "\"x2\":[0.2652371636080013,0.1131631581337271,-0.1733968125835168,0.5542760377872187,-0.2703889703579717,-0.9738417435175094,-0.2809827368307136,-0.1447564214978481,0.0644475141005745,-0.7471536741811885,0.332666475916741,-0.0629950127731978,0.2056103583865236,0.104431654304317,0.5664840990969573,-1.0495648140565847,0.2536768616246788,-0.2761135141493472,0.3493368067208611,0.8676643347174068,0.2055937907115666,0.0304518758765982,-0.2928911688056429,-0.2616158024179665,0.1900213149619263,0.2934043184970543,0.8060121948573069,0.9423968320967548,0.907577596867593,-0.0489215573745599,0.930637571027046,-0.2892187748666321,0.844429336656185,0.1948488158933971,0.8297690521016335,-0.2754489559417776,0.282157140320302,-0.0944628476014749,-0.0528019748880543,0.1444191969206713,0.1158649987352082,-0.1704789849984286,-0.2974741355044185,0.2596553580862287,-0.2027641617249829,-0.0434929286782988,0.3391932093799026,-0.3183082963677733,-0.288523663070645,0.0647987775052138,0.2789338082152699,-0.0488722256398076,-0.3089742165004436,-0.1766179873310608,0.9813919311504312,0.054313806250125,0.4132008485723928,-0.5794157848470212,-0.8593901572362995,-0.0735025076381132,-0.0313316649966544,-0.3185376024487463,0.0028548825752882,0.3133873839500231,-0.1543853907968707,0.2923346884579976,0.1821481559658309,0.9141371084312184,-0.9479939236831424,-0.3074126972255938,-0.4451727967606284,0.9061180886253783,-0.961244110512696,-0.9415387490175388,-0.7990238398898287,-0.2849812569237476,-0.9927782125396312,-0.326874972520039,-0.3519547786095817,0.2992716624137175,0.1492036291963577,-0.0701580063265388,0.2822237614674912,-0.1350032713914082,-0.2676682878697312,0.6338425748489701,0.8213314636683493,0.071374228222408,0.2293990963664102,-0.3218270729948077,-0.1523983486914295,0.1678347760625345,0.329848569301495,0.2807041698999101,0.2663889207575099,0.4930026014881612,-0.4294227483220789,0.2409628889297189,-0.3032109150627639,0.1885781927247894,-0.7858340459964889,-0.2881436317347385,-0.1038292510027524,-0.2862002262406735,0.2667345803488641,-0.9326587946364574,-0.2508328878950195,-0.1863045714191303,0.2267168279777539,0.885600156848997,0.2812554852180505,0.8243768095351488,0.0316445653054251,-0.7052526975071733,-0.0364421064613124,0.1660010099397162,0.7505056702488455,-0.8436709163211766,0.2447071094398613,0.6293622434506109,-0.055309709190533,-0.2747254488743664,0.2078941537530653,-0.1290937577125363,0.2687823219829763,0.0965721008173242,0.9928135519228352,-0.8314617636632805,0.1415760578381452,-0.9829355688815696,-0.2364820400491719,0.3029875688692609,-0.0595324329870121,-0.2774452921869543,-0.2935479170039495,-0.0490974015633818,0.1894694880654894,0.4697479432100694,-0.5206886837766459,0.4342399538351137,0.0620052186071577,-0.2153239576271855,0.2395781255800455,0.4027291342214513,-0.1224295217819224,0.0562038333494711,0.2847614208053449,0.2120624002553139,-0.1898363688373409,-0.4616959101056157,0.2694715732725421,-0.2669432440885079,0.2803951323091155,0.08211467558116,-0.3246326917360623,-0.1271337321925787,-0.2895351405322086,0.950472901868249,-0.8964157725916333,0.3549774183177498,-0.4603256356114163,-0.7465154738508565,-0.1660962957175607,-0.4380169935922285,-0.8898627675475289,-0.1311374774677391,0.1417070106723148,0.1663066486461884,0.8167953148361392,-0.0095235722544612,-0.9034019041111414,0.5013479149132963,0.0193057050975716,0.6696041926140632,-0.295303918520277,0.2774488551784269,-0.0927824356881496,0.2435866452714153,0.1000796251540871,-0.2387288160282165,0.1632927541153124,0.2944301092100326,-0.2913801891314825,0.1938865454203878,0.2035261563280287,-0.3038105956156146,-0.2174455965212358,-0.88787958156518,-0.2456551167722853,0.337351263849312,0.9943855519133892,-0.252687700121479,-0.3597897229401163,0.2821427613941182,-0.5961680247792361,-0.2362978873313303,0.2302594858191247,-0.7220287929982037,-0.257987459459346,-0.0804895267735471,0.2950633989942162,0.0605930235590264,-0.1295032610930377,-1.0149081426645932,-0.1585202333416705,0.1332714737137881,-0.287127361103908,0.2500521866517565,-1.0043298308880506,-0.277428796746492,0.3000031191936843,0.2163388716060334,0.0615925840399506,0.3083434026428979,-0.3778923386835714,-0.2135986479806618,0.4480581494503034,-0.2878395456321349,-0.2464260642369047,0.9688001665455054,-0.2655424789582648,-1.0305363951252238,0.275753525124778,0.1191277469884441,0.0611840438748541,0.1915653316602343,0.9298796772622973,-0.1254783694711939,-0.1339539630175936,-0.1526160773157683,1.0297488807679949,0.9897052682466312,0.6415074916921967,0.2615000269976806,-0.3091487036197269,0.0302350163816744,0.2805988128870121,-0.2733440562659821,0.1794826415234645,-0.3093279739635368,0.1134173995913723,-0.4970905687789675,0.261564085708122,0.1626077890147478,-0.2466580574942165,0.2407710725892861,0.0884498270029465,-0.118339633982951,0.1966240917499239,-0.1223416090089478,-0.1633372341570794,0.1643166778324766,0.6555539069489257,-0.2900520204925202,0.2942731603551886,0.8580229092788658,-0.1195421152566914,-0.0360872403461394,0.2970512981669859,-0.166628317767195,-0.3004090898873551,-0.112126239293557,-0.3200231743175771,-0.0752193944143551,-0.8129657879997427,0.2957859542791355,0.2896901071343193,0.8362974170913913,-0.3394958334510736,-0.9260349284809012,0.2137842818015388,0.1659784702150942,-0.0398510897772519,-0.2507149196355184,0.2299739538071087,0.1002221157473969,-0.2649838078813744,0.2998338124227729,0.1389507565387186,0.7038423129759274,0.2174231129412918,0.933366060623831,-0.2275110319876126,0.92872590728421,-0.0065714413110362,-0.482338977827536,-0.1496456271841312,0.966574029842997,0.3628324359670952,0.2642473300446784,0.9633195906980324,0.2986501364800509,-0.1626190600537517,0.1672813373877119,0.3171584516646223,-0.3128440438542335,-0.0602490959944065,0.5895916340392886,-0.1799396135085032,-0.9335905261431552,0.3147636982514512,1.00246417400761,-0.6731530465719038,0.0507496470337365,-0.7414669066654699,-0.1621308727918415,-0.7521025383448041,0.2677357719576643,-0.276104778213012,0.2661629004560222,0.2878701280400499,0.1661510579035321,-0.2023198460109206,-0.2851112690344138,1.001469780276227,-0.2102596940767441,0.245358450118863,-0.9061478530200316,0.3046170421513919,-0.14881363380965,0.2790100220633915,-0.0141344505094717,0.5526428183918866,0.1662701832766646,-0.2306618865776373,-0.245813122567351,0.4766370127342835,-0.2787874290371696,0.2392816940113908,-0.0383550740950973,-0.2761092950060416,0.7852158775113091,-0.099455611182671,-0.2260036495101958,-0.1731776458366091,-0.6182104207869628,-0.3026772630273666,0.2884417140118485,-0.7155713843674615,-0.3312498821733951,0.3320536172039431,0.3511600352408377,-0.0822134525204033,0.2271930911477635,-1.0204852695788813,-0.0691698597735019,-0.2466628741814805,1.0320603776894086,0.1777886264314118,0.9470476397345172,0.1564078763545993,-0.2529476335839155,-0.076336004936729,0.3493019694211195,-0.1811909800150039,-0.1803090731838064,-0.1260494464388945,-0.2308632959799021,0.2248271887831476,-0.2770653248216471,-0.2931299506331437,0.635843549052004,-1.0045697378444245,-0.5659049003582861,-0.2357262533955062,0.4614370994168014,0.273311434563696,0.118587219414095,-0.2637955319114227,-0.0268121309511584,0.1692772329157613,0.2021543481662527,-0.2804030474667302,-0.0541371400036683,0.0063696447200126,-0.9304205467600491,0.0372752441788764,0.8856403798729975,0.2272638305910354,0.6488221762526442,-0.0628627523024925,-0.8888004572220821,-0.0078409183285302,-0.984520312808786,-0.2697883808897913,-0.2997856730203719,0.823485378116767,0.3300881082158541,0.1964150756207749,0.0553558790363879,0.2980690851606423,-0.355015123657411,-0.0425349777585416,0.1276043211385286,0.3109312399960712,0.9609590223947072,-0.2188175167404903,0.2103583670512875,0.7851632735040004,-0.3140340538447883,-0.0834602219085916,0.1443998786378355,0.3170855881024673,-0.338429109976865,0.3271079769396653,0.2223127061201793,0.1482289285775872,-0.2778402952261284,-0.1669451256665561,-0.2647235545119191,0.218420860037877,0.2795481474987075,0.3041422247816124,0.5156473067204539,0.2465070300836643,-0.821618248605185,-0.2009426599367301,0.2686834465902072,0.2363372539383906,-0.2360695683725799,-0.1034136109453093,0.2870213426163214,-0.0839259432539535,-0.107503977500807,-0.2648339261012518,0.0718299541658804,0.2207444333297746,-0.2049392497181064,0.0457053391618798,0.2042269496845669,0.656099291359555,-0.1794773640861859,-0.2795637158904581,-0.3084108384112726,0.8035417468342286,-0.9153167344937808,0.0912497361063857,0.0749652681664013,0.2386147498031222,-0.1052964593956207,0.1861128800041065,-0.1970850200641405,-0.1908431796305255,-0.5310804898479734,0.0769097357013286,0.49987766399523,0.2441430656043869,-0.2339631346850983,0.0155456251704161,0.0276393609147959,0.122124439660633,0.1917191777511752,0.2749721078363209,0.1461344435755269,-1.016300631955758,-0.1082913497205865,-0.1317298640220179,-0.9816978446102236,-0.4288694920154729,0.9081572453312404,0.0698067105678496,-0.3125449918550497,0.349398191735692,0.8769986072936069,-0.0252096746223517,-0.1503892079752793,-0.91874580348208,-0.2123864708193523,-0.1019069880844156,0.6387186344910406,-0.0282489726526054,0.9317226543911152,0.1472735900912323,-0.257989098672355,-0.2017853451802106,0.1046610297396804,0.084865786731629,0.3166946534594271,-0.631234680334425,-0.096565988202898,-1.011750418626529,-0.2779334954282108,-0.1894454416280567,-0.9663864746101728,0.9906152668790824,0.8524422049011313,0.2277065726857104,0.2457762527621466,-0.3038610338808214,-0.8801192135510619,0.275776991921881,0.1830833207549121,0.1455036994919412,0.1553142163871034,1.0042050379125596,-0.0283829575475258,-0.0609814786526115,0.9081456233806297,0.2075929420277884,0.9860770604698562,0.2975918217765686,-0.1413903129508252,-0.1053925825662132,-0.6293940047078981,0.0944239988909747,0.3090093228807242,-0.1452920980729523,-0.5926412832891327,0.0519022891343913,0.1828508491362083,-0.1146521362953152,0.2294180646572948,0.0994492849266099,0.0094435340642309,-0.0271806613372591,-0.21354532719357,-0.2112616250078151,-0.6821172613729792,0.2067738985087301,0.3244476491158019,-0.1045434906028287,0.971476021290438,0.5606707886241333,0.9847609222868632,0.0310796185058175,-0.1424086824389013,-0.0099096673441004,-0.4895100677415752,0.8324724525638058,-0.0401899353813841,0.2840204191179817,-0.9433791285685728,-0.0666796822109468,0.1247629742963294,0.0493561246078026,-0.1415852741534608,-0.2035922900838217,0.0316280401462631,0.1527230097386204,-0.2850311693519323,-0.0884680766070353,0.1503915256983017,0.1829135341693611,0.2559222218128401,0.2138250474886925,0.2524945257899367,-0.1103553622659178,0.2325478246446699,0.2609087865310237,0.3024659397862442,0.0995187892277972,-0.3293941089210255,0.1145482615669584,-0.2510091590950814,-0.2397161180529355,-0.239374229064985,-0.2699003162835192,-0.4797855755476899,-0.1161858477283507,-0.878866061058939,0.0584048118024472,0.3133681655130588,0.2248743143776836,-0.1738060974702995,-0.8129654610380758,-0.563421868887842,-0.5558886663154244,0.72929113150443,-0.6281665207107145,0.0677537646300826,-0.11306062189975,-0.0075838671051072,0.7769618658264489,-0.7472122141451947,0.9459806596408944,-0.6847423110609132,-0.7862462941523636,-0.056551371715053,0.2826330859885383,0.2520508530919407,0.2785766073574482,-0.2857460188633601,0.2711378604656053,-0.988880840231652,-0.4283729783343166,0.2635017724481946,-0.2924550699176838,-0.2409855640133859,0.1921771336558048,0.9842538561883528,0.3555733208523491,0.2614098468419544,0.3704106167855925,-0.3268086442574207,0.2737492226764254,-0.8780530718192262,0.7951294482249827,0.1967727766149597,0.2926475978558732,0.3096855895585336,0.2136076464941758,0.1896350641502877,-0.0200478445770951,-0.1565714582958781,-0.2775361277031841,0.6907479354491847,-0.1848361853790237,-0.881896287132152,-0.3340908148422124,-0.0042436327343346,0.2645934322419024,-0.2899735774444527,-0.0326737588806977,-0.9546723785093884,0.1593511972475778,-0.3161942418048143,-0.2806781099828525,-0.041206067974424,-0.2079328863918057,-0.2693299233900741,-0.2221969976031504,-0.0447734316886132,-0.116117365629255,0.0415036043297627,-0.1047914921172094,-0.2591035829963722,-0.2272823900570433,1.016759265716177,0.6132173631801704,0.5690300816254703,-0.0930262966153586,-0.2558141750483992,-0.0224102672459832,0.310978847147113,0.2120493150062609,-0.2881599491272816,0.0231179304775611,-0.1744263611700889,0.0693314058199432,0.2266381541974703,0.0558923146673146,0.4999287815716387,0.9553842694425664,-0.5899732047558268,0.0095487722825467,-0.2108582721006077,0.0367456210293098,0.9793928678087755,-0.178204178682247,-0.9290476053619524,0.7353060594609491,-0.90147812914015,0.1148654001061918,0.1265129772195935,0.9410247757458868,0.1684634395732783,0.9325301947210628,0.3647015190119308,-0.8356948481870743,0.0652117744341481,0.1782630986376816,0.1558921278947655,-0.0259693432323901,-0.0064757994649313,0.725183611946918,0.2403647330562417,-0.7766616079526695,0.1266330008347067,0.1643549203178356,-0.2748085739197935,-0.3128834801610474,0.1621356699775474,-0.1889483333798719,-0.2244363018736242,0.0707886238405757,-0.0099728359789908,-1.0079958011070105,-6.410939429346216E-5,0.8184058024512865,-0.7273276495970026,0.079228237315331,0.0467242741767208,-0.0152296816661472,0.160133558625364,0.0961289527800789,-0.1898702391479661,0.2479408902634571,0.2278134728035442,-0.4078639379727601,-0.6085429770285297,-0.9966811025533324,-0.1351723145927699,-0.2036156926588073,-0.1056347303663288,-0.2794825047021656,0.2340625936425834,0.0088671696819266,0.2795067044658136,-0.1095237184017638,-0.187469484438833,-0.8112124867681116,-1.017701983903245,-0.2027457528822268,0.3099038887314614,0.0921378712570792,-0.2226797226005271,-0.0292787328254713,-0.23238885935364,-0.165935411912929,-0.031291907129724,0.3197121213116387,0.2372081129141459,-0.1418514904035895,0.4771232901438528,-0.963569734727803,0.2170938546709517,0.3237307475420091,-0.1531497797934581,-0.9327252212614304,-0.087323559767794,-0.0357335966385338,-0.6291679830766714,-0.3275956110249621,0.2575894766855051,-0.3037540490917575,-0.3482723662043058,-0.2259531150296332,-0.3103082238784214,0.2623022026437113,0.0122954685301421,-0.2538859548391994,0.0949341281977962,0.2721124368739338,-0.1368025364058689,-0.0761014535299178,0.2636740834729899,0.2256310249540437,-0.2962289499340148,-0.200462903380645,0.0654974321974737,0.2667548932185843,0.1681405658438711,-0.2749129289226926,-0.2367229518958467,-0.1328352343367074,-0.2925748940455244,0.0341543933758124,-0.3031490840962975,-0.0129290177635334,-0.2736146434341161,0.6352680463417846,0.1131631581337271,-0.3791726260961192,0.5542760377872187,-0.6133996328354325,-0.9738417435175094,-0.6794361804879825,-0.4258164094173878,0.1541558184803269,-0.7471536741811885,0.7288510461954015,-0.0881112205849231,0.4527542036226574,0.2039076091702589,0.5664840990969573,-1.0495648140565847,0.5992462285018129,-0.2761135141493472,0.3493368067208611,0.8676643347174068,0.5459915834294432,0.0354782918299393,-0.6790438243389524,-0.6450245180249169,0.3957971284745289,0.6931201075532899,0.8060121948573069,0.9423968320967548,0.907577596867593,-0.0489215573745599,0.930637571027046,-0.6880823349708777,0.844429336656185,0.5685803928760419,0.8297690521016335,-0.6701233336249248,0.6768315180034492,-0.2370275990867751,-0.1906591441578612,0.3327007697868043,0.2394717964851871,-0.3932292315937037,-0.2974741355044185,0.5772515175453627,-0.4538407062412631,-0.0434929286782988,0.6967297790404082,-0.7144928666464339,-0.6585545458044281,0.0647987775052138,0.675779688741061,-0.1336750696086295,-0.6355099167873173,-0.4035255669817633,0.9813919311504312,0.054313806250125,0.4132008485723928,-0.5794157848470212,-0.8593901572362995,-0.177839110154072,-0.0313316649966544,-0.7123633362604284,0.0974544813847781,0.7132610596633431,-0.2827628347197543,0.6498712581185031,0.4997443154249649,0.9141371084312184,-0.9479939236831424,-0.6893585151242511,-0.4451727967606284,0.9061180886253783,-0.961244110512696,-0.9415387490175388,-0.7990238398898287,-0.2849812569237476,-0.9927782125396312,-0.7248553793125591,-0.3519547786095817,0.6930973962253997,0.3419050988370437,-0.231320580612004,0.5936086820943005,-0.1350032713914082,-0.6551015523211836,0.6338425748489701,0.8213314636683493,0.1413834518125184,0.5823155869403916,-0.3218270729948077,-0.2712149813222436,0.3516667203111296,0.7217905902551937,0.6805778456132301,0.5929246210443834,0.4930026014881612,-0.4294227483220789,0.5491681860400346,-0.6941181644900413,0.451212495025972,-0.7858340459964889,-0.638666303752284,-0.3470013700805944,-0.6681460441393307,0.6264966809754126,-0.9326587946364574,-0.6476787684208107,-0.3520548038164439,0.531693832382333,0.885600156848997,0.6431863062044584,0.8243768095351488,0.0617752875165981,-0.7052526975071733,-0.1695699242705071,0.3845587486334239,0.7505056702488455,-0.8436709163211766,0.2447071094398613,0.6293622434506109,-0.174126341821347,-0.609736664891223,0.496017763708228,-0.1290937577125363,0.6574350151488458,0.2714184074776973,0.9928135519228352,-0.8314617636632805,0.3684836374888477,-0.9829355688815696,-0.4991163423503545,0.3029875688692609,-0.1046749869364045,-0.5655689021421171,-0.2935479170039495,-0.0591494397407166,0.4444390839649652,0.4697479432100694,-0.5206886837766459,0.4342399538351137,0.2139168568158781,-0.5137004157968584,0.5445551299846246,0.4027291342214513,-0.3151309914226086,0.1063371267751927,0.6709140763386545,0.4784671472290146,-0.4814238198059055,-0.4616959101056157,0.6175450751403524,-0.5845394035476421,0.6792586924133611,0.1961223805691505,-0.7144434408506932,-0.2411414371805692,-0.6131419382821875,0.950472901868249,-0.8964157725916333,0.3549774183177498,-0.4603256356114163,-0.7465154738508565,-0.4287305980187433,-0.4380169935922285,-0.8898627675475289,-0.3014491940937682,0.3474828241849174,0.3848643873398961,0.8167953148361392,-0.1235312772424516,-0.9034019041111414,0.5013479149132963,0.084360571175525,0.6696041926140632,-0.694798701162684,0.6672596042930578,-0.1824907400679021,0.6076290335454136,0.256629091888968,-0.2387288160282165,0.3860430007105875,0.674852715728094,-0.6893605959240026,0.3909774820397045,0.5909594207794813,-0.6757211899709151,-0.5191461488156773,-0.88787958156518,-0.5750681558236562,0.7320256415324592,0.9943855519133892,-0.5762944978714579,-0.7369859372972621,0.6640885792927753,-0.5961680247792361,-0.6355085787026389,0.5679906560199307,-0.7220287929982037,-0.5957186296601521,-0.1896703009804772,0.6824966634456686,0.1306022471491367,-0.2860527278279187,-1.0149081426645932,-0.1585202333416705,0.2944340479992532,-0.6423819406293259,0.6098142872783049,-1.0043298308880506,-0.6762923568507375,0.6909103686209617,0.5180394239004749,0.1266474501179039,0.7067968463001668,-0.3778923386835714,-0.518575652385241,0.4480581494503034,-0.6539360146805019,-0.6145188031832527,0.9688001665455054,-0.6489511945652151,-1.0305363951252238,0.6051665641761489,0.2802903212739092,0.1703648180817841,0.4307273248832419,0.9298796772622973,-0.3355482214557121,-0.2812037840914648,-0.3583918908283709,1.0297488807679949,0.9897052682466312,0.6415074916921967,0.6275964960460477,-0.3091487036197269,0.1345716188976332,0.6594381348849098,-0.616354718743443,0.3895524935079827,-0.706173854489328,0.1134173995913723,-0.4970905687789675,0.6370576287696716,0.4214301736425255,-0.6413324351773637,0.5912937446068315,0.1683338192087093,-0.2419464317329299,0.1966240917499239,-0.1223416090089478,-0.5114107360248897,0.4153932223487568,0.6555539069489257,-0.6900204381740467,0.6731124823530863,0.8580229092788658,-0.1195421152566914,-0.1110397661804293,0.2970512981669859,-0.3680775984214993,-0.6958697877825207,-0.112126239293557,-0.6988624963154747,-0.1452286180044655,-0.8129657879997427,0.6952807369215426,0.6805973565615967,0.8362974170913913,-0.7281485266169432,-0.9260349284809012,0.2137842818015388,0.3674277508693986,-0.0348246738239109,-0.4817440010044255,0.5283504119767816,0.2380792850172037,-0.6027149780821803,0.6735653894054177,0.3047009889360322,0.7038423129759274,0.468499657457572,0.933366060623831,-0.5121253028713267,0.92872590728421,-0.0065714413110362,-0.482338977827536,-0.328998913620144,0.966574029842997,0.7547744569207939,0.578762702899326,0.9633195906980324,0.6820588520870012,-0.3936481414226588,0.451895608271426,0.7171268693461488,-0.7123388264966405,-0.1053916499437991,0.5895916340392886,-0.4463443604822039,-0.9335905261431552,0.7076785985429266,1.00246417400761,-0.6731530465719038,0.1550862495496953,-0.7414669066654699,-0.1621308727918415,-0.7521025383448041,0.5942714722445379,-0.6690196785044875,0.6465855069740836,0.6084969219884006,0.3319012903008456,-0.51370476663773,-0.6699223376688481,1.001469780276227,-0.5308864880250946,0.5803696661357197,-0.9061478530200316,0.6894281107858262,-0.3370952066757831,0.6471027610097395,-0.0442651727206448,0.5526428183918866,0.4013842841936539,-0.5710596792955139,-0.6055752231938996,0.4766370127342835,-0.6317039196111509,0.5203416819309304,-0.0182573468231895,-0.6760777126875681,0.7852158775113091,-0.2467054322565422,-0.5812582290356135,-0.4163497649144513,-0.6182104207869628,-0.6707700019737147,0.6340110808889826,-0.7155713843674615,-0.7067434252349447,0.7139994351026003,0.7409707843554686,-0.2387629192552843,0.501011933519239,-1.0204852695788813,-0.1735064622894606,-0.5548681712917962,1.0320603776894086,0.3878584784159301,0.9470476397345172,0.3534988129739159,-0.5643325542107249,-0.199942802686708,0.3493019694211195,-0.4761962269582735,-0.4154231741007957,-0.259177264248089,-0.6195159891457717,0.5094414596668618,-0.2770653248216471,-0.6735525571512051,0.635843549052004,-1.0045697378444245,-0.5659049003582861,-0.4906958492949821,0.4614370994168014,0.5846963551905053,0.2082955237938474,-0.6426348539093204,0.0133325549893275,0.4003063142846684,0.4492981934023864,-0.2804030474667302,-0.0440851018263333,-0.0437636487057089,-0.9304205467600491,0.0322488282255356,0.8856403798729975,0.2272638305910354,0.6488221762526442,-0.1328719758926028,-0.8888004572220821,0.0373016356208622,-0.984520312808786,-0.5904151748381419,-0.6989963643916804,0.823485378116767,0.7275326324238575,0.4880025265893395,0.1104719953102431,0.6918948189723244,-0.355015123657411,-0.1026252134068443,0.2559817650614124,0.7083757642040746,0.9609590223947072,-0.5888483994742736,0.4535304861291296,0.7851632735040004,-0.6877656308274331,-0.148515087986545,0.2916496997117067,0.7162962794737758,-0.338429109976865,0.7200228772311408,0.4997740284453013,0.3275822150136001,-0.6497508895814289,-0.3683944063208605,-0.6287659427859174,0.5956170743950229,0.6414789684851153,0.7009881053074036,0.5156473067204539,0.618417624438965,-0.821618248605185,-0.4360567608537194,0.6167569484580175,0.5101560963098661,-0.5505849412272275,-0.1034136109453093,0.6718324112507557,-0.2264906947392539,-0.2732542098981207,-0.2648339261012518,0.1810107283728105,0.5224449856242162,-0.4599088456175822,0.1057955748101826,0.5187423225392145,0.656099291359555,-0.4496104873345956,-0.6060994161773318,-0.6839043814728223,0.8035417468342286,-0.9153167344937808,0.0912497361063857,0.1000814759781267,0.5790125425209989,-0.1900993033644425,0.4844893381737794,-0.4709038624356158,-0.4177507592812281,-0.5310804898479734,0.2472214523273576,0.49987766399523,0.576381425282712,-0.525550585653663,0.0656789185961378,0.0877295965630988,0.3490320193113356,0.4466887736506511,0.6711566781149815,0.3388359132162131,-1.016300631955758,-0.2876446361565994,-0.3788737092581516,-0.9816978446102236,-0.4288694920154729,0.9081572453312404,0.0698067105678496,-0.709989516063053,0.349398191735692,0.8769986072936069,-0.0302360905756927,-0.4014657524915594,-0.91874580348208,-0.5446248304976774,-0.2538186262931361,0.6387186344910406,-0.0883392083009084,0.9317226543911152,0.1472735900912323,-0.5874021377237258,-0.440947338403218,0.2186687347276708,0.2274305382169293,0.7028473089927366,-0.631234680334425,-0.2714122948632713,-1.011750418626529,-0.6235028623053448,-0.4595785648764665,-0.9663864746101728,0.9906152668790824,0.8524422049011313,0.4668685659087179,0.5887869152396076,-0.6636231345073698,-0.8801192135510619,0.675776991921881,0.3624366071909251,0.2927535205658123,0.1553142163871034,1.0042050379125596,-0.1033354833818157,-0.0609814786526115,0.9081456233806297,0.4507650611056306,0.9860770604698562,0.6930525196717342,-0.4077950599245259,-0.2757042991922421,-0.6293940047078981,0.2692703055513479,0.3090093228807242,-0.3291240423215474,-0.5926412832891327,0.1268548149686811,0.3666827933848035,-0.3332098749890228,0.2294180646572948,0.2513609231353303,0.0245196071322048,-0.0822967776111142,-0.4981595980772841,-0.488722947332937,-0.6821172613729792,0.5303806962587091,0.7233112092200475,-0.2329209345257125,0.971476021290438,0.5606707886241333,0.9847609222868632,0.0109818912339097,-0.3306902553050343,-0.0099096673441004,-0.4895100677415752,0.8324724525638058,-0.120073927587147,0.6839888367995082,-0.9433791285685728,-0.1758604564178769,0.1247629742963294,0.0844966032280998,-0.3386762107727775,-0.4624146747115993,0.0767705940956557,0.3092724764735013,-0.6331046712197426,-0.1830676754165251,0.3647222436899004,0.4911188312796768,0.5509274687561097,0.4448541288575995,0.5406181357450994,-0.3691777468936955,0.5136078125642095,0.5845155842810026,0.6779594828477937,0.174471315062087,-0.725578679199686,0.2524054308367652,-0.5655245319497291,-0.4868599632890693,-0.5377506872346578,-0.6049115323003758,-0.4797855755476899,-0.1161858477283507,-0.878866061058939,0.0483527736251122,0.6563788279905197,0.5455011083260343,-0.3708970340896161,-0.8129654610380758,-0.563421868887842,-0.5558886663154244,0.72929113150443,-0.6281665207107145,0.2008815824392772,-0.1929446141055129,-0.0327000749168325,0.7769618658264489,-0.7472122141451947,0.9459806596408944,-0.6847423110609132,-0.7862462941523636,-0.096696057655539,0.6712857791544079,0.6500312598844609,0.2785766073574482,-0.6786609191548355,0.6392305994119534,-0.988880840231652,-0.4283729783343166,0.6012329426490007,-0.6923287456310038,-0.6029163849997936,0.41492738025108,0.9842538561883528,0.3555733208523491,0.552997297810519,0.3704106167855925,-0.7266823199707407,0.6509454370335712,-0.8780530718192262,0.7951294482249827,0.4594070789161423,0.6566899861298715,0.7088962809298421,0.583638529227959,0.332199815635588,-0.0851027106550485,-0.3957334515188855,-0.6547323420603299,0.6907479354491847,-0.4075864319742989,-0.881896287132152,-0.7249980642694898,-0.0193197058023083,0.6306899012902695,-0.6896893665006882,-0.067814237500995,-0.9546723785093884,0.3608004779018821,-0.6617636086819484,-0.6544096869654973,-0.0913393614001457,-0.4889928743113453,-0.6647906212852398,-0.5727196696206958,-0.1344817360683654,-0.2539745348990617,0.0966197206036179,-0.2042674469831512,-0.6252000520447393,-0.2272823900570433,1.016759265716177,0.6132173631801704,0.5690300816254703,-0.244937934824079,-0.6133507447089047,-0.1218862221119252,0.7064395450422786,0.4821824382546707,-0.6743126046605912,0.0331699686548961,-0.3844962131546072,0.163931004629433,0.4967712774458801,0.1747089472981285,0.4999287815716387,0.9553842694425664,-0.5899732047558268,0.0943516162513686,-0.5190635692109232,0.0718860996496071,0.9793928678087755,-0.178204178682247,-0.9290476053619524,0.7353060594609491,-0.90147812914015,0.1148654001061918,0.2501197749695724,0.9410247757458868,0.4035775404902676,0.9325301947210628,0.7631549626691997,-0.8356948481870743,0.15001461840297,0.4557244209628037,0.4147145125225431,-0.041045416300364,0.0186404083467938,0.725183611946918,0.2403647330562417,-0.7766616079526695,0.2969447174607358,0.3786856383094343,-0.6722530981277969,-0.7128834801610474,0.295263487786742,-0.4906488856743132,-0.6092473705080585,0.1506726160463385,0.010124891292917,-1.0079958011070105,-0.0301948316054665,0.8184058024512865,-0.7273276495970026,0.079228237315331,0.0065795882362347,-1.536085981734E-4,0.4265383055990647,0.2844105256462119,-0.4636890815194416,0.6008573808374384,0.5628246888204009,-0.4078639379727601,-0.6085429770285297,-0.9966811025533324,-0.3495030325843684,-0.5358540523371323,-0.1607508466401841,-0.6733082385138478,0.2340625936425834,0.0088671696819266,0.2795067044658136,-0.270686292687229,-0.4755930943939957,-0.8112124867681116,-1.017701983903245,-0.520341912341361,0.7096196777876971,0.2109545038878932,-0.4412374612942346,-0.0292787328254713,-0.5273941062969096,-0.3586368815536151,-0.0312919071297239,0.7176925281041587,0.6091187072694465,-0.4193128127287115,0.4771232901438528,-0.963569734727803,0.5676165266884972,0.7232255301844162,-0.3674804977850568,-0.9327252212614304,-0.1819231585772839,-0.0708740752588311,-0.6291679830766714,-0.726049054682231,0.6128440562109229,-0.6956960700454562,-0.7479881552605415,-0.5663509077475101,-0.7022502448321202,0.557307449586981,0.0524401544706281,-0.6114225244997049,0.2233115721206799,0.6273670163993517,-0.3206344806544641,-0.0961991808018256,0.6470827990799403,0.5550440640054146,-0.6836622143854673,-0.5623937243670528,0.1649733870634157,0.5989932528969094,0.1681405658438711,-0.6553355354407541,-0.5416999563004257,-0.3076815409970804,-0.6566172823195227,0.0642851155869855,-0.6929598332109284,-0.0129290177635334,-0.6265311340080972],\n",
       "\"colour\":[\"2\",\"0\",\"1\",\"0\",\"3\",\"3\",\"3\",\"0\",\"0\",\"1\",\"2\",\"0\",\"2\",\"1\",\"0\",\"3\",\"2\",\"0\",\"0\",\"2\",\"0\",\"1\",\"3\",\"3\",\"1\",\"2\",\"2\",\"2\",\"2\",\"0\",\"2\",\"3\",\"2\",\"2\",\"2\",\"3\",\"2\",\"1\",\"0\",\"0\",\"0\",\"3\",\"0\",\"0\",\"3\",\"1\",\"2\",\"3\",\"3\",\"0\",\"2\",\"1\",\"3\",\"1\",\"2\",\"0\",\"1\",\"1\",\"3\",\"0\",\"0\",\"3\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"3\",\"3\",\"0\",\"2\",\"3\",\"3\",\"1\",\"1\",\"3\",\"3\",\"1\",\"2\",\"0\",\"0\",\"2\",\"1\",\"3\",\"2\",\"2\",\"1\",\"2\",\"1\",\"0\",\"1\",\"2\",\"2\",\"2\",\"0\",\"1\",\"0\",\"3\",\"0\",\"3\",\"3\",\"1\",\"3\",\"2\",\"3\",\"3\",\"0\",\"0\",\"2\",\"2\",\"0\",\"0\",\"3\",\"0\",\"0\",\"2\",\"3\",\"1\",\"0\",\"1\",\"3\",\"2\",\"1\",\"2\",\"0\",\"2\",\"3\",\"0\",\"3\",\"3\",\"1\",\"1\",\"3\",\"1\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"2\",\"0\",\"1\",\"0\",\"2\",\"0\",\"1\",\"1\",\"2\",\"3\",\"2\",\"0\",\"3\",\"1\",\"3\",\"2\",\"3\",\"0\",\"0\",\"1\",\"1\",\"0\",\"3\",\"0\",\"0\",\"2\",\"2\",\"0\",\"3\",\"0\",\"1\",\"0\",\"3\",\"2\",\"0\",\"2\",\"0\",\"0\",\"0\",\"2\",\"3\",\"2\",\"2\",\"3\",\"3\",\"3\",\"3\",\"2\",\"2\",\"3\",\"3\",\"2\",\"3\",\"3\",\"2\",\"3\",\"3\",\"0\",\"2\",\"0\",\"0\",\"3\",\"0\",\"0\",\"3\",\"2\",\"3\",\"3\",\"2\",\"0\",\"0\",\"2\",\"0\",\"3\",\"0\",\"3\",\"3\",\"2\",\"3\",\"3\",\"2\",\"1\",\"1\",\"1\",\"2\",\"1\",\"1\",\"0\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"2\",\"3\",\"1\",\"3\",\"1\",\"1\",\"2\",\"1\",\"3\",\"2\",\"1\",\"0\",\"0\",\"0\",\"3\",\"0\",\"2\",\"3\",\"2\",\"2\",\"0\",\"0\",\"0\",\"0\",\"3\",\"0\",\"3\",\"0\",\"3\",\"2\",\"2\",\"2\",\"3\",\"3\",\"1\",\"0\",\"0\",\"3\",\"2\",\"0\",\"3\",\"2\",\"1\",\"0\",\"2\",\"2\",\"1\",\"2\",\"1\",\"0\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"3\",\"0\",\"1\",\"1\",\"3\",\"2\",\"2\",\"3\",\"0\",\"3\",\"1\",\"3\",\"2\",\"3\",\"2\",\"2\",\"0\",\"3\",\"3\",\"2\",\"3\",\"2\",\"3\",\"2\",\"0\",\"2\",\"0\",\"1\",\"0\",\"1\",\"3\",\"1\",\"3\",\"2\",\"1\",\"3\",\"0\",\"0\",\"1\",\"3\",\"1\",\"3\",\"2\",\"1\",\"3\",\"2\",\"2\",\"1\",\"0\",\"3\",\"1\",\"3\",\"2\",\"0\",\"2\",\"0\",\"3\",\"1\",\"1\",\"1\",\"3\",\"1\",\"3\",\"0\",\"0\",\"3\",\"2\",\"3\",\"1\",\"1\",\"0\",\"2\",\"1\",\"3\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"3\",\"1\",\"2\",\"0\",\"0\",\"1\",\"3\",\"0\",\"3\",\"3\",\"3\",\"0\",\"2\",\"2\",\"1\",\"2\",\"0\",\"1\",\"1\",\"2\",\"2\",\"3\",\"0\",\"0\",\"3\",\"0\",\"1\",\"2\",\"0\",\"2\",\"0\",\"1\",\"3\",\"1\",\"3\",\"2\",\"2\",\"2\",\"1\",\"2\",\"3\",\"1\",\"2\",\"2\",\"1\",\"0\",\"2\",\"0\",\"1\",\"1\",\"0\",\"2\",\"3\",\"1\",\"0\",\"0\",\"3\",\"3\",\"3\",\"0\",\"3\",\"1\",\"1\",\"2\",\"0\",\"0\",\"1\",\"3\",\"0\",\"0\",\"1\",\"2\",\"3\",\"1\",\"0\",\"1\",\"2\",\"2\",\"1\",\"3\",\"0\",\"1\",\"3\",\"0\",\"2\",\"0\",\"3\",\"0\",\"2\",\"0\",\"1\",\"3\",\"3\",\"1\",\"0\",\"0\",\"2\",\"1\",\"3\",\"1\",\"1\",\"1\",\"2\",\"3\",\"0\",\"3\",\"3\",\"1\",\"3\",\"2\",\"2\",\"0\",\"2\",\"3\",\"3\",\"2\",\"0\",\"0\",\"1\",\"2\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"0\",\"1\",\"1\",\"1\",\"1\",\"1\",\"3\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"3\",\"1\",\"1\",\"0\",\"2\",\"0\",\"2\",\"1\",\"2\",\"1\",\"1\",\"0\",\"1\",\"2\",\"0\",\"2\",\"3\",\"1\",\"1\",\"0\",\"1\",\"3\",\"1\",\"2\",\"3\",\"1\",\"0\",\"2\",\"0\",\"2\",\"0\",\"1\",\"0\",\"2\",\"2\",\"1\",\"3\",\"1\",\"3\",\"3\",\"3\",\"3\",\"1\",\"1\",\"3\",\"0\",\"2\",\"0\",\"3\",\"3\",\"3\",\"1\",\"0\",\"1\",\"0\",\"1\",\"1\",\"2\",\"1\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"1\",\"3\",\"2\",\"3\",\"1\",\"2\",\"3\",\"3\",\"2\",\"2\",\"1\",\"0\",\"1\",\"3\",\"2\",\"3\",\"0\",\"2\",\"2\",\"2\",\"2\",\"0\",\"1\",\"0\",\"3\",\"2\",\"1\",\"3\",\"3\",\"1\",\"2\",\"3\",\"1\",\"3\",\"1\",\"3\",\"3\",\"0\",\"1\",\"3\",\"3\",\"1\",\"1\",\"0\",\"1\",\"3\",\"0\",\"2\",\"2\",\"0\",\"0\",\"3\",\"0\",\"2\",\"2\",\"3\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"2\",\"3\",\"0\",\"1\",\"1\",\"2\",\"1\",\"3\",\"2\",\"3\",\"0\",\"1\",\"2\",\"1\",\"2\",\"2\",\"1\",\"1\",\"2\",\"0\",\"0\",\"0\",\"2\",\"1\",\"3\",\"1\",\"1\",\"3\",\"3\",\"1\",\"1\",\"3\",\"0\",\"0\",\"3\",\"1\",\"2\",\"3\",\"1\",\"0\",\"0\",\"2\",\"1\",\"3\",\"0\",\"2\",\"0\",\"1\",\"3\",\"1\",\"1\",\"0\",\"3\",\"0\",\"1\",\"0\",\"1\",\"1\",\"3\",\"3\",\"1\",\"2\",\"1\",\"1\",\"1\",\"3\",\"0\",\"0\",\"2\",\"2\",\"0\",\"1\",\"3\",\"2\",\"2\",\"0\",\"3\",\"0\",\"0\",\"3\",\"3\",\"0\",\"3\",\"3\",\"3\",\"3\",\"2\",\"1\",\"3\",\"0\",\"2\",\"0\",\"0\",\"2\",\"2\",\"3\",\"1\",\"0\",\"2\",\"0\",\"3\",\"1\",\"1\",\"3\",\"1\",\"3\",\"1\",\"3\",\"2\",\"0\",\"1\",\"0\",\"3\",\"3\",\"3\",\"3\",\"0\",\"1\",\"2\",\"0\",\"2\",\"1\",\"0\",\"3\",\"2\",\"0\",\"0\",\"2\",\"2\",\"1\",\"3\",\"3\",\"1\",\"2\",\"2\",\"2\",\"2\",\"0\",\"2\",\"3\",\"2\",\"2\",\"2\",\"3\",\"2\",\"1\",\"0\",\"0\",\"0\",\"3\",\"0\",\"0\",\"3\",\"1\",\"2\",\"3\",\"3\",\"0\",\"2\",\"1\",\"3\",\"1\",\"2\",\"0\",\"1\",\"1\",\"3\",\"0\",\"0\",\"3\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"3\",\"3\",\"0\",\"2\",\"3\",\"3\",\"1\",\"1\",\"3\",\"3\",\"1\",\"2\",\"0\",\"0\",\"0\",\"1\",\"3\",\"2\",\"2\",\"1\",\"2\",\"1\",\"0\",\"1\",\"2\",\"2\",\"2\",\"0\",\"1\",\"0\",\"3\",\"0\",\"3\",\"3\",\"1\",\"3\",\"2\",\"3\",\"3\",\"0\",\"0\",\"2\",\"2\",\"0\",\"0\",\"3\",\"0\",\"0\",\"2\",\"3\",\"1\",\"0\",\"1\",\"3\",\"2\",\"1\",\"2\",\"0\",\"2\",\"3\",\"0\",\"3\",\"3\",\"1\",\"1\",\"3\",\"1\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"2\",\"0\",\"1\",\"0\",\"2\",\"0\",\"1\",\"1\",\"2\",\"3\",\"2\",\"0\",\"3\",\"1\",\"3\",\"2\",\"3\",\"0\",\"0\",\"1\",\"1\",\"0\",\"3\",\"0\",\"0\",\"1\",\"2\",\"0\",\"3\",\"0\",\"1\",\"0\",\"3\",\"2\",\"0\",\"2\",\"0\",\"0\",\"0\",\"2\",\"3\",\"1\",\"2\",\"3\",\"3\",\"3\",\"3\",\"2\",\"2\",\"3\",\"3\",\"2\",\"3\",\"3\",\"2\",\"3\",\"3\",\"0\",\"2\",\"0\",\"0\",\"3\",\"0\",\"0\",\"3\",\"2\",\"3\",\"3\",\"2\",\"0\",\"0\",\"2\",\"0\",\"3\",\"0\",\"3\",\"3\",\"2\",\"3\",\"3\",\"2\",\"1\",\"1\",\"1\",\"2\",\"1\",\"1\",\"0\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"2\",\"3\",\"1\",\"3\",\"1\",\"1\",\"2\",\"1\",\"3\",\"2\",\"1\",\"0\",\"0\",\"0\",\"3\",\"0\",\"2\",\"3\",\"2\",\"2\",\"0\",\"0\",\"0\",\"0\",\"3\",\"0\",\"3\",\"0\",\"3\",\"2\",\"2\",\"2\",\"3\",\"3\",\"1\",\"0\",\"0\",\"3\",\"2\",\"0\",\"3\",\"2\",\"1\",\"0\",\"2\",\"2\",\"1\",\"2\",\"1\",\"0\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"3\",\"0\",\"1\",\"1\",\"3\",\"2\",\"2\",\"3\",\"0\",\"3\",\"1\",\"3\",\"2\",\"3\",\"2\",\"2\",\"0\",\"3\",\"3\",\"2\",\"3\",\"2\",\"3\",\"2\",\"0\",\"2\",\"0\",\"1\",\"0\",\"3\",\"3\",\"1\",\"3\",\"2\",\"1\",\"3\",\"0\",\"0\",\"3\",\"3\",\"1\",\"3\",\"2\",\"1\",\"3\",\"2\",\"2\",\"1\",\"0\",\"3\",\"1\",\"3\",\"2\",\"0\",\"2\",\"0\",\"3\",\"1\",\"1\",\"1\",\"3\",\"1\",\"3\",\"0\",\"0\",\"3\",\"2\",\"3\",\"1\",\"1\",\"0\",\"2\",\"1\",\"3\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"3\",\"1\",\"2\",\"0\",\"0\",\"1\",\"3\",\"0\",\"3\",\"3\",\"3\",\"0\",\"2\",\"2\",\"1\",\"2\",\"0\",\"1\",\"1\",\"2\",\"2\",\"3\",\"0\",\"0\",\"3\",\"0\",\"1\",\"2\",\"0\",\"2\",\"0\",\"1\",\"3\",\"1\",\"3\",\"2\",\"2\",\"2\",\"1\",\"2\",\"3\",\"1\",\"2\",\"2\",\"1\",\"0\",\"2\",\"0\",\"1\",\"1\",\"0\",\"2\",\"3\",\"1\",\"0\",\"0\",\"3\",\"3\",\"3\",\"0\",\"3\",\"1\",\"1\",\"2\",\"0\",\"0\",\"1\",\"3\",\"0\",\"0\",\"1\",\"2\",\"3\",\"1\",\"0\",\"1\",\"2\",\"2\",\"1\",\"3\",\"0\",\"1\",\"3\",\"0\",\"2\",\"0\",\"3\",\"0\",\"2\",\"0\",\"1\",\"3\",\"3\",\"1\",\"0\",\"0\",\"2\",\"1\",\"3\",\"1\",\"1\",\"1\",\"2\",\"3\",\"0\",\"3\",\"3\",\"1\",\"3\",\"2\",\"2\",\"0\",\"2\",\"3\",\"3\",\"2\",\"0\",\"0\",\"1\",\"2\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"3\",\"1\",\"1\",\"1\",\"1\",\"1\",\"3\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"3\",\"1\",\"1\",\"0\",\"2\",\"0\",\"2\",\"1\",\"2\",\"1\",\"1\",\"0\",\"1\",\"2\",\"0\",\"2\",\"3\",\"1\",\"1\",\"0\",\"1\",\"3\",\"1\",\"1\",\"3\",\"1\",\"0\",\"2\",\"0\",\"2\",\"0\",\"1\",\"0\",\"2\",\"2\",\"1\",\"3\",\"1\",\"3\",\"3\",\"3\",\"3\",\"1\",\"1\",\"3\",\"0\",\"2\",\"0\",\"0\",\"3\",\"3\",\"1\",\"0\",\"1\",\"0\",\"1\",\"1\",\"2\",\"1\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"1\",\"3\",\"2\",\"3\",\"1\",\"2\",\"3\",\"3\",\"1\",\"2\",\"1\",\"0\",\"1\",\"3\",\"2\",\"3\",\"0\",\"2\",\"2\",\"2\",\"2\",\"0\",\"1\",\"3\",\"3\",\"2\",\"1\",\"3\",\"3\",\"1\",\"2\",\"3\",\"1\",\"3\",\"1\",\"3\",\"3\",\"0\",\"1\",\"3\",\"3\",\"1\",\"1\",\"0\",\"1\",\"3\",\"0\",\"2\",\"2\",\"0\",\"0\",\"3\",\"0\",\"2\",\"2\",\"3\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"2\",\"3\",\"0\",\"1\",\"1\",\"2\",\"1\",\"3\",\"2\",\"3\",\"0\",\"1\",\"2\",\"1\",\"2\",\"2\",\"1\",\"1\",\"2\",\"0\",\"0\",\"0\",\"2\",\"1\",\"3\",\"1\",\"1\",\"3\",\"3\",\"1\",\"1\",\"3\",\"0\",\"0\",\"3\",\"1\",\"2\",\"3\",\"1\",\"0\",\"0\",\"2\",\"1\",\"3\",\"2\",\"2\",\"0\",\"1\",\"3\",\"1\",\"1\",\"0\",\"3\",\"0\",\"1\",\"0\",\"1\",\"1\",\"3\",\"3\",\"1\",\"2\",\"1\",\"1\",\"1\",\"3\",\"0\",\"0\",\"2\",\"2\",\"3\",\"1\",\"3\",\"2\",\"2\",\"0\",\"3\",\"0\",\"0\",\"3\",\"3\",\"2\",\"3\",\"3\",\"3\",\"3\",\"2\",\"1\",\"3\",\"0\",\"2\",\"0\",\"0\",\"2\",\"2\",\"3\",\"3\",\"0\",\"2\",\"0\",\"3\",\"1\",\"1\",\"3\",\"1\",\"3\",\"1\",\"3\"]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"x1\",\n",
       "\"y\":\"x2\",\n",
       "\"colour\":\"colour\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"x1\"\n",
       "},{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"x2\"\n",
       "}]\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"minimal\",\n",
       "\"legend_position\":\"bottom\",\n",
       "\"panel_grid_minor\":{\n",
       "\"blank\":true\n",
       "}\n",
       "},\n",
       "\"guides\":{\n",
       "\"x\":{\n",
       "\"title\":\"First dimension\"\n",
       "},\n",
       "\"y\":{\n",
       "\"title\":\"Second dimension\"\n",
       "},\n",
       "\"colour\":{\n",
       "\"title\":\"Cluster #\"\n",
       "}\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[],\n",
       "\"spec_id\":\"6\"\n",
       "};\n",
       "               window.letsPlotCall(function() {\n",
       "       \n",
       "               var toolbar = null;\n",
       "               var plotContainer = containerDiv;               \n",
       "               \n",
       "                   var options = {\n",
       "                       sizing: {\n",
       "                           width_mode: \"min\",\n",
       "                           height_mode: \"scaled\",\n",
       "                           width: width\n",
       "                       }\n",
       "                   };\n",
       "                   var fig = LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer, options);\n",
       "                   if (toolbar) {\n",
       "                     toolbar.bind(fig);\n",
       "                   }\n",
       "               });\n",
       "               \n",
       "               break;\n",
       "           }\n",
       "       }\n",
       "   });\n",
       "   \n",
       "   observer.observe(containerDiv);\n",
       "   \n",
       "   // ----------\n",
       "   })();\n",
       "   \n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x3463a8dd0>"
      ]
     },
     "execution_count": 11,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "kmeans_labels = [str(i) for i in kmeans_model.labels_]\n",
    "\n",
    "(\n",
    "  ggplot(circles, aes(\"x1\", \"x2\", colour = kmeans_labels)) +\n",
    "  geom_point() +\n",
    "  theme_minimal() +\n",
    "  theme(panel_grid_minor = element_blank(),\n",
    "        legend_position = \"bottom\") +\n",
    "  labs(x = \"First dimension\", y = \"Second dimension\",\n",
    "       colour = \"Cluster #\")\n",
    "\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "🗣️ **CLASSROOM DISCUSSION:**\n",
    "\n",
    "What went wrong?\n",
    "\n",
    "Essentially, the k-means algorithm partitioned the feature space into 4 distinct slices, ignoring the nested ring structure of the data.\n",
    "\n",
    "👉 **NOTE:** To see more about how different clustering algorithms produce different kinds of clusters in different scenarios, click [here](https://scikit-learn.org/1.5/modules/clustering.html).\n",
    "\n",
    "# Introducing DBSCAN (30 minutes)\n",
    "\n",
    "The DBSCAN algorithm overcomes some of the short-comings of the k-means algorithm by using the distance between nearest points.\n",
    "\n",
    "The below code will implement `dbscan`."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"sgHcGy\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "   \n",
       "   (function() {\n",
       "   // ----------\n",
       "   \n",
       "   var containerDiv = document.getElementById(\"sgHcGy\");\n",
       "   var observer = new ResizeObserver(function(entries) {\n",
       "       for (let entry of entries) {\n",
       "           var width = containerDiv.clientWidth\n",
       "           if (entry.contentBoxSize && width > 0) {\n",
       "           \n",
       "               // Render plot\n",
       "               if (observer) {\n",
       "                   observer.disconnect();\n",
       "                   observer = null;\n",
       "               }\n",
       "\n",
       "               var plotSpec={\n",
       "\"data\":{\n",
       "\"x1\":[-0.1385234304379497,-0.968404878770772,0.2367122400692957,-0.8116432101298103,-0.1989328276846431,0.1562865006930383,0.0418799638221204,-0.234075069268132,-0.2791532938102485,0.6777068447254445,-0.1103164242844411,-0.3059735909635604,0.236909501962332,0.3392661048637714,-0.8174875761231151,0.2694949165160713,0.1881777130201391,-0.9517849323685644,-0.9354595052839584,-0.4900470062659255,-0.1595283266954398,0.2972496191943019,0.018101721084598,-0.0702451122816901,0.2926071500699811,-0.0077971267627824,-0.556345415179456,0.2727516407949819,0.3588624567451891,-0.9275324468001211,0.4070805128934966,-0.0099149661386284,0.3915481254883153,-0.0914228820295895,0.5568286456708167,0.0294298516101975,-0.0478517395521724,0.2421612596128086,-0.244605853816717,-0.2693045202222509,-0.3497641513762519,-0.232645615164422,-0.952521555253614,-0.2113184648650455,-0.2065585494361429,0.9825253087307356,0.1389748868262583,0.0660676940549479,0.1147984261855755,-0.9957867662800096,-0.0685288220083554,0.2954591437452022,0.1465467675073756,0.2665348147202847,-0.0345529929348901,-1.0056808667851926,0.9785656522339176,0.7831483757961263,-0.545033496554271,-0.3133949440447747,-1.029966844406068,0.1433343572413716,0.2866543649083677,-0.0317319389324139,0.2757281302046473,-0.0956636935884884,0.1729447541382895,-0.3969869348461352,0.2008646892693458,-0.0628612753383157,-0.8967901642193171,-0.4119444682544819,-0.1847258071316249,0.268930942736871,0.6174700682867629,0.951558505938648,0.0368723308533419,0.017909392351217,0.9363336815076668,-0.052040849025586,-0.2373288848444096,-0.2625045768510721,-0.1933961316655393,0.99468634061051,0.0888711962326175,0.8118057050296555,0.5428003709268114,0.3109444730143115,0.1541626302293454,0.9461645356719848,-0.2785657995173437,0.2484591226325496,-0.0010375311657842,-0.0081149062065542,-0.1554774300095328,-0.8431742590377078,0.8768496699399508,-0.1752182335470386,-0.1368912659662658,-0.2156320944370024,-0.7115498917632788,-0.1309104590881496,0.2111858100802197,0.1179473970125769,0.1445131385691795,-0.3426054612066069,-0.0434535102213614,-0.3061116659979073,-0.1717628078880773,-0.4986109153379811,-0.1204944728103138,-0.6851424401320018,-0.2806441968808778,-0.709423824654942,-0.2511548935355158,-0.2602342494941747,0.7485618060607664,0.5682912166172756,0.952319821343578,-0.783032829847297,0.2963783585240289,-0.2139941108125244,0.1878970439803911,0.967215856973874,0.0607521903251049,-0.243743643580321,0.1797270637757366,0.5172518436561979,-0.2270026320470816,0.3305688350788389,-0.2317967886000417,0.9457263940376598,0.2645786706948564,-0.1630364745694128,0.9954842048547822,0.3359013488637598,-0.2439907696142858,-0.8663029459878253,0.8929349969605112,-0.8622263476689399,-0.229159395809796,0.1727534048016044,0.1847864097917901,-0.929258669605182,0.2788222421729484,-0.2890456876692325,0.070612010505883,-0.2386969743092462,0.2103158289049959,0.9297879163722031,-0.1361139558303136,-0.1729538280734344,0.0265051909214146,-0.2569896933451047,-0.0560250582267893,0.309452147733206,0.1165203117253023,-0.1353851406625731,0.4672849615454277,-0.9614946430628382,-0.8596603536498789,0.6855381839573991,0.235492369177217,-0.9149504118553272,-0.4320624357453775,-0.2572714692018278,-0.2770231031182066,0.2174064476174789,0.5520296229140162,-0.2986750814168907,-0.2122121303986662,-0.919824049103648,0.2803887030153897,-0.7412017550335901,-0.0227292495679937,0.0328707576552672,-0.2599484094374302,-0.1012508986802072,-0.2589911277133656,-0.9721495522587272,-0.255665910713144,0.0755462508437808,-0.0111057147731749,0.2671712539142701,-0.0733161147152511,-0.1220718092646662,-0.2620300026221732,-0.45187714098771,-0.1302253370442017,0.0262748294558733,0.281440575851569,-0.201006020508358,0.1674044245528351,-0.07759791876031,-0.7808154562185049,0.019259429427906,0.1469610805524063,-0.6998192377652053,-0.1519638650170033,-0.3087517672749177,0.0768214610591858,-0.2895717869074933,-0.295674474298057,-0.0128035222042246,-0.9526397493413844,-0.2959259843206596,-0.1389338905923149,-0.1278931536688877,-0.059119117021386,-0.0618990395527633,0.0305940025459174,-0.2166065227007334,-0.2446527461868317,0.0242592435075139,-0.8919384305645286,-0.1565624578759386,-0.9267159313414686,-0.1205231841335554,0.1143114210952407,0.0835979974346431,0.1269357937068478,0.1438309826086942,0.1492461359336777,0.2339331251295731,0.307173926389369,0.3015374291838182,-0.2524063665116942,0.2260689628471303,0.285776413992703,-0.2554388301316829,-0.0633947685911547,-0.0520928082840772,0.7506486615307003,0.0973979944303854,0.9603707079528646,0.244236319278521,0.0656572307074492,0.1513813024724465,0.2727189272517276,0.0617791790546635,1.0319500897237133,0.9535442258249034,0.1159219333595456,0.2920651943746812,-0.0423096793316379,-0.1094746295847633,0.2773613107187705,-0.2823902067674736,-1.0342932056316818,-0.9966179135352626,-0.1522701336822554,-0.2237263933359271,0.7825010299658266,-0.0205410799752592,-0.0920946079310479,0.4880459764882904,-0.9621877717907642,-0.2747841503567565,-0.9211090771223024,-0.2680514044019541,-0.0424786731502672,-0.9759227103721552,0.0931600005271127,-0.2767699186921158,0.4833185137925599,0.0329937927999215,-0.0369265173389767,0.5362850505013546,0.0415430581699844,0.4386418992445642,1.007143828728354,-0.2655499938501351,-0.3355125561541497,-0.22004831891769,0.2090513957633389,-0.2369876816565132,0.1497335287608705,0.0762749047424607,0.262594831682373,-0.7312902227561765,0.2468292874100151,-0.416695228057896,0.2126765863927177,0.3467433930749246,0.2738751994417496,-0.8468271361832991,0.2585182283680209,0.1269668725871344,0.0281925929771764,0.1713775129940706,0.1875913591568772,0.1312300966224205,0.2557653558357532,0.198162671662213,-0.0265555224576158,-0.0158922879154333,-0.3033427842244655,0.8287446708849951,0.2338039037019024,-0.358653057773823,-0.0694072671488604,0.0702777562333065,-0.7015129353392298,-0.3100170370378283,-0.6807283196234142,0.9997251461455788,-0.7355142937294711,0.1553701071355268,-0.0826349134367788,-0.1054246891678987,0.1699716517358936,-0.3088524003154511,-0.1652009895809198,0.0571380908418484,0.232627919980537,-0.1585385662119197,0.2245090569808719,-0.4744773498248544,-0.1185769886504174,-0.2427846234659564,-0.0708168236481903,-0.3211265760412773,0.8048484088990872,-0.2501781788207414,0.1929554775659887,-0.0903248052094329,0.9103361075534347,-0.1637735214054645,0.2458662669660795,0.3646426688371993,0.0399614328647831,-0.5724228443825059,-0.3195230765430936,0.2157374376333453,-0.2039920176585973,0.7548841342909611,-0.0828265335296252,-0.1434333481310609,0.763762479176805,-0.1353156903554065,0.0727799134577408,-0.0742137733906372,0.2609679797741085,-0.2517775925270532,0.1659419198354751,0.2683074475389219,-0.1680800314241699,-0.1047476949117219,-0.289320156858102,-0.2222671356375418,-0.2501546070666143,0.1412219402848953,0.2627600006221074,0.928524276911942,0.182698137147228,-0.2476655186683797,0.2702020548040014,-0.0691127997875169,-0.1754735995920879,-1.0080183605813786,-0.0771211637192359,0.7571040681341497,-0.2516468870231406,0.8408097773234195,0.2232486196877526,-0.8151951121768007,0.1737237120650531,0.282187832165285,-0.0854576094362201,-0.2846315841575234,-0.247760171480601,-0.2489434969035713,0.9359928481470016,-0.3184276064053256,0.2780956955117652,0.3593078001282489,0.3464318685537267,-0.5306809422988833,-1.0140521453239366,-0.7404622088395693,0.3304868235001911,-0.5044513439820726,-0.3241633079759849,0.0247693429231923,0.1526058298680864,-0.0413855724251043,-0.639844432871609,0.078594594796724,0.1963993229360476,0.2316010422356015,0.0478157733234298,-0.9444019886054532,0.3084864306993309,0.276188691543865,-0.0077337874430667,0.1545653165760284,-0.1728553254128005,-0.2251287125382435,-0.614315207189044,-0.1372980662533991,-0.2993470316243778,0.2919630774114096,-0.0033792097852051,-0.9762381592208784,0.0240245554313452,-0.1639346029578446,0.2941649638616872,0.0522233380355403,0.2408065470951337,-0.0496471926621285,-0.1016302006257871,0.1035403272577982,0.0991342373848368,0.8130166458240975,0.0590314801582622,-0.5698784072524513,0.173491974008791,0.09282367661897,0.1865315360906637,0.2399089840710199,-1.0274187414969955,0.1051030276521082,-0.2951828114905452,0.2701473612686966,1.0067430590541928,-0.2780563393397526,0.1999889877471789,-0.2101098512134586,0.2893884170363056,-0.2014184832200256,-0.7811556134662724,-0.2419118146130908,-0.2469059605365172,0.1299723387510945,-0.6349043578159463,0.3577216733397898,0.9892913066641996,0.2815115065893698,0.1101039196644467,-0.2990603645882504,-0.1665950012358033,0.2151831150071114,-0.2634079878963455,-0.872701433606142,-0.2584667939331593,0.9130622018270764,0.1822193110457124,-0.2026757929289422,0.3296253723607074,-0.2957349048389931,0.2426537184815384,0.2196192862164607,0.0194419607894327,0.2838893965462531,0.0673594220392598,-0.2889713580299942,0.2898774923323535,0.2099808320938593,-0.9076812600775116,-0.4826357037325296,-0.9806322467983823,0.0366652105965166,-0.944768494943647,-0.4794425281092463,-0.2446399039688192,0.2449608564532175,-0.2442262844874063,-0.1665525033004358,0.2191795134362961,-0.7723072317119826,-0.273680018685718,-0.3189107027620051,0.9706294106731842,0.1633909902353295,0.2125178258060883,0.3308937475192985,0.2797034411102999,-0.080049110429213,-0.7368844693265978,-0.1939120234698752,0.0960467159500105,0.1559621092690796,0.2736952655741569,-0.0739232592964769,0.2984033567248106,0.6032217461717146,-0.2324744943344396,-0.1533683478630272,0.1327833364518977,0.5052238465804747,-0.0374998435501213,-0.2625289616650838,-0.2897987335147298,0.9893031769576068,-0.3154414067518175,0.2685765837671198,1.0119031003512942,0.3926914283093114,0.1964398440712108,-0.1818980214894232,-0.0486876206532493,-0.2561359663333503,0.3127764766709273,0.8352397396667975,0.2560847903909042,1.0271755359957966,0.2648894389219105,-0.8069033899887501,-0.2852804963466216,-0.2357006850682213,-0.1915082235262562,-1.014816072023465,0.3232186119328753,0.3248129964474673,0.3073252291718696,-0.2128921527608318,0.274715475968089,0.7235839815889867,-0.2121437035965687,0.0494289136960012,-0.2974331000568898,-0.2209840217785891,0.8124138416081572,-0.3646523324171764,0.2690827112807456,0.2544845456019077,-1.0072989783013135,0.8359224851409064,0.4936735407761751,-0.2289769588127978,0.0498610001309933,0.4466030222617423,0.2380142463204957,1.0336909657159474,-0.2716295973518515,0.2614953885022163,-0.277445305407101,0.2648714982454507,0.1830185504165012,0.1264543801950012,0.2565709451803408,-0.2462293047479328,0.227304640305774,-0.1937629854358601,0.243582662193687,-0.2090765909940639,0.2401931885494654,-0.2103285075427028,0.185252602787424,-0.1066693389905974,0.3139566544041806,-0.0727914756942635,0.2903717241461807,-0.2272296190307125,-0.2672343331192347,-0.2016477056085781,0.1363512446565452,0.9063183735064678,0.9720894997832696,-0.4432640831438624,-0.2591162598963109,0.1895019310156389,-0.1912847583582667,-0.2110829528563644,-0.6031511285084189,-0.8289398366808465,0.8452322158858073,-0.6982147293460435,0.7134656248336756,-0.2824297911897867,0.2919362017419363,0.303525342081807,0.6791653120568293,0.6232789147017476,-0.2433895216335896,0.666989640026438,0.5905926340143132,0.2748065621739277,-0.0666484961745779,0.0581288226349481,1.0164738813571057,0.102533531557135,0.0975442583808523,0.2600053963564839,0.9477942706980088,-0.1312244941210046,0.0142098607368106,-0.1287277172902274,0.2587165629064178,-0.0392819496064969,0.9894208889083764,-0.2303754789265607,0.9110382175889622,0.0026976763754824,0.0855041320588824,0.4034359137412558,-0.618980822674548,0.2187396801002969,0.1227946507389817,0.002238227312223,0.124761874517136,-0.272830303898087,0.3096937471726819,-0.2425434929175533,-0.1016433818875407,0.7068166927231019,0.260462617523079,-0.3779413623294649,0.0157880789215005,0.2643228102133578,-0.1228310428143801,-0.0217871757393988,0.2921830138717942,0.2686607838426416,0.2349306389039006,-0.1169757159477485,0.127689995510136,-0.2729585387171457,0.2255888302909137,-0.0163536026559523,0.1215000309103625,0.3269921007325545,0.3050090930669475,-0.3239815367794843,0.3219645533442101,0.1528473759180416,-0.9810409583251972,0.0848749714184419,0.7923509131395182,-0.7912583180656771,-0.3222116806483267,-0.1591297452117782,-0.3178149764899974,0.0632976121053907,0.2484822537932069,-0.0733512348213416,0.2565594154905227,-0.2711563768748005,-0.2792643703747319,-0.1953538331745301,-0.2977296780852061,0.8585256728675684,-0.0635884342637367,-0.8226819037486809,-0.2887779604287342,0.1742623862984751,0.3099086945282433,0.2205434726646344,0.980526013320548,-0.3339687804517109,0.6623272512110318,-0.223645693533557,-0.9634528117589096,0.3530202221728791,0.4182336702340584,0.2591836688074864,-0.3477753675742409,-0.0152469803664412,0.6079732494520961,0.2987441252484457,0.2304092462972853,-0.2021529561617544,-0.2829521293742039,-0.3449006851047188,0.6098815197645558,1.027407747163033,-0.660472346532067,0.2494283329140437,0.2424442397352634,-0.0176438583648665,0.0397605648841977,0.273897061679425,0.1873149641781564,-0.0660913563715643,-0.281445464058554,-0.3362869478876946,-0.0860631126659446,0.3471702806135713,0.5764806847498569,-0.7484960110020671,0.9682293278782568,-0.3134477874574476,-0.3053184526946665,0.202421243526702,0.3033458080892134,-0.1928442367642441,-0.1851994665195947,-0.1315245376354039,-0.8992927377044504,0.7741411952129615,-0.1579625837187375,0.2409294564713739,0.1685222962395413,-0.2580957494238489,-0.0497220947236745,-0.9421691120875696,0.9847598487670522,-0.9709107319210852,0.3021672804206495,0.1948269164803593,-0.5394557922749162,-0.0984001447749432,0.2405487859048737,-0.0453679499375168,0.3064578959887092,0.2051722353158377,0.9846014570678712,-0.1710000829293804,-0.337069301830705,-0.3122248793261121,-0.0641135000602808,-0.16265115411139,-0.2668360759743786,0.8555913440674121,-0.3040670931042752,0.1137514941753848,0.0036210061680852,-0.2736408370327245,-0.4033012804017144,-0.2315277783431498,-0.3286329083885775,-0.7950734076818805,-0.0951041689664277,-0.2340018489016148,-0.0542455995425817,0.0407281223457891,-0.1133911717619168,0.0397792928176397,0.2198895355057977,0.3587008418590788,0.1195748106317213,-0.2715079091354311,0.0950581093507428,-0.2597029805132124,-0.3094222828563848,-0.0657080446465774,-0.1444274825164247,-0.0724635044554179,0.1756011314790994,-0.2512237395078328,-0.1408273799927261,-0.9888559823720098,0.1233570667232021,0.2436402793243978,0.312375742240417,0.1402375134712878,0.2763825642151415,0.0226720175304713,0.9854904871758912,0.0988482820274384,-0.2904350686466702,-0.968404878770772,0.5797229025467567,-0.8116432101298103,-0.4047086411972457,0.1562865006930383,0.0770204424424176,-0.518689340151846,-0.6689640429248794,0.6777068447254445,-0.1654325405582963,-0.705184282334869,0.5514248748169797,0.7266993693152238,-0.8174875761231151,0.2694949165160713,0.3896269936744435,-0.9517849323685644,-0.9354595052839584,-0.4900470062659255,-0.3695981786799581,0.6972180368758283,0.1224383236005569,-0.1842528172696805,0.635617812547442,-0.0228731998307562,-0.556345415179456,0.2727516407949819,0.3588624567451891,-0.9275324468001211,0.4070805128934966,0.0202157560725448,0.3915481254883153,-0.2339876335148898,0.5568286456708167,0.0944847176881511,-0.1129066056301258,0.6158928365954536,-0.6200993968782667,-0.6222210107962322,-0.7301867578943133,-0.5648839748427471,-0.952521555253614,-0.4544905839428877,-0.5179434700629523,0.9825253087307356,0.3183281732622711,0.1211838103288032,0.2667100643942962,-0.9957867662800096,-0.1186621154340771,0.6863663931724796,0.3775758488762825,0.5959478537716556,-0.0345529929348901,-1.0056808667851926,0.9785656522339176,0.7831483757961263,-0.545033496554271,-0.6995475995780842,-1.029966844406068,0.2133435808314821,0.6753070580742373,-0.0417839771097488,0.6545674522025451,-0.2750169800245012,0.4161168732161316,-0.3969869348461352,0.2008646892693458,-0.1816779079691297,-0.8967901642193171,-0.4119444682544819,-0.1847258071316249,0.268930942736871,0.6174700682867629,0.951558505938648,0.0368723308533419,0.0580540782917029,0.9363336815076668,-0.1220500726156964,-0.5878515568619551,-0.628601045899439,-0.4444726761818194,0.99468634061051,0.1883471510985594,0.8118057050296555,0.5428003709268114,0.7047702068259937,0.3424442030954784,0.9461645356719848,-0.660511617416001,0.6037137021579674,-0.080921523371547,0.0019371319707808,-0.3865065113784399,-0.8431742590377078,0.8768496699399508,-0.4301878294465145,-0.2216941099350877,-0.517332646731444,-0.7115498917632788,-0.3236119287288357,0.528781969539354,0.2367640296433907,0.3193594452295526,-0.3426054612066069,-0.0935868036470829,-0.6701540542719056,-0.4305851925158551,-0.4986109153379811,-0.2908061894363429,-0.6851424401320018,-0.6795077569851233,-0.709423824654942,-0.6283511078926616,-0.5952454655110314,0.7485618060607664,0.5682912166172756,0.952319821343578,-0.783032829847297,0.678324176422686,-0.432551849506232,0.4653583663055131,0.967215856973874,0.1553517891345948,-0.6035057442068695,0.1797270637757366,0.5172518436561979,-0.5564156710984526,0.3305688350788389,-0.5334973408944832,0.9457263940376598,0.6620231949028598,-0.4404977968945348,0.9954842048547822,0.7357750245770797,-0.5521960667246015,-0.8663029459878253,0.8929349969605112,-0.8622263476689399,-0.5991902785435793,0.439158151775305,0.4436087944195678,-0.929258669605182,0.6293449141904938,-0.6858915681950237,0.1749486130218418,-0.537073432478919,0.4841346712764713,0.9297879163722031,-0.3332048924496302,-0.4161259471512764,-0.0036255312897585,-0.640398408952055,-0.1457333626065419,0.6928608633401563,0.3516344126422915,-0.1353851406625731,0.4672849615454277,-0.9614946430628382,-0.8596603536498789,0.6855381839573991,0.5371929214716585,-0.9149504118553272,-0.4320624357453775,-0.6192022901882356,-0.6200337655956675,0.5524176636343356,0.5520296229140162,-0.6820837970238411,-0.2122121303986662,-0.919824049103648,0.6750630806985369,-0.7412017550335901,-0.0026315222960858,0.1225790620350196,-0.649759158552061,-0.2670011310775208,-0.6270838666597137,-0.9721495522587272,-0.5879042703914691,0.1991530485937597,-0.051250400713661,0.6152447557820805,-0.172792069581193,-0.2693216303385374,-0.5246643049233557,-0.45187714098771,-0.3571329166949043,0.0913296955338267,0.281440575851569,-0.4361201214253473,0.3005322423620298,-0.196414551391124,-0.7808154562185049,0.0443756372396315,0.3612917985440049,-0.6998192377652053,-0.3662945830086019,-0.6935628359093521,0.1762974159251277,-0.6833975207191755,-0.6637672132444051,-0.0128035222042246,-0.9526397493413844,-0.6620224533690267,-0.3227658348409099,-0.3027394603292609,-0.059119117021386,-0.0920297617639363,0.1153968465147392,-0.479240825001916,-0.6393271238699789,-0.0108812351127833,-0.8919384305645286,-0.4153848425037162,-0.9267159313414686,-0.2816857584190205,0.2708608878301219,0.0835979974346431,0.2409434986948384,0.1438309826086942,0.3761537155843803,0.6000295941779402,0.6919849950238033,0.6221642231321688,-0.2524063665116942,0.5664667555650073,0.6576870083480036,-0.5984494926091438,-0.0633947685911547,-0.0520928082840772,0.7506486615307003,0.2585605687158505,0.9603707079528646,0.6303889748118305,0.194034674630333,0.3571571159850492,0.6131167199696043,0.1119124724803852,1.0319500897237133,0.9535442258249034,0.2537791026293524,0.5970421987792603,-0.1073645454095912,-0.3021760992254494,0.6693033316724692,-0.662812813285535,-1.0342932056316818,-0.9966179135352626,-0.3493610703015721,-0.5351113139627365,0.7825010299658266,-0.0155146640219182,-0.2204720518539317,0.4880459764882904,-0.9621877717907642,-0.6676990506482319,-0.9211090771223024,-0.6136207712790882,-0.1025689087985699,-0.9759227103721552,0.2215374444499964,-0.670595652503798,0.4833185137925599,0.0530915200718293,-0.1217293613077986,0.5362850505013546,0.1361426569794743,0.4386418992445642,1.007143828728354,-0.6111193607272692,-0.7354809738356762,-0.5465840192045636,0.4754561427370396,-0.6124812247180629,0.3640642467524692,0.218839656227761,0.6266372199563713,-0.7312902227561765,0.5582142080368244,-0.416695228057896,0.4937365743122575,0.3467433930749246,0.6738751994417496,-0.8468271361832991,0.6160547980285265,0.1269668725871344,0.1080765851829392,0.4185213582302043,0.1875913591568772,0.245237801610411,0.5823010561226267,0.4792226595817526,-0.0315819384109568,-0.035990015187341,-0.7007873084324688,0.8287446708849951,0.5321803618715752,-0.358653057773823,-0.1443597929831503,0.0702777562333065,-0.7015129353392298,-0.6961696925711378,-0.6807283196234142,0.9997251461455788,-0.7355142937294711,0.3863991885044338,-0.1575874392710687,-0.2290314869178777,0.4091336449589012,-0.6728947885894494,-0.4162775340971999,0.1663188650487787,0.232627919980537,-0.3977005594349272,0.4430667956745795,-0.4744773498248544,-0.2277577628573475,-0.5957011140399378,-0.2273662903830712,-0.7199901361455229,0.8048484088990872,-0.5737849765707204,0.4030253295505069,-0.2651711118698059,0.9103361075534347,-0.3520550942715974,0.5304805378497937,0.7641374514796063,0.034935016911442,-0.5724228443825059,-0.6914336708983942,0.3995693818819405,-0.5215881771177314,0.7548841342909611,-0.2393760002645061,-0.3448826287853652,0.763762479176805,-0.2731728596252132,0.1915965460885548,-0.1639220777703896,0.6290607187204565,-0.5433650434956179,0.1659419198354751,0.6544601030722313,-0.4230496273236457,-0.1047476949117219,-0.6297179495759787,-0.2222671356375418,-0.5982281089344246,0.3922984848011756,0.6431826071401687,0.928524276911942,0.4528312603956377,-0.5712723164183586,0.6473982691611473,-0.1637123985970066,-0.4565335875116276,-1.0080183605813786,-0.2007279614692149,0.7571040681341497,-0.2516468870231406,0.8408097773234195,0.5314539167980683,-0.8151951121768007,0.4248002565813333,0.6719985812799159,-0.213835053359104,-0.6826119909500434,-0.5742958717674745,-0.5634588697582189,0.9359928481470016,-0.7183012821186455,0.6749415760375564,0.3593078001282489,0.7464002862352532,-0.5306809422988833,-1.0140521453239366,-0.7404622088395693,0.7243125573118734,-0.5044513439820726,-0.7216078321839883,0.0247693429231923,0.3917678230910939,-0.0665017802368296,-0.639844432871609,0.1237371487461166,0.470218165307523,0.627785612514262,0.1178249969135402,-0.9444019886054532,0.7039471285944965,0.6550280135417627,-0.0528763413924594,0.1545653165760284,-0.3247669636215209,-0.5427248719973776,-0.614315207189044,-0.2798628177386993,-0.6940214093075251,0.6638736717667102,0.0217369980265202,-0.9762381592208784,0.0989770812656349,-0.4520582129130074,0.6517015335221927,0.1994731591094116,0.5863759139722678,-0.2153974250594422,-0.2347580184349819,0.2738520438838273,0.1492675308105585,0.8130166458240975,0.2062813012321333,-0.5698784072524513,0.49709877175877,0.2899146132382867,0.4781189870592283,0.4870528293071537,-1.0274187414969955,0.2142838018590383,-0.66891438847319,0.6341897495426948,1.0067430590541928,-0.662867407974187,0.4626232900483614,-0.5183151483237743,0.6848491149314712,-0.4485623284561594,-0.7811556134662724,-0.5369170615563604,-0.4779350419054242,0.2678295080209014,-0.6349043578159463,0.3577216733397898,0.9892913066641996,0.6807221979606783,0.320173771648965,-0.6899676140155279,-0.4329997482095039,0.5067705659756762,-0.5928210269477164,-0.872701433606142,-0.6203976149195671,0.9130622018270764,0.4049695576409876,-0.4764946353004176,0.7264712528864986,-0.6911956027341587,0.5720667575329094,0.5278245833267764,0.0745580770632879,0.6344120685637986,0.0673594220392598,-0.6465079276904997,0.6043928651870011,0.2099808320938593,-0.9076812600775116,-0.4826357037325296,-0.9806322467983823,0.0818077645459092,-0.944768494943647,-0.4794425281092463,-0.6446083216503458,0.5563457770800269,-0.2442262844874063,-0.3893027498957109,0.5892103961700794,-0.7723072317119826,-0.6691407165808836,-0.3189107027620051,0.9706294106731842,0.3902985698860323,0.5331446197544392,0.7143024631262489,0.6534350180929447,-0.1843857129451717,-0.7368844693265978,-0.5536741240964236,0.0960467159500105,0.3574113899233839,0.5687005125174264,-0.0739232592964769,0.2984033567248106,0.6032217461717146,-0.5531012882827904,-0.3591441613756297,0.3076296431122708,0.5052238465804747,-0.0374998435501213,-0.6200655313255893,-0.6617093278700305,0.9893031769576068,-0.3154414067518175,0.6614914840585953,1.0119031003512942,0.3926914283093114,0.514036003530345,-0.1818980214894232,-0.1087778563015521,-0.5545124245030232,0.6747072976573352,0.8352397396667975,0.6158468910174526,1.0271755359957966,0.6201440184473284,-0.8069033899887501,-0.6781953966380971,-0.5909552645936391,-0.5265194395431129,-1.014816072023465,0.6932494946666585,0.7245287855037029,0.7035097994505302,-0.4939521406803715,0.5628390859232518,0.7235839815889867,-0.4472578045135579,0.0795596359071743,-0.6762724220547874,-0.2209840217785891,0.8124138416081572,-0.3646523324171764,0.6685774939231526,0.607401036175889,-1.0072989783013135,0.8359224851409064,0.4936735407761751,-0.6209189797664965,0.0548874160843343,0.4466030222617423,0.62282531495493,1.0336909657159474,-0.6700830410091204,0.6095688903700266,-0.5824223098116801,0.6623160224534541,0.5511112893628494,0.3235453168143177,0.6452236383462104,-0.5839604749487387,0.4822742362052499,-0.46389610868427,0.5701183624805606,-0.486537913319186,0.5451701929540446,-0.4949427784264169,0.4203667037044132,-0.2445265082604042,0.7068715546956561,-0.1279075919681186,0.6658652672077302,-0.474373464266846,-0.5817497059738822,-0.4680524525822788,0.3549089833502529,0.9063183735064678,0.9720894997832696,-0.4432640831438624,-0.6589899356096308,0.3952777445282415,-0.4304467515812742,-0.5591564547241747,-0.6031511285084189,-0.8289398366808465,0.8452322158858073,-0.6982147293460435,0.7134656248336756,-0.6596260055469325,0.683878222695635,0.7027360334531155,0.6791653120568293,0.6232789147017476,-0.2433895216335896,0.666989640026438,0.5905926340143132,0.6727869689664477,-0.1612480949840677,0.0982735085754341,1.0164738813571057,0.1774860573914251,0.2540937251157332,0.2600053963564839,0.9477942706980088,-0.3455552121126032,0.0242618989141456,-0.2990394339162566,0.5909549225847428,-0.0392819496064969,0.9894208889083764,-0.5041943212980362,0.9110382175889622,-0.0073543618018523,0.218631949868077,0.4034359137412558,-0.618980822674548,0.5204402323947384,0.2885448831362953,-0.0228779804995022,0.2766735127258564,-0.6465618808807317,0.7043681248558291,-0.563170286865904,-0.2347711996967351,0.7068166927231019,0.592700977201404,-0.3779413623294649,0.1005909228903223,0.6640385992695935,-0.2839936170998452,-0.006711102671425,0.6906364575290632,0.2686607838426416,0.5805000057810348,-0.3184249966020528,0.2702547469954363,-0.6698044192429369,0.510203101174628,0.0437366329923505,0.3142015005510489,0.7168028498471853,0.6805026361284972,-0.7201661070581449,0.7093978177956625,0.3140099502035066,-0.9810409583251972,0.0848749714184419,0.7923509131395182,-0.7912583180656771,-0.6922425633821099,-0.338483031647791,-0.7052482409414499,0.1233878477536935,0.5434875007364764,-0.1776878373373003,0.6564330912038427,-0.6115541695926772,-0.6679170635406015,-0.4903590801177996,-0.6796754959838632,0.8585256728675684,-0.0635884342637367,-0.8226819037486809,-0.6796852098560117,0.4292319821979511,0.7083621381855122,0.2205434726646344,0.980526013320548,-0.3339687804517109,0.6623272512110318,-0.223645693533557,-0.9634528117589096,0.7334428286909405,0.4182336702340584,0.5827904665574654,-0.3477753675742409,0.0198934982538559,0.6079732494520961,0.6896513746757231,0.518532856252448,-0.5071299605663336,-0.6826679184304395,-0.7441113764760273,0.6098815197645558,1.027407747163033,-0.660472346532067,0.6113591539004516,0.5801754099360694,-0.0627864123142593,0.0397605648841976,0.6510932760365709,0.4499492664793391,-0.1752721305784943,-0.6733874850122528,-0.7357817305301017,-0.0860631126659446,0.7460338407178169,0.5764806847498569,-0.7484960110020671,0.9682293278782568,-0.7114281942499676,-0.7050342417509021,0.5007977016963748,0.6562622986631947,-0.4844316877328087,-0.3734810393857278,-0.3500822763291115,-0.8992927377044504,0.7741411952129615,-0.1579625837187375,0.5786606266721801,0.3912725428348166,-0.6542803197025094,-0.1197313183137849,-0.9421691120875696,0.9847598487670522,-0.9709107319210852,0.6682637494690166,0.4722882388054813,-0.5394557922749162,-0.0984001447749432,0.4837209049827158,-0.030291876869543,0.6884037138873664,0.5401834513326944,0.9846014570678712,-0.4411332061777901,-0.6875919738482503,-0.7122248793261121,-0.1042581860007668,-0.3099009751852611,-0.5549596859295413,0.8555913440674121,-0.3040670931042752,0.306452963816071,-0.0164767211038226,-0.6113720072335306,-0.4033012804017144,-0.6201804715090193,-0.7270863520458464,-0.7950734076818805,-0.130244647586725,-0.4178337931502098,-0.1341295917483446,0.0256520492778155,-0.3234610237464349,0.1196632850234024,0.4900226587542076,0.7566812486515988,0.2989280970677342,-0.6503472311333288,0.2788900535993379,-0.6149575600386302,-0.7089170654987919,-0.1797157496345678,-0.3713350621671273,-0.1719394593213597,0.3459128481051284,-0.6386570039592853,-0.3635776265880013,-0.9888559823720098,0.246963864473181,0.5024626639521756,0.6721378428669654,0.3059877458686014,0.6752461243193871,0.1123803219102238,0.9854904871758912,0.2871298548935716],\n",
       "\"x2\":[0.2652371636080013,0.1131631581337271,-0.1733968125835168,0.5542760377872187,-0.2703889703579717,-0.9738417435175094,-0.2809827368307136,-0.1447564214978481,0.0644475141005745,-0.7471536741811885,0.332666475916741,-0.0629950127731978,0.2056103583865236,0.104431654304317,0.5664840990969573,-1.0495648140565847,0.2536768616246788,-0.2761135141493472,0.3493368067208611,0.8676643347174068,0.2055937907115666,0.0304518758765982,-0.2928911688056429,-0.2616158024179665,0.1900213149619263,0.2934043184970543,0.8060121948573069,0.9423968320967548,0.907577596867593,-0.0489215573745599,0.930637571027046,-0.2892187748666321,0.844429336656185,0.1948488158933971,0.8297690521016335,-0.2754489559417776,0.282157140320302,-0.0944628476014749,-0.0528019748880543,0.1444191969206713,0.1158649987352082,-0.1704789849984286,-0.2974741355044185,0.2596553580862287,-0.2027641617249829,-0.0434929286782988,0.3391932093799026,-0.3183082963677733,-0.288523663070645,0.0647987775052138,0.2789338082152699,-0.0488722256398076,-0.3089742165004436,-0.1766179873310608,0.9813919311504312,0.054313806250125,0.4132008485723928,-0.5794157848470212,-0.8593901572362995,-0.0735025076381132,-0.0313316649966544,-0.3185376024487463,0.0028548825752882,0.3133873839500231,-0.1543853907968707,0.2923346884579976,0.1821481559658309,0.9141371084312184,-0.9479939236831424,-0.3074126972255938,-0.4451727967606284,0.9061180886253783,-0.961244110512696,-0.9415387490175388,-0.7990238398898287,-0.2849812569237476,-0.9927782125396312,-0.326874972520039,-0.3519547786095817,0.2992716624137175,0.1492036291963577,-0.0701580063265388,0.2822237614674912,-0.1350032713914082,-0.2676682878697312,0.6338425748489701,0.8213314636683493,0.071374228222408,0.2293990963664102,-0.3218270729948077,-0.1523983486914295,0.1678347760625345,0.329848569301495,0.2807041698999101,0.2663889207575099,0.4930026014881612,-0.4294227483220789,0.2409628889297189,-0.3032109150627639,0.1885781927247894,-0.7858340459964889,-0.2881436317347385,-0.1038292510027524,-0.2862002262406735,0.2667345803488641,-0.9326587946364574,-0.2508328878950195,-0.1863045714191303,0.2267168279777539,0.885600156848997,0.2812554852180505,0.8243768095351488,0.0316445653054251,-0.7052526975071733,-0.0364421064613124,0.1660010099397162,0.7505056702488455,-0.8436709163211766,0.2447071094398613,0.6293622434506109,-0.055309709190533,-0.2747254488743664,0.2078941537530653,-0.1290937577125363,0.2687823219829763,0.0965721008173242,0.9928135519228352,-0.8314617636632805,0.1415760578381452,-0.9829355688815696,-0.2364820400491719,0.3029875688692609,-0.0595324329870121,-0.2774452921869543,-0.2935479170039495,-0.0490974015633818,0.1894694880654894,0.4697479432100694,-0.5206886837766459,0.4342399538351137,0.0620052186071577,-0.2153239576271855,0.2395781255800455,0.4027291342214513,-0.1224295217819224,0.0562038333494711,0.2847614208053449,0.2120624002553139,-0.1898363688373409,-0.4616959101056157,0.2694715732725421,-0.2669432440885079,0.2803951323091155,0.08211467558116,-0.3246326917360623,-0.1271337321925787,-0.2895351405322086,0.950472901868249,-0.8964157725916333,0.3549774183177498,-0.4603256356114163,-0.7465154738508565,-0.1660962957175607,-0.4380169935922285,-0.8898627675475289,-0.1311374774677391,0.1417070106723148,0.1663066486461884,0.8167953148361392,-0.0095235722544612,-0.9034019041111414,0.5013479149132963,0.0193057050975716,0.6696041926140632,-0.295303918520277,0.2774488551784269,-0.0927824356881496,0.2435866452714153,0.1000796251540871,-0.2387288160282165,0.1632927541153124,0.2944301092100326,-0.2913801891314825,0.1938865454203878,0.2035261563280287,-0.3038105956156146,-0.2174455965212358,-0.88787958156518,-0.2456551167722853,0.337351263849312,0.9943855519133892,-0.252687700121479,-0.3597897229401163,0.2821427613941182,-0.5961680247792361,-0.2362978873313303,0.2302594858191247,-0.7220287929982037,-0.257987459459346,-0.0804895267735471,0.2950633989942162,0.0605930235590264,-0.1295032610930377,-1.0149081426645932,-0.1585202333416705,0.1332714737137881,-0.287127361103908,0.2500521866517565,-1.0043298308880506,-0.277428796746492,0.3000031191936843,0.2163388716060334,0.0615925840399506,0.3083434026428979,-0.3778923386835714,-0.2135986479806618,0.4480581494503034,-0.2878395456321349,-0.2464260642369047,0.9688001665455054,-0.2655424789582648,-1.0305363951252238,0.275753525124778,0.1191277469884441,0.0611840438748541,0.1915653316602343,0.9298796772622973,-0.1254783694711939,-0.1339539630175936,-0.1526160773157683,1.0297488807679949,0.9897052682466312,0.6415074916921967,0.2615000269976806,-0.3091487036197269,0.0302350163816744,0.2805988128870121,-0.2733440562659821,0.1794826415234645,-0.3093279739635368,0.1134173995913723,-0.4970905687789675,0.261564085708122,0.1626077890147478,-0.2466580574942165,0.2407710725892861,0.0884498270029465,-0.118339633982951,0.1966240917499239,-0.1223416090089478,-0.1633372341570794,0.1643166778324766,0.6555539069489257,-0.2900520204925202,0.2942731603551886,0.8580229092788658,-0.1195421152566914,-0.0360872403461394,0.2970512981669859,-0.166628317767195,-0.3004090898873551,-0.112126239293557,-0.3200231743175771,-0.0752193944143551,-0.8129657879997427,0.2957859542791355,0.2896901071343193,0.8362974170913913,-0.3394958334510736,-0.9260349284809012,0.2137842818015388,0.1659784702150942,-0.0398510897772519,-0.2507149196355184,0.2299739538071087,0.1002221157473969,-0.2649838078813744,0.2998338124227729,0.1389507565387186,0.7038423129759274,0.2174231129412918,0.933366060623831,-0.2275110319876126,0.92872590728421,-0.0065714413110362,-0.482338977827536,-0.1496456271841312,0.966574029842997,0.3628324359670952,0.2642473300446784,0.9633195906980324,0.2986501364800509,-0.1626190600537517,0.1672813373877119,0.3171584516646223,-0.3128440438542335,-0.0602490959944065,0.5895916340392886,-0.1799396135085032,-0.9335905261431552,0.3147636982514512,1.00246417400761,-0.6731530465719038,0.0507496470337365,-0.7414669066654699,-0.1621308727918415,-0.7521025383448041,0.2677357719576643,-0.276104778213012,0.2661629004560222,0.2878701280400499,0.1661510579035321,-0.2023198460109206,-0.2851112690344138,1.001469780276227,-0.2102596940767441,0.245358450118863,-0.9061478530200316,0.3046170421513919,-0.14881363380965,0.2790100220633915,-0.0141344505094717,0.5526428183918866,0.1662701832766646,-0.2306618865776373,-0.245813122567351,0.4766370127342835,-0.2787874290371696,0.2392816940113908,-0.0383550740950973,-0.2761092950060416,0.7852158775113091,-0.099455611182671,-0.2260036495101958,-0.1731776458366091,-0.6182104207869628,-0.3026772630273666,0.2884417140118485,-0.7155713843674615,-0.3312498821733951,0.3320536172039431,0.3511600352408377,-0.0822134525204033,0.2271930911477635,-1.0204852695788813,-0.0691698597735019,-0.2466628741814805,1.0320603776894086,0.1777886264314118,0.9470476397345172,0.1564078763545993,-0.2529476335839155,-0.076336004936729,0.3493019694211195,-0.1811909800150039,-0.1803090731838064,-0.1260494464388945,-0.2308632959799021,0.2248271887831476,-0.2770653248216471,-0.2931299506331437,0.635843549052004,-1.0045697378444245,-0.5659049003582861,-0.2357262533955062,0.4614370994168014,0.273311434563696,0.118587219414095,-0.2637955319114227,-0.0268121309511584,0.1692772329157613,0.2021543481662527,-0.2804030474667302,-0.0541371400036683,0.0063696447200126,-0.9304205467600491,0.0372752441788764,0.8856403798729975,0.2272638305910354,0.6488221762526442,-0.0628627523024925,-0.8888004572220821,-0.0078409183285302,-0.984520312808786,-0.2697883808897913,-0.2997856730203719,0.823485378116767,0.3300881082158541,0.1964150756207749,0.0553558790363879,0.2980690851606423,-0.355015123657411,-0.0425349777585416,0.1276043211385286,0.3109312399960712,0.9609590223947072,-0.2188175167404903,0.2103583670512875,0.7851632735040004,-0.3140340538447883,-0.0834602219085916,0.1443998786378355,0.3170855881024673,-0.338429109976865,0.3271079769396653,0.2223127061201793,0.1482289285775872,-0.2778402952261284,-0.1669451256665561,-0.2647235545119191,0.218420860037877,0.2795481474987075,0.3041422247816124,0.5156473067204539,0.2465070300836643,-0.821618248605185,-0.2009426599367301,0.2686834465902072,0.2363372539383906,-0.2360695683725799,-0.1034136109453093,0.2870213426163214,-0.0839259432539535,-0.107503977500807,-0.2648339261012518,0.0718299541658804,0.2207444333297746,-0.2049392497181064,0.0457053391618798,0.2042269496845669,0.656099291359555,-0.1794773640861859,-0.2795637158904581,-0.3084108384112726,0.8035417468342286,-0.9153167344937808,0.0912497361063857,0.0749652681664013,0.2386147498031222,-0.1052964593956207,0.1861128800041065,-0.1970850200641405,-0.1908431796305255,-0.5310804898479734,0.0769097357013286,0.49987766399523,0.2441430656043869,-0.2339631346850983,0.0155456251704161,0.0276393609147959,0.122124439660633,0.1917191777511752,0.2749721078363209,0.1461344435755269,-1.016300631955758,-0.1082913497205865,-0.1317298640220179,-0.9816978446102236,-0.4288694920154729,0.9081572453312404,0.0698067105678496,-0.3125449918550497,0.349398191735692,0.8769986072936069,-0.0252096746223517,-0.1503892079752793,-0.91874580348208,-0.2123864708193523,-0.1019069880844156,0.6387186344910406,-0.0282489726526054,0.9317226543911152,0.1472735900912323,-0.257989098672355,-0.2017853451802106,0.1046610297396804,0.084865786731629,0.3166946534594271,-0.631234680334425,-0.096565988202898,-1.011750418626529,-0.2779334954282108,-0.1894454416280567,-0.9663864746101728,0.9906152668790824,0.8524422049011313,0.2277065726857104,0.2457762527621466,-0.3038610338808214,-0.8801192135510619,0.275776991921881,0.1830833207549121,0.1455036994919412,0.1553142163871034,1.0042050379125596,-0.0283829575475258,-0.0609814786526115,0.9081456233806297,0.2075929420277884,0.9860770604698562,0.2975918217765686,-0.1413903129508252,-0.1053925825662132,-0.6293940047078981,0.0944239988909747,0.3090093228807242,-0.1452920980729523,-0.5926412832891327,0.0519022891343913,0.1828508491362083,-0.1146521362953152,0.2294180646572948,0.0994492849266099,0.0094435340642309,-0.0271806613372591,-0.21354532719357,-0.2112616250078151,-0.6821172613729792,0.2067738985087301,0.3244476491158019,-0.1045434906028287,0.971476021290438,0.5606707886241333,0.9847609222868632,0.0310796185058175,-0.1424086824389013,-0.0099096673441004,-0.4895100677415752,0.8324724525638058,-0.0401899353813841,0.2840204191179817,-0.9433791285685728,-0.0666796822109468,0.1247629742963294,0.0493561246078026,-0.1415852741534608,-0.2035922900838217,0.0316280401462631,0.1527230097386204,-0.2850311693519323,-0.0884680766070353,0.1503915256983017,0.1829135341693611,0.2559222218128401,0.2138250474886925,0.2524945257899367,-0.1103553622659178,0.2325478246446699,0.2609087865310237,0.3024659397862442,0.0995187892277972,-0.3293941089210255,0.1145482615669584,-0.2510091590950814,-0.2397161180529355,-0.239374229064985,-0.2699003162835192,-0.4797855755476899,-0.1161858477283507,-0.878866061058939,0.0584048118024472,0.3133681655130588,0.2248743143776836,-0.1738060974702995,-0.8129654610380758,-0.563421868887842,-0.5558886663154244,0.72929113150443,-0.6281665207107145,0.0677537646300826,-0.11306062189975,-0.0075838671051072,0.7769618658264489,-0.7472122141451947,0.9459806596408944,-0.6847423110609132,-0.7862462941523636,-0.056551371715053,0.2826330859885383,0.2520508530919407,0.2785766073574482,-0.2857460188633601,0.2711378604656053,-0.988880840231652,-0.4283729783343166,0.2635017724481946,-0.2924550699176838,-0.2409855640133859,0.1921771336558048,0.9842538561883528,0.3555733208523491,0.2614098468419544,0.3704106167855925,-0.3268086442574207,0.2737492226764254,-0.8780530718192262,0.7951294482249827,0.1967727766149597,0.2926475978558732,0.3096855895585336,0.2136076464941758,0.1896350641502877,-0.0200478445770951,-0.1565714582958781,-0.2775361277031841,0.6907479354491847,-0.1848361853790237,-0.881896287132152,-0.3340908148422124,-0.0042436327343346,0.2645934322419024,-0.2899735774444527,-0.0326737588806977,-0.9546723785093884,0.1593511972475778,-0.3161942418048143,-0.2806781099828525,-0.041206067974424,-0.2079328863918057,-0.2693299233900741,-0.2221969976031504,-0.0447734316886132,-0.116117365629255,0.0415036043297627,-0.1047914921172094,-0.2591035829963722,-0.2272823900570433,1.016759265716177,0.6132173631801704,0.5690300816254703,-0.0930262966153586,-0.2558141750483992,-0.0224102672459832,0.310978847147113,0.2120493150062609,-0.2881599491272816,0.0231179304775611,-0.1744263611700889,0.0693314058199432,0.2266381541974703,0.0558923146673146,0.4999287815716387,0.9553842694425664,-0.5899732047558268,0.0095487722825467,-0.2108582721006077,0.0367456210293098,0.9793928678087755,-0.178204178682247,-0.9290476053619524,0.7353060594609491,-0.90147812914015,0.1148654001061918,0.1265129772195935,0.9410247757458868,0.1684634395732783,0.9325301947210628,0.3647015190119308,-0.8356948481870743,0.0652117744341481,0.1782630986376816,0.1558921278947655,-0.0259693432323901,-0.0064757994649313,0.725183611946918,0.2403647330562417,-0.7766616079526695,0.1266330008347067,0.1643549203178356,-0.2748085739197935,-0.3128834801610474,0.1621356699775474,-0.1889483333798719,-0.2244363018736242,0.0707886238405757,-0.0099728359789908,-1.0079958011070105,-6.410939429346216E-5,0.8184058024512865,-0.7273276495970026,0.079228237315331,0.0467242741767208,-0.0152296816661472,0.160133558625364,0.0961289527800789,-0.1898702391479661,0.2479408902634571,0.2278134728035442,-0.4078639379727601,-0.6085429770285297,-0.9966811025533324,-0.1351723145927699,-0.2036156926588073,-0.1056347303663288,-0.2794825047021656,0.2340625936425834,0.0088671696819266,0.2795067044658136,-0.1095237184017638,-0.187469484438833,-0.8112124867681116,-1.017701983903245,-0.2027457528822268,0.3099038887314614,0.0921378712570792,-0.2226797226005271,-0.0292787328254713,-0.23238885935364,-0.165935411912929,-0.031291907129724,0.3197121213116387,0.2372081129141459,-0.1418514904035895,0.4771232901438528,-0.963569734727803,0.2170938546709517,0.3237307475420091,-0.1531497797934581,-0.9327252212614304,-0.087323559767794,-0.0357335966385338,-0.6291679830766714,-0.3275956110249621,0.2575894766855051,-0.3037540490917575,-0.3482723662043058,-0.2259531150296332,-0.3103082238784214,0.2623022026437113,0.0122954685301421,-0.2538859548391994,0.0949341281977962,0.2721124368739338,-0.1368025364058689,-0.0761014535299178,0.2636740834729899,0.2256310249540437,-0.2962289499340148,-0.200462903380645,0.0654974321974737,0.2667548932185843,0.1681405658438711,-0.2749129289226926,-0.2367229518958467,-0.1328352343367074,-0.2925748940455244,0.0341543933758124,-0.3031490840962975,-0.0129290177635334,-0.2736146434341161,0.6352680463417846,0.1131631581337271,-0.3791726260961192,0.5542760377872187,-0.6133996328354325,-0.9738417435175094,-0.6794361804879825,-0.4258164094173878,0.1541558184803269,-0.7471536741811885,0.7288510461954015,-0.0881112205849231,0.4527542036226574,0.2039076091702589,0.5664840990969573,-1.0495648140565847,0.5992462285018129,-0.2761135141493472,0.3493368067208611,0.8676643347174068,0.5459915834294432,0.0354782918299393,-0.6790438243389524,-0.6450245180249169,0.3957971284745289,0.6931201075532899,0.8060121948573069,0.9423968320967548,0.907577596867593,-0.0489215573745599,0.930637571027046,-0.6880823349708777,0.844429336656185,0.5685803928760419,0.8297690521016335,-0.6701233336249248,0.6768315180034492,-0.2370275990867751,-0.1906591441578612,0.3327007697868043,0.2394717964851871,-0.3932292315937037,-0.2974741355044185,0.5772515175453627,-0.4538407062412631,-0.0434929286782988,0.6967297790404082,-0.7144928666464339,-0.6585545458044281,0.0647987775052138,0.675779688741061,-0.1336750696086295,-0.6355099167873173,-0.4035255669817633,0.9813919311504312,0.054313806250125,0.4132008485723928,-0.5794157848470212,-0.8593901572362995,-0.177839110154072,-0.0313316649966544,-0.7123633362604284,0.0974544813847781,0.7132610596633431,-0.2827628347197543,0.6498712581185031,0.4997443154249649,0.9141371084312184,-0.9479939236831424,-0.6893585151242511,-0.4451727967606284,0.9061180886253783,-0.961244110512696,-0.9415387490175388,-0.7990238398898287,-0.2849812569237476,-0.9927782125396312,-0.7248553793125591,-0.3519547786095817,0.6930973962253997,0.3419050988370437,-0.231320580612004,0.5936086820943005,-0.1350032713914082,-0.6551015523211836,0.6338425748489701,0.8213314636683493,0.1413834518125184,0.5823155869403916,-0.3218270729948077,-0.2712149813222436,0.3516667203111296,0.7217905902551937,0.6805778456132301,0.5929246210443834,0.4930026014881612,-0.4294227483220789,0.5491681860400346,-0.6941181644900413,0.451212495025972,-0.7858340459964889,-0.638666303752284,-0.3470013700805944,-0.6681460441393307,0.6264966809754126,-0.9326587946364574,-0.6476787684208107,-0.3520548038164439,0.531693832382333,0.885600156848997,0.6431863062044584,0.8243768095351488,0.0617752875165981,-0.7052526975071733,-0.1695699242705071,0.3845587486334239,0.7505056702488455,-0.8436709163211766,0.2447071094398613,0.6293622434506109,-0.174126341821347,-0.609736664891223,0.496017763708228,-0.1290937577125363,0.6574350151488458,0.2714184074776973,0.9928135519228352,-0.8314617636632805,0.3684836374888477,-0.9829355688815696,-0.4991163423503545,0.3029875688692609,-0.1046749869364045,-0.5655689021421171,-0.2935479170039495,-0.0591494397407166,0.4444390839649652,0.4697479432100694,-0.5206886837766459,0.4342399538351137,0.2139168568158781,-0.5137004157968584,0.5445551299846246,0.4027291342214513,-0.3151309914226086,0.1063371267751927,0.6709140763386545,0.4784671472290146,-0.4814238198059055,-0.4616959101056157,0.6175450751403524,-0.5845394035476421,0.6792586924133611,0.1961223805691505,-0.7144434408506932,-0.2411414371805692,-0.6131419382821875,0.950472901868249,-0.8964157725916333,0.3549774183177498,-0.4603256356114163,-0.7465154738508565,-0.4287305980187433,-0.4380169935922285,-0.8898627675475289,-0.3014491940937682,0.3474828241849174,0.3848643873398961,0.8167953148361392,-0.1235312772424516,-0.9034019041111414,0.5013479149132963,0.084360571175525,0.6696041926140632,-0.694798701162684,0.6672596042930578,-0.1824907400679021,0.6076290335454136,0.256629091888968,-0.2387288160282165,0.3860430007105875,0.674852715728094,-0.6893605959240026,0.3909774820397045,0.5909594207794813,-0.6757211899709151,-0.5191461488156773,-0.88787958156518,-0.5750681558236562,0.7320256415324592,0.9943855519133892,-0.5762944978714579,-0.7369859372972621,0.6640885792927753,-0.5961680247792361,-0.6355085787026389,0.5679906560199307,-0.7220287929982037,-0.5957186296601521,-0.1896703009804772,0.6824966634456686,0.1306022471491367,-0.2860527278279187,-1.0149081426645932,-0.1585202333416705,0.2944340479992532,-0.6423819406293259,0.6098142872783049,-1.0043298308880506,-0.6762923568507375,0.6909103686209617,0.5180394239004749,0.1266474501179039,0.7067968463001668,-0.3778923386835714,-0.518575652385241,0.4480581494503034,-0.6539360146805019,-0.6145188031832527,0.9688001665455054,-0.6489511945652151,-1.0305363951252238,0.6051665641761489,0.2802903212739092,0.1703648180817841,0.4307273248832419,0.9298796772622973,-0.3355482214557121,-0.2812037840914648,-0.3583918908283709,1.0297488807679949,0.9897052682466312,0.6415074916921967,0.6275964960460477,-0.3091487036197269,0.1345716188976332,0.6594381348849098,-0.616354718743443,0.3895524935079827,-0.706173854489328,0.1134173995913723,-0.4970905687789675,0.6370576287696716,0.4214301736425255,-0.6413324351773637,0.5912937446068315,0.1683338192087093,-0.2419464317329299,0.1966240917499239,-0.1223416090089478,-0.5114107360248897,0.4153932223487568,0.6555539069489257,-0.6900204381740467,0.6731124823530863,0.8580229092788658,-0.1195421152566914,-0.1110397661804293,0.2970512981669859,-0.3680775984214993,-0.6958697877825207,-0.112126239293557,-0.6988624963154747,-0.1452286180044655,-0.8129657879997427,0.6952807369215426,0.6805973565615967,0.8362974170913913,-0.7281485266169432,-0.9260349284809012,0.2137842818015388,0.3674277508693986,-0.0348246738239109,-0.4817440010044255,0.5283504119767816,0.2380792850172037,-0.6027149780821803,0.6735653894054177,0.3047009889360322,0.7038423129759274,0.468499657457572,0.933366060623831,-0.5121253028713267,0.92872590728421,-0.0065714413110362,-0.482338977827536,-0.328998913620144,0.966574029842997,0.7547744569207939,0.578762702899326,0.9633195906980324,0.6820588520870012,-0.3936481414226588,0.451895608271426,0.7171268693461488,-0.7123388264966405,-0.1053916499437991,0.5895916340392886,-0.4463443604822039,-0.9335905261431552,0.7076785985429266,1.00246417400761,-0.6731530465719038,0.1550862495496953,-0.7414669066654699,-0.1621308727918415,-0.7521025383448041,0.5942714722445379,-0.6690196785044875,0.6465855069740836,0.6084969219884006,0.3319012903008456,-0.51370476663773,-0.6699223376688481,1.001469780276227,-0.5308864880250946,0.5803696661357197,-0.9061478530200316,0.6894281107858262,-0.3370952066757831,0.6471027610097395,-0.0442651727206448,0.5526428183918866,0.4013842841936539,-0.5710596792955139,-0.6055752231938996,0.4766370127342835,-0.6317039196111509,0.5203416819309304,-0.0182573468231895,-0.6760777126875681,0.7852158775113091,-0.2467054322565422,-0.5812582290356135,-0.4163497649144513,-0.6182104207869628,-0.6707700019737147,0.6340110808889826,-0.7155713843674615,-0.7067434252349447,0.7139994351026003,0.7409707843554686,-0.2387629192552843,0.501011933519239,-1.0204852695788813,-0.1735064622894606,-0.5548681712917962,1.0320603776894086,0.3878584784159301,0.9470476397345172,0.3534988129739159,-0.5643325542107249,-0.199942802686708,0.3493019694211195,-0.4761962269582735,-0.4154231741007957,-0.259177264248089,-0.6195159891457717,0.5094414596668618,-0.2770653248216471,-0.6735525571512051,0.635843549052004,-1.0045697378444245,-0.5659049003582861,-0.4906958492949821,0.4614370994168014,0.5846963551905053,0.2082955237938474,-0.6426348539093204,0.0133325549893275,0.4003063142846684,0.4492981934023864,-0.2804030474667302,-0.0440851018263333,-0.0437636487057089,-0.9304205467600491,0.0322488282255356,0.8856403798729975,0.2272638305910354,0.6488221762526442,-0.1328719758926028,-0.8888004572220821,0.0373016356208622,-0.984520312808786,-0.5904151748381419,-0.6989963643916804,0.823485378116767,0.7275326324238575,0.4880025265893395,0.1104719953102431,0.6918948189723244,-0.355015123657411,-0.1026252134068443,0.2559817650614124,0.7083757642040746,0.9609590223947072,-0.5888483994742736,0.4535304861291296,0.7851632735040004,-0.6877656308274331,-0.148515087986545,0.2916496997117067,0.7162962794737758,-0.338429109976865,0.7200228772311408,0.4997740284453013,0.3275822150136001,-0.6497508895814289,-0.3683944063208605,-0.6287659427859174,0.5956170743950229,0.6414789684851153,0.7009881053074036,0.5156473067204539,0.618417624438965,-0.821618248605185,-0.4360567608537194,0.6167569484580175,0.5101560963098661,-0.5505849412272275,-0.1034136109453093,0.6718324112507557,-0.2264906947392539,-0.2732542098981207,-0.2648339261012518,0.1810107283728105,0.5224449856242162,-0.4599088456175822,0.1057955748101826,0.5187423225392145,0.656099291359555,-0.4496104873345956,-0.6060994161773318,-0.6839043814728223,0.8035417468342286,-0.9153167344937808,0.0912497361063857,0.1000814759781267,0.5790125425209989,-0.1900993033644425,0.4844893381737794,-0.4709038624356158,-0.4177507592812281,-0.5310804898479734,0.2472214523273576,0.49987766399523,0.576381425282712,-0.525550585653663,0.0656789185961378,0.0877295965630988,0.3490320193113356,0.4466887736506511,0.6711566781149815,0.3388359132162131,-1.016300631955758,-0.2876446361565994,-0.3788737092581516,-0.9816978446102236,-0.4288694920154729,0.9081572453312404,0.0698067105678496,-0.709989516063053,0.349398191735692,0.8769986072936069,-0.0302360905756927,-0.4014657524915594,-0.91874580348208,-0.5446248304976774,-0.2538186262931361,0.6387186344910406,-0.0883392083009084,0.9317226543911152,0.1472735900912323,-0.5874021377237258,-0.440947338403218,0.2186687347276708,0.2274305382169293,0.7028473089927366,-0.631234680334425,-0.2714122948632713,-1.011750418626529,-0.6235028623053448,-0.4595785648764665,-0.9663864746101728,0.9906152668790824,0.8524422049011313,0.4668685659087179,0.5887869152396076,-0.6636231345073698,-0.8801192135510619,0.675776991921881,0.3624366071909251,0.2927535205658123,0.1553142163871034,1.0042050379125596,-0.1033354833818157,-0.0609814786526115,0.9081456233806297,0.4507650611056306,0.9860770604698562,0.6930525196717342,-0.4077950599245259,-0.2757042991922421,-0.6293940047078981,0.2692703055513479,0.3090093228807242,-0.3291240423215474,-0.5926412832891327,0.1268548149686811,0.3666827933848035,-0.3332098749890228,0.2294180646572948,0.2513609231353303,0.0245196071322048,-0.0822967776111142,-0.4981595980772841,-0.488722947332937,-0.6821172613729792,0.5303806962587091,0.7233112092200475,-0.2329209345257125,0.971476021290438,0.5606707886241333,0.9847609222868632,0.0109818912339097,-0.3306902553050343,-0.0099096673441004,-0.4895100677415752,0.8324724525638058,-0.120073927587147,0.6839888367995082,-0.9433791285685728,-0.1758604564178769,0.1247629742963294,0.0844966032280998,-0.3386762107727775,-0.4624146747115993,0.0767705940956557,0.3092724764735013,-0.6331046712197426,-0.1830676754165251,0.3647222436899004,0.4911188312796768,0.5509274687561097,0.4448541288575995,0.5406181357450994,-0.3691777468936955,0.5136078125642095,0.5845155842810026,0.6779594828477937,0.174471315062087,-0.725578679199686,0.2524054308367652,-0.5655245319497291,-0.4868599632890693,-0.5377506872346578,-0.6049115323003758,-0.4797855755476899,-0.1161858477283507,-0.878866061058939,0.0483527736251122,0.6563788279905197,0.5455011083260343,-0.3708970340896161,-0.8129654610380758,-0.563421868887842,-0.5558886663154244,0.72929113150443,-0.6281665207107145,0.2008815824392772,-0.1929446141055129,-0.0327000749168325,0.7769618658264489,-0.7472122141451947,0.9459806596408944,-0.6847423110609132,-0.7862462941523636,-0.096696057655539,0.6712857791544079,0.6500312598844609,0.2785766073574482,-0.6786609191548355,0.6392305994119534,-0.988880840231652,-0.4283729783343166,0.6012329426490007,-0.6923287456310038,-0.6029163849997936,0.41492738025108,0.9842538561883528,0.3555733208523491,0.552997297810519,0.3704106167855925,-0.7266823199707407,0.6509454370335712,-0.8780530718192262,0.7951294482249827,0.4594070789161423,0.6566899861298715,0.7088962809298421,0.583638529227959,0.332199815635588,-0.0851027106550485,-0.3957334515188855,-0.6547323420603299,0.6907479354491847,-0.4075864319742989,-0.881896287132152,-0.7249980642694898,-0.0193197058023083,0.6306899012902695,-0.6896893665006882,-0.067814237500995,-0.9546723785093884,0.3608004779018821,-0.6617636086819484,-0.6544096869654973,-0.0913393614001457,-0.4889928743113453,-0.6647906212852398,-0.5727196696206958,-0.1344817360683654,-0.2539745348990617,0.0966197206036179,-0.2042674469831512,-0.6252000520447393,-0.2272823900570433,1.016759265716177,0.6132173631801704,0.5690300816254703,-0.244937934824079,-0.6133507447089047,-0.1218862221119252,0.7064395450422786,0.4821824382546707,-0.6743126046605912,0.0331699686548961,-0.3844962131546072,0.163931004629433,0.4967712774458801,0.1747089472981285,0.4999287815716387,0.9553842694425664,-0.5899732047558268,0.0943516162513686,-0.5190635692109232,0.0718860996496071,0.9793928678087755,-0.178204178682247,-0.9290476053619524,0.7353060594609491,-0.90147812914015,0.1148654001061918,0.2501197749695724,0.9410247757458868,0.4035775404902676,0.9325301947210628,0.7631549626691997,-0.8356948481870743,0.15001461840297,0.4557244209628037,0.4147145125225431,-0.041045416300364,0.0186404083467938,0.725183611946918,0.2403647330562417,-0.7766616079526695,0.2969447174607358,0.3786856383094343,-0.6722530981277969,-0.7128834801610474,0.295263487786742,-0.4906488856743132,-0.6092473705080585,0.1506726160463385,0.010124891292917,-1.0079958011070105,-0.0301948316054665,0.8184058024512865,-0.7273276495970026,0.079228237315331,0.0065795882362347,-1.536085981734E-4,0.4265383055990647,0.2844105256462119,-0.4636890815194416,0.6008573808374384,0.5628246888204009,-0.4078639379727601,-0.6085429770285297,-0.9966811025533324,-0.3495030325843684,-0.5358540523371323,-0.1607508466401841,-0.6733082385138478,0.2340625936425834,0.0088671696819266,0.2795067044658136,-0.270686292687229,-0.4755930943939957,-0.8112124867681116,-1.017701983903245,-0.520341912341361,0.7096196777876971,0.2109545038878932,-0.4412374612942346,-0.0292787328254713,-0.5273941062969096,-0.3586368815536151,-0.0312919071297239,0.7176925281041587,0.6091187072694465,-0.4193128127287115,0.4771232901438528,-0.963569734727803,0.5676165266884972,0.7232255301844162,-0.3674804977850568,-0.9327252212614304,-0.1819231585772839,-0.0708740752588311,-0.6291679830766714,-0.726049054682231,0.6128440562109229,-0.6956960700454562,-0.7479881552605415,-0.5663509077475101,-0.7022502448321202,0.557307449586981,0.0524401544706281,-0.6114225244997049,0.2233115721206799,0.6273670163993517,-0.3206344806544641,-0.0961991808018256,0.6470827990799403,0.5550440640054146,-0.6836622143854673,-0.5623937243670528,0.1649733870634157,0.5989932528969094,0.1681405658438711,-0.6553355354407541,-0.5416999563004257,-0.3076815409970804,-0.6566172823195227,0.0642851155869855,-0.6929598332109284,-0.0129290177635334,-0.6265311340080972],\n",
       "\"colour\":[\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"0\",\"1\",\"1\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"1\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"1\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"1\",\"1\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"1\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"1\",\"1\",\"0\",\"1\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"1\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"1\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"1\",\"0\",\"1\",\"1\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"1\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"1\",\"1\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"1\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"1\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"1\",\"1\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"1\",\"0\",\"1\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"0\",\"1\",\"0\",\"0\",\"1\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"1\",\"1\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"1\",\"1\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\",\"1\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"1\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"0\",\"0\",\"0\",\"0\",\"0\",\"1\",\"0\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"1\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"1\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"2\",\"1\",\"1\",\"1\",\"1\",\"1\",\"1\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"1\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"1\",\"1\",\"1\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"1\",\"1\",\"2\",\"1\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"1\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"1\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"1\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"1\",\"1\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"1\",\"1\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"1\",\"1\",\"1\",\"2\",\"1\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"1\",\"2\",\"1\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"1\",\"1\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"1\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"2\",\"1\",\"2\",\"2\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"1\",\"1\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"1\",\"2\",\"2\",\"1\",\"1\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"1\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"1\",\"2\"]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"x1\",\n",
       "\"y\":\"x2\",\n",
       "\"colour\":\"colour\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"x1\"\n",
       "},{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"x2\"\n",
       "}]\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"minimal\",\n",
       "\"legend_position\":\"bottom\",\n",
       "\"panel_grid_minor\":{\n",
       "\"blank\":true\n",
       "}\n",
       "},\n",
       "\"guides\":{\n",
       "\"x\":{\n",
       "\"title\":\"First dimension\"\n",
       "},\n",
       "\"y\":{\n",
       "\"title\":\"Second dimension\"\n",
       "},\n",
       "\"colour\":{\n",
       "\"title\":\"Cluster #\"\n",
       "}\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[],\n",
       "\"spec_id\":\"7\"\n",
       "};\n",
       "               window.letsPlotCall(function() {\n",
       "       \n",
       "               var toolbar = null;\n",
       "               var plotContainer = containerDiv;               \n",
       "               \n",
       "                   var options = {\n",
       "                       sizing: {\n",
       "                           width_mode: \"min\",\n",
       "                           height_mode: \"scaled\",\n",
       "                           width: width\n",
       "                       }\n",
       "                   };\n",
       "                   var fig = LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer, options);\n",
       "                   if (toolbar) {\n",
       "                     toolbar.bind(fig);\n",
       "                   }\n",
       "               });\n",
       "               \n",
       "               break;\n",
       "           }\n",
       "       }\n",
       "   });\n",
       "   \n",
       "   observer.observe(containerDiv);\n",
       "   \n",
       "   // ----------\n",
       "   })();\n",
       "   \n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x3463dba40>"
      ]
     },
     "execution_count": 12,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "dbscan_model = DBSCAN(min_samples=4, eps=0.15)\n",
    "\n",
    "dbscan_model.fit(circles)\n",
    "\n",
    "dbscan_labels = [str(i) for i in dbscan_model.labels_]\n",
    "\n",
    "(\n",
    "  ggplot(circles, aes(\"x1\", \"x2\", colour = dbscan_labels)) +\n",
    "  geom_point() +\n",
    "  theme_minimal() +\n",
    "  theme(panel_grid_minor = element_blank(),\n",
    "        legend_position = \"bottom\") +\n",
    "  labs(x = \"First dimension\", y = \"Second dimension\",\n",
    "       colour = \"Cluster #\")\n",
    "\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Applying dbscan to the customer segmentation data set\n",
    "\n",
    "Use `eps = 0.6` and `min_samples = 4` when applying dbscan to the customer segmentation data."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Create a pipeline that standardises the data and instantiates a DBSCAN\n",
    "pipe_dbscan = Pipeline([(\"standardise\",StandardScaler()), (\"dbscan\", DBSCAN(min_samples=4, eps=0.6))])\n",
    "\n",
    "# Fit the pipeline to the customers data\n",
    "pipe_dbscan.fit(customers)\n",
    "\n",
    "# Retrieve the labels using a list comprehension\n",
    "dbscan_labels = [str(i) for i in pipe_dbscan.named_steps[\"dbscan\"].labels_]\n",
    "\n",
    "# Create a list of outlier labels\n",
    "outlier_labels = [np.where(row == \"-1\", \"Yes\", \"No\") for row in dbscan_labels]"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Try plotting the results yourself to see the differences."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"9UXKMV\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "   \n",
       "   (function() {\n",
       "   // ----------\n",
       "   \n",
       "   var containerDiv = document.getElementById(\"9UXKMV\");\n",
       "   var observer = new ResizeObserver(function(entries) {\n",
       "       for (let entry of entries) {\n",
       "           var width = containerDiv.clientWidth\n",
       "           if (entry.contentBoxSize && width > 0) {\n",
       "           \n",
       "               // Render plot\n",
       "               if (observer) {\n",
       "                   observer.disconnect();\n",
       "                   observer = null;\n",
       "               }\n",
       "\n",
       "               var plotSpec={\n",
       "\"data\":{\n",
       "\"income\":[15.0,15.0,16.0,16.0,17.0,17.0,18.0,18.0,19.0,19.0,19.0,19.0,20.0,20.0,20.0,20.0,21.0,21.0,23.0,23.0,24.0,24.0,25.0,25.0,28.0,28.0,28.0,28.0,29.0,29.0,30.0,30.0,33.0,33.0,33.0,33.0,34.0,34.0,37.0,37.0,38.0,38.0,39.0,39.0,39.0,39.0,40.0,40.0,40.0,40.0,42.0,42.0,43.0,43.0,43.0,43.0,44.0,44.0,46.0,46.0,46.0,46.0,47.0,47.0,48.0,48.0,48.0,48.0,48.0,48.0,49.0,49.0,50.0,50.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,54.0,57.0,57.0,58.0,58.0,59.0,59.0,60.0,60.0,60.0,60.0,60.0,60.0,61.0,61.0,62.0,62.0,62.0,62.0,62.0,62.0,63.0,63.0,63.0,63.0,63.0,63.0,64.0,64.0,65.0,65.0,65.0,65.0,67.0,67.0,67.0,67.0,69.0,69.0,70.0,70.0,71.0,71.0,71.0,71.0,71.0,71.0,72.0,72.0,73.0,73.0,73.0,73.0,74.0,74.0,75.0,75.0,76.0,76.0,77.0,77.0,77.0,77.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,78.0,79.0,79.0,81.0,81.0,85.0,85.0,86.0,86.0,87.0,87.0,87.0,87.0,87.0,87.0,88.0,88.0,88.0,88.0,93.0,93.0,97.0,97.0,98.0,98.0,99.0,99.0,101.0,101.0,103.0,103.0,103.0,103.0,113.0,113.0,120.0,120.0,126.0,126.0,137.0,137.0],\n",
       "\"spending_score\":[39.0,81.0,6.0,77.0,40.0,76.0,6.0,94.0,3.0,72.0,14.0,99.0,15.0,77.0,13.0,79.0,35.0,66.0,29.0,98.0,35.0,73.0,5.0,73.0,14.0,82.0,32.0,61.0,31.0,87.0,4.0,73.0,4.0,92.0,14.0,81.0,17.0,73.0,26.0,75.0,35.0,92.0,36.0,61.0,28.0,65.0,55.0,47.0,42.0,42.0,52.0,60.0,54.0,60.0,45.0,41.0,50.0,46.0,51.0,46.0,56.0,55.0,52.0,59.0,51.0,59.0,50.0,48.0,59.0,47.0,55.0,42.0,49.0,56.0,47.0,54.0,53.0,48.0,52.0,42.0,51.0,55.0,41.0,44.0,57.0,46.0,58.0,55.0,60.0,46.0,55.0,41.0,49.0,40.0,42.0,52.0,47.0,50.0,42.0,49.0,41.0,48.0,59.0,55.0,56.0,42.0,50.0,46.0,43.0,48.0,52.0,54.0,42.0,46.0,48.0,50.0,43.0,59.0,43.0,57.0,56.0,40.0,58.0,91.0,29.0,77.0,35.0,95.0,11.0,75.0,9.0,75.0,34.0,71.0,5.0,88.0,7.0,73.0,10.0,72.0,5.0,93.0,40.0,87.0,12.0,97.0,36.0,74.0,22.0,90.0,17.0,88.0,20.0,76.0,16.0,89.0,1.0,78.0,1.0,73.0,35.0,83.0,5.0,93.0,26.0,75.0,20.0,95.0,27.0,63.0,13.0,75.0,10.0,92.0,13.0,86.0,15.0,69.0,14.0,90.0,32.0,86.0,15.0,88.0,39.0,97.0,24.0,68.0,17.0,85.0,23.0,69.0,8.0,91.0,16.0,79.0,28.0,74.0,18.0,83.0],\n",
       "\"colour\":[\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"1\",\"0\",\"2\",\"0\",\"1\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"2\",\"3\",\"4\",\"3\",\"2\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"2\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"4\",\"3\",\"-1\",\"3\",\"-1\",\"-1\",\"-1\",\"-1\"],\n",
       "\"shape\":[\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"Yes\",\"No\",\"Yes\",\"Yes\",\"Yes\",\"Yes\"]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"income\",\n",
       "\"y\":\"spending_score\",\n",
       "\"colour\":\"colour\",\n",
       "\"shape\":\"shape\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"type\":\"int\",\n",
       "\"column\":\"income\"\n",
       "},{\n",
       "\"type\":\"int\",\n",
       "\"column\":\"spending_score\"\n",
       "},{\n",
       "\"type\":\"str\",\n",
       "\"column\":\"labels\"\n",
       "}]\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"minimal\",\n",
       "\"legend_position\":\"bottom\",\n",
       "\"panel_grid_minor\":{\n",
       "\"blank\":true\n",
       "}\n",
       "},\n",
       "\"guides\":{\n",
       "\"x\":{\n",
       "\"title\":\"Income\"\n",
       "},\n",
       "\"y\":{\n",
       "\"title\":\"Spending score\"\n",
       "},\n",
       "\"colour\":{\n",
       "\"title\":\"Cluster #\"\n",
       "},\n",
       "\"shape\":{\n",
       "\"title\":\"Outlier\"\n",
       "}\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"shape\",\n",
       "\"values\":[16.0,4.0]\n",
       "},{\n",
       "\"aesthetic\":\"color\",\n",
       "\"scale_mapper_kind\":\"color_cmap\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[],\n",
       "\"spec_id\":\"8\"\n",
       "};\n",
       "               window.letsPlotCall(function() {\n",
       "       \n",
       "               var toolbar = null;\n",
       "               var plotContainer = containerDiv;               \n",
       "               \n",
       "                   var options = {\n",
       "                       sizing: {\n",
       "                           width_mode: \"min\",\n",
       "                           height_mode: \"scaled\",\n",
       "                           width: width\n",
       "                       }\n",
       "                   };\n",
       "                   var fig = LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer, options);\n",
       "                   if (toolbar) {\n",
       "                     toolbar.bind(fig);\n",
       "                   }\n",
       "               });\n",
       "               \n",
       "               break;\n",
       "           }\n",
       "       }\n",
       "   });\n",
       "   \n",
       "   observer.observe(containerDiv);\n",
       "   \n",
       "   // ----------\n",
       "   })();\n",
       "   \n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x3463cb440>"
      ]
     },
     "execution_count": 14,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "(\n",
    "  ggplot(customers, aes(\"income\", \"spending_score\", colour = dbscan_labels, shape = outlier_labels)) +\n",
    "  geom_point() +\n",
    "  theme_minimal() +\n",
    "  theme(panel_grid_minor = element_blank(),\n",
    "        legend_position = \"bottom\") +\n",
    "  scale_shape_manual(values = [16,4]) +\n",
    "  scale_color_viridis() +\n",
    "  labs(x = \"Income\", y = \"Spending score\",\n",
    "       colour = \"Cluster #\", shape = \"Outlier\")\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "👥 **DISCUSS IN PAIRS/GROUPS:**\n",
    "\n",
    "What difference in clustering do you see with dbscan?\n",
    "\n",
    "*We now have 5 outlier observations!*\n",
    "\n",
    "# Using DBSCAN with UMAP\n",
    "\n",
    "You will remember from last week that we can employ Uniform Manifold Approximation and Projection (UMAP) to create two-dimensional representations of data.  With the Varieties of Democracy (V-Dem) data set, we found that employing UMAP led to several highly repressive regimes forming their own distinct cluster.  We can employ DBSCAN on the UMAP embeddings to find new insights into political regimes.\n",
    "\n",
    "**📝Task:** Let's load the data!"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "metadata": {},
   "outputs": [],
   "source": [
    "vdem = pd.read_csv(\"../data/vdem-data-subset.csv\")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**📝Task:** Next, we can build a UMAP model, fit it to `vdem` and retrieve the embeddings."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 16,
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/opt/anaconda3/lib/python3.12/site-packages/sklearn/utils/deprecation.py:151: FutureWarning: 'force_all_finite' was renamed to 'ensure_all_finite' in 1.6 and will be removed in 1.8.\n",
      "  warnings.warn(\n"
     ]
    }
   ],
   "source": [
    "# Set a random seed\n",
    "np.random.seed(123)\n",
    "\n",
    "# Instantiate a UMAP with the relevant hyperparameter choice\n",
    "reducer = UMAP(n_neighbors=100)\n",
    "\n",
    "# Create a subset of the data using only variables beginning with \"v2x\"\n",
    "vdem_subset = vdem[vdem.columns[vdem.columns.str.contains(\"v2x\")]].to_numpy()\n",
    "\n",
    "# Fit / transform the model to the subset of data to obtain the embeddings\n",
    "embedding = reducer.fit_transform(vdem_subset)\n",
    "\n",
    "# Convert the embeddings to a data frame\n",
    "embedding = pd.DataFrame(embedding, columns = [\"first_dim\", \"second_dim\"])"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**📝Task:** After this, we can instantiate a DBSCAN, fit it to the embeddings, and plot the results.  Try experimenting with different combinations of minimum points and epsilon neighbourhood."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 17,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "   <div id=\"rmul0S\"></div>\n",
       "   <script type=\"text/javascript\" data-lets-plot-script=\"plot\">\n",
       "   \n",
       "   (function() {\n",
       "   // ----------\n",
       "   \n",
       "   var containerDiv = document.getElementById(\"rmul0S\");\n",
       "   var observer = new ResizeObserver(function(entries) {\n",
       "       for (let entry of entries) {\n",
       "           var width = containerDiv.clientWidth\n",
       "           if (entry.contentBoxSize && width > 0) {\n",
       "           \n",
       "               // Render plot\n",
       "               if (observer) {\n",
       "                   observer.disconnect();\n",
       "                   observer = null;\n",
       "               }\n",
       "\n",
       "               var plotSpec={\n",
       "\"data\":{\n",
       "\"first_dim\":[6.158900737762451,6.111730098724365,6.01248836517334,4.512054443359375,4.554729461669922,5.396109580993652,5.395242691040039,5.65577507019043,6.19191837310791,5.988819599151611,5.399044036865234,4.028928279876709,3.710935592651367,2.4895009994506836,10.995383262634277,10.860190391540527,10.805184364318848,10.838398933410645,10.820338249206543,10.910290718078613,10.90095043182373,10.788498878479004,10.654296875,9.300203323364258,10.759954452514648,10.7689208984375,11.412829399108887,10.817116737365723,16.336753845214844,16.408700942993164,16.46516227722168,16.513628005981445,16.61916160583496,16.61092185974121,16.599023818969727,16.626249313354492,16.63275146484375,16.720966339111328,16.75404167175293,16.759748458862305,16.800281524658203,16.68859100341797,15.11043643951416,15.119625091552734,15.110505104064941,15.118732452392578,15.091522216796875,15.083332061767578,15.088666915893555,15.101116180419922,15.07146167755127,15.076761245727539,15.13209056854248,15.097789764404297,15.10839557647705,15.136597633361816,9.908262252807617,9.897834777832031,9.915304183959961,9.867542266845703,9.842456817626953,9.859152793884277,9.824297904968262,9.838292121887207,9.840259552001953,9.79630184173584,9.755995750427246,5.50146484375,5.523075580596924,5.505089282989502,11.815044403076172,11.733102798461914,11.786466598510742,11.275310516357422,11.009027481079102,11.020060539245605,10.998010635375977,10.694878578186035,10.787020683288574,9.661177635192871,9.5470552444458,9.705352783203125,9.519100189208984,8.386006355285645,14.276388168334961,14.284404754638672,14.242162704467773,13.311235427856445,13.306649208068848,13.293848037719727,13.272828102111816,13.27321720123291,13.46149730682373,13.472660064697266,13.3899507522583,13.134113311767578,13.16073226928711,13.167787551879883,-3.1045424938201904,-2.9566705226898193,-2.4431474208831787,-1.835778832435608,-1.7420413494110107,-1.5899076461791992,-0.8029016256332397,-0.7506121397018433,-0.7327824234962463,-0.2446531355381012,-0.29415008425712585,-3.1792962551116943,-3.196282148361206,-3.2749645709991455,-2.5448250770568848,-2.639801263809204,-2.6748316287994385,-2.7212135791778564,-2.7752668857574463,-2.7508599758148193,-2.7856507301330566,-2.7946860790252686,-2.805297613143921,-2.7993385791778564,-2.9200706481933594,-2.9066667556762695,-2.9203176498413086,-2.8812334537506104,3.1199285984039307,3.1142072677612305,3.001962184906006,2.370973825454712,2.521897792816162,2.4663662910461426,2.451134204864502,2.606168746948242,2.4079318046569824,2.1905179023742676,2.6875085830688477,2.5147674083709717,2.3267574310302734,1.8668277263641357,-2.5845937728881836,-2.6425156593322754,-1.7856758832931519,-2.6639904975891113,-2.7050490379333496,-2.6598591804504395,-2.736414670944214,-2.6915791034698486,-2.759103298187256,-2.919053316116333,-2.8574717044830322,-2.8771841526031494,-2.8593270778656006,-2.822587490081787,-1.9864376783370972,-2.241466760635376,-1.9754072427749634,-1.9394147396087646,-1.9546655416488647,-2.4362001419067383,-3.0001180171966553,-2.9843273162841797,-2.9795382022857666,-2.9704368114471436,-2.9568917751312256,-2.922863006591797,-2.928431272506714,-2.8770833015441895,6.476869583129883,7.667760372161865,7.640127182006836,7.654754161834717,7.859543323516846,8.079076766967773,8.201744079589844,8.203727722167969,8.064934730529785,7.256323337554932,6.847177028656006,6.950000286102295,8.275209426879883,8.625064849853516,16.141685485839844,16.15531349182129,16.34728240966797,16.34697914123535,16.155017852783203,14.986359596252441,9.872544288635254,7.952733516693115,7.686919689178467,7.572658538818359,5.270691394805908,4.026565074920654,3.8309707641601563,4.185606479644775,14.74554443359375,14.837197303771973,14.845300674438477,15.09311580657959,15.139408111572266,14.94163990020752,11.924718856811523,11.528451919555664,10.638788223266602,7.816578388214111,7.906857490539551,7.548458576202393,7.861313343048096,12.643035888671875,16.600482940673828,16.571857452392578,16.5653018951416,16.574398040771484,16.583532333374023,16.585269927978516,16.42288589477539,14.14834213256836,13.819334983825684,13.736407279968262,13.640423774719238,14.103484153747559,14.286894798278809,14.532700538635254,16.453136444091797,16.309490203857422,16.367380142211914,16.39217185974121,16.402860641479492,16.363855361938477,16.38958168029785,16.69213104248047,16.652366638183594,15.980252265930176,15.738593101501465,15.939364433288574,14.12404727935791,13.96887493133545,4.92099666595459,5.0365495681762695,5.113595485687256,5.30593729019165,6.2114787101745605,6.149324417114258,6.2018513679504395,6.227832794189453,5.779784202575684,3.9304311275482178,1.6734570264816284,-1.5333356857299805,-1.7637897729873657,-1.7860795259475708,-1.8120532035827637,-1.849367380142212,-1.9255648851394653,-2.056058883666992,-2.226250171661377,-2.341798782348633,-2.2948923110961914,-2.3702914714813232,-2.32936429977417,-2.347407817840576,-2.296147584915161,-2.359494209289551,-2.3445606231689453,-2.3381123542785645,7.238034725189209,7.183502197265625,7.189733028411865,7.05932092666626,7.070185661315918,5.012685775756836,5.089318752288818,4.823002338409424,4.006460189819336,1.287287712097168,-0.840006411075592,3.9944655895233154,3.880155086517334,3.837897539138794,-0.4110049307346344,-0.7777308225631714,-0.6769363880157471,-0.7498805522918701,-0.7227779030799866,-0.9117922782897949,-1.0744332075119019,-0.9505146145820618,-0.8375616669654846,-1.28080415725708,-1.9976881742477417,-1.755919098854065,-2.6488475799560547,-2.2908425331115723,-0.3823975920677185,-0.21416115760803223,-0.23688361048698425,-0.19335533678531647,0.1784563511610031,-0.057264670729637146,0.018488189205527306,-0.23323673009872437,-0.8505541086196899,-0.8605582118034363,-0.8194741010665894,-0.5262296795845032,2.770714521408081,2.3470611572265625,4.335842609405518,4.3328776359558105,-0.7314803004264832,-1.1166778802871704,2.2010996341705322,2.5899531841278076,2.545682430267334,1.9820674657821655,1.720785140991211,1.6430633068084717,-1.0322602987289429,-2.4976346492767334,-2.7581658363342285,-3.008683681488037,0.8069191575050354,0.7211308479309082,0.7206628918647766,0.7895938158035278,0.8107620477676392,0.1646900773048401,-0.182094544172287,-0.2684803009033203,-0.5657671093940735,-0.9392943978309631,-0.7968247532844543,-0.7167571187019348,-0.7668523788452148,-1.0935783386230469,12.633318901062012,13.117510795593262,13.292779922485352,13.186864852905273,13.180755615234375,13.12277603149414,12.450979232788086,12.59807014465332,13.358397483825684,13.196676254272461,13.429216384887695,12.04207706451416,11.257314682006836,8.672212600708008,7.4785237312316895,7.431048393249512,7.791092872619629,9.190028190612793,9.196523666381836,9.20868968963623,9.184446334838867,8.279587745666504,8.193788528442383,9.108797073364258,9.22128677368164,9.075146675109863,7.884429454803467,5.4282941818237305,-2.5166420936584473,-2.524941921234131,-2.4825186729431152,-2.455519676208496,-2.593040704727173,-2.2604753971099854,-2.2525856494903564,-2.2459323406219482,-2.3198225498199463,-2.562037467956543,-2.7428109645843506,-2.7129933834075928,-2.697964668273926,-2.4703314304351807,-2.4010674953460693,-2.515073776245117,-2.113438367843628,-2.0910236835479736,-2.119443655014038,-2.1487467288970947,-2.1369740962982178,-2.11596417427063,-2.7253615856170654,-2.8355071544647217,-2.5661308765411377,-2.8868579864501953,-3.0645713806152344,-4.170978546142578,-4.160085201263428,-4.194543361663818,-4.158290386199951,-4.173528671264648,-4.188693523406982,-4.189680576324463,-4.182443618774414,-4.122185230255127,-3.137967109680176,-3.1277530193328857,-4.063983917236328,-4.133213996887207,-4.187211990356445,-1.99849534034729,-1.9958969354629517,-1.9950588941574097,-2.0195765495300293,-2.0214266777038574,-2.0059573650360107,-1.9362118244171143,-1.9471611976623535,-1.8915482759475708,-1.9145808219909668,-1.9541685581207275,-2.1911160945892334,-4.112111568450928,-4.125917434692383,11.272260665893555,11.309486389160156,11.495293617248535,11.592854499816895,11.668265342712402,11.478272438049316,11.177108764648438,11.151419639587402,11.957009315490723,11.872350692749023,12.471068382263184,12.429605484008789,12.702082633972168,13.165172576904297,-2.1632277965545654,-2.220150947570801,-2.248487949371338,-2.3023300170898438,-2.2716782093048096,-2.261770009994507,-2.149094820022583,-2.239788770675659,-1.959322452545166,-2.15274977684021,-2.1486709117889404,-2.5520150661468506,-2.5050771236419678,-2.6918256282806396,7.88117790222168,7.859045505523682,7.774570465087891,7.422306060791016,5.829682350158691,3.028451919555664,2.4136340618133545,1.2719480991363525,1.1034456491470337,0.08126421272754669,-0.7189516425132751,-0.6727541089057922,-0.78895103931427,-1.064254641532898,0.3363999128341675,0.42611321806907654,0.4976337254047394,2.960313081741333,3.197068214416504,3.1737802028656006,3.159301280975342,2.813715696334839,1.9921151399612427,1.995476484298706,2.0413479804992676,2.3894357681274414,3.3762073516845703,4.034799098968506,-3.9160778522491455,-3.8928472995758057,-3.9240057468414307,-3.943002223968506,-3.9142496585845947,-3.9403557777404785,-3.9253294467926025,-3.929230213165283,-3.932748556137085,-3.9465601444244385,-3.954460620880127,-3.941791296005249,-3.9335148334503174,-3.935612201690674,11.903546333312988,11.888439178466797,11.464136123657227,9.905216217041016,9.750480651855469,9.710728645324707,10.444356918334961,15.277448654174805,15.408082962036133,14.671950340270996,14.973979949951172,14.761651992797852,13.316107749938965,9.688838005065918,1.8416200876235962,1.364248514175415,1.511265516281128,1.5942834615707397,3.5366523265838623,4.83036470413208,5.082470893859863,3.4161648750305176,5.931044578552246,6.41731071472168,6.216614246368408,6.322212219238281,6.571484565734863,6.439513206481934,0.3641863167285919,0.4709475338459015,0.46373462677001953,0.6313106417655945,0.5561529397964478,0.5423928499221802,0.508393406867981,0.4435577094554901,-0.0917300134897232,-0.715026319026947,-0.6998224854469299,-0.7101169228553772,-1.0839741230010986,-1.136950969696045,0.2884676158428192,2.015310764312744,2.506042003631592,2.8358218669891357,3.0146241188049316,3.7136499881744385,3.595122814178467,3.5467989444732666,3.478175640106201,2.652137041091919,2.644731044769287,1.2291816473007202,1.6163368225097656,1.7287870645523071,2.9705469608306885,3.4170143604278564,3.365612506866455,3.3928260803222656,3.3880844116210938,3.4224932193756104,2.645202159881592,2.1027393341064453,1.3981564044952393,0.7200883626937866,0.13030435144901276,0.1651909351348877,0.11753249913454056,0.07879924774169922,1.4660893678665161,1.5084317922592163,1.5551574230194092,1.4427329301834106,1.4033094644546509,1.2473180294036865,0.09345024824142456,0.06039765104651451,-0.09266020357608795,-0.15390050411224365,-0.11428243666887283,-0.18243679404258728,0.07248406112194061,0.3516765832901001,13.386175155639648,13.352192878723145,13.333417892456055,13.294771194458008,13.292182922363281,13.231328964233398,13.947565078735352,13.998178482055664,14.200035095214844,13.963438987731934,13.592352867126465,13.473344802856445,13.976274490356445,13.97089958190918,-0.21388722956180573,0.39053088426589966,1.4172691106796265,0.12320876866579056,-3.0402908325195313,-3.1762521266937256,-3.212657928466797,-3.5539565086364746,-3.5151872634887695,-3.363175630569458,-3.458667278289795,-3.4823906421661377,-3.4496541023254395,-1.0248935222625732,-0.8603907823562622,-0.8578692674636841,-0.8357517123222351,-0.8690837025642395,-0.8465360403060913,-0.8896539807319641,-0.9221255779266357,-1.0139375925064087,-1.0284701585769653,-1.0546722412109375,-1.0882266759872437,-1.1782883405685425,-1.0999341011047363,-1.1372954845428467,-0.5206657648086548,-0.6095710396766663,-0.6614004969596863,-2.757197856903076,-2.8029136657714844,-2.8366708755493164,-2.863300323486328,-3.0357770919799805,-2.9962329864501953,-2.994601011276245,-2.975165843963623,-2.9759044647216797,-2.9253711700439453,-3.005540132522583,6.873430252075195,5.702573299407959,5.734000205993652,5.693343162536621,5.739907741546631,7.57363748550415,9.432046890258789,9.553958892822266,5.886430263519287,0.6026244759559631,-0.7537966966629028,-0.8622072339057922,-0.0945073738694191,0.9762393236160278,5.7300004959106445,5.831126689910889,5.721529006958008,4.375278949737549,4.329300403594971,4.355813026428223,4.152710914611816,4.258669853210449,4.424543380737305,5.859439849853516,5.7013163566589355,4.2978739738464355,3.260957956314087,2.57281231880188,2.7945611476898193,2.917423963546753,3.0270321369171143,3.919912099838257,3.6604325771331787,-0.8839720487594604,7.215969085693359,7.4499664306640625,6.5422844886779785,6.200193881988525,6.176252365112305,4.7168450355529785,-1.0458223819732666,-3.419633150100708,-2.6541926860809326,-2.636000871658325,-2.646155834197998,-2.686284303665161,-2.722320795059204,-2.68125581741333,-2.713942527770996,-2.9513866901397705,-2.8873722553253174,-2.894869089126587,-2.9211721420288086,-2.9012153148651123,-2.8437929153442383,-2.873878002166748,8.08273983001709,8.20137882232666,8.081064224243164,7.8191728591918945,7.5999579429626465,7.343966960906982,6.874513626098633,6.486993789672852,5.604353427886963,5.605113983154297,3.960700273513794,3.4339399337768555,3.5326035022735596,2.8620083332061768,-0.03041177988052368,-0.0017698360607028008,-0.004982819780707359,-0.014267141930758953,0.06857141107320786,0.07849839329719543,-0.017438696697354317,-0.4408445358276367,-0.6970975399017334,-0.8426133394241333,-1.0407111644744873,-0.8144444227218628,-0.9692721962928772,-1.016580581665039,2.345493793487549,2.3467977046966553,-1.568962574005127,-1.4580397605895996,4.7612810134887695,5.917881488800049,6.212823867797852,7.94534158706665,6.68345832824707,5.682074546813965,5.586801528930664,5.710638523101807,6.573874473571777,7.678467750549316,-0.6448475122451782,-0.6299493908882141,-1.6751585006713867,-2.6099226474761963,-2.6139016151428223,-2.5948078632354736,-2.5681674480438232,-2.6961255073547363,-2.8265695571899414,-2.8061654567718506,-2.787341356277466,-2.731473684310913,-2.691223621368408,-2.620669364929199,-1.069345474243164,3.8175506591796875,6.8466315269470215,7.046617031097412,6.934253692626953,6.848081111907959,4.183545112609863,3.019357681274414,2.3091094493865967,2.613140344619751,3.232318878173828,2.263409376144409,1.9111778736114502,-0.4647873640060425,1.9618264436721802,1.9177966117858887,1.9283411502838135,1.260362982749939,1.1752811670303345,0.6226778030395508,-0.7168815732002258,-0.859545111656189,-0.8618373870849609,-0.8745810389518738,-0.8564801812171936,-0.012418029829859734,3.044553756713867,3.124307632446289,-1.1135908365249634,-1.1389073133468628,-1.1338425874710083,-1.0062657594680786,-0.9823493957519531,-1.0054388046264648,-1.012437105178833,-0.9583154916763306,-0.9848985075950623,-1.0212056636810303,-1.080689549446106,-1.0556252002716064,-1.0645172595977783,-1.2131081819534302,-3.0195577144622803,-2.788782835006714,-2.79093861579895,-2.784322738647461,-1.6075270175933838,-1.563299298286438,-1.5532034635543823,-1.6381845474243164,-1.665465235710144,-1.79197096824646,-2.889132261276245,-3.0008034706115723,-3.4281301498413086,-3.0114710330963135,0.31947532296180725,0.10737872868776321,1.0290160179138184,0.912168562412262,0.9142878651618958,1.1024858951568604,2.719102621078491,2.9363369941711426,2.8890981674194336,2.669489860534668,2.087876796722412,0.3422852158546448,0.4237600862979889,0.43782880902290344,-1.6704137325286865,-1.6561096906661987,-1.6841704845428467,-1.954877257347107,-1.9462734460830688,-1.8671151399612427,-1.9556232690811157,-2.0818212032318115,-1.5748211145401,-0.7570118308067322,-0.8812414407730103,-0.8768829107284546,-0.8545572757720947,-1.5354713201522827,14.285589218139648,13.519503593444824,13.424846649169922,13.574727058410645,13.476885795593262,13.56960678100586,14.529383659362793,14.579791069030762,14.516937255859375,14.81080150604248,14.57291030883789,14.459944725036621,14.436389923095703,14.36497974395752,16.803632736206055,16.786108016967773,16.806964874267578,15.638259887695313,15.420332908630371,15.833248138427734,16.063154220581055,16.28643035888672,15.546468734741211,14.454877853393555,14.810161590576172,14.488815307617188,15.044073104858398,15.054693222045898,9.848295211791992,9.807397842407227,9.698376655578613,9.690420150756836,9.682953834533691,8.610262870788574,8.485347747802734,7.90912389755249,8.09302806854248,7.263567924499512,4.466213703155518,5.692923545837402,4.1778035163879395,2.555389165878296,-2.606255531311035,-2.762437105178833,-2.7581655979156494,-2.920586347579956,-2.9133946895599365,-3.0511744022369385,-3.0709526538848877,-3.0660669803619385,-3.083191156387329,-3.0829434394836426,-2.501819372177124,-2.360257387161255,-2.163113832473755,-2.047293186187744,11.637045860290527,11.75123119354248,11.789880752563477,11.849998474121094,11.857678413391113,11.830021858215332,11.81667709350586,11.826048851013184,11.707335472106934,11.792104721069336,11.870033264160156,11.425515174865723,10.911640167236328,10.895069122314453,-1.9234548807144165,-1.8831349611282349,-1.8181354999542236,-1.8607182502746582,-1.7513327598571777,-1.6432414054870605,-1.6404999494552612,-1.7559709548950195,-1.6588006019592285,-2.006906032562256,-1.9791228771209717,-1.8769099712371826,-1.8090540170669556,-2.2771341800689697,16.148101806640625,16.09927749633789,16.123960494995117,16.168569564819336,16.160907745361328,16.176176071166992,16.132596969604492,16.17910385131836,15.428382873535156,14.04461669921875,14.262365341186523,14.66319751739502,14.536296844482422,14.633298873901367,16.006044387817383,15.980466842651367,15.988033294677734,16.027305603027344,16.002246856689453,16.123558044433594,16.153369903564453,16.39496612548828,16.20956039428711,16.543094635009766,16.532230377197266,16.579898834228516,15.537832260131836,15.734707832336426,4.888561725616455,4.872806072235107,5.26590633392334,5.1207427978515625,4.82370138168335,4.859048843383789,4.610597133636475,6.000397682189941,6.5047221183776855,7.065489768981934,6.294862747192383,6.425642967224121,7.356167316436768,7.513758182525635,3.8640475273132324,3.8237109184265137,3.8322267532348633,2.486727476119995,2.4004886150360107,2.43460750579834,2.4715821743011475,3.3172030448913574,6.938701152801514,6.321235179901123,6.674944877624512,6.341858386993408,7.547756195068359,7.1411213874816895,15.920696258544922,15.981891632080078,16.035676956176758,16.155323028564453,16.15730857849121,16.22066879272461,16.220733642578125,16.207839965820313,15.653952598571777,15.50175952911377,15.379573822021484,15.341955184936523,15.700886726379395,15.701607704162598,16.698984146118164,16.660945892333984,16.698759078979492,16.678428649902344,16.63932991027832,16.6928768157959,16.659778594970703,16.553319931030273,16.47954559326172,16.521760940551758,16.336223602294922,15.657570838928223,15.512716293334961,15.559699058532715,3.810032367706299,3.7500507831573486,3.5720841884613037,3.730149507522583,3.703571081161499,4.262777328491211,4.998477935791016,4.825632572174072,4.0244879722595215,4.1273512840271,4.00811243057251,2.9061896800994873,1.1499730348587036,1.011215090751648,-2.6989195346832275,-2.71423602104187,-2.710923671722412,-2.6823294162750244,-2.666466474533081,-2.7130484580993652,-2.671262741088867,-2.6926822662353516,-2.7123944759368896,-2.660130262374878,-2.7014687061309814,-2.4854743480682373,-2.4171652793884277,-2.498309850692749,-0.21083319187164307,-0.23083022236824036,-0.2010454386472702,-0.24607685208320618,-0.5782301425933838,-0.7351260185241699,-0.811991274356842,-0.957499623298645,-0.7476662993431091,-0.7664977312088013,-1.1738300323486328,-1.3185378313064575,-1.3602617979049683,-1.3824671506881714,16.283313751220703,16.245576858520508,16.23131561279297,16.292049407958984,16.321842193603516,16.314987182617188,16.244325637817383,16.254037857055664,16.269466400146484,16.235897064208984,16.26232147216797,16.390968322753906,16.21327781677246,16.327363967895508,14.354024887084961,14.510265350341797,14.643527030944824,14.519829750061035,14.518111228942871,14.52912712097168,14.634261131286621,14.600215911865234,14.577282905578613,14.476932525634766,14.458337783813477,14.458919525146484,14.329455375671387,14.175630569458008,-1.0623266696929932,-1.0625795125961304,-1.0456311702728271,-0.9885461926460266,-0.988024890422821,-0.9919286370277405,-1.0560986995697021,-0.9423220157623291,-0.9719786643981934,-0.9626179337501526,-0.9906449913978577,-0.9984887838363647,-0.9196673631668091,-0.9708828330039978,13.399471282958984,14.013215065002441,14.033735275268555,14.22458553314209,14.228804588317871,14.282355308532715,14.203266143798828,14.032868385314941,14.058372497558594,14.038583755493164,13.978375434875488,14.042292594909668,13.944503784179688,14.483197212219238,3.7259154319763184,3.859663486480713,4.180516719818115,5.65311336517334,5.639413833618164,4.369790077209473,3.7996695041656494,1.7133712768554688,4.357088088989258,5.930742263793945,6.145273685455322,5.961589336395264,6.393418788909912,6.079253196716309,5.2474284172058105,5.414819240570068,5.0952467918396,4.65180778503418,4.639223575592041,4.604980945587158,4.6359782218933105,4.747943878173828,4.4631571769714355,4.372290134429932,4.558743953704834,4.4502363204956055,4.535613536834717,4.605055332183838,1.5159211158752441,1.525362253189087,1.706899881362915,2.428966999053955,2.953901767730713,2.7801756858825684,2.780212640762329,3.1034252643585205,2.6964683532714844,1.4593043327331543,3.4842169284820557,6.118157386779785,5.831913471221924,4.33483362197876,3.5632448196411133,4.359283924102783,2.7773420810699463,0.23442183434963226,-0.63652503490448,-1.2241315841674805,-1.5264521837234497,-1.6016619205474854,-1.0661571025848389,3.4858510494232178,3.520611524581909,3.5803005695343018,3.727327823638916,4.458786964416504,7.512951374053955,7.6867995262146,7.73689079284668,7.718374252319336,7.685084342956543,6.414947509765625,6.222874164581299,6.129316329956055,6.012737274169922,6.023706912994385,5.200160980224609,4.732974529266357,2.5925235748291016,1.547540307044983,-0.9376207590103149,-0.9822463989257813,-0.9957453012466431,-1.0386279821395874,-1.02517831325531,-1.0354199409484863,-1.0079195499420166,-0.9827283620834351,-0.9892561435699463,-0.9497032761573792,-0.9261735677719116,-0.9712662696838379,-0.9724013805389404,-0.9255033731460571,16.083885192871094,16.10271453857422,16.10454559326172,16.097209930419922,16.090383529663086,16.144906997680664,16.506256103515625,16.427289962768555,16.492658615112305,15.597392082214355,15.460864067077637,15.531405448913574,15.308914184570313,15.25334358215332,9.200888633728027,9.20995044708252,9.191731452941895,9.219070434570313,9.168964385986328,9.224637985229492,9.192858695983887,9.103199005126953,8.972443580627441,8.899483680725098,8.98291015625,8.991023063659668,9.041089057922363,9.127313613891602,0.7490016222000122,0.6899598240852356,0.3355867564678192,0.24719013273715973,0.24836979806423187,0.2578429877758026,0.23815631866455078,0.23628731071949005,0.32486486434936523,0.33107516169548035,0.3515322804450989,0.39937156438827515,0.7976394891738892,1.0677955150604248,-3.224520206451416,-3.2190656661987305,-3.209031105041504,-3.2146496772766113,-3.2248435020446777,-3.220414161682129,-3.22904896736145,-3.225184202194214,-3.2034494876861572,-3.220208168029785,-3.2046594619750977,-3.1587095260620117,-3.1639716625213623,-3.204071521759033,2.052521228790283,2.007100820541382,1.8890811204910278,1.9762241840362549,1.9237885475158691,1.9389963150024414,1.953890323638916,1.977135181427002,3.0199875831604004,3.1151700019836426,3.2634434700012207,3.3459808826446533,3.505263328552246,1.7800462245941162,16.13538360595703,16.07372283935547,15.163495063781738,14.965364456176758,15.055808067321777,14.484553337097168,14.522377014160156,14.31725788116455,14.659082412719727,15.510183334350586,15.212434768676758,14.570974349975586,14.959091186523438,14.245929718017578,-2.4934632778167725,-2.58367919921875,-2.5783329010009766,-2.6453771591186523,-2.649860143661499,-2.598466396331787,-2.5986671447753906,-2.6242597103118896,-2.6702802181243896,-2.686131477355957,-2.604801654815674,-2.6145901679992676,-2.631155014038086,-2.510737657546997,-3.150254726409912,-0.9192065596580505,10.761817932128906,10.632770538330078,9.972155570983887,9.747580528259277,9.718208312988281,9.784327507019043,10.991595268249512,10.602593421936035,9.849599838256836,3.2014870643615723,-1.0604976415634155,0.7748280167579651,2.866353988647461,2.688556432723999,2.513451337814331,0.8461609482765198,-0.047698020935058594,-0.6220844388008118,-2.648435592651367,-2.8464012145996094,-2.7988998889923096,-2.7877304553985596,-2.7441070079803467,-2.669426202774048,-2.6564276218414307,-2.6807966232299805,0.5681121945381165,0.4048667848110199,0.38059598207473755,0.22953402996063232,-0.3401399850845337,-0.19015292823314667,-0.0876198336482048,-0.19805358350276947,-0.16405393183231354,1.9485424757003784,2.400540351867676,2.0280981063842773,-0.28081271052360535,-0.18266965448856354,15.452754974365234,15.116336822509766,15.154806137084961,15.055933952331543,15.123038291931152,14.839229583740234,14.836130142211914,15.092087745666504,15.218496322631836,14.9124174118042,15.099825859069824,14.864336013793945,14.431135177612305,14.580501556396484,15.225639343261719,15.291413307189941,15.285059928894043,15.267890930175781,15.291224479675293,15.400064468383789,15.369991302490234,15.456329345703125,15.506682395935059,15.457568168640137,14.788125038146973,14.563410758972168,14.153392791748047,14.330001831054688,-1.8743655681610107,-1.8592599630355835,-1.8684144020080566,-1.8245607614517212,-1.7731287479400635,-1.7866605520248413,-1.7989051342010498,-1.8032728433609009,-1.8144205808639526,-1.812074899673462,-1.8083369731903076,-1.88023841381073,-1.9676793813705444,-1.9428472518920898,-2.0805070400238037,-1.7210350036621094,-1.750859260559082,-1.6960211992263794,-1.6703492403030396,-1.701863408088684,-1.6912785768508911,-1.6382721662521362,-1.7429931163787842,-1.7200056314468384,-1.7240713834762573,-1.710851788520813,-1.7616548538208008,-1.7414140701293945,-1.697687029838562,-1.6418882608413696,-1.6275618076324463,-1.625266671180725,-1.3266026973724365,-1.5655038356781006,-1.2261607646942139,-0.6961477398872375,2.7981743812561035,12.234313011169434,11.439749717712402,8.926511764526367,5.931461334228516,4.4507927894592285,-1.9864825010299683,-2.016037940979004,-2.0345089435577393,-2.0385167598724365,-1.8885504007339478,-1.8634614944458008,-1.9215902090072632,-1.986770510673523,-1.8510018587112427,-1.868208885192871,-1.8817847967147827,-1.8088736534118652,-1.7865623235702515,-1.816178798675537,-2.1924896240234375,-2.1938090324401855,-2.2279536724090576,-2.1044867038726807,-2.0434694290161133,-2.0994269847869873,-2.047574758529663,-2.1299571990966797,-2.0651743412017822,-2.0539474487304688,-2.111250638961792,-2.0586371421813965,-2.063847064971924,-2.1970691680908203,-2.1677589416503906,-2.1453754901885986,-2.150637149810791,-2.151195526123047,-2.1854193210601807,-2.184251070022583,-1.8412485122680664,-1.8617968559265137,-1.886963963508606,-1.894942283630371,-1.859977126121521,-1.8820836544036865,-1.8639291524887085,-1.8612849712371826,-2.3041117191314697,-2.3228108882904053,-2.286288261413574,-2.283825159072876,-2.2899739742279053,-2.275801658630371,-2.256225824356079,-2.2959024906158447,-2.3047447204589844,-2.290724992752075,-2.2936151027679443,-2.822432279586792,-2.852489471435547,-3.045050621032715,-3.4201838970184326,-3.394571304321289,-3.3561739921569824,-3.4243292808532715,-3.428701639175415,-3.45167875289917,-3.3874645233154297,-3.4315803050994873,-3.446338415145874,-3.3999452590942383,-3.486480474472046,-3.438495635986328,-3.44010329246521,-3.5475823879241943,-1.622521162033081,-1.7059593200683594,-2.5731685161590576,-2.6439990997314453,-2.668944835662842,-2.699784278869629,-2.681123971939087,-2.753326892852783,-2.7435412406921387,-1.9615610837936401,-1.854230284690857,-2.2064502239227295,-2.2128190994262695,-2.5980329513549805,-2.380467653274536,-2.3400630950927734,-2.354001998901367,-2.3759605884552,-2.32633376121521,-2.409947156906128,-2.399143934249878,-2.998842477798462,-2.993812322616577,-3.032274007797241,-2.999666690826416,-3.012300491333008,-3.0431387424468994,-3.0082385540008545,-2.8420307636260986,-2.809390068054199,-2.7759687900543213,-2.8675360679626465,-2.801729679107666,-2.8621628284454346,-2.842527389526367,-2.8234927654266357,-2.7566142082214355,-2.7378761768341064,-2.755554676055908,-2.7913613319396973,-2.842656135559082,-2.8216023445129395,3.9276983737945557,3.8687193393707275,3.7643606662750244,3.6580679416656494,3.6396522521972656,3.0385539531707764,2.4724087715148926,2.322465658187866,2.401134967803955,2.497668504714966,5.602853775024414,7.072213649749756,7.0252556800842285,6.50825834274292,-4.246834754943848,-4.2473931312561035,-4.252810001373291,-4.260010719299316,-4.2449822425842285,-4.239299297332764,-4.234219551086426,-4.284492492675781,-4.235384941101074,-4.250739097595215,-4.282804489135742,-4.25057315826416,-4.208159923553467,-4.248528480529785,-0.7223843336105347,-0.8061695098876953,-0.6662040948867798,-0.6571676731109619,-0.7226731777191162,-0.6893604397773743,-0.6108564734458923,-0.37032413482666016,-0.5781712532043457,-0.6116868257522583,-0.690111517906189,-0.7618236541748047,-0.8193117380142212,-1.1585350036621094,-2.8714709281921387,-2.8561387062072754,-2.8923988342285156,-2.8844149112701416,-2.8871560096740723,-2.8728137016296387,-2.842759370803833,1.675359845161438,2.8451852798461914,2.4144763946533203,1.7601654529571533,2.042163610458374,6.1043267250061035,6.629210472106934,1.7476272583007813,1.7406305074691772,2.1241767406463623,5.640944957733154,7.37109899520874,7.51116943359375,7.990054607391357,7.749589920043945,7.757816314697266,6.265022277832031,6.030090808868408,5.970717430114746,5.898531913757324,4.805541515350342,-1.5395252704620361,-1.559367060661316,-1.9744292497634888,-1.2612595558166504,-1.5764051675796509,0.37385761737823486,0.4160386323928833,0.364393949508667,0.48144015669822693,0.5408278703689575,0.6370813846588135,0.6663386821746826,-2.09153151512146,-1.6184254884719849,11.801663398742676,11.777430534362793,12.132905960083008,12.635157585144043,12.64350414276123,12.652859687805176,12.727376937866211,12.981571197509766,12.852962493896484,13.043866157531738,12.926576614379883,12.783528327941895,12.737043380737305,12.33177375793457,-2.0494697093963623,-2.0732312202453613,-2.0468976497650146,-2.067392349243164,-2.042057514190674,-2.041780471801758,-2.0681161880493164,-2.042057752609253,-2.0623490810394287,-2.0401611328125,-2.0171000957489014,-2.047689914703369,-1.8729941844940186,-1.8966752290725708,-0.9324887990951538,0.8307813405990601,0.8173738121986389,0.17872756719589233,0.1536688506603241,0.22905968129634857,0.1706295758485794,0.1611076295375824,0.4842524528503418,0.1493072360754013,-1.142153263092041,-0.8725656867027283,-1.4598402976989746,-1.7007249593734741,-3.614534378051758,-3.5670621395111084,-3.6129815578460693,-3.602992534637451,-3.5982446670532227,-3.6026556491851807,-3.592961311340332,-3.5923268795013428,-3.640256643295288,-3.6192855834960938,-3.5408763885498047,-3.758589029312134,-3.71940016746521,-3.7118208408355713,-3.4473135471343994,-2.6567723751068115,-1.1035170555114746,1.8958253860473633,-2.145540475845337,-2.100388765335083,-2.079672336578369,-2.2061643600463867,-2.4172966480255127,-2.4969730377197266,-2.4766602516174316,-3.0846822261810303,-3.0894060134887695,-3.131253719329834,-2.9801597595214844,-3.007999897003174,-3.0049102306365967,-2.8411314487457275,0.18661624193191528,0.6302587985992432,0.5946506857872009,0.5579337477684021,0.8870400190353394,0.5796104669570923,0.5909265279769897,0.5842441916465759,0.5892970561981201,0.3684101700782776,5.845642566680908,8.105290412902832,7.886237621307373,6.709845066070557,6.364511013031006,4.097583293914795,2.8970565795898438,1.9647305011749268,1.824718713760376,4.279601097106934,7.463736534118652,11.840509414672852,12.025519371032715,10.464731216430664,6.73845911026001,6.857014179229736,6.824489593505859,7.386744022369385,7.626081943511963,9.46595573425293,9.301396369934082,9.109455108642578,8.017744064331055,6.320429801940918,6.2983717918396,6.162169456481934,6.200997352600098,5.867562294006348,-2.573373794555664,-2.5665745735168457,-2.582396984100342,-2.183983325958252,-2.1920204162597656,-2.215364933013916,-2.26291823387146,-2.1313881874084473,-1.9700266122817993,-1.1952730417251587,-2.4079017639160156,-2.5328328609466553,-2.582064628601074,-2.5502781867980957,-3.092066526412964,-3.1330339908599854,-3.1321163177490234,-3.111276149749756,-3.0725646018981934,-3.09045672416687,-3.0905814170837402,-3.1629698276519775,-3.1207056045532227,-3.1199522018432617,-3.0931930541992188,-3.077714204788208,-3.1156740188598633,-3.034252882003784,-2.6426217555999756,-2.5247509479522705,-2.996070623397827,-3.0392282009124756,-3.0248029232025146,-3.0501739978790283,-3.087110996246338,-3.033756732940674,-3.0718085765838623,-3.1245479583740234,-3.140425205230713,-3.0865066051483154,-3.107243776321411,-2.9793167114257813,-1.2482798099517822,-1.2700341939926147,-1.2527304887771606,-0.7212985754013062,-0.7745326161384583,3.3194704055786133,4.686468124389648,4.368355751037598,5.703273296356201,3.532835006713867,3.0720198154449463,3.4639601707458496,4.384073734283447,3.8788230419158936,-3.747939348220825,-3.747199773788452,-3.7510876655578613,-3.7215633392333984,-3.7522640228271484,-3.72812819480896,-3.787343740463257,-3.76302433013916,-3.746866226196289,-3.7162013053894043,-3.6985535621643066,-3.6606361865997314,-3.3285372257232666,-3.3491902351379395,-2.04530668258667,-2.0548577308654785,-2.013576030731201,-1.8924931287765503,-1.8467464447021484,-1.8233929872512817,-2.002406597137451,-2.047241449356079,-2.1013050079345703,-2.124687433242798,-2.069683790206909,-1.9842979907989502,-2.092191457748413,-2.0899109840393066,-1.646751046180725,-1.6331793069839478,-1.6527801752090454,-1.6443030834197998,-1.5683937072753906,-1.5468251705169678,-1.5323082208633423,-1.639870285987854,-1.5609569549560547,-0.8011729717254639,0.2491966187953949,-0.2940506339073181,-0.24435001611709595,-0.781381368637085,11.36594295501709,11.443610191345215,11.452969551086426,10.741454124450684,10.684891700744629,11.1950044631958,11.069559097290039,10.833391189575195,10.804852485656738,10.782418251037598,10.83769416809082,11.177300453186035,10.850821495056152,10.85122299194336,-2.5081474781036377,-2.4680633544921875,-2.4192490577697754,-2.4034464359283447,-2.3984694480895996,-2.3959743976593018,-2.4074902534484863,-2.3698580265045166,-2.3381733894348145,-2.3892669677734375,-2.3357930183410645,-2.343165397644043,-2.285982847213745,-2.292715549468994,-3.687013626098633,-3.726179599761963,-3.731752872467041,-3.4397361278533936,-3.460258722305298,-3.437742233276367,-3.445852756500244,-3.4337961673736572,-3.119279384613037,-3.5163064002990723,-3.2615630626678467,-3.3781726360321045,-3.4513235092163086,-3.459167242050171,-0.16773033142089844,0.22791481018066406,0.21219131350517273,-0.7537432312965393,-0.7775965332984924,-0.7796617746353149,-0.8233532905578613,-0.651107668876648,-0.9814619421958923,-1.0382537841796875,-0.998382031917572,-0.853935182094574,-0.7528829574584961,-0.85576993227005,-2.1516265869140625,-2.1414411067962646,-2.1663858890533447,-2.104827404022217,-2.14034366607666,-2.1374361515045166,-2.1201181411743164,-1.7971725463867188,-1.8500123023986816,-1.935660481452942,-2.0002787113189697,-1.9646644592285156,-1.9679170846939087,-2.0386433601379395,15.286351203918457,15.360970497131348,15.445182800292969,15.004053115844727,15.03506851196289,14.956097602844238,14.731470108032227,14.756903648376465,14.709966659545898,14.953926086425781,14.855204582214355,14.710183143615723,14.137007713317871,14.525647163391113,-2.325059175491333,-2.139619827270508,-2.0563433170318604,-2.0930254459381104,-2.1720995903015137,-2.5602190494537354,-2.5036957263946533,-2.567296266555786,-2.6601524353027344,-2.6264374256134033,-2.6392033100128174,-2.60565447807312,-2.64066481590271,-2.6040821075439453,9.968981742858887,9.973560333251953,9.976648330688477,9.953035354614258,9.958831787109375,9.953041076660156,9.965946197509766,9.963704109191895,9.962523460388184,9.9752836227417,9.94080638885498,9.974770545959473,9.985152244567871,9.988212585449219,16.385669708251953,16.43182373046875,16.402389526367188,16.476781845092773,16.541540145874023,16.52603530883789,16.440404891967773,16.47353744506836,16.478952407836914,16.49338150024414,16.208248138427734,16.220735549926758,16.382709503173828,16.14713478088379,3.2590794563293457,3.2532055377960205,3.305220127105713,2.968975305557251,2.9163618087768555,2.6585946083068848,2.715214252471924,2.5160739421844482,1.6411118507385254,1.7425428628921509,1.8172231912612915,1.6304740905761719,1.7633672952651978,1.674581527709961,8.284168243408203,8.167874336242676,8.077630996704102,8.067512512207031,8.286515235900879,8.2037353515625,8.26126766204834,7.31346321105957,7.000967502593994,6.944693088531494,6.926628112792969,8.221189498901367,9.919437408447266,8.289855003356934,0.20955824851989746,0.6748610734939575,0.7030531764030457,1.8992527723312378,1.8421440124511719,-0.13644586503505707,-0.27750614285469055,-0.669964075088501,-1.4549453258514404,-2.75325345993042,-2.895198345184326,-2.918764114379883,-2.9098546504974365,-2.907503843307495,13.859145164489746,14.09148120880127,14.17386531829834,13.625917434692383,13.566981315612793,13.387447357177734,12.04091739654541,11.21083927154541,11.29354190826416,11.344442367553711,12.026949882507324,11.67947006225586,11.099316596984863,11.001350402832031,-2.3583641052246094,-2.338064193725586,-2.380788803100586,-2.336503028869629,-2.3482413291931152,-2.3269667625427246,-2.334866523742676,-2.3623812198638916,-2.3974406719207764,-2.4986650943756104,-2.472348928451538,-2.5020503997802734,-2.474632740020752,-2.5094892978668213,13.961946487426758,13.996464729309082,13.939748764038086,14.01292610168457,14.008628845214844,14.035903930664063,14.032503128051758,13.660584449768066,13.539088249206543,13.5016450881958,12.726401329040527,12.029366493225098,11.540221214294434,11.32555866241455,15.83241081237793,15.9804105758667,16.019668579101563,15.292683601379395,14.639010429382324,14.708868980407715,14.651634216308594,13.795555114746094,13.1643705368042,12.971170425415039,13.151603698730469,12.81490421295166,14.71878719329834,15.415215492248535,15.89256763458252,15.927373886108398,15.913701057434082,15.930891990661621,15.926230430603027,15.934123992919922,15.926773071289063,15.934632301330566,15.927352905273438,15.94090461730957,15.965689659118652,15.99814510345459,15.95080852508545,15.927082061767578,-1.8868472576141357,-1.797200322151184,-1.8253986835479736,-1.765429139137268,-1.7566925287246704,-1.7772825956344604,-1.7873677015304565,-1.8230350017547607,-1.8217408657073975,-1.7845298051834106,-1.8288731575012207,-1.815056562423706,-1.8230891227722168,-1.7798292636871338,16.43297576904297,16.427120208740234,16.409896850585938,16.455745697021484,16.5430908203125,16.632984161376953,16.683963775634766,16.73343276977539,16.67934799194336,16.602235794067383,16.614944458007813,16.658809661865234,16.73443031311035,16.64441680908203,-3.386171579360962,-3.3373913764953613,-3.244748592376709,-3.2267534732818604,-3.6185336112976074,-1.5913399457931519,-1.5711852312088013,-1.5186269283294678,-1.5263028144836426,-1.6410434246063232,-1.5923775434494019,-1.5340174436569214,-1.437094807624817,1.4657440185546875,16.574283599853516,16.579225540161133,16.54448127746582,16.606517791748047,16.683412551879883,15.90665340423584,15.797677040100098,15.998675346374512,16.306699752807617,16.33193016052246,16.307588577270508,16.177204132080078,16.16379165649414,15.714353561401367,16.145416259765625,16.147302627563477,16.054832458496094,15.816489219665527,15.765542030334473,15.01508617401123,14.944819450378418,14.887958526611328,14.8478364944458,14.782943725585938,13.137853622436523,11.998751640319824,11.759771347045898,11.344367027282715,3.386448860168457,3.376408100128174,3.460940361022949,4.231205463409424,4.251580715179443,5.870672225952148,6.147021293640137,6.204882621765137,6.108604907989502,5.6033172607421875,3.356895685195923,2.3152902126312256,1.6788763999938965,1.6367967128753662,-4.83750581741333,-4.850495338439941,-4.887818813323975,-4.883022785186768,-4.871554851531982,-4.931617736816406,-4.955904006958008,-4.988049030303955,-4.990959644317627,-4.9508748054504395,-1.1020786762237549,-2.6200313568115234,-2.700469493865967,-2.7176735401153564,15.02614974975586,15.021472930908203,15.019282341003418,14.830138206481934,14.832047462463379,14.844914436340332,14.851956367492676,14.802448272705078,15.026707649230957,14.72383975982666,14.773661613464355,14.012367248535156,13.815949440002441,13.971908569335938,11.185324668884277,11.222295761108398,11.236170768737793,11.044330596923828,11.056159019470215,11.026910781860352,10.896519660949707,10.120365142822266,9.738245964050293,9.868675231933594,10.678950309753418,11.132458686828613,10.96275520324707,10.52878189086914,-4.987098693847656,-4.970977783203125,-4.999197006225586,-4.980068683624268,-4.985127925872803,-5.01775598526001,-5.000604629516602,-5.004998683929443,-4.9717936515808105,-4.979372024536133,-4.995092391967773,-5.016040325164795,-4.9861063957214355,-4.975736141204834,14.832785606384277,14.759236335754395,14.615312576293945,14.407064437866211,14.393360137939453,14.587432861328125,14.154229164123535,13.959189414978027,14.045073509216309,14.127457618713379,13.994680404663086,13.78586196899414,13.849044799804688,13.763222694396973,15.102343559265137,15.10329818725586,15.055645942687988,15.105162620544434,15.151721954345703,15.060760498046875,15.104738235473633,15.106465339660645,15.165618896484375,15.092476844787598,15.18530559539795,15.12585163116455,15.299552917480469,15.361090660095215,2.712791681289673,1.1854591369628906,0.8238729238510132,0.42205819487571716,0.4094099700450897,0.288496196269989,0.32155710458755493,3.175717830657959,3.995389461517334,4.469711780548096,4.328419208526611,4.112708568572998,3.2597970962524414,3.27254056930542,-1.0585589408874512,-1.0278319120407104,-1.0446707010269165,-1.1514220237731934,-1.0904529094696045,-1.0923360586166382,-1.0747674703598022,-1.148932933807373,0.14036449790000916,0.9274911284446716,-0.027175378054380417,-0.03090566210448742,0.22222429513931274,1.629078984260559,12.455758094787598,12.567440032958984,12.49211311340332,11.842997550964355,11.679937362670898,11.839531898498535,11.832554817199707,11.717995643615723,11.660247802734375,11.762438774108887,11.949880599975586,12.011580467224121,12.0431547164917,12.029666900634766,11.196680068969727,11.06993293762207,11.124704360961914,10.962888717651367,9.92924976348877,10.66611385345459,10.641046524047852,10.666686058044434,10.700821876525879,8.784475326538086,3.00944447517395,2.4811041355133057,1.7335647344589233,1.1289982795715332,1.970203161239624,1.986189365386963,1.9612009525299072,1.3202985525131226,1.1724318265914917,1.164102554321289,1.0462671518325806,0.9884213805198669,1.0477561950683594,0.8563651442527771,1.2931174039840698,1.807969093322754,1.6363613605499268,4.2541584968566895,16.043167114257813,15.885700225830078,15.908609390258789,15.823837280273438,15.848567962646484,15.869178771972656,15.868163108825684,15.836092948913574,15.899868965148926,15.910463333129883,15.903766632080078,15.888185501098633,16.013216018676758,16.109167098999023,16.710771560668945,16.761207580566406,16.75986099243164,16.697973251342773,16.73322868347168,16.80177879333496,16.808555603027344,16.802522659301758,16.657424926757813,16.726099014282227,16.401159286499023,16.5225772857666,16.537691116333008,16.460142135620117,-2.9838035106658936,-3.641704797744751,-3.6749088764190674,-3.665037155151367,-3.669127941131592,-3.664571523666382,-3.665224075317383,-3.66971755027771,-3.669431447982788,-3.66782808303833,-3.672901153564453,-3.668430805206299,-3.6383988857269287,-3.6827149391174316,6.397737503051758,6.4883317947387695,5.6945695877075195,3.9420814514160156,4.142938137054443,4.058089256286621,4.004226207733154,4.056652545928955,4.033143520355225,4.052403450012207,3.88992977142334,3.9404044151306152,3.8997976779937744,3.759253978729248,8.116089820861816,8.17857837677002,7.989584445953369,8.189423561096191,8.202840805053711,9.95510196685791,11.035103797912598,7.913299083709717,7.353360176086426,11.608861923217773,13.204785346984863,11.906119346618652,8.265116691589355,7.446605682373047,7.9149885177612305,7.937206745147705,7.851287841796875,7.890623569488525,7.987188816070557,8.295341491699219,8.0053071975708,7.807652473449707,7.737457275390625,8.887299537658691,8.491787910461426,8.333904266357422,8.02192211151123,7.898716449737549,-3.239060163497925,-3.2361793518066406,-3.239097833633423,-3.2390527725219727,-3.2393598556518555,-3.2391257286071777,-3.2388932704925537,-3.241689682006836,-3.2392642498016357,-3.225020408630371,-3.2427287101745605,-3.240203619003296,-3.2377593517303467,-3.239419460296631,6.261501789093018,6.394824504852295,5.712802886962891,2.0046119689941406,0.7553738355636597,0.22887730598449707,0.05730138346552849,-0.8530569672584534,-0.9583778381347656,-0.8901837468147278,-0.9103615880012512,-0.872776210308075,-0.8892063498497009,-0.9302698969841003,0.35687562823295593,0.39595887064933777,0.3595705032348633,0.34103459119796753,0.5154052376747131,0.6089869141578674,4.12061882019043,4.451449871063232,4.632552146911621,4.638071537017822,5.381459712982178,9.925080299377441,9.957306861877441,9.896551132202148,-4.812816619873047,-4.814406394958496,-4.807174205780029,-4.810848712921143,-4.826629638671875,-4.8199076652526855,-4.810934543609619,-4.805072784423828,-4.8092193603515625,-4.792898178100586,-4.809659957885742,-4.813675403594971,-4.806131839752197,-4.777331829071045,14.225641250610352,14.282710075378418,14.198010444641113,13.963859558105469,13.99240779876709,14.017020225524902,13.972928047180176,13.942628860473633,13.440705299377441,14.076801300048828,14.474533081054688,14.531709671020508,14.349870681762695,13.894291877746582,15.279733657836914,15.204702377319336,14.837482452392578,14.632482528686523,14.678702354431152,14.752569198608398,14.618624687194824,14.589600563049316,14.161053657531738,13.842324256896973,12.145454406738281,10.980419158935547,13.710128784179688,12.037054061889648,2.4974582195281982,2.601322650909424,2.613626003265381,2.620159149169922,2.69374680519104,2.9250266551971436,3.407787561416626,4.292710304260254,4.349953651428223,4.9816179275512695,4.773880958557129,4.721979141235352,4.802588939666748,5.019822120666504,9.38742446899414,9.334735870361328,9.391504287719727,9.490447044372559,9.487776756286621,9.501720428466797,10.980097770690918,11.1875581741333,11.107049942016602,10.808687210083008,10.578153610229492,11.110406875610352,11.262491226196289,11.84373664855957,-3.1908648014068604,-3.1379916667938232,-3.150484800338745,-3.1415529251098633,-3.1436657905578613,-3.1489169597625732,-3.134679079055786,-3.1251981258392334,-3.155959129333496,-3.139540433883667,-3.1184818744659424,-3.131640672683716,-3.135113477706909,-3.1013474464416504,13.011734962463379,12.05138874053955,11.876147270202637,9.32383918762207,7.528806686401367,6.120164394378662,6.114889144897461,3.539905548095703,1.416511058807373,1.1694210767745972,1.1001548767089844,0.8722190260887146,0.7899609208106995,0.279134601354599,-0.8944501280784607,-0.857042670249939,-0.8442472219467163,-0.826991856098175,-0.8901838660240173,-0.9341634511947632,-1.119497537612915,-1.0722732543945313,-1.0920771360397339,-1.106950283050537,-1.1145025491714478,-1.0775543451309204,-1.0725812911987305,-1.0766602754592896],\n",
       "\"second_dim\":[12.119108200073242,12.082037925720215,12.173379898071289,12.156977653503418,12.197991371154785,12.093864440917969,12.118324279785156,12.104242324829102,12.063191413879395,12.057682991027832,12.032106399536133,11.57538890838623,11.323811531066895,10.818525314331055,11.142985343933105,11.238039016723633,11.225175857543945,11.27743148803711,11.279531478881836,11.213951110839844,11.139165878295898,11.232616424560547,11.293061256408691,11.680424690246582,11.335944175720215,11.28942584991455,10.972556114196777,11.27561092376709,4.501993179321289,4.549220561981201,4.571778774261475,4.593479156494141,4.628398418426514,4.611839294433594,4.638992786407471,4.629079818725586,4.60062313079834,4.704183578491211,4.763711929321289,4.736015796661377,4.80049991607666,6.186304092407227,3.832298755645752,3.8346986770629883,3.8224966526031494,3.8164966106414795,3.799311399459839,3.7922916412353516,3.8026254177093506,3.810777425765991,3.780776023864746,3.7804722785949707,3.857647180557251,3.838074207305908,3.8350539207458496,3.867783784866333,12.595911979675293,12.594286918640137,12.540583610534668,12.63903522491455,12.625951766967773,12.659122467041016,12.650527954101563,12.619174003601074,12.627826690673828,12.755635261535645,12.703713417053223,13.00024700164795,13.010488510131836,12.999197959899902,10.560097694396973,10.617667198181152,10.589888572692871,10.837881088256836,11.002963066101074,11.018776893615723,10.957551956176758,11.195890426635742,11.194144248962402,11.775318145751953,11.882464408874512,11.798397064208984,11.921916007995605,12.422968864440918,8.674059867858887,8.677831649780273,8.726364135742188,9.456972122192383,9.45845890045166,9.47986125946045,9.503888130187988,9.493992805480957,9.40479564666748,9.38729190826416,9.398445129394531,9.626799583435059,9.581844329833984,9.591772079467773,-1.4814599752426147,2.446554660797119,4.302464962005615,6.089515209197998,6.265918731689453,6.412362575531006,7.809689998626709,7.925845146179199,7.864596843719482,8.594766616821289,8.62105655670166,-1.4717497825622559,-1.6046007871627808,-1.8579145669937134,4.584432601928711,4.4323835372924805,4.027484893798828,3.899592399597168,3.0214221477508545,2.879884958267212,2.859877586364746,2.8002688884735107,2.8770830631256104,2.817819833755493,3.6716086864471436,2.617867946624756,1.5031592845916748,1.3452668190002441,12.558090209960938,12.555464744567871,12.534646034240723,12.303887367248535,12.410843849182129,12.3792724609375,12.332467079162598,12.422181129455566,12.308810234069824,12.1893310546875,12.474364280700684,12.389460563659668,12.284601211547852,11.801336288452148,0.4062281847000122,0.3839660882949829,3.379952907562256,-0.10622244328260422,-1.214444875717163,-0.661383867263794,-0.24595023691654205,-0.2516517639160156,-0.2343883216381073,-0.0925348550081253,-0.07609729468822479,-0.0954928994178772,-0.037031084299087524,0.0645175501704216,3.729325294494629,4.760479927062988,5.144696235656738,4.617034435272217,3.1029510498046875,-0.7369052767753601,-1.9402875900268555,-1.9750678539276123,-1.9403842687606812,-1.921815037727356,-1.9926642179489136,-1.9166747331619263,-1.917724609375,-1.818132758140564,12.46211051940918,12.196612358093262,12.222372055053711,12.19731330871582,12.098873138427734,11.985886573791504,11.825590133666992,11.829509735107422,11.872376441955566,12.179394721984863,12.238896369934082,12.213770866394043,11.827430725097656,11.770820617675781,5.537652969360352,5.600308895111084,5.890452861785889,6.038783073425293,6.527371406555176,7.339151382446289,11.455079078674316,11.992897033691406,12.06972599029541,12.108959197998047,12.268784523010254,12.21881103515625,12.26425552368164,12.443634033203125,6.747310638427734,6.702606201171875,6.754154205322266,6.751820087432861,6.960011959075928,7.2402849197387695,10.431025505065918,10.768699645996094,11.280815124511719,12.234116554260254,12.063065528869629,12.302791595458984,12.100541114807129,9.827783584594727,4.945124626159668,5.049789905548096,5.03941011428833,4.9317731857299805,4.993468761444092,4.886282920837402,5.476931095123291,8.29662036895752,8.605001449584961,8.67227840423584,8.7726411819458,8.41749095916748,8.288104057312012,8.044290542602539,4.979986190795898,5.487802028656006,5.502163887023926,6.263548374176025,6.275700569152832,6.024212837219238,6.1149797439575195,5.5193963050842285,5.805570125579834,6.9273200035095215,7.104269504547119,6.957883834838867,8.634523391723633,8.865460395812988,12.132613182067871,12.144694328308105,12.152714729309082,12.188834190368652,12.101512908935547,12.084317207336426,12.101964950561523,12.090167999267578,12.1123628616333,12.141204833984375,10.683385848999023,6.630581855773926,6.325494289398193,6.263399124145508,6.6159443855285645,6.555423736572266,6.458704948425293,5.231168746948242,2.7388391494750977,2.678623676300049,2.7085134983062744,2.673307418823242,2.298440933227539,2.215993881225586,2.2360012531280518,2.2004897594451904,2.2944109439849854,2.2098960876464844,11.976318359375,11.937042236328125,11.931107521057129,11.94951343536377,11.948750495910645,11.790412902832031,11.755274772644043,11.724225044250488,11.426145553588867,9.96484375,6.817825794219971,11.42851448059082,11.368890762329102,11.385272979736328,8.735267639160156,8.16373348236084,8.358028411865234,8.242916107177734,8.231059074401855,7.836385250091553,7.762890815734863,7.843084812164307,7.9617509841918945,7.614400863647461,5.599048137664795,5.1780500411987305,0.5236214995384216,0.4812837839126587,8.287044525146484,8.575379371643066,8.522796630859375,8.58806324005127,9.259201049804688,8.716060638427734,8.866567611694336,8.483033180236816,7.298703670501709,7.3551764488220215,7.492902755737305,8.118547439575195,11.718395233154297,11.836196899414063,11.83764362335205,11.867262840270996,7.294719696044922,6.191440582275391,10.90182113647461,11.334611892700195,11.275516510009766,10.718252182006836,10.527116775512695,10.673623085021973,7.283034324645996,3.9531848430633545,3.784386396408081,3.717557430267334,9.74837589263916,9.62669849395752,9.609601974487305,9.712820053100586,9.700857162475586,9.18160629272461,8.714035034179688,8.59072494506836,8.149518966674805,7.434620380401611,8.01031494140625,8.083589553833008,7.75079870223999,6.386670112609863,9.421605110168457,8.860233306884766,8.659896850585938,8.90190601348877,8.904623031616211,9.01855754852295,9.905220985412598,9.814225196838379,8.592803001403809,8.873257637023926,8.533476829528809,10.200486183166504,10.745933532714844,11.781563758850098,12.492920875549316,12.499686241149902,12.426279067993164,12.008955955505371,12.02851676940918,12.01784896850586,11.905333518981934,11.984527587890625,11.923413276672363,11.690704345703125,11.572765350341797,11.811543464660645,12.078579902648926,12.353655815124512,0.29055333137512207,0.1936531662940979,-0.84253990650177,-0.981060802936554,-0.8556228280067444,-1.3212648630142212,-1.4180651903152466,-1.5241901874542236,-1.136532187461853,-0.912102222442627,-1.9616165161132813,-2.0040669441223145,-1.3159894943237305,0.9509410858154297,0.8175175786018372,0.890903890132904,0.15349015593528748,0.07804577797651291,0.38576608896255493,0.37927189469337463,0.6524840593338013,0.5279138088226318,1.2331076860427856,-0.9451533555984497,-1.1053704023361206,-0.9588308930397034,-1.30405855178833,1.719391942024231,1.7025035619735718,1.7125656604766846,1.7290676832199097,1.704957127571106,1.6983919143676758,1.709362506866455,1.7185065746307373,1.7734639644622803,3.6177191734313965,3.5283315181732178,1.7418526411056519,1.7310466766357422,1.7122184038162231,5.624906063079834,5.6358537673950195,5.616128444671631,5.688916206359863,5.697068214416504,5.656650066375732,5.3196492195129395,5.372601509094238,5.408945560455322,4.894489765167236,5.147254943847656,-1.9419699907302856,-4.3223395347595215,-4.363347053527832,10.470300674438477,10.42398452758789,10.343913078308105,10.268855094909668,10.282636642456055,10.362874984741211,10.834634780883789,10.800832748413086,10.385224342346191,10.335203170776367,9.784368515014648,9.83158016204834,9.407687187194824,9.069856643676758,0.6229321360588074,0.6568681597709656,0.6270687580108643,0.6462924480438232,0.6694655418395996,0.6998414993286133,0.6158844232559204,0.6466563940048218,2.9174153804779053,4.862117767333984,4.812826156616211,4.304346561431885,4.473817348480225,3.8324646949768066,12.078754425048828,12.076651573181152,12.11313247680664,12.289566040039063,12.646519660949707,12.440407752990723,12.116716384887695,11.10770034790039,11.045570373535156,10.108526229858398,8.56518268585205,8.803189277648926,8.470930099487305,8.016042709350586,10.510396003723145,10.516929626464844,10.593705177307129,12.054959297180176,12.133322715759277,12.115333557128906,12.138596534729004,11.97800350189209,11.719139099121094,11.721996307373047,11.736802101135254,12.149601936340332,12.35030460357666,12.708222389221191,-3.345534086227417,-3.369020938873291,-3.3435781002044678,-3.3555848598480225,-3.366138219833374,-3.366591215133667,-3.3529725074768066,-3.3504600524902344,-3.3273539543151855,-3.332902431488037,-3.3638594150543213,-3.3550667762756348,-3.3430535793304443,-3.308873176574707,10.485575675964355,10.480971336364746,10.831194877624512,11.620170593261719,11.719563484191895,11.742791175842285,11.44198989868164,7.632262706756592,7.489449501037598,8.322232246398926,7.9763336181640625,8.174842834472656,9.421091079711914,11.763805389404297,11.604270935058594,11.231733322143555,11.328533172607422,11.022229194641113,12.287723541259766,12.512743949890137,12.283727645874023,11.960515975952148,12.261178970336914,12.288664817810059,12.312254905700684,12.24559211730957,12.401994705200195,12.30332088470459,9.790202140808105,9.96095085144043,10.002083778381348,10.086835861206055,10.09668254852295,10.053613662719727,10.040750503540039,9.978429794311523,9.432177543640137,8.416748046875,8.464839935302734,8.434901237487793,7.848056793212891,6.894284248352051,9.919597625732422,11.093951225280762,11.310946464538574,11.611832618713379,11.703621864318848,11.918235778808594,11.817671775817871,11.843245506286621,11.899413108825684,11.31947135925293,11.294022560119629,10.458027839660645,10.570002555847168,10.628902435302734,11.970298767089844,12.194090843200684,12.198498725891113,12.181321144104004,12.09953784942627,12.171353340148926,11.292951583862305,10.981423377990723,10.457427978515625,9.719801902770996,9.480464935302734,9.407748222351074,9.385085105895996,9.528942108154297,11.569231986999512,11.631295204162598,11.610219955444336,11.540644645690918,11.507811546325684,11.366206169128418,10.282096862792969,10.219490051269531,10.049362182617188,9.99944019317627,10.02726936340332,9.94834041595459,10.246882438659668,10.555931091308594,8.5441312789917,8.576069831848145,8.57119369506836,8.659902572631836,8.647405624389648,8.710664749145508,7.534407138824463,7.551087379455566,6.792465686798096,7.339449882507324,8.287626266479492,8.389359474182129,7.338518142700195,7.393488883972168,9.846187591552734,10.60521125793457,11.55380630493164,10.292778968811035,-0.16136622428894043,-0.2722219228744507,-0.2696644365787506,-0.5457661151885986,-0.0715385302901268,0.8525479435920715,0.7659181356430054,0.7955183386802673,0.8258097767829895,4.631934642791748,6.624987602233887,6.620264053344727,6.60154390335083,6.426048278808594,6.409675121307373,6.278992176055908,5.774839401245117,5.620114803314209,5.589427947998047,5.481179237365723,5.242683410644531,4.675816535949707,4.692600250244141,4.566138744354248,7.716596603393555,7.583503723144531,7.518438816070557,4.906261444091797,4.850642204284668,4.794518947601318,4.681166172027588,3.378584623336792,1.7615405321121216,1.7129878997802734,1.6976655721664429,1.7860029935836792,1.5794081687927246,1.76046621799469,12.547243118286133,12.601188659667969,12.651017189025879,12.655913352966309,12.631242752075195,12.257731437683105,11.643789291381836,11.63982105255127,12.554655075073242,10.55295181274414,8.46511173248291,8.25611400604248,9.616117477416992,10.377082824707031,12.798912048339844,12.830462455749512,12.782410621643066,12.891605377197266,12.929300308227539,12.919902801513672,12.887066841125488,12.886759757995605,12.931313514709473,12.815150260925293,12.779184341430664,12.942258834838867,12.653322219848633,12.438076972961426,11.446916580200195,11.529176712036133,11.558176040649414,12.2113618850708,12.396536827087402,8.501049995422363,12.403904914855957,12.375215530395508,12.26646614074707,12.277149200439453,12.3226900100708,12.612139701843262,4.919054985046387,0.9076650738716125,4.507181167602539,4.555243492126465,4.513833045959473,4.353798866271973,4.354195594787598,4.336991786956787,3.8748602867126465,2.3170604705810547,1.5071749687194824,1.4241539239883423,1.4315799474716187,1.4017289876937866,1.364980697631836,1.405808925628662,11.960156440734863,11.94395923614502,11.998641967773438,11.935829162597656,12.095293045043945,12.197728157043457,12.312994956970215,12.420110702514648,12.449824333190918,12.45509147644043,12.054791450500488,11.927209854125977,11.812772750854492,11.353584289550781,9.66369915008545,9.717042922973633,9.709845542907715,9.731372833251953,9.836304664611816,9.824352264404297,9.623887062072754,8.53911304473877,8.312139511108398,7.953398704528809,6.97028112411499,7.276089668273926,6.965381622314453,6.5716094970703125,12.271374702453613,12.221867561340332,7.784698009490967,4.380423545837402,12.81427001953125,12.992791175842285,13.027400016784668,12.213506698608398,12.534794807434082,12.562341690063477,12.516573905944824,12.601471900939941,12.453241348266602,12.034500122070313,7.630421161651611,7.646108150482178,6.429511547088623,4.785329341888428,4.73393440246582,4.694622039794922,4.4883246421813965,4.1024346351623535,1.4532310962677002,1.3900601863861084,1.3117426633834839,0.9445613026618958,-0.9238297939300537,-1.033976435661316,5.454206943511963,11.807940483093262,12.240583419799805,12.14924430847168,12.189456939697266,12.225872993469238,12.619057655334473,12.366683006286621,12.067082405090332,11.903294563293457,11.936251640319824,11.806591033935547,11.656708717346191,8.589924812316895,11.868728637695313,11.871306419372559,11.896105766296387,11.279227256774902,11.197092056274414,10.701191902160645,8.693378448486328,6.415717124938965,6.831587791442871,6.718719005584717,6.456199645996094,9.876301765441895,12.200042724609375,12.11193561553955,5.263652801513672,5.186553955078125,5.074573516845703,5.613218784332275,5.689711093902588,5.67549991607666,5.6189165115356445,5.753708362579346,5.72212553024292,5.626054286956787,5.52090311050415,5.508176326751709,5.461149215698242,5.300121784210205,3.7363812923431396,4.857113361358643,4.877730369567871,4.873365879058838,6.507857322692871,6.53891658782959,6.5626091957092285,6.390663146972656,6.4197916984558105,6.273836612701416,4.684124946594238,3.8708722591400146,1.903160810470581,1.4268139600753784,9.860877990722656,9.707991600036621,10.453557968139648,10.254055976867676,10.37318229675293,10.50776481628418,11.279349327087402,11.298625946044922,11.272319793701172,11.057388305664063,10.573436737060547,9.182849884033203,9.26974105834961,9.266724586486816,7.645097255706787,7.633772850036621,7.622879505157471,6.427779197692871,6.456940174102783,6.580251216888428,6.543431758880615,5.521502494812012,6.545188903808594,7.42115592956543,7.305061340332031,7.3004961013793945,7.349937915802002,6.502378463745117,8.570051193237305,9.188094139099121,9.307061195373535,9.141279220581055,9.221892356872559,9.147372245788574,8.23947525024414,8.175362586975098,8.223011016845703,7.69376277923584,7.934235095977783,8.066865921020508,8.064006805419922,8.121214866638184,4.870719909667969,4.796040058135986,4.779664516448975,7.526604652404785,7.752073764801025,7.319976329803467,7.154849529266357,6.424771308898926,7.026508331298828,8.302079200744629,7.881159782409668,8.27434253692627,7.750870227813721,6.892346382141113,11.721098899841309,11.752792358398438,11.787128448486328,11.802380561828613,11.808475494384766,12.290816307067871,12.346134185791016,12.69794750213623,12.623786926269531,12.716548919677734,12.891475677490234,12.574321746826172,12.740395545959473,12.36397933959961,5.016053199768066,4.7150187492370605,4.713418960571289,4.545224189758301,4.3546142578125,1.8326094150543213,1.105393648147583,1.0928109884262085,1.112736463546753,1.2007646560668945,-0.9946739673614502,-0.6925480961799622,-0.4427396357059479,-0.6761571764945984,11.161157608032227,11.160332679748535,11.164072036743164,11.097294807434082,11.137203216552734,11.124818801879883,11.13955020904541,11.111100196838379,11.173702239990234,11.124275207519531,11.078642845153809,11.117608070373535,11.38980484008789,11.409082412719727,5.128639221191406,4.567378044128418,4.564759254455566,3.0497238636016846,3.3652303218841553,3.6511149406433105,7.364596366882324,7.221391201019287,7.542026042938232,5.689671993255615,5.508668899536133,4.699773788452148,4.170836925506592,2.68251633644104,7.243903636932373,7.190357685089111,7.195434093475342,7.163771152496338,7.160403728485107,7.13482666015625,7.1349029541015625,7.136974811553955,7.738273620605469,8.842388153076172,8.280757904052734,8.188010215759277,8.199804306030273,8.155651092529297,4.420563220977783,4.44618558883667,4.481836795806885,4.5571112632751465,4.5855560302734375,4.616331100463867,4.673039436340332,4.859551429748535,5.327981472015381,5.174461364746094,5.076613903045654,5.284574508666992,7.2401347160339355,7.20192813873291,12.78495979309082,12.784914016723633,12.873382568359375,12.840246200561523,12.707331657409668,12.642339706420898,12.59573745727539,12.449348449707031,12.336087226867676,12.45794677734375,12.340386390686035,12.304242134094238,12.281145095825195,12.2051362991333,11.36385726928711,11.353203773498535,11.370760917663574,10.786674499511719,10.736140251159668,10.764527320861816,10.779694557189941,11.361722946166992,12.073944091796875,12.199045181274414,12.23309326171875,12.217557907104492,12.017963409423828,11.982991218566895,5.570085048675537,5.566064834594727,5.5811285972595215,5.6377363204956055,5.671202659606934,6.038424015045166,6.157550811767578,6.371657848358154,7.146456241607666,7.274285316467285,7.361103534698486,7.151469707489014,7.167207717895508,7.155235290527344,4.743645668029785,4.787268161773682,4.721571445465088,4.855645656585693,5.263789176940918,5.337851047515869,5.363349437713623,5.266634464263916,6.214416980743408,6.171517372131348,6.4816718101501465,7.056270122528076,7.27786922454834,7.264267921447754,12.214408874511719,12.172466278076172,11.995321273803711,12.331867218017578,12.370048522949219,12.426621437072754,12.542336463928223,12.579309463500977,12.325862884521484,12.336287498474121,12.23005485534668,11.516074180603027,10.392640113830566,10.296507835388184,-0.5479885339736938,-0.6176590919494629,-0.47497084736824036,-0.3114820718765259,-0.3146049678325653,-0.2787967026233673,-0.26182812452316284,-0.2861904799938202,-0.262254536151886,-0.34289872646331787,-0.4251987934112549,-1.1102666854858398,-1.4967825412750244,-1.2882816791534424,8.555106163024902,8.599064826965332,8.602571487426758,8.409631729125977,8.124282836914063,7.897718906402588,7.989274501800537,7.405208110809326,7.9453020095825195,7.7948079109191895,6.867110729217529,6.837934494018555,6.749587535858154,6.679708957672119,5.731956481933594,5.736494541168213,5.739434242248535,5.681464672088623,5.675573825836182,5.68282413482666,6.0050225257873535,6.003830909729004,5.925586223602295,6.243738651275635,5.8381500244140625,6.037538528442383,6.320621967315674,6.214056968688965,6.397634029388428,6.120457172393799,5.937215805053711,6.123215675354004,6.178950786590576,6.195631504058838,5.929574012756348,5.9839582443237305,6.054854393005371,6.218689441680908,6.204225063323975,6.214772701263428,6.465393543243408,6.951123237609863,3.620389223098755,3.6418299674987793,3.635751962661743,3.7095119953155518,3.701117753982544,3.720641613006592,3.616548538208008,3.7638742923736572,3.7164342403411865,3.7226972579956055,3.7014715671539307,3.696326971054077,3.763164758682251,3.723881721496582,8.553966522216797,7.225488662719727,7.172811508178711,6.695651054382324,6.652883052825928,6.551121711730957,6.96422815322876,7.509056568145752,8.030396461486816,8.259163856506348,8.216964721679688,8.211435317993164,8.351448059082031,7.8023552894592285,12.41291618347168,12.463318824768066,12.635574340820313,12.709582328796387,12.70486068725586,12.560734748840332,12.360630989074707,11.302319526672363,12.187711715698242,12.590607643127441,12.726840019226074,12.735217094421387,12.555720329284668,12.737815856933594,12.843754768371582,12.861777305603027,12.80408000946045,12.635720252990723,12.641366958618164,12.60290241241455,12.648377418518066,12.660835266113281,12.405243873596191,12.3318452835083,12.422056198120117,12.391098022460938,12.422795295715332,12.45930004119873,11.619811058044434,11.633384704589844,11.778533935546875,12.264111518859863,12.475920677185059,12.490053176879883,12.493346214294434,12.572957038879395,12.460870742797852,11.573677062988281,12.694408416748047,12.70715618133545,12.703932762145996,12.943011283874512,12.261533737182617,11.854748725891113,11.18808650970459,9.06828498840332,7.6766510009765625,6.870745658874512,6.525611400604248,6.421921730041504,7.052700519561768,12.303848266601563,12.453696250915527,12.381067276000977,12.47319507598877,12.589555740356445,12.73204517364502,12.711450576782227,12.78698444366455,12.740341186523438,12.719121932983398,12.9548978805542,13.001724243164063,13.00837230682373,13.019246101379395,13.021817207336426,12.903295516967773,12.7913818359375,12.342795372009277,11.679363250732422,3.8297364711761475,4.621315002441406,4.641294002532959,4.659127712249756,4.65388822555542,4.697425365447998,4.680282115936279,4.609817981719971,4.639618396759033,4.603464603424072,4.578943729400635,4.593757629394531,4.609225273132324,4.573600769042969,7.070478916168213,7.08082389831543,7.0347466468811035,7.029007911682129,6.992471218109131,7.081572532653809,6.195680618286133,6.360325336456299,6.384111404418945,7.6300554275512695,7.7236785888671875,7.705040454864502,7.85452938079834,7.879859447479248,11.522274017333984,11.541997909545898,11.516215324401855,11.524603843688965,11.524895668029785,11.518560409545898,11.56500244140625,11.625005722045898,11.758193016052246,11.827198028564453,11.816227912902832,11.802035331726074,12.001696586608887,12.002413749694824,10.822266578674316,10.753081321716309,10.551887512207031,10.459023475646973,10.52988052368164,10.449213981628418,10.477994918823242,10.411881446838379,10.553982734680176,10.537393569946289,10.596480369567871,10.634561538696289,10.916983604431152,11.154343605041504,-4.83708381652832,-4.876502990722656,-4.878100872039795,-4.8802924156188965,-4.883967399597168,-4.8781538009643555,-4.914894104003906,-4.887734413146973,-4.903228282928467,-4.907516956329346,-4.88047456741333,-4.354175567626953,-4.331645488739014,-4.303464412689209,10.660319328308105,10.644570350646973,10.598762512207031,10.598735809326172,10.580442428588867,10.591293334960938,10.571245193481445,10.751605033874512,11.60030746459961,11.636667251586914,12.093816757202148,12.191326141357422,12.299033164978027,11.560555458068848,5.572041988372803,5.561095237731934,6.546253204345703,7.108189105987549,7.167144775390625,7.892055988311768,7.9915852546691895,8.342753410339355,8.019856452941895,6.987552165985107,7.003762245178223,8.053391456604004,7.658838748931885,8.31490707397461,-1.8982239961624146,-1.9731767177581787,-2.048940896987915,-2.11893892288208,-2.0963854789733887,-2.143087387084961,-2.1441361904144287,-2.0775094032287598,-2.0808827877044678,-2.0645558834075928,-2.1236774921417236,-2.081928014755249,-2.1194493770599365,-1.9267832040786743,1.6358413696289063,6.149969577789307,11.494606018066406,11.549630165100098,12.12767219543457,12.351938247680664,12.284488677978516,12.353863716125488,10.99298095703125,11.322437286376953,11.694209098815918,12.629329681396484,5.437526702880859,9.860821723937988,11.45518684387207,11.303763389587402,11.252649307250977,9.831748008728027,8.763358116149902,7.675100326538086,4.887073993682861,4.5436201095581055,4.528918743133545,4.49124002456665,4.429185390472412,4.289016246795654,4.118940830230713,4.163406848907471,9.51101016998291,9.364282608032227,9.335787773132324,9.10609245300293,8.044610977172852,8.488140106201172,8.65257740020752,8.508453369140625,8.555451393127441,10.65548324584961,10.895299911499023,10.717586517333984,8.40318775177002,8.550663948059082,7.311470985412598,6.811047554016113,6.779321193695068,6.792240142822266,6.7593488693237305,7.048976421356201,7.043567657470703,6.829268455505371,6.524017810821533,7.05370569229126,6.623433589935303,7.0729804039001465,8.129475593566895,7.971515655517578,3.981513261795044,4.052605628967285,4.05322265625,4.020808219909668,4.0532732009887695,4.204807281494141,4.190900802612305,4.256352424621582,4.262392520904541,4.227396011352539,5.736177921295166,6.062625408172607,6.938459873199463,6.466813087463379,4.432823657989502,4.314373970031738,4.406863212585449,4.008297920227051,3.8004701137542725,3.874147415161133,3.3856558799743652,3.3699846267700195,3.4502756595611572,3.214036464691162,3.1340854167938232,3.0292577743530273,2.589571714401245,2.6596126556396484,0.65027916431427,3.2039260864257813,3.143554210662842,3.1812796592712402,3.2117207050323486,3.2005488872528076,3.1947174072265625,3.3313682079315186,3.849034309387207,3.8559467792510986,3.8044321537017822,3.6994833946228027,3.797110080718994,3.8671658039093018,5.518087387084961,5.615279197692871,6.083009243011475,5.971673011779785,6.2354207038879395,5.975865364074707,6.509736061096191,7.517275810241699,12.044597625732422,9.88542366027832,10.363224983215332,11.800848960876465,12.078184127807617,12.400278091430664,-0.1841897815465927,-0.204306960105896,-0.21054546535015106,-0.2839888334274292,-0.7025192975997925,-0.6615772247314453,-0.49436768889427185,-0.3181200325489044,-0.6948426961898804,-0.6718288660049438,-0.7042801976203918,-0.7534063458442688,-0.9761974811553955,-0.9026933908462524,0.5760968923568726,0.46882739663124084,0.4961959421634674,0.7290933728218079,0.7557694911956787,0.9458144903182983,1.2423982620239258,1.3213105201721191,1.1982673406600952,1.2817633152008057,0.0153650538995862,-1.4441630840301514,-1.3714711666107178,-1.6361767053604126,4.786723613739014,4.802195072174072,4.853348255157471,4.808946132659912,4.879707336425781,4.868719100952148,3.3597207069396973,3.1898248195648193,3.1132915019989014,3.02235746383667,3.1002414226531982,3.099984645843506,3.271275758743286,3.1701457500457764,2.636597156524658,2.6166014671325684,2.6178395748138428,2.5129446983337402,2.488354444503784,2.493898868560791,2.4694392681121826,2.3841230869293213,2.3476994037628174,2.461125612258911,2.4555883407592773,-0.9382094740867615,-1.2916486263275146,-1.0465123653411865,-3.5341455936431885,-3.501511812210083,-3.461402177810669,-3.5525472164154053,-3.581120729446411,-3.5764782428741455,-3.559900999069214,-3.591355800628662,-3.5697810649871826,-3.598982572555542,-3.558457374572754,-3.5893051624298096,-3.586721420288086,-3.5149986743927,6.395023822784424,6.381280899047852,5.068754196166992,4.984826564788818,4.9963765144348145,4.937600135803223,4.844357490539551,4.839817047119141,4.8781046867370605,6.081860065460205,6.238500595092773,5.5759758949279785,4.913052082061768,4.524397850036621,2.325608730316162,2.23616099357605,2.232480764389038,2.2113583087921143,2.227731466293335,2.2755911350250244,2.2887065410614014,3.643497943878174,3.762920379638672,3.619326591491699,3.7991538047790527,3.7906482219696045,3.681415557861328,3.7642765045166016,2.6136672496795654,2.649017572402954,2.65588641166687,2.5566511154174805,2.584871768951416,2.580300807952881,2.6372804641723633,2.625450611114502,2.6720898151397705,2.6793954372406006,2.661344051361084,2.6876370906829834,2.77451229095459,2.8100104331970215,11.474442481994629,11.408674240112305,11.350708961486816,11.346536636352539,11.368966102600098,11.039092063903809,10.833965301513672,10.747955322265625,10.80217170715332,10.821342468261719,11.990996360778809,12.02772331237793,12.027253150939941,12.052695274353027,-4.461725234985352,-4.463418960571289,-4.4689531326293945,-4.473462104797363,-4.468326091766357,-4.457949638366699,-4.48426628112793,-4.500690460205078,-4.452083110809326,-4.474557399749756,-4.483571529388428,-4.4591803550720215,-4.420621395111084,-4.459987163543701,7.325884819030762,7.2694993019104,7.41796350479126,7.4436211585998535,7.395343780517578,7.387288570404053,7.544386386871338,8.123392105102539,7.576696395874023,7.487011432647705,7.3837890625,7.320191383361816,7.194504261016846,5.456264972686768,2.5845253467559814,2.634680986404419,2.648860454559326,2.5476810932159424,2.5116260051727295,2.563324451446533,2.6274240016937256,11.661951065063477,12.376836776733398,12.175211906433105,11.780335426330566,11.968688011169434,12.673598289489746,12.567140579223633,10.919219017028809,10.921586990356445,11.090885162353516,12.320164680480957,12.213155746459961,12.243114471435547,11.956292152404785,12.048521995544434,12.15188217163086,12.55478286743164,12.578984260559082,12.497644424438477,12.57558822631836,12.733674049377441,7.8509202003479,7.816091060638428,4.8463134765625,4.389955520629883,7.875696182250977,10.159101486206055,10.22386646270752,10.201069831848145,10.209793090820313,10.308915138244629,10.413750648498535,10.400046348571777,5.558231353759766,7.5541558265686035,10.627076148986816,10.691903114318848,10.29495906829834,9.811205863952637,9.823691368103027,9.854313850402832,9.766510963439941,9.49821949005127,9.619544982910156,9.509160041809082,9.594182014465332,9.768856048583984,9.793588638305664,10.171320915222168,0.7759994268417358,0.7647431492805481,0.7220526933670044,0.706574559211731,0.7207978963851929,0.7275354862213135,0.7410907745361328,0.7503420114517212,0.7461535334587097,0.7226875424385071,0.7747156620025635,1.1268504858016968,2.990569829940796,3.1899425983428955,7.69625186920166,10.486352920532227,10.337964057922363,10.00018310546875,9.976696968078613,10.067873001098633,9.929522514343262,9.962940216064453,10.476497650146484,10.017513275146484,7.765745639801025,8.271310806274414,7.426951885223389,5.83447265625,-1.0485472679138184,-1.0270768404006958,-1.093630313873291,-1.0954893827438354,-1.1153641939163208,-1.0992730855941772,-1.101372241973877,-0.7680796980857849,-0.7876605987548828,-0.6561625003814697,-0.8208047747612,-0.6552987694740295,-0.6541252732276917,-0.6684142351150513,-3.560472249984741,-0.8001646995544434,6.239632606506348,10.629074096679688,4.310792922973633,4.341739177703857,4.322440147399902,4.131489276885986,3.9940249919891357,3.9213833808898926,3.8920228481292725,2.780198812484741,2.3214919567108154,1.9811947345733643,2.244417190551758,2.424041748046875,2.4839584827423096,3.8011386394500732,8.965272903442383,9.39894962310791,9.405607223510742,9.372272491455078,9.721444129943848,9.431879997253418,9.428231239318848,9.372407913208008,9.402295112609863,9.232494354248047,12.727812767028809,12.26818561553955,12.418184280395508,12.610346794128418,12.646753311157227,12.875410079956055,12.357069969177246,11.78269100189209,11.655220031738281,12.299253463745117,12.16951847076416,10.191644668579102,10.270088195800781,11.12159252166748,12.654725074768066,12.65833568572998,12.643675804138184,12.54381275177002,12.59376335144043,11.90734577178955,11.96295166015625,12.021522521972656,12.598430633544922,12.707268714904785,12.784927368164063,12.777039527893066,12.716208457946777,12.9779052734375,3.9953854084014893,3.978485107421875,4.004001140594482,4.162103176116943,4.1941046714782715,4.13034725189209,4.1311516761779785,4.2053542137146,4.357629299163818,4.900921821594238,4.0600266456604,3.9212820529937744,3.8289835453033447,3.8047964572906494,3.6234893798828125,3.5956273078918457,3.589829206466675,3.6194660663604736,3.6353259086608887,3.6471476554870605,3.658536195755005,3.6449215412139893,3.6237521171569824,3.606048822402954,3.540849447250366,3.1011106967926025,3.089627981185913,2.254312038421631,0.20593176782131195,0.3140636086463928,-0.0283176489174366,-0.06814752519130707,-0.07682938128709793,-0.05324118211865425,-0.0728866308927536,0.005417888052761555,-0.17111244797706604,-0.21223334968090057,-0.14175991714000702,-0.09326998144388199,-0.08349976688623428,-0.01907987892627716,7.643899440765381,7.623734474182129,7.678788185119629,8.404298782348633,8.303035736083984,11.92702865600586,12.28363037109375,12.305550575256348,12.63192367553711,12.451820373535156,11.60058307647705,11.96835994720459,12.465554237365723,12.340354919433594,-0.703184962272644,-0.6689713597297668,-0.6626227498054504,-0.6589821577072144,-0.6652518510818481,-0.6506294012069702,-0.614734947681427,-0.6482864022254944,-0.6365715861320496,-0.634424090385437,-0.6466402411460876,-0.7780985832214355,-0.5993156433105469,-0.5466353893280029,0.01276632770895958,0.02493605576455593,-0.02034818008542061,-0.6929857134819031,-0.7963505983352661,-1.2241382598876953,-1.4752912521362305,-1.4567617177963257,-1.4876704216003418,-1.546523094177246,-1.426921010017395,-1.3773064613342285,-1.5509039163589478,-1.499488353729248,7.572188854217529,7.5879106521606445,7.571913242340088,7.681743621826172,7.772737503051758,7.763714790344238,7.7815351486206055,7.686967849731445,7.760062217712402,7.666537761688232,9.13431453704834,8.454444885253906,8.437044143676758,7.671487331390381,11.057193756103516,11.033112525939941,11.007779121398926,11.311745643615723,11.334573745727539,11.113553047180176,11.146170616149902,11.231374740600586,11.267352104187012,11.276124954223633,11.278226852416992,11.11384105682373,11.201617240905762,11.172053337097168,-2.080465316772461,-2.0908751487731934,-2.128885269165039,-2.1798253059387207,-2.1726784706115723,-2.17022705078125,-2.153317928314209,-2.154086112976074,-2.1707682609558105,-2.1704859733581543,-2.193636655807495,-2.1834309101104736,-2.1679892539978027,-2.2188591957092285,-0.3990640640258789,-0.5025805234909058,-0.34488698840141296,-0.8862057328224182,-0.9176658987998962,-0.9637172222137451,-0.9757322669029236,-0.9507758617401123,-1.3696255683898926,-0.9615923166275024,-1.1071301698684692,-0.9719119071960449,-0.9334915280342102,-0.9588431715965271,8.577191352844238,9.170368194580078,9.178750991821289,7.994473934173584,7.912226676940918,7.962780475616455,7.931410312652588,8.22518539428711,7.69978141784668,7.628536701202393,7.662660121917725,7.938111782073975,8.080286979675293,7.923947334289551,-1.9191348552703857,-1.9201925992965698,-1.9541794061660767,-1.892509937286377,-1.928088665008545,-1.9287831783294678,-1.9259735345840454,-1.104891061782837,-0.7256458401679993,-0.44378766417503357,-0.35430124402046204,-0.30970919132232666,-0.2708890438079834,-0.05844542011618614,6.818784713745117,6.866433143615723,6.869516849517822,6.20401668548584,6.279590606689453,6.221217155456543,6.9834723472595215,6.915050983428955,7.009737968444824,6.971949100494385,7.077143669128418,7.917877674102783,8.34108829498291,8.23670768737793,0.7508566379547119,-1.39523184299469,-1.6637929677963257,-1.823517918586731,-1.7971574068069458,-2.1503217220306396,-2.1593093872070313,-2.2383949756622314,-2.24576473236084,-2.202819585800171,-2.2076480388641357,-2.1864449977874756,-2.194709300994873,-2.1702609062194824,12.994604110717773,13.011075019836426,13.022927284240723,12.985904693603516,13.035807609558105,12.988407135009766,13.002527236938477,12.993803024291992,12.99211311340332,13.00765323638916,12.947195053100586,13.006845474243164,12.98875617980957,13.026372909545898,5.534943103790283,5.518948554992676,5.521200656890869,5.351770877838135,5.356036186218262,5.329476356506348,5.488348960876465,5.459427356719971,5.4672112464904785,5.527196884155273,6.065537929534912,6.011983394622803,5.99495792388916,6.068954944610596,11.713000297546387,11.759659767150879,11.783327102661133,11.550427436828613,11.576976776123047,11.397454261779785,11.418477058410645,11.380231857299805,10.904098510742188,10.938907623291016,10.891839027404785,10.846575736999512,10.946183204650879,10.883155822753906,12.430992126464844,12.369181632995605,12.330849647521973,11.921819686889648,11.831344604492188,11.966839790344238,11.843111038208008,12.153509140014648,12.24850082397461,12.265734672546387,12.174139022827148,11.823967933654785,11.541034698486328,11.96385383605957,9.065122604370117,9.515105247497559,9.552807807922363,10.536808013916016,10.555477142333984,8.583996772766113,8.410460472106934,7.4719929695129395,6.70186185836792,4.9275007247924805,4.6411309242248535,4.662013530731201,4.652258396148682,4.47199010848999,8.931787490844727,8.729538917541504,8.344123840332031,8.30697250366211,8.354719161987305,8.549748420715332,10.237215995788574,10.713157653808594,10.668052673339844,10.607904434204102,10.272547721862793,10.561137199401855,10.908316612243652,10.954769134521484,-1.115037441253662,-1.1620948314666748,-1.1032017469406128,-1.093042254447937,-1.0884513854980469,-1.0695626735687256,-1.1101703643798828,-1.0758429765701294,-0.95698082447052,-0.797907829284668,-0.8869709968566895,-0.9155935645103455,-0.8883967399597168,-0.9116033315658569,8.882370948791504,8.81728458404541,8.869629859924316,8.798375129699707,8.80004596710205,8.843554496765137,8.813811302185059,9.041777610778809,9.180288314819336,9.076690673828125,9.813908576965332,10.34749984741211,10.839994430541992,10.920294761657715,7.0258378982543945,6.819262981414795,6.766770839691162,7.715407371520996,8.33521556854248,8.251229286193848,8.328064918518066,8.972506523132324,9.524624824523926,9.681595802307129,9.540436744689941,9.79221248626709,8.40958023071289,7.7335124015808105,4.030887603759766,4.042455196380615,4.034998416900635,4.046003818511963,4.048738479614258,4.046578884124756,4.024021148681641,4.049111366271973,4.046957969665527,4.097581386566162,4.0974040031433105,4.162622451782227,4.0565643310546875,4.078893661499023,-1.3894344568252563,-1.2249585390090942,-1.2122864723205566,-1.094984531402588,-1.0915558338165283,-1.1327651739120483,-1.178823709487915,-1.2397305965423584,-1.2468056678771973,-1.2127387523651123,-1.274271845817566,-1.2871456146240234,-1.3076703548431396,-1.1418304443359375,6.189016342163086,6.240536689758301,6.286189556121826,6.305386543273926,6.3317694664001465,6.0228657722473145,4.846374988555908,4.841747283935547,4.808334827423096,5.80103063583374,5.923239707946777,5.8949079513549805,6.037452697753906,5.997385025024414,-0.4566503167152405,-0.42574426531791687,-0.3324979841709137,-0.2662546634674072,0.5887721180915833,7.73250150680542,7.738133907318115,7.795938491821289,7.734490394592285,7.634018421173096,7.749979019165039,7.793759822845459,7.794086456298828,11.585156440734863,6.392765998840332,6.397899150848389,6.405634880065918,6.428457260131836,6.403177261352539,7.226487636566162,7.309072017669678,7.182028770446777,6.837841510772705,6.787755966186523,6.817007064819336,6.974517822265625,6.988653182983398,7.4240803718566895,6.508941173553467,6.498109340667725,6.702413082122803,7.066136360168457,7.066572666168213,6.721251487731934,6.7392191886901855,6.783264636993408,7.060999393463135,6.945600986480713,8.985245704650879,10.236608505249023,10.228696823120117,10.432817459106445,11.77398681640625,11.762672424316406,11.830331802368164,11.988354682922363,11.977638244628906,12.131113052368164,12.080378532409668,12.059184074401855,12.050444602966309,12.103561401367188,11.915489196777344,11.29740047454834,10.96216106414795,10.791912078857422,8.1547269821167,8.136069297790527,8.088939666748047,8.056903839111328,8.064407348632813,7.989173412322998,7.939044952392578,7.9098639488220215,7.8802080154418945,7.840585708618164,3.61905574798584,0.3363944888114929,-0.2582913339138031,-0.41521841287612915,6.247037410736084,6.285193920135498,6.35267448425293,6.8058013916015625,6.811890602111816,6.723320007324219,6.77829122543335,6.803948879241943,6.378983974456787,6.988856792449951,7.07627534866333,8.077600479125977,8.456546783447266,8.402582168579102,11.222732543945313,11.22795295715332,11.2312650680542,11.321910858154297,11.257122039794922,11.34449577331543,11.371723175048828,11.626591682434082,11.826642036437988,11.708852767944336,11.419157028198242,11.177245140075684,11.322624206542969,11.371858596801758,7.8952107429504395,7.916014671325684,7.873531818389893,7.9014363288879395,7.89525032043457,7.864647388458252,7.874189853668213,7.87742280960083,7.900301933288574,7.893929481506348,7.886746883392334,7.856258392333984,7.877382755279541,7.912827014923096,7.81062650680542,7.883561611175537,8.086702346801758,8.318696022033691,7.696740627288818,7.4207024574279785,7.974537372589111,8.308510780334473,8.105501174926758,7.7788777351379395,8.191496849060059,8.520586967468262,8.46977710723877,8.560958862304688,6.595673084259033,6.63780403137207,6.692066192626953,6.737992286682129,6.830204010009766,6.640229225158691,6.616959571838379,6.614496231079102,6.735519886016846,6.640035629272461,6.961827278137207,6.973968029022217,7.792409420013428,7.824385166168213,11.360090255737305,10.700738906860352,10.169623374938965,9.476972579956055,9.38189697265625,9.287552833557129,9.35367488861084,11.712831497192383,11.783635139465332,11.86840534210205,11.835986137390137,11.784927368164063,11.632457733154297,11.461084365844727,6.319790840148926,6.259494304656982,6.285736083984375,6.219299793243408,6.226063251495361,6.256799221038818,6.248045921325684,6.2514448165893555,10.0043306350708,10.574570655822754,9.725801467895508,9.693267822265625,10.024548530578613,11.005956649780273,9.562366485595703,9.461731910705566,9.547661781311035,10.147353172302246,10.2258882522583,10.1443510055542,10.165968894958496,10.185036659240723,10.243353843688965,10.182893753051758,10.136463165283203,10.101749420166016,10.095337867736816,10.117836952209473,11.240447998046875,11.252974510192871,11.238951683044434,11.275466918945313,11.707541465759277,11.402826309204102,11.395496368408203,11.345545768737793,11.40231704711914,12.250008583068848,12.540532112121582,12.192951202392578,11.3321533203125,11.081165313720703,11.764022827148438,11.733765602111816,11.739890098571777,11.271374702453613,11.181796073913574,11.147674560546875,11.066550254821777,10.97795295715332,11.058679580688477,10.863896369934082,11.265445709228516,11.824277877807617,11.665884017944336,12.820536613464355,4.657039165496826,4.545295715332031,4.610570430755615,4.649722099304199,4.6186652183532715,4.594015598297119,4.603419303894043,4.6109843254089355,4.560794353485107,4.583632946014404,4.653255462646484,5.056026458740234,5.2945098876953125,5.329437732696533,4.729987144470215,4.750108242034912,4.757630825042725,5.844911098480225,5.598700523376465,4.838072299957275,4.836818218231201,5.0967020988464355,5.9312357902526855,5.864717960357666,6.329152584075928,6.255044460296631,6.232913017272949,6.207446098327637,-0.14703823626041412,0.48773717880249023,0.5654487013816833,0.5487161874771118,0.5941419005393982,0.5832996368408203,0.5578375458717346,0.5918909907341003,0.5893070697784424,0.6126341223716736,0.5812948346138,0.6044653058052063,0.5519298911094666,0.5961548686027527,12.585551261901855,12.500875473022461,12.547658920288086,12.07812786102295,12.057332038879395,12.084230422973633,12.089942932128906,12.158447265625,12.168774604797363,12.173555374145508,12.28964900970459,12.36429500579834,12.399725914001465,12.405271530151367,11.820577621459961,11.80970573425293,11.892776489257813,11.897329330444336,11.878779411315918,11.43191909790039,10.846314430236816,12.020651817321777,11.987221717834473,10.25812816619873,8.734642028808594,10.1488618850708,11.798871994018555,11.94906234741211,12.654736518859863,12.645796775817871,12.658626556396484,12.686124801635742,12.662412643432617,12.499774932861328,12.61595630645752,12.673517227172852,12.619453430175781,12.190631866455078,12.411090850830078,12.45317268371582,12.601752281188965,12.667350769042969,-6.077772617340088,-6.062844276428223,-6.06938362121582,-6.0744123458862305,-6.076942443847656,-6.0799455642700195,-6.084315299987793,-6.072610855102539,-6.0826640129089355,-6.055039405822754,-6.0370354652404785,-6.069077968597412,-6.085394859313965,-6.055871963500977,12.669918060302734,12.592814445495605,12.61524772644043,11.731826782226563,10.785345077514648,10.437362670898438,10.10127067565918,8.444184303283691,7.953025817871094,8.283947944641113,6.9180989265441895,6.46997594833374,7.3171796798706055,7.288387775421143,10.497289657592773,10.564973831176758,10.514185905456543,10.547773361206055,10.6732816696167,10.832657814025879,12.807945251464844,12.884392738342285,12.888535499572754,12.848640441894531,13.054024696350098,12.983322143554688,13.01370620727539,12.927456855773926,8.438946723937988,8.43368911743164,8.449807167053223,8.447826385498047,8.428951263427734,8.440508842468262,8.463208198547363,8.464849472045898,8.445834159851074,8.463069915771484,8.453278541564941,8.439648628234863,8.461860656738281,8.448760986328125,6.727847576141357,6.62811279296875,6.737975120544434,7.357448101043701,7.321194171905518,7.300945281982422,7.468749046325684,7.677929401397705,8.549071311950684,7.676173686981201,7.68576192855835,7.834639072418213,8.094602584838867,8.383378982543945,4.402801513671875,4.66836404800415,5.568772315979004,5.910138130187988,5.875378608703613,5.781925678253174,6.151572227478027,7.202901363372803,7.7982378005981445,8.328437805175781,10.13339900970459,10.919946670532227,8.593321800231934,10.120606422424316,12.364978790283203,12.379368782043457,12.390351295471191,12.391264915466309,12.432250022888184,12.486907005310059,12.55528450012207,12.607268333435059,12.65363597869873,12.730010032653809,12.680530548095703,12.671453475952148,12.72591495513916,12.798561096191406,12.023594856262207,12.039302825927734,12.050543785095215,11.96700668334961,11.999438285827637,11.966859817504883,11.384331703186035,11.256240844726563,11.335406303405762,11.42543888092041,11.46029281616211,11.160502433776855,11.166764259338379,11.03753662109375,-4.438926696777344,-4.387212753295898,-4.332549095153809,-4.354091644287109,-4.356149673461914,-4.376470565795898,-4.343746662139893,-4.336981296539307,-4.337602138519287,-4.352540493011475,-4.32934045791626,-4.329068660736084,-4.337905406951904,-4.281732559204102,9.095419883728027,10.068805694580078,10.128214836120605,11.470221519470215,12.21037483215332,12.514830589294434,12.362604141235352,12.24570369720459,11.329462051391602,11.17746353149414,11.052825927734375,10.813977241516113,10.616959571838379,10.177227973937988,6.091394424438477,6.413701057434082,6.451160430908203,6.49097204208374,6.393270492553711,5.728386402130127,4.756078720092773,4.703718185424805,4.7417311668396,4.7664079666137695,4.700054168701172,4.728423118591309,4.7811598777771,4.832261562347412],\n",
       "\"country_year\":[\"Mexico-2010\",\"Mexico-2011\",\"Mexico-2012\",\"Mexico-2013\",\"Mexico-2014\",\"Mexico-2015\",\"Mexico-2016\",\"Mexico-2017\",\"Mexico-2018\",\"Mexico-2019\",\"Mexico-2020\",\"Mexico-2021\",\"Mexico-2022\",\"Mexico-2023\",\"Suriname-2010\",\"Suriname-2011\",\"Suriname-2012\",\"Suriname-2013\",\"Suriname-2014\",\"Suriname-2015\",\"Suriname-2016\",\"Suriname-2017\",\"Suriname-2018\",\"Suriname-2019\",\"Suriname-2020\",\"Suriname-2021\",\"Suriname-2022\",\"Suriname-2023\",\"Sweden-2010\",\"Sweden-2011\",\"Sweden-2012\",\"Sweden-2013\",\"Sweden-2014\",\"Sweden-2015\",\"Sweden-2016\",\"Sweden-2017\",\"Sweden-2018\",\"Sweden-2019\",\"Sweden-2020\",\"Sweden-2021\",\"Sweden-2022\",\"Sweden-2023\",\"Switzerland-2010\",\"Switzerland-2011\",\"Switzerland-2012\",\"Switzerland-2013\",\"Switzerland-2014\",\"Switzerland-2015\",\"Switzerland-2016\",\"Switzerland-2017\",\"Switzerland-2018\",\"Switzerland-2019\",\"Switzerland-2020\",\"Switzerland-2021\",\"Switzerland-2022\",\"Switzerland-2023\",\"Ghana-2010\",\"Ghana-2011\",\"Ghana-2012\",\"Ghana-2013\",\"Ghana-2014\",\"Ghana-2015\",\"Ghana-2016\",\"Ghana-2017\",\"Ghana-2018\",\"Ghana-2019\",\"Ghana-2020\",\"Ghana-2021\",\"Ghana-2022\",\"Ghana-2023\",\"South Africa-2010\",\"South Africa-2011\",\"South Africa-2012\",\"South Africa-2013\",\"South Africa-2014\",\"South Africa-2015\",\"South Africa-2016\",\"South Africa-2017\",\"South Africa-2018\",\"South Africa-2019\",\"South Africa-2020\",\"South Africa-2021\",\"South Africa-2022\",\"South Africa-2023\",\"Japan-2010\",\"Japan-2011\",\"Japan-2012\",\"Japan-2013\",\"Japan-2014\",\"Japan-2015\",\"Japan-2016\",\"Japan-2017\",\"Japan-2018\",\"Japan-2019\",\"Japan-2020\",\"Japan-2021\",\"Japan-2022\",\"Japan-2023\",\"Burma/Myanmar-2010\",\"Burma/Myanmar-2011\",\"Burma/Myanmar-2012\",\"Burma/Myanmar-2013\",\"Burma/Myanmar-2014\",\"Burma/Myanmar-2015\",\"Burma/Myanmar-2016\",\"Burma/Myanmar-2017\",\"Burma/Myanmar-2018\",\"Burma/Myanmar-2019\",\"Burma/Myanmar-2020\",\"Burma/Myanmar-2021\",\"Burma/Myanmar-2022\",\"Burma/Myanmar-2023\",\"Russia-2010\",\"Russia-2011\",\"Russia-2012\",\"Russia-2013\",\"Russia-2014\",\"Russia-2015\",\"Russia-2016\",\"Russia-2017\",\"Russia-2018\",\"Russia-2019\",\"Russia-2020\",\"Russia-2021\",\"Russia-2022\",\"Russia-2023\",\"Albania-2010\",\"Albania-2011\",\"Albania-2012\",\"Albania-2013\",\"Albania-2014\",\"Albania-2015\",\"Albania-2016\",\"Albania-2017\",\"Albania-2018\",\"Albania-2019\",\"Albania-2020\",\"Albania-2021\",\"Albania-2022\",\"Albania-2023\",\"Egypt-2010\",\"Egypt-2011\",\"Egypt-2012\",\"Egypt-2013\",\"Egypt-2014\",\"Egypt-2015\",\"Egypt-2016\",\"Egypt-2017\",\"Egypt-2018\",\"Egypt-2019\",\"Egypt-2020\",\"Egypt-2021\",\"Egypt-2022\",\"Egypt-2023\",\"Yemen-2010\",\"Yemen-2011\",\"Yemen-2012\",\"Yemen-2013\",\"Yemen-2014\",\"Yemen-2015\",\"Yemen-2016\",\"Yemen-2017\",\"Yemen-2018\",\"Yemen-2019\",\"Yemen-2020\",\"Yemen-2021\",\"Yemen-2022\",\"Yemen-2023\",\"Colombia-2010\",\"Colombia-2011\",\"Colombia-2012\",\"Colombia-2013\",\"Colombia-2014\",\"Colombia-2015\",\"Colombia-2016\",\"Colombia-2017\",\"Colombia-2018\",\"Colombia-2019\",\"Colombia-2020\",\"Colombia-2021\",\"Colombia-2022\",\"Colombia-2023\",\"Poland-2010\",\"Poland-2011\",\"Poland-2012\",\"Poland-2013\",\"Poland-2014\",\"Poland-2015\",\"Poland-2016\",\"Poland-2017\",\"Poland-2018\",\"Poland-2019\",\"Poland-2020\",\"Poland-2021\",\"Poland-2022\",\"Poland-2023\",\"Brazil-2010\",\"Brazil-2011\",\"Brazil-2012\",\"Brazil-2013\",\"Brazil-2014\",\"Brazil-2015\",\"Brazil-2016\",\"Brazil-2017\",\"Brazil-2018\",\"Brazil-2019\",\"Brazil-2020\",\"Brazil-2021\",\"Brazil-2022\",\"Brazil-2023\",\"United States of America-2010\",\"United States of America-2011\",\"United States of America-2012\",\"United States of America-2013\",\"United States of America-2014\",\"United States of America-2015\",\"United States of America-2016\",\"United States of America-2017\",\"United States of America-2018\",\"United States of America-2019\",\"United States of America-2020\",\"United States of America-2021\",\"United States of America-2022\",\"United States of America-2023\",\"Portugal-2010\",\"Portugal-2011\",\"Portugal-2012\",\"Portugal-2013\",\"Portugal-2014\",\"Portugal-2015\",\"Portugal-2016\",\"Portugal-2017\",\"Portugal-2018\",\"Portugal-2019\",\"Portugal-2020\",\"Portugal-2021\",\"Portugal-2022\",\"Portugal-2023\",\"El Salvador-2010\",\"El Salvador-2011\",\"El Salvador-2012\",\"El Salvador-2013\",\"El Salvador-2014\",\"El Salvador-2015\",\"El Salvador-2016\",\"El Salvador-2017\",\"El Salvador-2018\",\"El Salvador-2019\",\"El Salvador-2020\",\"El Salvador-2021\",\"El Salvador-2022\",\"El Salvador-2023\",\"Bangladesh-2010\",\"Bangladesh-2011\",\"Bangladesh-2012\",\"Bangladesh-2013\",\"Bangladesh-2014\",\"Bangladesh-2015\",\"Bangladesh-2016\",\"Bangladesh-2017\",\"Bangladesh-2018\",\"Bangladesh-2019\",\"Bangladesh-2020\",\"Bangladesh-2021\",\"Bangladesh-2022\",\"Bangladesh-2023\",\"Bolivia-2010\",\"Bolivia-2011\",\"Bolivia-2012\",\"Bolivia-2013\",\"Bolivia-2014\",\"Bolivia-2015\",\"Bolivia-2016\",\"Bolivia-2017\",\"Bolivia-2018\",\"Bolivia-2019\",\"Bolivia-2020\",\"Bolivia-2021\",\"Bolivia-2022\",\"Bolivia-2023\",\"Haiti-2010\",\"Haiti-2011\",\"Haiti-2012\",\"Haiti-2013\",\"Haiti-2014\",\"Haiti-2015\",\"Haiti-2016\",\"Haiti-2017\",\"Haiti-2018\",\"Haiti-2019\",\"Haiti-2020\",\"Haiti-2021\",\"Haiti-2022\",\"Haiti-2023\",\"Honduras-2010\",\"Honduras-2011\",\"Honduras-2012\",\"Honduras-2013\",\"Honduras-2014\",\"Honduras-2015\",\"Honduras-2016\",\"Honduras-2017\",\"Honduras-2018\",\"Honduras-2019\",\"Honduras-2020\",\"Honduras-2021\",\"Honduras-2022\",\"Honduras-2023\",\"Mali-2010\",\"Mali-2011\",\"Mali-2012\",\"Mali-2013\",\"Mali-2014\",\"Mali-2015\",\"Mali-2016\",\"Mali-2017\",\"Mali-2018\",\"Mali-2019\",\"Mali-2020\",\"Mali-2021\",\"Mali-2022\",\"Mali-2023\",\"Pakistan-2010\",\"Pakistan-2011\",\"Pakistan-2012\",\"Pakistan-2013\",\"Pakistan-2014\",\"Pakistan-2015\",\"Pakistan-2016\",\"Pakistan-2017\",\"Pakistan-2018\",\"Pakistan-2019\",\"Pakistan-2020\",\"Pakistan-2021\",\"Pakistan-2022\",\"Pakistan-2023\",\"Peru-2010\",\"Peru-2011\",\"Peru-2012\",\"Peru-2013\",\"Peru-2014\",\"Peru-2015\",\"Peru-2016\",\"Peru-2017\",\"Peru-2018\",\"Peru-2019\",\"Peru-2020\",\"Peru-2021\",\"Peru-2022\",\"Peru-2023\",\"Senegal-2010\",\"Senegal-2011\",\"Senegal-2012\",\"Senegal-2013\",\"Senegal-2014\",\"Senegal-2015\",\"Senegal-2016\",\"Senegal-2017\",\"Senegal-2018\",\"Senegal-2019\",\"Senegal-2020\",\"Senegal-2021\",\"Senegal-2022\",\"Senegal-2023\",\"South Sudan-2011\",\"South Sudan-2012\",\"South Sudan-2013\",\"South Sudan-2014\",\"South Sudan-2015\",\"South Sudan-2016\",\"South Sudan-2017\",\"South Sudan-2018\",\"South Sudan-2019\",\"South Sudan-2020\",\"South Sudan-2021\",\"South Sudan-2022\",\"South Sudan-2023\",\"Sudan-2010\",\"Sudan-2011\",\"Sudan-2012\",\"Sudan-2013\",\"Sudan-2014\",\"Sudan-2015\",\"Sudan-2016\",\"Sudan-2017\",\"Sudan-2018\",\"Sudan-2019\",\"Sudan-2020\",\"Sudan-2021\",\"Sudan-2022\",\"Sudan-2023\",\"Vietnam-2010\",\"Vietnam-2011\",\"Vietnam-2012\",\"Vietnam-2013\",\"Vietnam-2014\",\"Vietnam-2015\",\"Vietnam-2016\",\"Vietnam-2017\",\"Vietnam-2018\",\"Vietnam-2019\",\"Vietnam-2020\",\"Vietnam-2021\",\"Vietnam-2022\",\"Vietnam-2023\",\"Afghanistan-2010\",\"Afghanistan-2011\",\"Afghanistan-2012\",\"Afghanistan-2013\",\"Afghanistan-2014\",\"Afghanistan-2015\",\"Afghanistan-2016\",\"Afghanistan-2017\",\"Afghanistan-2018\",\"Afghanistan-2019\",\"Afghanistan-2020\",\"Afghanistan-2021\",\"Afghanistan-2022\",\"Afghanistan-2023\",\"Argentina-2010\",\"Argentina-2011\",\"Argentina-2012\",\"Argentina-2013\",\"Argentina-2014\",\"Argentina-2015\",\"Argentina-2016\",\"Argentina-2017\",\"Argentina-2018\",\"Argentina-2019\",\"Argentina-2020\",\"Argentina-2021\",\"Argentina-2022\",\"Argentina-2023\",\"Ethiopia-2010\",\"Ethiopia-2011\",\"Ethiopia-2012\",\"Ethiopia-2013\",\"Ethiopia-2014\",\"Ethiopia-2015\",\"Ethiopia-2016\",\"Ethiopia-2017\",\"Ethiopia-2018\",\"Ethiopia-2019\",\"Ethiopia-2020\",\"Ethiopia-2021\",\"Ethiopia-2022\",\"Ethiopia-2023\",\"India-2010\",\"India-2011\",\"India-2012\",\"India-2013\",\"India-2014\",\"India-2015\",\"India-2016\",\"India-2017\",\"India-2018\",\"India-2019\",\"India-2020\",\"India-2021\",\"India-2022\",\"India-2023\",\"Kenya-2010\",\"Kenya-2011\",\"Kenya-2012\",\"Kenya-2013\",\"Kenya-2014\",\"Kenya-2015\",\"Kenya-2016\",\"Kenya-2017\",\"Kenya-2018\",\"Kenya-2019\",\"Kenya-2020\",\"Kenya-2021\",\"Kenya-2022\",\"Kenya-2023\",\"North Korea-2010\",\"North Korea-2011\",\"North Korea-2012\",\"North Korea-2013\",\"North Korea-2014\",\"North Korea-2015\",\"North Korea-2016\",\"North Korea-2017\",\"North Korea-2018\",\"North Korea-2019\",\"North Korea-2020\",\"North Korea-2021\",\"North Korea-2022\",\"North Korea-2023\",\"South Korea-2010\",\"South Korea-2011\",\"South Korea-2012\",\"South Korea-2013\",\"South Korea-2014\",\"South Korea-2015\",\"South Korea-2016\",\"South Korea-2017\",\"South Korea-2018\",\"South Korea-2019\",\"South Korea-2020\",\"South Korea-2021\",\"South Korea-2022\",\"South Korea-2023\",\"Kosovo-2010\",\"Kosovo-2011\",\"Kosovo-2012\",\"Kosovo-2013\",\"Kosovo-2014\",\"Kosovo-2015\",\"Kosovo-2016\",\"Kosovo-2017\",\"Kosovo-2018\",\"Kosovo-2019\",\"Kosovo-2020\",\"Kosovo-2021\",\"Kosovo-2022\",\"Kosovo-2023\",\"Lebanon-2010\",\"Lebanon-2011\",\"Lebanon-2012\",\"Lebanon-2013\",\"Lebanon-2014\",\"Lebanon-2015\",\"Lebanon-2016\",\"Lebanon-2017\",\"Lebanon-2018\",\"Lebanon-2019\",\"Lebanon-2020\",\"Lebanon-2021\",\"Lebanon-2022\",\"Lebanon-2023\",\"Nigeria-2010\",\"Nigeria-2011\",\"Nigeria-2012\",\"Nigeria-2013\",\"Nigeria-2014\",\"Nigeria-2015\",\"Nigeria-2016\",\"Nigeria-2017\",\"Nigeria-2018\",\"Nigeria-2019\",\"Nigeria-2020\",\"Nigeria-2021\",\"Nigeria-2022\",\"Nigeria-2023\",\"Philippines-2010\",\"Philippines-2011\",\"Philippines-2012\",\"Philippines-2013\",\"Philippines-2014\",\"Philippines-2015\",\"Philippines-2016\",\"Philippines-2017\",\"Philippines-2018\",\"Philippines-2019\",\"Philippines-2020\",\"Philippines-2021\",\"Philippines-2022\",\"Philippines-2023\",\"Tanzania-2010\",\"Tanzania-2011\",\"Tanzania-2012\",\"Tanzania-2013\",\"Tanzania-2014\",\"Tanzania-2015\",\"Tanzania-2016\",\"Tanzania-2017\",\"Tanzania-2018\",\"Tanzania-2019\",\"Tanzania-2020\",\"Tanzania-2021\",\"Tanzania-2022\",\"Tanzania-2023\",\"Taiwan-2010\",\"Taiwan-2011\",\"Taiwan-2012\",\"Taiwan-2013\",\"Taiwan-2014\",\"Taiwan-2015\",\"Taiwan-2016\",\"Taiwan-2017\",\"Taiwan-2018\",\"Taiwan-2019\",\"Taiwan-2020\",\"Taiwan-2021\",\"Taiwan-2022\",\"Taiwan-2023\",\"Thailand-2010\",\"Thailand-2011\",\"Thailand-2012\",\"Thailand-2013\",\"Thailand-2014\",\"Thailand-2015\",\"Thailand-2016\",\"Thailand-2017\",\"Thailand-2018\",\"Thailand-2019\",\"Thailand-2020\",\"Thailand-2021\",\"Thailand-2022\",\"Thailand-2023\",\"Uganda-2010\",\"Uganda-2011\",\"Uganda-2012\",\"Uganda-2013\",\"Uganda-2014\",\"Uganda-2015\",\"Uganda-2016\",\"Uganda-2017\",\"Uganda-2018\",\"Uganda-2019\",\"Uganda-2020\",\"Uganda-2021\",\"Uganda-2022\",\"Uganda-2023\",\"Venezuela-2010\",\"Venezuela-2011\",\"Venezuela-2012\",\"Venezuela-2013\",\"Venezuela-2014\",\"Venezuela-2015\",\"Venezuela-2016\",\"Venezuela-2017\",\"Venezuela-2018\",\"Venezuela-2019\",\"Venezuela-2020\",\"Venezuela-2021\",\"Venezuela-2022\",\"Venezuela-2023\",\"Benin-2010\",\"Benin-2011\",\"Benin-2012\",\"Benin-2013\",\"Benin-2014\",\"Benin-2015\",\"Benin-2016\",\"Benin-2017\",\"Benin-2018\",\"Benin-2019\",\"Benin-2020\",\"Benin-2021\",\"Benin-2022\",\"Benin-2023\",\"Bhutan-2010\",\"Bhutan-2011\",\"Bhutan-2012\",\"Bhutan-2013\",\"Bhutan-2014\",\"Bhutan-2015\",\"Bhutan-2016\",\"Bhutan-2017\",\"Bhutan-2018\",\"Bhutan-2019\",\"Bhutan-2020\",\"Bhutan-2021\",\"Bhutan-2022\",\"Bhutan-2023\",\"Burkina Faso-2010\",\"Burkina Faso-2011\",\"Burkina Faso-2012\",\"Burkina Faso-2013\",\"Burkina Faso-2014\",\"Burkina Faso-2015\",\"Burkina Faso-2016\",\"Burkina Faso-2017\",\"Burkina Faso-2018\",\"Burkina Faso-2019\",\"Burkina Faso-2020\",\"Burkina Faso-2021\",\"Burkina Faso-2022\",\"Burkina Faso-2023\",\"Cambodia-2010\",\"Cambodia-2011\",\"Cambodia-2012\",\"Cambodia-2013\",\"Cambodia-2014\",\"Cambodia-2015\",\"Cambodia-2016\",\"Cambodia-2017\",\"Cambodia-2018\",\"Cambodia-2019\",\"Cambodia-2020\",\"Cambodia-2021\",\"Cambodia-2022\",\"Cambodia-2023\",\"Indonesia-2010\",\"Indonesia-2011\",\"Indonesia-2012\",\"Indonesia-2013\",\"Indonesia-2014\",\"Indonesia-2015\",\"Indonesia-2016\",\"Indonesia-2017\",\"Indonesia-2018\",\"Indonesia-2019\",\"Indonesia-2020\",\"Indonesia-2021\",\"Indonesia-2022\",\"Indonesia-2023\",\"Mozambique-2010\",\"Mozambique-2011\",\"Mozambique-2012\",\"Mozambique-2013\",\"Mozambique-2014\",\"Mozambique-2015\",\"Mozambique-2016\",\"Mozambique-2017\",\"Mozambique-2018\",\"Mozambique-2019\",\"Mozambique-2020\",\"Mozambique-2021\",\"Mozambique-2022\",\"Mozambique-2023\",\"Nepal-2010\",\"Nepal-2011\",\"Nepal-2012\",\"Nepal-2013\",\"Nepal-2014\",\"Nepal-2015\",\"Nepal-2016\",\"Nepal-2017\",\"Nepal-2018\",\"Nepal-2019\",\"Nepal-2020\",\"Nepal-2021\",\"Nepal-2022\",\"Nepal-2023\",\"Nicaragua-2010\",\"Nicaragua-2011\",\"Nicaragua-2012\",\"Nicaragua-2013\",\"Nicaragua-2014\",\"Nicaragua-2015\",\"Nicaragua-2016\",\"Nicaragua-2017\",\"Nicaragua-2018\",\"Nicaragua-2019\",\"Nicaragua-2020\",\"Nicaragua-2021\",\"Nicaragua-2022\",\"Nicaragua-2023\",\"Niger-2010\",\"Niger-2011\",\"Niger-2012\",\"Niger-2013\",\"Niger-2014\",\"Niger-2015\",\"Niger-2016\",\"Niger-2017\",\"Niger-2018\",\"Niger-2019\",\"Niger-2020\",\"Niger-2021\",\"Niger-2022\",\"Niger-2023\",\"Zambia-2010\",\"Zambia-2011\",\"Zambia-2012\",\"Zambia-2013\",\"Zambia-2014\",\"Zambia-2015\",\"Zambia-2016\",\"Zambia-2017\",\"Zambia-2018\",\"Zambia-2019\",\"Zambia-2020\",\"Zambia-2021\",\"Zambia-2022\",\"Zambia-2023\",\"Zimbabwe-2010\",\"Zimbabwe-2011\",\"Zimbabwe-2012\",\"Zimbabwe-2013\",\"Zimbabwe-2014\",\"Zimbabwe-2015\",\"Zimbabwe-2016\",\"Zimbabwe-2017\",\"Zimbabwe-2018\",\"Zimbabwe-2019\",\"Zimbabwe-2020\",\"Zimbabwe-2021\",\"Zimbabwe-2022\",\"Zimbabwe-2023\",\"Guinea-2010\",\"Guinea-2011\",\"Guinea-2012\",\"Guinea-2013\",\"Guinea-2014\",\"Guinea-2015\",\"Guinea-2016\",\"Guinea-2017\",\"Guinea-2018\",\"Guinea-2019\",\"Guinea-2020\",\"Guinea-2021\",\"Guinea-2022\",\"Guinea-2023\",\"Ivory Coast-2010\",\"Ivory Coast-2011\",\"Ivory Coast-2012\",\"Ivory Coast-2013\",\"Ivory Coast-2014\",\"Ivory Coast-2015\",\"Ivory Coast-2016\",\"Ivory Coast-2017\",\"Ivory Coast-2018\",\"Ivory Coast-2019\",\"Ivory Coast-2020\",\"Ivory Coast-2021\",\"Ivory Coast-2022\",\"Ivory Coast-2023\",\"Mauritania-2010\",\"Mauritania-2011\",\"Mauritania-2012\",\"Mauritania-2013\",\"Mauritania-2014\",\"Mauritania-2015\",\"Mauritania-2016\",\"Mauritania-2017\",\"Mauritania-2018\",\"Mauritania-2019\",\"Mauritania-2020\",\"Mauritania-2021\",\"Mauritania-2022\",\"Mauritania-2023\",\"Canada-2010\",\"Canada-2011\",\"Canada-2012\",\"Canada-2013\",\"Canada-2014\",\"Canada-2015\",\"Canada-2016\",\"Canada-2017\",\"Canada-2018\",\"Canada-2019\",\"Canada-2020\",\"Canada-2021\",\"Canada-2022\",\"Canada-2023\",\"Australia-2010\",\"Australia-2011\",\"Australia-2012\",\"Australia-2013\",\"Australia-2014\",\"Australia-2015\",\"Australia-2016\",\"Australia-2017\",\"Australia-2018\",\"Australia-2019\",\"Australia-2020\",\"Australia-2021\",\"Australia-2022\",\"Australia-2023\",\"Botswana-2010\",\"Botswana-2011\",\"Botswana-2012\",\"Botswana-2013\",\"Botswana-2014\",\"Botswana-2015\",\"Botswana-2016\",\"Botswana-2017\",\"Botswana-2018\",\"Botswana-2019\",\"Botswana-2020\",\"Botswana-2021\",\"Botswana-2022\",\"Botswana-2023\",\"Burundi-2010\",\"Burundi-2011\",\"Burundi-2012\",\"Burundi-2013\",\"Burundi-2014\",\"Burundi-2015\",\"Burundi-2016\",\"Burundi-2017\",\"Burundi-2018\",\"Burundi-2019\",\"Burundi-2020\",\"Burundi-2021\",\"Burundi-2022\",\"Burundi-2023\",\"Cape Verde-2010\",\"Cape Verde-2011\",\"Cape Verde-2012\",\"Cape Verde-2013\",\"Cape Verde-2014\",\"Cape Verde-2015\",\"Cape Verde-2016\",\"Cape Verde-2017\",\"Cape Verde-2018\",\"Cape Verde-2019\",\"Cape Verde-2020\",\"Cape Verde-2021\",\"Cape Verde-2022\",\"Cape Verde-2023\",\"Central African Republic-2010\",\"Central African Republic-2011\",\"Central African Republic-2012\",\"Central African Republic-2013\",\"Central African Republic-2014\",\"Central African Republic-2015\",\"Central African Republic-2016\",\"Central African Republic-2017\",\"Central African Republic-2018\",\"Central African Republic-2019\",\"Central African Republic-2020\",\"Central African Republic-2021\",\"Central African Republic-2022\",\"Central African Republic-2023\",\"Chile-2010\",\"Chile-2011\",\"Chile-2012\",\"Chile-2013\",\"Chile-2014\",\"Chile-2015\",\"Chile-2016\",\"Chile-2017\",\"Chile-2018\",\"Chile-2019\",\"Chile-2020\",\"Chile-2021\",\"Chile-2022\",\"Chile-2023\",\"Costa Rica-2010\",\"Costa Rica-2011\",\"Costa Rica-2012\",\"Costa Rica-2013\",\"Costa Rica-2014\",\"Costa Rica-2015\",\"Costa Rica-2016\",\"Costa Rica-2017\",\"Costa Rica-2018\",\"Costa Rica-2019\",\"Costa Rica-2020\",\"Costa Rica-2021\",\"Costa Rica-2022\",\"Costa Rica-2023\",\"Timor-Leste-2010\",\"Timor-Leste-2011\",\"Timor-Leste-2012\",\"Timor-Leste-2013\",\"Timor-Leste-2014\",\"Timor-Leste-2015\",\"Timor-Leste-2016\",\"Timor-Leste-2017\",\"Timor-Leste-2018\",\"Timor-Leste-2019\",\"Timor-Leste-2020\",\"Timor-Leste-2021\",\"Timor-Leste-2022\",\"Timor-Leste-2023\",\"Ecuador-2010\",\"Ecuador-2011\",\"Ecuador-2012\",\"Ecuador-2013\",\"Ecuador-2014\",\"Ecuador-2015\",\"Ecuador-2016\",\"Ecuador-2017\",\"Ecuador-2018\",\"Ecuador-2019\",\"Ecuador-2020\",\"Ecuador-2021\",\"Ecuador-2022\",\"Ecuador-2023\",\"France-2010\",\"France-2011\",\"France-2012\",\"France-2013\",\"France-2014\",\"France-2015\",\"France-2016\",\"France-2017\",\"France-2018\",\"France-2019\",\"France-2020\",\"France-2021\",\"France-2022\",\"France-2023\",\"Germany-2010\",\"Germany-2011\",\"Germany-2012\",\"Germany-2013\",\"Germany-2014\",\"Germany-2015\",\"Germany-2016\",\"Germany-2017\",\"Germany-2018\",\"Germany-2019\",\"Germany-2020\",\"Germany-2021\",\"Germany-2022\",\"Germany-2023\",\"Guatemala-2010\",\"Guatemala-2011\",\"Guatemala-2012\",\"Guatemala-2013\",\"Guatemala-2014\",\"Guatemala-2015\",\"Guatemala-2016\",\"Guatemala-2017\",\"Guatemala-2018\",\"Guatemala-2019\",\"Guatemala-2020\",\"Guatemala-2021\",\"Guatemala-2022\",\"Guatemala-2023\",\"Iran-2010\",\"Iran-2011\",\"Iran-2012\",\"Iran-2013\",\"Iran-2014\",\"Iran-2015\",\"Iran-2016\",\"Iran-2017\",\"Iran-2018\",\"Iran-2019\",\"Iran-2020\",\"Iran-2021\",\"Iran-2022\",\"Iran-2023\",\"Iraq-2010\",\"Iraq-2011\",\"Iraq-2012\",\"Iraq-2013\",\"Iraq-2014\",\"Iraq-2015\",\"Iraq-2016\",\"Iraq-2017\",\"Iraq-2018\",\"Iraq-2019\",\"Iraq-2020\",\"Iraq-2021\",\"Iraq-2022\",\"Iraq-2023\",\"Ireland-2010\",\"Ireland-2011\",\"Ireland-2012\",\"Ireland-2013\",\"Ireland-2014\",\"Ireland-2015\",\"Ireland-2016\",\"Ireland-2017\",\"Ireland-2018\",\"Ireland-2019\",\"Ireland-2020\",\"Ireland-2021\",\"Ireland-2022\",\"Ireland-2023\",\"Italy-2010\",\"Italy-2011\",\"Italy-2012\",\"Italy-2013\",\"Italy-2014\",\"Italy-2015\",\"Italy-2016\",\"Italy-2017\",\"Italy-2018\",\"Italy-2019\",\"Italy-2020\",\"Italy-2021\",\"Italy-2022\",\"Italy-2023\",\"Jordan-2010\",\"Jordan-2011\",\"Jordan-2012\",\"Jordan-2013\",\"Jordan-2014\",\"Jordan-2015\",\"Jordan-2016\",\"Jordan-2017\",\"Jordan-2018\",\"Jordan-2019\",\"Jordan-2020\",\"Jordan-2021\",\"Jordan-2022\",\"Jordan-2023\",\"Latvia-2010\",\"Latvia-2011\",\"Latvia-2012\",\"Latvia-2013\",\"Latvia-2014\",\"Latvia-2015\",\"Latvia-2016\",\"Latvia-2017\",\"Latvia-2018\",\"Latvia-2019\",\"Latvia-2020\",\"Latvia-2021\",\"Latvia-2022\",\"Latvia-2023\",\"Lesotho-2010\",\"Lesotho-2011\",\"Lesotho-2012\",\"Lesotho-2013\",\"Lesotho-2014\",\"Lesotho-2015\",\"Lesotho-2016\",\"Lesotho-2017\",\"Lesotho-2018\",\"Lesotho-2019\",\"Lesotho-2020\",\"Lesotho-2021\",\"Lesotho-2022\",\"Lesotho-2023\",\"Liberia-2010\",\"Liberia-2011\",\"Liberia-2012\",\"Liberia-2013\",\"Liberia-2014\",\"Liberia-2015\",\"Liberia-2016\",\"Liberia-2017\",\"Liberia-2018\",\"Liberia-2019\",\"Liberia-2020\",\"Liberia-2021\",\"Liberia-2022\",\"Liberia-2023\",\"Malawi-2010\",\"Malawi-2011\",\"Malawi-2012\",\"Malawi-2013\",\"Malawi-2014\",\"Malawi-2015\",\"Malawi-2016\",\"Malawi-2017\",\"Malawi-2018\",\"Malawi-2019\",\"Malawi-2020\",\"Malawi-2021\",\"Malawi-2022\",\"Malawi-2023\",\"Maldives-2010\",\"Maldives-2011\",\"Maldives-2012\",\"Maldives-2013\",\"Maldives-2014\",\"Maldives-2015\",\"Maldives-2016\",\"Maldives-2017\",\"Maldives-2018\",\"Maldives-2019\",\"Maldives-2020\",\"Maldives-2021\",\"Maldives-2022\",\"Maldives-2023\",\"Mongolia-2010\",\"Mongolia-2011\",\"Mongolia-2012\",\"Mongolia-2013\",\"Mongolia-2014\",\"Mongolia-2015\",\"Mongolia-2016\",\"Mongolia-2017\",\"Mongolia-2018\",\"Mongolia-2019\",\"Mongolia-2020\",\"Mongolia-2021\",\"Mongolia-2022\",\"Mongolia-2023\",\"Morocco-2010\",\"Morocco-2011\",\"Morocco-2012\",\"Morocco-2013\",\"Morocco-2014\",\"Morocco-2015\",\"Morocco-2016\",\"Morocco-2017\",\"Morocco-2018\",\"Morocco-2019\",\"Morocco-2020\",\"Morocco-2021\",\"Morocco-2022\",\"Morocco-2023\",\"Netherlands-2010\",\"Netherlands-2011\",\"Netherlands-2012\",\"Netherlands-2013\",\"Netherlands-2014\",\"Netherlands-2015\",\"Netherlands-2016\",\"Netherlands-2017\",\"Netherlands-2018\",\"Netherlands-2019\",\"Netherlands-2020\",\"Netherlands-2021\",\"Netherlands-2022\",\"Netherlands-2023\",\"Panama-2010\",\"Panama-2011\",\"Panama-2012\",\"Panama-2013\",\"Panama-2014\",\"Panama-2015\",\"Panama-2016\",\"Panama-2017\",\"Panama-2018\",\"Panama-2019\",\"Panama-2020\",\"Panama-2021\",\"Panama-2022\",\"Panama-2023\",\"Papua New Guinea-2010\",\"Papua New Guinea-2011\",\"Papua New Guinea-2012\",\"Papua New Guinea-2013\",\"Papua New Guinea-2014\",\"Papua New Guinea-2015\",\"Papua New Guinea-2016\",\"Papua New Guinea-2017\",\"Papua New Guinea-2018\",\"Papua New Guinea-2019\",\"Papua New Guinea-2020\",\"Papua New Guinea-2021\",\"Papua New Guinea-2022\",\"Papua New Guinea-2023\",\"Qatar-2010\",\"Qatar-2011\",\"Qatar-2012\",\"Qatar-2013\",\"Qatar-2014\",\"Qatar-2015\",\"Qatar-2016\",\"Qatar-2017\",\"Qatar-2018\",\"Qatar-2019\",\"Qatar-2020\",\"Qatar-2021\",\"Qatar-2022\",\"Qatar-2023\",\"Sierra Leone-2010\",\"Sierra Leone-2011\",\"Sierra Leone-2012\",\"Sierra Leone-2013\",\"Sierra Leone-2014\",\"Sierra Leone-2015\",\"Sierra Leone-2016\",\"Sierra Leone-2017\",\"Sierra Leone-2018\",\"Sierra Leone-2019\",\"Sierra Leone-2020\",\"Sierra Leone-2021\",\"Sierra Leone-2022\",\"Sierra Leone-2023\",\"Spain-2010\",\"Spain-2011\",\"Spain-2012\",\"Spain-2013\",\"Spain-2014\",\"Spain-2015\",\"Spain-2016\",\"Spain-2017\",\"Spain-2018\",\"Spain-2019\",\"Spain-2020\",\"Spain-2021\",\"Spain-2022\",\"Spain-2023\",\"Syria-2010\",\"Syria-2011\",\"Syria-2012\",\"Syria-2013\",\"Syria-2014\",\"Syria-2015\",\"Syria-2016\",\"Syria-2017\",\"Syria-2018\",\"Syria-2019\",\"Syria-2020\",\"Syria-2021\",\"Syria-2022\",\"Syria-2023\",\"Tunisia-2010\",\"Tunisia-2011\",\"Tunisia-2012\",\"Tunisia-2013\",\"Tunisia-2014\",\"Tunisia-2015\",\"Tunisia-2016\",\"Tunisia-2017\",\"Tunisia-2018\",\"Tunisia-2019\",\"Tunisia-2020\",\"Tunisia-2021\",\"Tunisia-2022\",\"Tunisia-2023\",\"Türkiye-2010\",\"Türkiye-2011\",\"Türkiye-2012\",\"Türkiye-2013\",\"Türkiye-2014\",\"Türkiye-2015\",\"Türkiye-2016\",\"Türkiye-2017\",\"Türkiye-2018\",\"Türkiye-2019\",\"Türkiye-2020\",\"Türkiye-2021\",\"Türkiye-2022\",\"Türkiye-2023\",\"Ukraine-2010\",\"Ukraine-2011\",\"Ukraine-2012\",\"Ukraine-2013\",\"Ukraine-2014\",\"Ukraine-2015\",\"Ukraine-2016\",\"Ukraine-2017\",\"Ukraine-2018\",\"Ukraine-2019\",\"Ukraine-2020\",\"Ukraine-2021\",\"Ukraine-2022\",\"Ukraine-2023\",\"United Kingdom-2010\",\"United Kingdom-2011\",\"United Kingdom-2012\",\"United Kingdom-2013\",\"United Kingdom-2014\",\"United Kingdom-2015\",\"United Kingdom-2016\",\"United Kingdom-2017\",\"United Kingdom-2018\",\"United Kingdom-2019\",\"United Kingdom-2020\",\"United Kingdom-2021\",\"United Kingdom-2022\",\"United Kingdom-2023\",\"Uruguay-2010\",\"Uruguay-2011\",\"Uruguay-2012\",\"Uruguay-2013\",\"Uruguay-2014\",\"Uruguay-2015\",\"Uruguay-2016\",\"Uruguay-2017\",\"Uruguay-2018\",\"Uruguay-2019\",\"Uruguay-2020\",\"Uruguay-2021\",\"Uruguay-2022\",\"Uruguay-2023\",\"Algeria-2010\",\"Algeria-2011\",\"Algeria-2012\",\"Algeria-2013\",\"Algeria-2014\",\"Algeria-2015\",\"Algeria-2016\",\"Algeria-2017\",\"Algeria-2018\",\"Algeria-2019\",\"Algeria-2020\",\"Algeria-2021\",\"Algeria-2022\",\"Algeria-2023\",\"Angola-2010\",\"Angola-2011\",\"Angola-2012\",\"Angola-2013\",\"Angola-2014\",\"Angola-2015\",\"Angola-2016\",\"Angola-2017\",\"Angola-2018\",\"Angola-2019\",\"Angola-2020\",\"Angola-2021\",\"Angola-2022\",\"Angola-2023\",\"Armenia-2010\",\"Armenia-2011\",\"Armenia-2012\",\"Armenia-2013\",\"Armenia-2014\",\"Armenia-2015\",\"Armenia-2016\",\"Armenia-2017\",\"Armenia-2018\",\"Armenia-2019\",\"Armenia-2020\",\"Armenia-2021\",\"Armenia-2022\",\"Armenia-2023\",\"Azerbaijan-2010\",\"Azerbaijan-2011\",\"Azerbaijan-2012\",\"Azerbaijan-2013\",\"Azerbaijan-2014\",\"Azerbaijan-2015\",\"Azerbaijan-2016\",\"Azerbaijan-2017\",\"Azerbaijan-2018\",\"Azerbaijan-2019\",\"Azerbaijan-2020\",\"Azerbaijan-2021\",\"Azerbaijan-2022\",\"Azerbaijan-2023\",\"Belarus-2010\",\"Belarus-2011\",\"Belarus-2012\",\"Belarus-2013\",\"Belarus-2014\",\"Belarus-2015\",\"Belarus-2016\",\"Belarus-2017\",\"Belarus-2018\",\"Belarus-2019\",\"Belarus-2020\",\"Belarus-2021\",\"Belarus-2022\",\"Belarus-2023\",\"Cameroon-2010\",\"Cameroon-2011\",\"Cameroon-2012\",\"Cameroon-2013\",\"Cameroon-2014\",\"Cameroon-2015\",\"Cameroon-2016\",\"Cameroon-2017\",\"Cameroon-2018\",\"Cameroon-2019\",\"Cameroon-2020\",\"Cameroon-2021\",\"Cameroon-2022\",\"Cameroon-2023\",\"Chad-2010\",\"Chad-2011\",\"Chad-2012\",\"Chad-2013\",\"Chad-2014\",\"Chad-2015\",\"Chad-2016\",\"Chad-2017\",\"Chad-2018\",\"Chad-2019\",\"Chad-2020\",\"Chad-2021\",\"Chad-2022\",\"Chad-2023\",\"China-2010\",\"China-2011\",\"China-2012\",\"China-2013\",\"China-2014\",\"China-2015\",\"China-2016\",\"China-2017\",\"China-2018\",\"China-2019\",\"China-2020\",\"China-2021\",\"China-2022\",\"China-2023\",\"Democratic Republic of the Congo-2010\",\"Democratic Republic of the Congo-2011\",\"Democratic Republic of the Congo-2012\",\"Democratic Republic of the Congo-2013\",\"Democratic Republic of the Congo-2014\",\"Democratic Republic of the Congo-2015\",\"Democratic Republic of the Congo-2016\",\"Democratic Republic of the Congo-2017\",\"Democratic Republic of the Congo-2018\",\"Democratic Republic of the Congo-2019\",\"Democratic Republic of the Congo-2020\",\"Democratic Republic of the Congo-2021\",\"Democratic Republic of the Congo-2022\",\"Democratic Republic of the Congo-2023\",\"Republic of the Congo-2010\",\"Republic of the Congo-2011\",\"Republic of the Congo-2012\",\"Republic of the Congo-2013\",\"Republic of the Congo-2014\",\"Republic of the Congo-2015\",\"Republic of the Congo-2016\",\"Republic of the Congo-2017\",\"Republic of the Congo-2018\",\"Republic of the Congo-2019\",\"Republic of the Congo-2020\",\"Republic of the Congo-2021\",\"Republic of the Congo-2022\",\"Republic of the Congo-2023\",\"Djibouti-2010\",\"Djibouti-2011\",\"Djibouti-2012\",\"Djibouti-2013\",\"Djibouti-2014\",\"Djibouti-2015\",\"Djibouti-2016\",\"Djibouti-2017\",\"Djibouti-2018\",\"Djibouti-2019\",\"Djibouti-2020\",\"Djibouti-2021\",\"Djibouti-2022\",\"Djibouti-2023\",\"Dominican Republic-2010\",\"Dominican Republic-2011\",\"Dominican Republic-2012\",\"Dominican Republic-2013\",\"Dominican Republic-2014\",\"Dominican Republic-2015\",\"Dominican Republic-2016\",\"Dominican Republic-2017\",\"Dominican Republic-2018\",\"Dominican Republic-2019\",\"Dominican Republic-2020\",\"Dominican Republic-2021\",\"Dominican Republic-2022\",\"Dominican Republic-2023\",\"Eritrea-2010\",\"Eritrea-2011\",\"Eritrea-2012\",\"Eritrea-2013\",\"Eritrea-2014\",\"Eritrea-2015\",\"Eritrea-2016\",\"Eritrea-2017\",\"Eritrea-2018\",\"Eritrea-2019\",\"Eritrea-2020\",\"Eritrea-2021\",\"Eritrea-2022\",\"Eritrea-2023\",\"Gabon-2010\",\"Gabon-2011\",\"Gabon-2012\",\"Gabon-2013\",\"Gabon-2014\",\"Gabon-2015\",\"Gabon-2016\",\"Gabon-2017\",\"Gabon-2018\",\"Gabon-2019\",\"Gabon-2020\",\"Gabon-2021\",\"Gabon-2022\",\"Gabon-2023\",\"The Gambia-2010\",\"The Gambia-2011\",\"The Gambia-2012\",\"The Gambia-2013\",\"The Gambia-2014\",\"The Gambia-2015\",\"The Gambia-2016\",\"The Gambia-2017\",\"The Gambia-2018\",\"The Gambia-2019\",\"The Gambia-2020\",\"The Gambia-2021\",\"The Gambia-2022\",\"The Gambia-2023\",\"Georgia-2010\",\"Georgia-2011\",\"Georgia-2012\",\"Georgia-2013\",\"Georgia-2014\",\"Georgia-2015\",\"Georgia-2016\",\"Georgia-2017\",\"Georgia-2018\",\"Georgia-2019\",\"Georgia-2020\",\"Georgia-2021\",\"Georgia-2022\",\"Georgia-2023\",\"Guinea-Bissau-2010\",\"Guinea-Bissau-2011\",\"Guinea-Bissau-2012\",\"Guinea-Bissau-2013\",\"Guinea-Bissau-2014\",\"Guinea-Bissau-2015\",\"Guinea-Bissau-2016\",\"Guinea-Bissau-2017\",\"Guinea-Bissau-2018\",\"Guinea-Bissau-2019\",\"Guinea-Bissau-2020\",\"Guinea-Bissau-2021\",\"Guinea-Bissau-2022\",\"Guinea-Bissau-2023\",\"Jamaica-2010\",\"Jamaica-2011\",\"Jamaica-2012\",\"Jamaica-2013\",\"Jamaica-2014\",\"Jamaica-2015\",\"Jamaica-2016\",\"Jamaica-2017\",\"Jamaica-2018\",\"Jamaica-2019\",\"Jamaica-2020\",\"Jamaica-2021\",\"Jamaica-2022\",\"Jamaica-2023\",\"Kazakhstan-2010\",\"Kazakhstan-2011\",\"Kazakhstan-2012\",\"Kazakhstan-2013\",\"Kazakhstan-2014\",\"Kazakhstan-2015\",\"Kazakhstan-2016\",\"Kazakhstan-2017\",\"Kazakhstan-2018\",\"Kazakhstan-2019\",\"Kazakhstan-2020\",\"Kazakhstan-2021\",\"Kazakhstan-2022\",\"Kazakhstan-2023\",\"Kyrgyzstan-2010\",\"Kyrgyzstan-2011\",\"Kyrgyzstan-2012\",\"Kyrgyzstan-2013\",\"Kyrgyzstan-2014\",\"Kyrgyzstan-2015\",\"Kyrgyzstan-2016\",\"Kyrgyzstan-2017\",\"Kyrgyzstan-2018\",\"Kyrgyzstan-2019\",\"Kyrgyzstan-2020\",\"Kyrgyzstan-2021\",\"Kyrgyzstan-2022\",\"Kyrgyzstan-2023\",\"Laos-2010\",\"Laos-2011\",\"Laos-2012\",\"Laos-2013\",\"Laos-2014\",\"Laos-2015\",\"Laos-2016\",\"Laos-2017\",\"Laos-2018\",\"Laos-2019\",\"Laos-2020\",\"Laos-2021\",\"Laos-2022\",\"Laos-2023\",\"Libya-2010\",\"Libya-2011\",\"Libya-2012\",\"Libya-2013\",\"Libya-2014\",\"Libya-2015\",\"Libya-2016\",\"Libya-2017\",\"Libya-2018\",\"Libya-2019\",\"Libya-2020\",\"Libya-2021\",\"Libya-2022\",\"Libya-2023\",\"Madagascar-2010\",\"Madagascar-2011\",\"Madagascar-2012\",\"Madagascar-2013\",\"Madagascar-2014\",\"Madagascar-2015\",\"Madagascar-2016\",\"Madagascar-2017\",\"Madagascar-2018\",\"Madagascar-2019\",\"Madagascar-2020\",\"Madagascar-2021\",\"Madagascar-2022\",\"Madagascar-2023\",\"Moldova-2010\",\"Moldova-2011\",\"Moldova-2012\",\"Moldova-2013\",\"Moldova-2014\",\"Moldova-2015\",\"Moldova-2016\",\"Moldova-2017\",\"Moldova-2018\",\"Moldova-2019\",\"Moldova-2020\",\"Moldova-2021\",\"Moldova-2022\",\"Moldova-2023\",\"Namibia-2010\",\"Namibia-2011\",\"Namibia-2012\",\"Namibia-2013\",\"Namibia-2014\",\"Namibia-2015\",\"Namibia-2016\",\"Namibia-2017\",\"Namibia-2018\",\"Namibia-2019\",\"Namibia-2020\",\"Namibia-2021\",\"Namibia-2022\",\"Namibia-2023\",\"Palestine/West Bank-2010\",\"Palestine/West Bank-2011\",\"Palestine/West Bank-2012\",\"Palestine/West Bank-2013\",\"Palestine/West Bank-2014\",\"Palestine/West Bank-2015\",\"Palestine/West Bank-2016\",\"Palestine/West Bank-2017\",\"Palestine/West Bank-2018\",\"Palestine/West Bank-2019\",\"Palestine/West Bank-2020\",\"Palestine/West Bank-2021\",\"Palestine/West Bank-2022\",\"Palestine/West Bank-2023\",\"Rwanda-2010\",\"Rwanda-2011\",\"Rwanda-2012\",\"Rwanda-2013\",\"Rwanda-2014\",\"Rwanda-2015\",\"Rwanda-2016\",\"Rwanda-2017\",\"Rwanda-2018\",\"Rwanda-2019\",\"Rwanda-2020\",\"Rwanda-2021\",\"Rwanda-2022\",\"Rwanda-2023\",\"Somalia-2010\",\"Somalia-2011\",\"Somalia-2012\",\"Somalia-2013\",\"Somalia-2014\",\"Somalia-2015\",\"Somalia-2016\",\"Somalia-2017\",\"Somalia-2018\",\"Somalia-2019\",\"Somalia-2020\",\"Somalia-2021\",\"Somalia-2022\",\"Somalia-2023\",\"Sri Lanka-2010\",\"Sri Lanka-2011\",\"Sri Lanka-2012\",\"Sri Lanka-2013\",\"Sri Lanka-2014\",\"Sri Lanka-2015\",\"Sri Lanka-2016\",\"Sri Lanka-2017\",\"Sri Lanka-2018\",\"Sri Lanka-2019\",\"Sri Lanka-2020\",\"Sri Lanka-2021\",\"Sri Lanka-2022\",\"Sri Lanka-2023\",\"Eswatini-2010\",\"Eswatini-2011\",\"Eswatini-2012\",\"Eswatini-2013\",\"Eswatini-2014\",\"Eswatini-2015\",\"Eswatini-2016\",\"Eswatini-2017\",\"Eswatini-2018\",\"Eswatini-2019\",\"Eswatini-2020\",\"Eswatini-2021\",\"Eswatini-2022\",\"Eswatini-2023\",\"Tajikistan-2010\",\"Tajikistan-2011\",\"Tajikistan-2012\",\"Tajikistan-2013\",\"Tajikistan-2014\",\"Tajikistan-2015\",\"Tajikistan-2016\",\"Tajikistan-2017\",\"Tajikistan-2018\",\"Tajikistan-2019\",\"Tajikistan-2020\",\"Tajikistan-2021\",\"Tajikistan-2022\",\"Tajikistan-2023\",\"Togo-2010\",\"Togo-2011\",\"Togo-2012\",\"Togo-2013\",\"Togo-2014\",\"Togo-2015\",\"Togo-2016\",\"Togo-2017\",\"Togo-2018\",\"Togo-2019\",\"Togo-2020\",\"Togo-2021\",\"Togo-2022\",\"Togo-2023\",\"Trinidad and Tobago-2010\",\"Trinidad and Tobago-2011\",\"Trinidad and Tobago-2012\",\"Trinidad and Tobago-2013\",\"Trinidad and Tobago-2014\",\"Trinidad and Tobago-2015\",\"Trinidad and Tobago-2016\",\"Trinidad and Tobago-2017\",\"Trinidad and Tobago-2018\",\"Trinidad and Tobago-2019\",\"Trinidad and Tobago-2020\",\"Trinidad and Tobago-2021\",\"Trinidad and Tobago-2022\",\"Trinidad and Tobago-2023\",\"Turkmenistan-2010\",\"Turkmenistan-2011\",\"Turkmenistan-2012\",\"Turkmenistan-2013\",\"Turkmenistan-2014\",\"Turkmenistan-2015\",\"Turkmenistan-2016\",\"Turkmenistan-2017\",\"Turkmenistan-2018\",\"Turkmenistan-2019\",\"Turkmenistan-2020\",\"Turkmenistan-2021\",\"Turkmenistan-2022\",\"Turkmenistan-2023\",\"Palestine/Gaza-2010\",\"Palestine/Gaza-2011\",\"Palestine/Gaza-2012\",\"Palestine/Gaza-2013\",\"Palestine/Gaza-2014\",\"Palestine/Gaza-2015\",\"Palestine/Gaza-2016\",\"Palestine/Gaza-2017\",\"Palestine/Gaza-2018\",\"Palestine/Gaza-2019\",\"Palestine/Gaza-2020\",\"Palestine/Gaza-2021\",\"Palestine/Gaza-2022\",\"Palestine/Gaza-2023\",\"Somaliland-2010\",\"Somaliland-2011\",\"Somaliland-2012\",\"Somaliland-2013\",\"Somaliland-2014\",\"Somaliland-2015\",\"Somaliland-2016\",\"Somaliland-2017\",\"Somaliland-2018\",\"Somaliland-2019\",\"Somaliland-2020\",\"Somaliland-2021\",\"Somaliland-2022\",\"Somaliland-2023\",\"Uzbekistan-2010\",\"Uzbekistan-2011\",\"Uzbekistan-2012\",\"Uzbekistan-2013\",\"Uzbekistan-2014\",\"Uzbekistan-2015\",\"Uzbekistan-2016\",\"Uzbekistan-2017\",\"Uzbekistan-2018\",\"Uzbekistan-2019\",\"Uzbekistan-2020\",\"Uzbekistan-2021\",\"Uzbekistan-2022\",\"Uzbekistan-2023\",\"Austria-2010\",\"Austria-2011\",\"Austria-2012\",\"Austria-2013\",\"Austria-2014\",\"Austria-2015\",\"Austria-2016\",\"Austria-2017\",\"Austria-2018\",\"Austria-2019\",\"Austria-2020\",\"Austria-2021\",\"Austria-2022\",\"Austria-2023\",\"Bahrain-2010\",\"Bahrain-2011\",\"Bahrain-2012\",\"Bahrain-2013\",\"Bahrain-2014\",\"Bahrain-2015\",\"Bahrain-2016\",\"Bahrain-2017\",\"Bahrain-2018\",\"Bahrain-2019\",\"Bahrain-2020\",\"Bahrain-2021\",\"Bahrain-2022\",\"Bahrain-2023\",\"Barbados-2010\",\"Barbados-2011\",\"Barbados-2012\",\"Barbados-2013\",\"Barbados-2014\",\"Barbados-2015\",\"Barbados-2016\",\"Barbados-2017\",\"Barbados-2018\",\"Barbados-2019\",\"Barbados-2020\",\"Barbados-2021\",\"Barbados-2022\",\"Barbados-2023\",\"Belgium-2010\",\"Belgium-2011\",\"Belgium-2012\",\"Belgium-2013\",\"Belgium-2014\",\"Belgium-2015\",\"Belgium-2016\",\"Belgium-2017\",\"Belgium-2018\",\"Belgium-2019\",\"Belgium-2020\",\"Belgium-2021\",\"Belgium-2022\",\"Belgium-2023\",\"Bosnia and Herzegovina-2010\",\"Bosnia and Herzegovina-2011\",\"Bosnia and Herzegovina-2012\",\"Bosnia and Herzegovina-2013\",\"Bosnia and Herzegovina-2014\",\"Bosnia and Herzegovina-2015\",\"Bosnia and Herzegovina-2016\",\"Bosnia and Herzegovina-2017\",\"Bosnia and Herzegovina-2018\",\"Bosnia and Herzegovina-2019\",\"Bosnia and Herzegovina-2020\",\"Bosnia and Herzegovina-2021\",\"Bosnia and Herzegovina-2022\",\"Bosnia and Herzegovina-2023\",\"Bulgaria-2010\",\"Bulgaria-2011\",\"Bulgaria-2012\",\"Bulgaria-2013\",\"Bulgaria-2014\",\"Bulgaria-2015\",\"Bulgaria-2016\",\"Bulgaria-2017\",\"Bulgaria-2018\",\"Bulgaria-2019\",\"Bulgaria-2020\",\"Bulgaria-2021\",\"Bulgaria-2022\",\"Bulgaria-2023\",\"Comoros-2010\",\"Comoros-2011\",\"Comoros-2012\",\"Comoros-2013\",\"Comoros-2014\",\"Comoros-2015\",\"Comoros-2016\",\"Comoros-2017\",\"Comoros-2018\",\"Comoros-2019\",\"Comoros-2020\",\"Comoros-2021\",\"Comoros-2022\",\"Comoros-2023\",\"Croatia-2010\",\"Croatia-2011\",\"Croatia-2012\",\"Croatia-2013\",\"Croatia-2014\",\"Croatia-2015\",\"Croatia-2016\",\"Croatia-2017\",\"Croatia-2018\",\"Croatia-2019\",\"Croatia-2020\",\"Croatia-2021\",\"Croatia-2022\",\"Croatia-2023\",\"Cuba-2010\",\"Cuba-2011\",\"Cuba-2012\",\"Cuba-2013\",\"Cuba-2014\",\"Cuba-2015\",\"Cuba-2016\",\"Cuba-2017\",\"Cuba-2018\",\"Cuba-2019\",\"Cuba-2020\",\"Cuba-2021\",\"Cuba-2022\",\"Cuba-2023\",\"Cyprus-2010\",\"Cyprus-2011\",\"Cyprus-2012\",\"Cyprus-2013\",\"Cyprus-2014\",\"Cyprus-2015\",\"Cyprus-2016\",\"Cyprus-2017\",\"Cyprus-2018\",\"Cyprus-2019\",\"Cyprus-2020\",\"Cyprus-2021\",\"Cyprus-2022\",\"Cyprus-2023\",\"Czechia-2010\",\"Czechia-2011\",\"Czechia-2012\",\"Czechia-2013\",\"Czechia-2014\",\"Czechia-2015\",\"Czechia-2016\",\"Czechia-2017\",\"Czechia-2018\",\"Czechia-2019\",\"Czechia-2020\",\"Czechia-2021\",\"Czechia-2022\",\"Czechia-2023\",\"Denmark-2010\",\"Denmark-2011\",\"Denmark-2012\",\"Denmark-2013\",\"Denmark-2014\",\"Denmark-2015\",\"Denmark-2016\",\"Denmark-2017\",\"Denmark-2018\",\"Denmark-2019\",\"Denmark-2020\",\"Denmark-2021\",\"Denmark-2022\",\"Denmark-2023\",\"Equatorial Guinea-2010\",\"Equatorial Guinea-2011\",\"Equatorial Guinea-2012\",\"Equatorial Guinea-2013\",\"Equatorial Guinea-2014\",\"Equatorial Guinea-2015\",\"Equatorial Guinea-2016\",\"Equatorial Guinea-2017\",\"Equatorial Guinea-2018\",\"Equatorial Guinea-2019\",\"Equatorial Guinea-2020\",\"Equatorial Guinea-2021\",\"Equatorial Guinea-2022\",\"Equatorial Guinea-2023\",\"Estonia-2010\",\"Estonia-2011\",\"Estonia-2012\",\"Estonia-2013\",\"Estonia-2014\",\"Estonia-2015\",\"Estonia-2016\",\"Estonia-2017\",\"Estonia-2018\",\"Estonia-2019\",\"Estonia-2020\",\"Estonia-2021\",\"Estonia-2022\",\"Estonia-2023\",\"Fiji-2010\",\"Fiji-2011\",\"Fiji-2012\",\"Fiji-2013\",\"Fiji-2014\",\"Fiji-2015\",\"Fiji-2016\",\"Fiji-2017\",\"Fiji-2018\",\"Fiji-2019\",\"Fiji-2020\",\"Fiji-2021\",\"Fiji-2022\",\"Fiji-2023\",\"Finland-2010\",\"Finland-2011\",\"Finland-2012\",\"Finland-2013\",\"Finland-2014\",\"Finland-2015\",\"Finland-2016\",\"Finland-2017\",\"Finland-2018\",\"Finland-2019\",\"Finland-2020\",\"Finland-2021\",\"Finland-2022\",\"Finland-2023\",\"Greece-2010\",\"Greece-2011\",\"Greece-2012\",\"Greece-2013\",\"Greece-2014\",\"Greece-2015\",\"Greece-2016\",\"Greece-2017\",\"Greece-2018\",\"Greece-2019\",\"Greece-2020\",\"Greece-2021\",\"Greece-2022\",\"Greece-2023\",\"Guyana-2010\",\"Guyana-2011\",\"Guyana-2012\",\"Guyana-2013\",\"Guyana-2014\",\"Guyana-2015\",\"Guyana-2016\",\"Guyana-2017\",\"Guyana-2018\",\"Guyana-2019\",\"Guyana-2020\",\"Guyana-2021\",\"Guyana-2022\",\"Guyana-2023\",\"Hong Kong-2010\",\"Hong Kong-2011\",\"Hong Kong-2012\",\"Hong Kong-2013\",\"Hong Kong-2014\",\"Hong Kong-2015\",\"Hong Kong-2016\",\"Hong Kong-2017\",\"Hong Kong-2018\",\"Hong Kong-2019\",\"Hong Kong-2020\",\"Hong Kong-2021\",\"Hong Kong-2022\",\"Hong Kong-2023\",\"Iceland-2010\",\"Iceland-2011\",\"Iceland-2012\",\"Iceland-2013\",\"Iceland-2014\",\"Iceland-2015\",\"Iceland-2016\",\"Iceland-2017\",\"Iceland-2018\",\"Iceland-2019\",\"Iceland-2020\",\"Iceland-2021\",\"Iceland-2022\",\"Iceland-2023\",\"Israel-2010\",\"Israel-2011\",\"Israel-2012\",\"Israel-2013\",\"Israel-2014\",\"Israel-2015\",\"Israel-2016\",\"Israel-2017\",\"Israel-2018\",\"Israel-2019\",\"Israel-2020\",\"Israel-2021\",\"Israel-2022\",\"Israel-2023\",\"Kuwait-2010\",\"Kuwait-2011\",\"Kuwait-2012\",\"Kuwait-2013\",\"Kuwait-2014\",\"Kuwait-2015\",\"Kuwait-2016\",\"Kuwait-2017\",\"Kuwait-2018\",\"Kuwait-2019\",\"Kuwait-2020\",\"Kuwait-2021\",\"Kuwait-2022\",\"Kuwait-2023\",\"Lithuania-2010\",\"Lithuania-2011\",\"Lithuania-2012\",\"Lithuania-2013\",\"Lithuania-2014\",\"Lithuania-2015\",\"Lithuania-2016\",\"Lithuania-2017\",\"Lithuania-2018\",\"Lithuania-2019\",\"Lithuania-2020\",\"Lithuania-2021\",\"Lithuania-2022\",\"Lithuania-2023\",\"Luxembourg-2010\",\"Luxembourg-2011\",\"Luxembourg-2012\",\"Luxembourg-2013\",\"Luxembourg-2014\",\"Luxembourg-2015\",\"Luxembourg-2016\",\"Luxembourg-2017\",\"Luxembourg-2018\",\"Luxembourg-2019\",\"Luxembourg-2020\",\"Luxembourg-2021\",\"Luxembourg-2022\",\"Luxembourg-2023\",\"North Macedonia-2010\",\"North Macedonia-2011\",\"North Macedonia-2012\",\"North Macedonia-2013\",\"North Macedonia-2014\",\"North Macedonia-2015\",\"North Macedonia-2016\",\"North Macedonia-2017\",\"North Macedonia-2018\",\"North Macedonia-2019\",\"North Macedonia-2020\",\"North Macedonia-2021\",\"North Macedonia-2022\",\"North Macedonia-2023\",\"Malaysia-2010\",\"Malaysia-2011\",\"Malaysia-2012\",\"Malaysia-2013\",\"Malaysia-2014\",\"Malaysia-2015\",\"Malaysia-2016\",\"Malaysia-2017\",\"Malaysia-2018\",\"Malaysia-2019\",\"Malaysia-2020\",\"Malaysia-2021\",\"Malaysia-2022\",\"Malaysia-2023\",\"Malta-2010\",\"Malta-2011\",\"Malta-2012\",\"Malta-2013\",\"Malta-2014\",\"Malta-2015\",\"Malta-2016\",\"Malta-2017\",\"Malta-2018\",\"Malta-2019\",\"Malta-2020\",\"Malta-2021\",\"Malta-2022\",\"Malta-2023\",\"Mauritius-2010\",\"Mauritius-2011\",\"Mauritius-2012\",\"Mauritius-2013\",\"Mauritius-2014\",\"Mauritius-2015\",\"Mauritius-2016\",\"Mauritius-2017\",\"Mauritius-2018\",\"Mauritius-2019\",\"Mauritius-2020\",\"Mauritius-2021\",\"Mauritius-2022\",\"Mauritius-2023\",\"Montenegro-2010\",\"Montenegro-2011\",\"Montenegro-2012\",\"Montenegro-2013\",\"Montenegro-2014\",\"Montenegro-2015\",\"Montenegro-2016\",\"Montenegro-2017\",\"Montenegro-2018\",\"Montenegro-2019\",\"Montenegro-2020\",\"Montenegro-2021\",\"Montenegro-2022\",\"Montenegro-2023\",\"New Zealand-2010\",\"New Zealand-2011\",\"New Zealand-2012\",\"New Zealand-2013\",\"New Zealand-2014\",\"New Zealand-2015\",\"New Zealand-2016\",\"New Zealand-2017\",\"New Zealand-2018\",\"New Zealand-2019\",\"New Zealand-2020\",\"New Zealand-2021\",\"New Zealand-2022\",\"New Zealand-2023\",\"Norway-2010\",\"Norway-2011\",\"Norway-2012\",\"Norway-2013\",\"Norway-2014\",\"Norway-2015\",\"Norway-2016\",\"Norway-2017\",\"Norway-2018\",\"Norway-2019\",\"Norway-2020\",\"Norway-2021\",\"Norway-2022\",\"Norway-2023\",\"Oman-2010\",\"Oman-2011\",\"Oman-2012\",\"Oman-2013\",\"Oman-2014\",\"Oman-2015\",\"Oman-2016\",\"Oman-2017\",\"Oman-2018\",\"Oman-2019\",\"Oman-2020\",\"Oman-2021\",\"Oman-2022\",\"Oman-2023\",\"Paraguay-2010\",\"Paraguay-2011\",\"Paraguay-2012\",\"Paraguay-2013\",\"Paraguay-2014\",\"Paraguay-2015\",\"Paraguay-2016\",\"Paraguay-2017\",\"Paraguay-2018\",\"Paraguay-2019\",\"Paraguay-2020\",\"Paraguay-2021\",\"Paraguay-2022\",\"Paraguay-2023\",\"Romania-2010\",\"Romania-2011\",\"Romania-2012\",\"Romania-2013\",\"Romania-2014\",\"Romania-2015\",\"Romania-2016\",\"Romania-2017\",\"Romania-2018\",\"Romania-2019\",\"Romania-2020\",\"Romania-2021\",\"Romania-2022\",\"Romania-2023\",\"Sao Tome and Principe-2010\",\"Sao Tome and Principe-2011\",\"Sao Tome and Principe-2012\",\"Sao Tome and Principe-2013\",\"Sao Tome and Principe-2014\",\"Sao Tome and Principe-2015\",\"Sao Tome and Principe-2016\",\"Sao Tome and Principe-2017\",\"Sao Tome and Principe-2018\",\"Sao Tome and Principe-2019\",\"Sao Tome and Principe-2020\",\"Sao Tome and Principe-2021\",\"Sao Tome and Principe-2022\",\"Sao Tome and Principe-2023\",\"Saudi Arabia-2010\",\"Saudi Arabia-2011\",\"Saudi Arabia-2012\",\"Saudi Arabia-2013\",\"Saudi Arabia-2014\",\"Saudi Arabia-2015\",\"Saudi Arabia-2016\",\"Saudi Arabia-2017\",\"Saudi Arabia-2018\",\"Saudi Arabia-2019\",\"Saudi Arabia-2020\",\"Saudi Arabia-2021\",\"Saudi Arabia-2022\",\"Saudi Arabia-2023\",\"Serbia-2010\",\"Serbia-2011\",\"Serbia-2012\",\"Serbia-2013\",\"Serbia-2014\",\"Serbia-2015\",\"Serbia-2016\",\"Serbia-2017\",\"Serbia-2018\",\"Serbia-2019\",\"Serbia-2020\",\"Serbia-2021\",\"Serbia-2022\",\"Serbia-2023\",\"Seychelles-2010\",\"Seychelles-2011\",\"Seychelles-2012\",\"Seychelles-2013\",\"Seychelles-2014\",\"Seychelles-2015\",\"Seychelles-2016\",\"Seychelles-2017\",\"Seychelles-2018\",\"Seychelles-2019\",\"Seychelles-2020\",\"Seychelles-2021\",\"Seychelles-2022\",\"Seychelles-2023\",\"Singapore-2010\",\"Singapore-2011\",\"Singapore-2012\",\"Singapore-2013\",\"Singapore-2014\",\"Singapore-2015\",\"Singapore-2016\",\"Singapore-2017\",\"Singapore-2018\",\"Singapore-2019\",\"Singapore-2020\",\"Singapore-2021\",\"Singapore-2022\",\"Singapore-2023\",\"Slovakia-2010\",\"Slovakia-2011\",\"Slovakia-2012\",\"Slovakia-2013\",\"Slovakia-2014\",\"Slovakia-2015\",\"Slovakia-2016\",\"Slovakia-2017\",\"Slovakia-2018\",\"Slovakia-2019\",\"Slovakia-2020\",\"Slovakia-2021\",\"Slovakia-2022\",\"Slovakia-2023\",\"Slovenia-2010\",\"Slovenia-2011\",\"Slovenia-2012\",\"Slovenia-2013\",\"Slovenia-2014\",\"Slovenia-2015\",\"Slovenia-2016\",\"Slovenia-2017\",\"Slovenia-2018\",\"Slovenia-2019\",\"Slovenia-2020\",\"Slovenia-2021\",\"Slovenia-2022\",\"Slovenia-2023\",\"Solomon Islands-2010\",\"Solomon Islands-2011\",\"Solomon Islands-2012\",\"Solomon Islands-2013\",\"Solomon Islands-2014\",\"Solomon Islands-2015\",\"Solomon Islands-2016\",\"Solomon Islands-2017\",\"Solomon Islands-2018\",\"Solomon Islands-2019\",\"Solomon Islands-2020\",\"Solomon Islands-2021\",\"Solomon Islands-2022\",\"Solomon Islands-2023\",\"Vanuatu-2010\",\"Vanuatu-2011\",\"Vanuatu-2012\",\"Vanuatu-2013\",\"Vanuatu-2014\",\"Vanuatu-2015\",\"Vanuatu-2016\",\"Vanuatu-2017\",\"Vanuatu-2018\",\"Vanuatu-2019\",\"Vanuatu-2020\",\"Vanuatu-2021\",\"Vanuatu-2022\",\"Vanuatu-2023\",\"United Arab Emirates-2010\",\"United Arab Emirates-2011\",\"United Arab Emirates-2012\",\"United Arab Emirates-2013\",\"United Arab Emirates-2014\",\"United Arab Emirates-2015\",\"United Arab Emirates-2016\",\"United Arab Emirates-2017\",\"United Arab Emirates-2018\",\"United Arab Emirates-2019\",\"United Arab Emirates-2020\",\"United Arab Emirates-2021\",\"United Arab Emirates-2022\",\"United Arab Emirates-2023\",\"Hungary-2010\",\"Hungary-2011\",\"Hungary-2012\",\"Hungary-2013\",\"Hungary-2014\",\"Hungary-2015\",\"Hungary-2016\",\"Hungary-2017\",\"Hungary-2018\",\"Hungary-2019\",\"Hungary-2020\",\"Hungary-2021\",\"Hungary-2022\",\"Hungary-2023\",\"Zanzibar-2010\",\"Zanzibar-2011\",\"Zanzibar-2012\",\"Zanzibar-2013\",\"Zanzibar-2014\",\"Zanzibar-2015\",\"Zanzibar-2016\",\"Zanzibar-2017\",\"Zanzibar-2018\",\"Zanzibar-2019\",\"Zanzibar-2020\",\"Zanzibar-2021\",\"Zanzibar-2022\",\"Zanzibar-2023\"],\n",
       "\"colour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n",
       "\"shape\":[\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\",\"No\"]\n",
       "},\n",
       "\"mapping\":{\n",
       "\"x\":\"first_dim\",\n",
       "\"y\":\"second_dim\",\n",
       "\"colour\":\"colour\",\n",
       "\"shape\":\"shape\"\n",
       "},\n",
       "\"data_meta\":{\n",
       "\"series_annotations\":[{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"first_dim\"\n",
       "},{\n",
       "\"type\":\"float\",\n",
       "\"column\":\"second_dim\"\n",
       "},{\n",
       "\"type\":\"str\",\n",
       "\"column\":\"country_year\"\n",
       "}]\n",
       "},\n",
       "\"theme\":{\n",
       "\"name\":\"minimal\",\n",
       "\"legend_position\":\"bottom\",\n",
       "\"panel_grid_minor\":{\n",
       "\"blank\":true\n",
       "}\n",
       "},\n",
       "\"guides\":{\n",
       "\"x\":{\n",
       "\"title\":\"First dimension\"\n",
       "},\n",
       "\"y\":{\n",
       "\"title\":\"Second dimension\"\n",
       "},\n",
       "\"colour\":{\n",
       "\"title\":\"Cluster #\"\n",
       "},\n",
       "\"shape\":{\n",
       "\"title\":\"Outlier\"\n",
       "}\n",
       "},\n",
       "\"kind\":\"plot\",\n",
       "\"scales\":[{\n",
       "\"aesthetic\":\"shape\",\n",
       "\"values\":[16.0,4.0]\n",
       "},{\n",
       "\"aesthetic\":\"color\",\n",
       "\"scale_mapper_kind\":\"color_cmap\"\n",
       "}],\n",
       "\"layers\":[{\n",
       "\"geom\":\"point\",\n",
       "\"mapping\":{\n",
       "},\n",
       "\"tooltips\":{\n",
       "\"formats\":[],\n",
       "\"lines\":[\"@country_year\"]\n",
       "},\n",
       "\"data_meta\":{\n",
       "},\n",
       "\"data\":{\n",
       "}\n",
       "}],\n",
       "\"metainfo_list\":[],\n",
       "\"spec_id\":\"9\"\n",
       "};\n",
       "               window.letsPlotCall(function() {\n",
       "       \n",
       "               var toolbar = null;\n",
       "               var plotContainer = containerDiv;               \n",
       "               \n",
       "                   var options = {\n",
       "                       sizing: {\n",
       "                           width_mode: \"min\",\n",
       "                           height_mode: \"scaled\",\n",
       "                           width: width\n",
       "                       }\n",
       "                   };\n",
       "                   var fig = LetsPlot.buildPlotFromProcessedSpecs(plotSpec, -1, -1, plotContainer, options);\n",
       "                   if (toolbar) {\n",
       "                     toolbar.bind(fig);\n",
       "                   }\n",
       "               });\n",
       "               \n",
       "               break;\n",
       "           }\n",
       "       }\n",
       "   });\n",
       "   \n",
       "   observer.observe(containerDiv);\n",
       "   \n",
       "   // ----------\n",
       "   })();\n",
       "   \n",
       "   </script>"
      ],
      "text/plain": [
       "<lets_plot.plot.core.PlotSpec at 0x171ce8170>"
      ]
     },
     "execution_count": 17,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# Instantiate a dbscan \n",
    "dbscan_model = DBSCAN(min_samples = 6, eps = 1.15)\n",
    "\n",
    "# Fit the model to the data\n",
    "dbscan_model.fit(embedding)\n",
    "\n",
    "# Retrieve the labels using a list comprehension\n",
    "dbscan_labels = [str(i) for i in dbscan_model.labels_]\n",
    "\n",
    "# Create a list of outlier labels\n",
    "outlier_labels = [np.where(row == \"-1\", \"Yes\", \"No\") for row in dbscan_labels]\n",
    "\n",
    "# Add the country_year variable in vdem to the embeddings\n",
    "embedding[\"country_year\"] = vdem[\"country_year\"]\n",
    "\n",
    "# Plot the output\n",
    "(\n",
    "  ggplot(embedding, aes(\"first_dim\", \"second_dim\", colour = dbscan_labels, shape = outlier_labels)) +\n",
    "  geom_point(tooltips = layer_tooltips().line('@country_year')) +\n",
    "  theme_minimal() +\n",
    "  theme(panel_grid_minor = element_blank(),\n",
    "        legend_position = \"bottom\") +\n",
    "  scale_shape_manual(values = [16,4]) +\n",
    "  scale_color_viridis() +\n",
    "  labs(x = \"First dimension\", y = \"Second dimension\",\n",
    "       colour = \"Cluster #\", shape = \"Outlier\")\n",
    ")"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "base",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.12.2"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
